
module Make

# 5 "src/parser/grammar.mly"
           ( C : Parser_config.ParseFile )
# 7 "src/parser/grammar.ml"

= struct
  
  module MenhirBasics = struct
    
    exception Error of int
    
    let _eRR =
      fun _s ->
        raise (Error _s)
    
    type token = Elpi_lexer_config.Tokens.token
    
  end
  
  include MenhirBasics
  
# 7 "src/parser/grammar.mly"
  
open Elpi_util
open Elpi_lexer_config

open Lexer_config
open Parser_config
open Ast
open Term


let loc (startpos, endpos) = {
  Util.Loc.source_name = startpos.Lexing.pos_fname;
  source_start = startpos.Lexing.pos_cnum;
  source_stop = endpos.Lexing.pos_cnum;
  line = startpos.Lexing.pos_lnum;
  line_starts_at = startpos.Lexing.pos_bol;
}

let desugar_multi_binder loc = function
  | App(Const hd as binder,args)
    when Func.equal hd Func.pif || Func.equal hd Func.sigmaf && List.length args > 1 ->
      let last, rev_rest = let l = List.rev args in List.hd l, List.tl l in
      let names = List.map (function
        | Const x -> Func.show x
        | (App _ | Lam _ | CData _ | Quoted _) ->
            raise (ParseError(loc,"Only names are allowed after 'pi' or 'sigma'"))) rev_rest in
      let body = mkApp loc [binder;last] in
      List.fold_left (fun bo name -> mkApp loc [binder;mkLam name bo]) body names
  | (App _ | Const _ | Lam _ | CData _ | Quoted _) as t -> t
;;

let desugar_macro loc lhs rhs =
  match lhs, rhs with
  | Const name, body ->
      if ((Func.show name).[0] != '@') then
        raise (ParseError(loc,"Macro name must begin with '@'"));
      name, body
  | App(Const name,args), body ->
      if ((Func.show name).[0] != '@') then
        raise (ParseError(loc,"Macro name must begin with '@'"));
      let names = List.map (function
        | Const x -> Func.show x
        | (App _ | Lam _ | CData _ | Quoted _) ->
              raise (ParseError(loc,"Macro parameters must be names"))) args in
      name, List.fold_right mkLam names body
  | _ ->
        raise (ParseError(loc,"Illformed macro left hand side"))
;;

let mkApp loc = function
  | Const c :: a :: App (Const c1, args) :: [] when Func.(equal c andf && equal c1 andf) ->
      mkAppF loc c (a :: args)
  | l -> mkApp loc l

let binder l = function
  | None -> l
  | Some (loc,b) ->
      match List.rev l with
      | Const name :: rest ->
          List.rev rest @ [mkLam (Func.show name) b]
      | _ -> raise (ParseError(loc,"bind '\\' operator must follow a name"))
;;

let underscore () = Const Func.dummyname

let decode_sequent t =
  match t with
  | App(Const c,[hyps;bo]) when c == Func.sequentf -> hyps, bo
  | _ -> underscore (), t

let prop = Func.from_string "prop"

let fix_church x = if Func.show x = "o" then prop else x

let mode_of_IO io =
  if io = 'i' then true
  else if io = 'o' then false
  else assert false


# 106 "src/parser/grammar.ml"
  
  type ('s, 'r) _menhir_state = 
    | MenhirState000 : ('s, _menhir_box_goal) _menhir_state
      (** State 000.
        Stack shape : .
        Start symbol: goal. *)

    | MenhirState008 : (('s, 'r) _menhir_cell1_LPAREN, 'r) _menhir_state
      (** State 008.
        Stack shape : LPAREN.
        Start symbol: <undetermined>. *)

    | MenhirState018 : (('s, 'r) _menhir_cell1_LCURLY, 'r) _menhir_state
      (** State 018.
        Stack shape : LCURLY.
        Start symbol: <undetermined>. *)

    | MenhirState019 : (('s, 'r) _menhir_cell1_LBRACKET, 'r) _menhir_state
      (** State 019.
        Stack shape : LBRACKET.
        Start symbol: <undetermined>. *)

    | MenhirState021 : (('s, 'r) _menhir_cell1_PIPE, 'r) _menhir_state
      (** State 021.
        Stack shape : PIPE.
        Start symbol: <undetermined>. *)

    | MenhirState028 : (('s, 'r) _menhir_cell1_FAMILY_TILDE, 'r) _menhir_state
      (** State 028.
        Stack shape : FAMILY_TILDE.
        Start symbol: <undetermined>. *)

    | MenhirState036 : (('s, 'r) _menhir_cell1_head_term, 'r) _menhir_state
      (** State 036.
        Stack shape : head_term.
        Start symbol: <undetermined>. *)

    | MenhirState037 : ((('s, 'r) _menhir_cell1_head_term, 'r) _menhir_cell1_nonempty_list_closed_term_, 'r) _menhir_state
      (** State 037.
        Stack shape : head_term nonempty_list(closed_term).
        Start symbol: <undetermined>. *)

    | MenhirState038 : (('s, 'r) _menhir_cell1_BIND, 'r) _menhir_state
      (** State 038.
        Stack shape : BIND.
        Start symbol: <undetermined>. *)

    | MenhirState039 : (('s, 'r) _menhir_cell1_FAMILY_TILDE, 'r) _menhir_state
      (** State 039.
        Stack shape : FAMILY_TILDE.
        Start symbol: <undetermined>. *)

    | MenhirState043 : (('s, 'r) _menhir_cell1_head_term, 'r) _menhir_state
      (** State 043.
        Stack shape : head_term.
        Start symbol: <undetermined>. *)

    | MenhirState044 : ((('s, 'r) _menhir_cell1_head_term, 'r) _menhir_cell1_nonempty_list_closed_term_, 'r) _menhir_state
      (** State 044.
        Stack shape : head_term nonempty_list(closed_term).
        Start symbol: <undetermined>. *)

    | MenhirState049 : (('s, 'r) _menhir_cell1_closed_term, 'r) _menhir_state
      (** State 049.
        Stack shape : closed_term.
        Start symbol: <undetermined>. *)

    | MenhirState051 : (('s, 'r) _menhir_cell1_constant, 'r) _menhir_state
      (** State 051.
        Stack shape : constant.
        Start symbol: <undetermined>. *)

    | MenhirState056 : (('s, 'r) _menhir_cell1_term _menhir_cell0_VDASH, 'r) _menhir_state
      (** State 056.
        Stack shape : term VDASH.
        Start symbol: <undetermined>. *)

    | MenhirState058 : (('s, 'r) _menhir_cell1_term _menhir_cell0_SLASH, 'r) _menhir_state
      (** State 058.
        Stack shape : term SLASH.
        Start symbol: <undetermined>. *)

    | MenhirState060 : (('s, 'r) _menhir_cell1_term _menhir_cell0_FAMILY_SHARP, 'r) _menhir_state
      (** State 060.
        Stack shape : term FAMILY_SHARP.
        Start symbol: <undetermined>. *)

    | MenhirState062 : (('s, 'r) _menhir_cell1_term _menhir_cell0_FAMILY_OR, 'r) _menhir_state
      (** State 062.
        Stack shape : term FAMILY_OR.
        Start symbol: <undetermined>. *)

    | MenhirState064 : (('s, 'r) _menhir_cell1_term _menhir_cell0_FAMILY_AND, 'r) _menhir_state
      (** State 064.
        Stack shape : term FAMILY_AND.
        Start symbol: <undetermined>. *)

    | MenhirState066 : (('s, 'r) _menhir_cell1_term _menhir_cell0_FAMILY_MINUS, 'r) _menhir_state
      (** State 066.
        Stack shape : term FAMILY_MINUS.
        Start symbol: <undetermined>. *)

    | MenhirState068 : (('s, 'r) _menhir_cell1_term _menhir_cell0_FAMILY_EQ, 'r) _menhir_state
      (** State 068.
        Stack shape : term FAMILY_EQ.
        Start symbol: <undetermined>. *)

    | MenhirState070 : (('s, 'r) _menhir_cell1_term _menhir_cell0_FAMILY_BTICK, 'r) _menhir_state
      (** State 070.
        Stack shape : term FAMILY_BTICK.
        Start symbol: <undetermined>. *)

    | MenhirState072 : (('s, 'r) _menhir_cell1_term _menhir_cell0_OR, 'r) _menhir_state
      (** State 072.
        Stack shape : term OR.
        Start symbol: <undetermined>. *)

    | MenhirState074 : (('s, 'r) _menhir_cell1_term _menhir_cell0_MOD, 'r) _menhir_state
      (** State 074.
        Stack shape : term MOD.
        Start symbol: <undetermined>. *)

    | MenhirState076 : (('s, 'r) _menhir_cell1_term _menhir_cell0_MINUSs, 'r) _menhir_state
      (** State 076.
        Stack shape : term MINUSs.
        Start symbol: <undetermined>. *)

    | MenhirState078 : (('s, 'r) _menhir_cell1_term _menhir_cell0_FAMILY_TIMES, 'r) _menhir_state
      (** State 078.
        Stack shape : term FAMILY_TIMES.
        Start symbol: <undetermined>. *)

    | MenhirState080 : (('s, 'r) _menhir_cell1_term _menhir_cell0_DIV, 'r) _menhir_state
      (** State 080.
        Stack shape : term DIV.
        Start symbol: <undetermined>. *)

    | MenhirState082 : (('s, 'r) _menhir_cell1_term _menhir_cell0_MINUSr, 'r) _menhir_state
      (** State 082.
        Stack shape : term MINUSr.
        Start symbol: <undetermined>. *)

    | MenhirState084 : (('s, 'r) _menhir_cell1_term _menhir_cell0_MINUSi, 'r) _menhir_state
      (** State 084.
        Stack shape : term MINUSi.
        Start symbol: <undetermined>. *)

    | MenhirState086 : (('s, 'r) _menhir_cell1_term _menhir_cell0_MINUS, 'r) _menhir_state
      (** State 086.
        Stack shape : term MINUS.
        Start symbol: <undetermined>. *)

    | MenhirState088 : (('s, 'r) _menhir_cell1_term _menhir_cell0_IS, 'r) _menhir_state
      (** State 088.
        Stack shape : term IS.
        Start symbol: <undetermined>. *)

    | MenhirState090 : (('s, 'r) _menhir_cell1_term _menhir_cell0_FAMILY_TICK, 'r) _menhir_state
      (** State 090.
        Stack shape : term FAMILY_TICK.
        Start symbol: <undetermined>. *)

    | MenhirState092 : (('s, 'r) _menhir_cell1_term _menhir_cell0_FAMILY_PLUS, 'r) _menhir_state
      (** State 092.
        Stack shape : term FAMILY_PLUS.
        Start symbol: <undetermined>. *)

    | MenhirState094 : (('s, 'r) _menhir_cell1_term _menhir_cell0_FAMILY_EXP, 'r) _menhir_state
      (** State 094.
        Stack shape : term FAMILY_EXP.
        Start symbol: <undetermined>. *)

    | MenhirState096 : (('s, 'r) _menhir_cell1_term _menhir_cell0_CONS, 'r) _menhir_state
      (** State 096.
        Stack shape : term CONS.
        Start symbol: <undetermined>. *)

    | MenhirState098 : (('s, 'r) _menhir_cell1_term _menhir_cell0_FAMILY_LT, 'r) _menhir_state
      (** State 098.
        Stack shape : term FAMILY_LT.
        Start symbol: <undetermined>. *)

    | MenhirState100 : (('s, 'r) _menhir_cell1_term _menhir_cell0_FAMILY_GT, 'r) _menhir_state
      (** State 100.
        Stack shape : term FAMILY_GT.
        Start symbol: <undetermined>. *)

    | MenhirState102 : (('s, 'r) _menhir_cell1_term _menhir_cell0_EQ2, 'r) _menhir_state
      (** State 102.
        Stack shape : term EQ2.
        Start symbol: <undetermined>. *)

    | MenhirState104 : (('s, 'r) _menhir_cell1_term _menhir_cell0_EQ, 'r) _menhir_state
      (** State 104.
        Stack shape : term EQ.
        Start symbol: <undetermined>. *)

    | MenhirState106 : (('s, 'r) _menhir_cell1_term _menhir_cell0_DARROW, 'r) _menhir_state
      (** State 106.
        Stack shape : term DARROW.
        Start symbol: <undetermined>. *)

    | MenhirState108 : (('s, 'r) _menhir_cell1_term _menhir_cell0_CONJ2, 'r) _menhir_state
      (** State 108.
        Stack shape : term CONJ2.
        Start symbol: <undetermined>. *)

    | MenhirState110 : (('s, 'r) _menhir_cell1_term _menhir_cell0_CONJ, 'r) _menhir_state
      (** State 110.
        Stack shape : term CONJ.
        Start symbol: <undetermined>. *)

    | MenhirState112 : (('s, 'r) _menhir_cell1_term _menhir_cell0_ARROW, 'r) _menhir_state
      (** State 112.
        Stack shape : term ARROW.
        Start symbol: <undetermined>. *)

    | MenhirState114 : (('s, 'r) _menhir_cell1_term _menhir_cell0_QDASH, 'r) _menhir_state
      (** State 114.
        Stack shape : term QDASH.
        Start symbol: <undetermined>. *)

    | MenhirState118 : (('s, 'r) _menhir_cell1_constant _menhir_cell0_BIND, 'r) _menhir_state
      (** State 118.
        Stack shape : constant BIND.
        Start symbol: <undetermined>. *)

    | MenhirState123 : (('s, 'r) _menhir_cell1_term_noconj _menhir_cell0_VDASH, 'r) _menhir_state
      (** State 123.
        Stack shape : term_noconj VDASH.
        Start symbol: <undetermined>. *)

    | MenhirState125 : (('s, 'r) _menhir_cell1_term_noconj _menhir_cell0_SLASH, 'r) _menhir_state
      (** State 125.
        Stack shape : term_noconj SLASH.
        Start symbol: <undetermined>. *)

    | MenhirState127 : (('s, 'r) _menhir_cell1_term_noconj _menhir_cell0_FAMILY_SHARP, 'r) _menhir_state
      (** State 127.
        Stack shape : term_noconj FAMILY_SHARP.
        Start symbol: <undetermined>. *)

    | MenhirState129 : (('s, 'r) _menhir_cell1_term_noconj _menhir_cell0_FAMILY_OR, 'r) _menhir_state
      (** State 129.
        Stack shape : term_noconj FAMILY_OR.
        Start symbol: <undetermined>. *)

    | MenhirState131 : (('s, 'r) _menhir_cell1_term_noconj _menhir_cell0_FAMILY_AND, 'r) _menhir_state
      (** State 131.
        Stack shape : term_noconj FAMILY_AND.
        Start symbol: <undetermined>. *)

    | MenhirState133 : (('s, 'r) _menhir_cell1_term_noconj _menhir_cell0_FAMILY_MINUS, 'r) _menhir_state
      (** State 133.
        Stack shape : term_noconj FAMILY_MINUS.
        Start symbol: <undetermined>. *)

    | MenhirState135 : (('s, 'r) _menhir_cell1_term_noconj _menhir_cell0_FAMILY_EQ, 'r) _menhir_state
      (** State 135.
        Stack shape : term_noconj FAMILY_EQ.
        Start symbol: <undetermined>. *)

    | MenhirState137 : (('s, 'r) _menhir_cell1_term_noconj _menhir_cell0_FAMILY_BTICK, 'r) _menhir_state
      (** State 137.
        Stack shape : term_noconj FAMILY_BTICK.
        Start symbol: <undetermined>. *)

    | MenhirState139 : (('s, 'r) _menhir_cell1_term_noconj _menhir_cell0_OR, 'r) _menhir_state
      (** State 139.
        Stack shape : term_noconj OR.
        Start symbol: <undetermined>. *)

    | MenhirState141 : (('s, 'r) _menhir_cell1_term_noconj _menhir_cell0_MOD, 'r) _menhir_state
      (** State 141.
        Stack shape : term_noconj MOD.
        Start symbol: <undetermined>. *)

    | MenhirState143 : (('s, 'r) _menhir_cell1_term_noconj _menhir_cell0_MINUSs, 'r) _menhir_state
      (** State 143.
        Stack shape : term_noconj MINUSs.
        Start symbol: <undetermined>. *)

    | MenhirState145 : (('s, 'r) _menhir_cell1_term_noconj _menhir_cell0_FAMILY_TIMES, 'r) _menhir_state
      (** State 145.
        Stack shape : term_noconj FAMILY_TIMES.
        Start symbol: <undetermined>. *)

    | MenhirState147 : (('s, 'r) _menhir_cell1_term_noconj _menhir_cell0_DIV, 'r) _menhir_state
      (** State 147.
        Stack shape : term_noconj DIV.
        Start symbol: <undetermined>. *)

    | MenhirState149 : (('s, 'r) _menhir_cell1_term_noconj _menhir_cell0_MINUSr, 'r) _menhir_state
      (** State 149.
        Stack shape : term_noconj MINUSr.
        Start symbol: <undetermined>. *)

    | MenhirState151 : (('s, 'r) _menhir_cell1_term_noconj _menhir_cell0_MINUSi, 'r) _menhir_state
      (** State 151.
        Stack shape : term_noconj MINUSi.
        Start symbol: <undetermined>. *)

    | MenhirState153 : (('s, 'r) _menhir_cell1_term_noconj _menhir_cell0_MINUS, 'r) _menhir_state
      (** State 153.
        Stack shape : term_noconj MINUS.
        Start symbol: <undetermined>. *)

    | MenhirState155 : (('s, 'r) _menhir_cell1_term_noconj _menhir_cell0_IS, 'r) _menhir_state
      (** State 155.
        Stack shape : term_noconj IS.
        Start symbol: <undetermined>. *)

    | MenhirState157 : (('s, 'r) _menhir_cell1_term_noconj _menhir_cell0_FAMILY_TICK, 'r) _menhir_state
      (** State 157.
        Stack shape : term_noconj FAMILY_TICK.
        Start symbol: <undetermined>. *)

    | MenhirState159 : (('s, 'r) _menhir_cell1_term_noconj _menhir_cell0_FAMILY_PLUS, 'r) _menhir_state
      (** State 159.
        Stack shape : term_noconj FAMILY_PLUS.
        Start symbol: <undetermined>. *)

    | MenhirState161 : (('s, 'r) _menhir_cell1_term_noconj _menhir_cell0_FAMILY_EXP, 'r) _menhir_state
      (** State 161.
        Stack shape : term_noconj FAMILY_EXP.
        Start symbol: <undetermined>. *)

    | MenhirState163 : (('s, 'r) _menhir_cell1_term_noconj _menhir_cell0_CONS, 'r) _menhir_state
      (** State 163.
        Stack shape : term_noconj CONS.
        Start symbol: <undetermined>. *)

    | MenhirState165 : (('s, 'r) _menhir_cell1_term_noconj _menhir_cell0_FAMILY_LT, 'r) _menhir_state
      (** State 165.
        Stack shape : term_noconj FAMILY_LT.
        Start symbol: <undetermined>. *)

    | MenhirState167 : (('s, 'r) _menhir_cell1_term_noconj _menhir_cell0_FAMILY_GT, 'r) _menhir_state
      (** State 167.
        Stack shape : term_noconj FAMILY_GT.
        Start symbol: <undetermined>. *)

    | MenhirState169 : (('s, 'r) _menhir_cell1_term_noconj _menhir_cell0_EQ2, 'r) _menhir_state
      (** State 169.
        Stack shape : term_noconj EQ2.
        Start symbol: <undetermined>. *)

    | MenhirState171 : (('s, 'r) _menhir_cell1_term_noconj _menhir_cell0_EQ, 'r) _menhir_state
      (** State 171.
        Stack shape : term_noconj EQ.
        Start symbol: <undetermined>. *)

    | MenhirState173 : (('s, 'r) _menhir_cell1_term_noconj _menhir_cell0_DARROW, 'r) _menhir_state
      (** State 173.
        Stack shape : term_noconj DARROW.
        Start symbol: <undetermined>. *)

    | MenhirState175 : (('s, 'r) _menhir_cell1_term_noconj _menhir_cell0_CONJ2, 'r) _menhir_state
      (** State 175.
        Stack shape : term_noconj CONJ2.
        Start symbol: <undetermined>. *)

    | MenhirState177 : (('s, 'r) _menhir_cell1_term_noconj _menhir_cell0_ARROW, 'r) _menhir_state
      (** State 177.
        Stack shape : term_noconj ARROW.
        Start symbol: <undetermined>. *)

    | MenhirState180 : (('s, 'r) _menhir_cell1_term_noconj _menhir_cell0_QDASH, 'r) _menhir_state
      (** State 180.
        Stack shape : term_noconj QDASH.
        Start symbol: <undetermined>. *)

    | MenhirState184 : (('s, 'r) _menhir_cell1_term_noconj, 'r) _menhir_state
      (** State 184.
        Stack shape : term_noconj.
        Start symbol: <undetermined>. *)

    | MenhirState187 : (('s, 'r) _menhir_cell1_term_noconj _menhir_cell0_CONJ, 'r) _menhir_state
      (** State 187.
        Stack shape : term_noconj CONJ.
        Start symbol: <undetermined>. *)

    | MenhirState196 : ((('s, 'r) _menhir_cell1_LPAREN, 'r) _menhir_cell1_FAMILY_TILDE, 'r) _menhir_state
      (** State 196.
        Stack shape : LPAREN FAMILY_TILDE.
        Start symbol: <undetermined>. *)

    | MenhirState221 : ((('s, 'r) _menhir_cell1_LPAREN, 'r) _menhir_cell1_term, 'r) _menhir_state
      (** State 221.
        Stack shape : LPAREN term.
        Start symbol: <undetermined>. *)

    | MenhirState268 : ('s, _menhir_box_program) _menhir_state
      (** State 268.
        Stack shape : .
        Start symbol: program. *)

    | MenhirState270 : (('s, _menhir_box_program) _menhir_cell1_USEONLY, _menhir_box_program) _menhir_state
      (** State 270.
        Stack shape : USEONLY.
        Start symbol: program. *)

    | MenhirState271 : (('s, _menhir_box_program) _menhir_cell1_LPAREN, _menhir_box_program) _menhir_state
      (** State 271.
        Stack shape : LPAREN.
        Start symbol: program. *)

    | MenhirState273 : ((('s, _menhir_box_program) _menhir_cell1_USEONLY, _menhir_box_program) _menhir_cell1_separated_nonempty_list_CONJ_constant_, _menhir_box_program) _menhir_state
      (** State 273.
        Stack shape : USEONLY separated_nonempty_list(CONJ,constant).
        Start symbol: program. *)

    | MenhirState274 : (('s, _menhir_box_program) _menhir_cell1_LPAREN, _menhir_box_program) _menhir_state
      (** State 274.
        Stack shape : LPAREN.
        Start symbol: program. *)

    | MenhirState277 : (('s, _menhir_box_program) _menhir_cell1_type_term _menhir_cell0_ARROW, _menhir_box_program) _menhir_state
      (** State 277.
        Stack shape : type_term ARROW.
        Start symbol: program. *)

    | MenhirState279 : (('s, _menhir_box_program) _menhir_cell1_constant, _menhir_box_program) _menhir_state
      (** State 279.
        Stack shape : constant.
        Start symbol: program. *)

    | MenhirState281 : (('s, _menhir_box_program) _menhir_cell1_LPAREN, _menhir_box_program) _menhir_state
      (** State 281.
        Stack shape : LPAREN.
        Start symbol: program. *)

    | MenhirState286 : (('s, _menhir_box_program) _menhir_cell1_atype_term, _menhir_box_program) _menhir_state
      (** State 286.
        Stack shape : atype_term.
        Start symbol: program. *)

    | MenhirState290 : (('s, _menhir_box_program) _menhir_cell1_constant _menhir_cell0_CONJ, _menhir_box_program) _menhir_state
      (** State 290.
        Stack shape : constant CONJ.
        Start symbol: program. *)

    | MenhirState292 : (('s, _menhir_box_program) _menhir_cell1_TYPEABBREV, _menhir_box_program) _menhir_state
      (** State 292.
        Stack shape : TYPEABBREV.
        Start symbol: program. *)

    | MenhirState293 : ((('s, _menhir_box_program) _menhir_cell1_TYPEABBREV, _menhir_box_program) _menhir_cell1_LPAREN, _menhir_box_program) _menhir_state
      (** State 293.
        Stack shape : TYPEABBREV LPAREN.
        Start symbol: program. *)

    | MenhirState294 : (((('s, _menhir_box_program) _menhir_cell1_TYPEABBREV, _menhir_box_program) _menhir_cell1_LPAREN, _menhir_box_program) _menhir_cell1_constant, _menhir_box_program) _menhir_state
      (** State 294.
        Stack shape : TYPEABBREV LPAREN constant.
        Start symbol: program. *)

    | MenhirState297 : ((('s, _menhir_box_program) _menhir_cell1_constant, _menhir_box_program) _menhir_cell1_constant, _menhir_box_program) _menhir_state
      (** State 297.
        Stack shape : constant constant.
        Start symbol: program. *)

    | MenhirState300 : ((('s, _menhir_box_program) _menhir_cell1_TYPEABBREV, _menhir_box_program) _menhir_cell1_abbrevform, _menhir_box_program) _menhir_state
      (** State 300.
        Stack shape : TYPEABBREV abbrevform.
        Start symbol: program. *)

    | MenhirState302 : (('s, _menhir_box_program) _menhir_cell1_SIG, _menhir_box_program) _menhir_state
      (** State 302.
        Stack shape : SIG.
        Start symbol: program. *)

    | MenhirState304 : (('s, _menhir_box_program) _menhir_cell1_SHORTEN, _menhir_box_program) _menhir_state
      (** State 304.
        Stack shape : SHORTEN.
        Start symbol: program. *)

    | MenhirState310 : ((('s, _menhir_box_program) _menhir_cell1_SHORTEN, _menhir_box_program) _menhir_cell1_constant _menhir_cell0_FULLSTOP _menhir_cell0_LCURLY, _menhir_box_program) _menhir_state
      (** State 310.
        Stack shape : SHORTEN constant FULLSTOP LCURLY.
        Start symbol: program. *)

    | MenhirState312 : (('s, _menhir_box_program) _menhir_cell1_subtrie _menhir_cell0_CONJ, _menhir_box_program) _menhir_state
      (** State 312.
        Stack shape : subtrie CONJ.
        Start symbol: program. *)

    | MenhirState316 : (('s, _menhir_box_program) _menhir_cell1_constant _menhir_cell0_FULLSTOP _menhir_cell0_LCURLY, _menhir_box_program) _menhir_state
      (** State 316.
        Stack shape : constant FULLSTOP LCURLY.
        Start symbol: program. *)

    | MenhirState322 : (('s, _menhir_box_program) _menhir_cell1_NAMESPACE, _menhir_box_program) _menhir_state
      (** State 322.
        Stack shape : NAMESPACE.
        Start symbol: program. *)

    | MenhirState325 : (('s, _menhir_box_program) _menhir_cell1_MODULE, _menhir_box_program) _menhir_state
      (** State 325.
        Stack shape : MODULE.
        Start symbol: program. *)

    | MenhirState328 : (('s, _menhir_box_program) _menhir_cell1_MODE _menhir_cell0_LPAREN, _menhir_box_program) _menhir_state
      (** State 328.
        Stack shape : MODE LPAREN.
        Start symbol: program. *)

    | MenhirState329 : ((('s, _menhir_box_program) _menhir_cell1_MODE _menhir_cell0_LPAREN, _menhir_box_program) _menhir_cell1_constant, _menhir_box_program) _menhir_state
      (** State 329.
        Stack shape : MODE LPAREN constant.
        Start symbol: program. *)

    | MenhirState333 : (('s, _menhir_box_program) _menhir_cell1_i_o, _menhir_box_program) _menhir_state
      (** State 333.
        Stack shape : i_o.
        Start symbol: program. *)

    | MenhirState335 : (('s, _menhir_box_program) _menhir_cell1_MACRO, _menhir_box_program) _menhir_state
      (** State 335.
        Stack shape : MACRO.
        Start symbol: program. *)

    | MenhirState337 : ((('s, _menhir_box_program) _menhir_cell1_MACRO, _menhir_box_program) _menhir_cell1_term _menhir_cell0_VDASH, _menhir_box_program) _menhir_state
      (** State 337.
        Stack shape : MACRO term VDASH.
        Start symbol: program. *)

    | MenhirState339 : (('s, _menhir_box_program) _menhir_cell1_LOCALKIND, _menhir_box_program) _menhir_state
      (** State 339.
        Stack shape : LOCALKIND.
        Start symbol: program. *)

    | MenhirState341 : (('s, _menhir_box_program) _menhir_cell1_LOCAL, _menhir_box_program) _menhir_state
      (** State 341.
        Stack shape : LOCAL.
        Start symbol: program. *)

    | MenhirState342 : ((('s, _menhir_box_program) _menhir_cell1_LOCAL, _menhir_box_program) _menhir_cell1_separated_nonempty_list_CONJ_constant_, _menhir_box_program) _menhir_state
      (** State 342.
        Stack shape : LOCAL separated_nonempty_list(CONJ,constant).
        Start symbol: program. *)

    | MenhirState347 : (('s, _menhir_box_program) _menhir_cell1_KIND, _menhir_box_program) _menhir_state
      (** State 347.
        Stack shape : KIND.
        Start symbol: program. *)

    | MenhirState348 : ((('s, _menhir_box_program) _menhir_cell1_KIND, _menhir_box_program) _menhir_cell1_separated_nonempty_list_CONJ_constant_, _menhir_box_program) _menhir_state
      (** State 348.
        Stack shape : KIND separated_nonempty_list(CONJ,constant).
        Start symbol: program. *)

    | MenhirState350 : (('s, _menhir_box_program) _menhir_cell1_TYPE _menhir_cell0_ARROW, _menhir_box_program) _menhir_state
      (** State 350.
        Stack shape : TYPE ARROW.
        Start symbol: program. *)

    | MenhirState354 : (('s, _menhir_box_program) _menhir_cell1_FIXITY, _menhir_box_program) _menhir_state
      (** State 354.
        Stack shape : FIXITY.
        Start symbol: program. *)

    | MenhirState360 : (('s, _menhir_box_program) _menhir_cell1_EXPORTDEF, _menhir_box_program) _menhir_state
      (** State 360.
        Stack shape : EXPORTDEF.
        Start symbol: program. *)

    | MenhirState361 : ((('s, _menhir_box_program) _menhir_cell1_EXPORTDEF, _menhir_box_program) _menhir_cell1_separated_nonempty_list_CONJ_constant_, _menhir_box_program) _menhir_state
      (** State 361.
        Stack shape : EXPORTDEF separated_nonempty_list(CONJ,constant).
        Start symbol: program. *)

    | MenhirState364 : (('s, _menhir_box_program) _menhir_cell1_CONSTRAINT, _menhir_box_program) _menhir_state
      (** State 364.
        Stack shape : CONSTRAINT.
        Start symbol: program. *)

    | MenhirState367 : (('s, _menhir_box_program) _menhir_cell1_constant, _menhir_box_program) _menhir_state
      (** State 367.
        Stack shape : constant.
        Start symbol: program. *)

    | MenhirState369 : (('s, _menhir_box_program) _menhir_cell1_COLON, _menhir_box_program) _menhir_state
      (** State 369.
        Stack shape : COLON.
        Start symbol: program. *)

    | MenhirState375 : (('s, _menhir_box_program) _menhir_cell1_INDEX _menhir_cell0_LPAREN, _menhir_box_program) _menhir_state
      (** State 375.
        Stack shape : INDEX LPAREN.
        Start symbol: program. *)

    | MenhirState380 : (('s, _menhir_box_program) _menhir_cell1_indexing, _menhir_box_program) _menhir_state
      (** State 380.
        Stack shape : indexing.
        Start symbol: program. *)

    | MenhirState391 : (('s, _menhir_box_program) _menhir_cell1_attribute _menhir_cell0_COLON, _menhir_box_program) _menhir_state
      (** State 391.
        Stack shape : attribute COLON.
        Start symbol: program. *)

    | MenhirState393 : (('s, _menhir_box_program) _menhir_cell1_CLOSED, _menhir_box_program) _menhir_state
      (** State 393.
        Stack shape : CLOSED.
        Start symbol: program. *)

    | MenhirState414 : (('s, _menhir_box_program) _menhir_cell1_decl, _menhir_box_program) _menhir_state
      (** State 414.
        Stack shape : decl.
        Start symbol: program. *)

    | MenhirState420 : (('s, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_state
      (** State 420.
        Stack shape : attributes.
        Start symbol: program. *)

    | MenhirState421 : ((('s, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_TYPE, _menhir_box_program) _menhir_state
      (** State 421.
        Stack shape : attributes TYPE.
        Start symbol: program. *)

    | MenhirState422 : (((('s, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_TYPE, _menhir_box_program) _menhir_cell1_separated_nonempty_list_CONJ_constant_, _menhir_box_program) _menhir_state
      (** State 422.
        Stack shape : attributes TYPE separated_nonempty_list(CONJ,constant).
        Start symbol: program. *)

    | MenhirState424 : ((('s, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_RULE, _menhir_box_program) _menhir_state
      (** State 424.
        Stack shape : attributes RULE.
        Start symbol: program. *)

    | MenhirState425 : (('s, _menhir_box_program) _menhir_cell1_LPAREN, _menhir_box_program) _menhir_state
      (** State 425.
        Stack shape : LPAREN.
        Start symbol: program. *)

    | MenhirState426 : ((('s, _menhir_box_program) _menhir_cell1_LPAREN, _menhir_box_program) _menhir_cell1_constant, _menhir_box_program) _menhir_state
      (** State 426.
        Stack shape : LPAREN constant.
        Start symbol: program. *)

    | MenhirState427 : (((('s, _menhir_box_program) _menhir_cell1_LPAREN, _menhir_box_program) _menhir_cell1_constant, _menhir_box_program) _menhir_cell1_COLON, _menhir_box_program) _menhir_state
      (** State 427.
        Stack shape : LPAREN constant COLON.
        Start symbol: program. *)

    | MenhirState430 : (('s, _menhir_box_program) _menhir_cell1_sequent, _menhir_box_program) _menhir_state
      (** State 430.
        Stack shape : sequent.
        Start symbol: program. *)

    | MenhirState434 : (((('s, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_RULE, _menhir_box_program) _menhir_cell1_list_sequent_ _menhir_cell0_BIND, _menhir_box_program) _menhir_state
      (** State 434.
        Stack shape : attributes RULE list(sequent) BIND.
        Start symbol: program. *)

    | MenhirState435 : (('s, _menhir_box_program) _menhir_cell1_sequent, _menhir_box_program) _menhir_state
      (** State 435.
        Stack shape : sequent.
        Start symbol: program. *)

    | MenhirState439 : (((('s, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_RULE, _menhir_box_program) _menhir_cell1_list_sequent_ _menhir_cell0_option_preceded_BIND_nonempty_list_sequent___, _menhir_box_program) _menhir_state
      (** State 439.
        Stack shape : attributes RULE list(sequent) option(preceded(BIND,nonempty_list(sequent))).
        Start symbol: program. *)

    | MenhirState442 : (((('s, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_RULE, _menhir_box_program) _menhir_cell1_list_sequent_ _menhir_cell0_option_preceded_BIND_nonempty_list_sequent___ _menhir_cell0_option_preceded_PIPE_term__, _menhir_box_program) _menhir_state
      (** State 442.
        Stack shape : attributes RULE list(sequent) option(preceded(BIND,nonempty_list(sequent))) option(preceded(PIPE,term)).
        Start symbol: program. *)

    | MenhirState445 : ((('s, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_PRED, _menhir_box_program) _menhir_state
      (** State 445.
        Stack shape : attributes PRED.
        Start symbol: program. *)

    | MenhirState446 : (((('s, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_PRED, _menhir_box_program) _menhir_cell1_constant, _menhir_box_program) _menhir_state
      (** State 446.
        Stack shape : attributes PRED constant.
        Start symbol: program. *)

    | MenhirState447 : (('s, _menhir_box_program) _menhir_cell1_IO_COLON, _menhir_box_program) _menhir_state
      (** State 447.
        Stack shape : IO_COLON.
        Start symbol: program. *)

    | MenhirState452 : (('s, _menhir_box_program) _menhir_cell1_pred_item _menhir_cell0_option_CONJ_, _menhir_box_program) _menhir_state
      (** State 452.
        Stack shape : pred_item option(CONJ).
        Start symbol: program. *)

    | MenhirState455 : ((('s, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_LPAREN, _menhir_box_program) _menhir_state
      (** State 455.
        Stack shape : attributes LPAREN.
        Start symbol: program. *)

    | MenhirState458 : ((('s, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_FAMILY_TILDE, _menhir_box_program) _menhir_state
      (** State 458.
        Stack shape : attributes FAMILY_TILDE.
        Start symbol: program. *)

    | MenhirState460 : ((('s, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_head_term, _menhir_box_program) _menhir_state
      (** State 460.
        Stack shape : attributes head_term.
        Start symbol: program. *)

    | MenhirState461 : (((('s, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_head_term, _menhir_box_program) _menhir_cell1_nonempty_list_closed_term_, _menhir_box_program) _menhir_state
      (** State 461.
        Stack shape : attributes head_term nonempty_list(closed_term).
        Start symbol: program. *)

    | MenhirState465 : ((('s, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_clause_hd_term _menhir_cell0_VDASH, _menhir_box_program) _menhir_state
      (** State 465.
        Stack shape : attributes clause_hd_term VDASH.
        Start symbol: program. *)

    | MenhirState467 : ((('s, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_clause_hd_term _menhir_cell0_SLASH, _menhir_box_program) _menhir_state
      (** State 467.
        Stack shape : attributes clause_hd_term SLASH.
        Start symbol: program. *)

    | MenhirState469 : ((('s, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_clause_hd_term _menhir_cell0_QDASH, _menhir_box_program) _menhir_state
      (** State 469.
        Stack shape : attributes clause_hd_term QDASH.
        Start symbol: program. *)

    | MenhirState471 : ((('s, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_clause_hd_term _menhir_cell0_OR, _menhir_box_program) _menhir_state
      (** State 471.
        Stack shape : attributes clause_hd_term OR.
        Start symbol: program. *)

    | MenhirState473 : ((('s, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_clause_hd_term _menhir_cell0_MOD, _menhir_box_program) _menhir_state
      (** State 473.
        Stack shape : attributes clause_hd_term MOD.
        Start symbol: program. *)

    | MenhirState475 : ((('s, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_clause_hd_term _menhir_cell0_MINUSs, _menhir_box_program) _menhir_state
      (** State 475.
        Stack shape : attributes clause_hd_term MINUSs.
        Start symbol: program. *)

    | MenhirState477 : ((('s, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_clause_hd_term _menhir_cell0_MINUSr, _menhir_box_program) _menhir_state
      (** State 477.
        Stack shape : attributes clause_hd_term MINUSr.
        Start symbol: program. *)

    | MenhirState479 : ((('s, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_clause_hd_term _menhir_cell0_MINUSi, _menhir_box_program) _menhir_state
      (** State 479.
        Stack shape : attributes clause_hd_term MINUSi.
        Start symbol: program. *)

    | MenhirState481 : ((('s, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_clause_hd_term _menhir_cell0_MINUS, _menhir_box_program) _menhir_state
      (** State 481.
        Stack shape : attributes clause_hd_term MINUS.
        Start symbol: program. *)

    | MenhirState483 : ((('s, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_clause_hd_term _menhir_cell0_IS, _menhir_box_program) _menhir_state
      (** State 483.
        Stack shape : attributes clause_hd_term IS.
        Start symbol: program. *)

    | MenhirState485 : ((('s, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_clause_hd_term _menhir_cell0_FAMILY_TIMES, _menhir_box_program) _menhir_state
      (** State 485.
        Stack shape : attributes clause_hd_term FAMILY_TIMES.
        Start symbol: program. *)

    | MenhirState487 : ((('s, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_clause_hd_term _menhir_cell0_FAMILY_TICK, _menhir_box_program) _menhir_state
      (** State 487.
        Stack shape : attributes clause_hd_term FAMILY_TICK.
        Start symbol: program. *)

    | MenhirState489 : ((('s, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_clause_hd_term _menhir_cell0_FAMILY_SHARP, _menhir_box_program) _menhir_state
      (** State 489.
        Stack shape : attributes clause_hd_term FAMILY_SHARP.
        Start symbol: program. *)

    | MenhirState492 : ((('s, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_clause_hd_term _menhir_cell0_FAMILY_PLUS, _menhir_box_program) _menhir_state
      (** State 492.
        Stack shape : attributes clause_hd_term FAMILY_PLUS.
        Start symbol: program. *)

    | MenhirState494 : ((('s, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_clause_hd_term _menhir_cell0_FAMILY_OR, _menhir_box_program) _menhir_state
      (** State 494.
        Stack shape : attributes clause_hd_term FAMILY_OR.
        Start symbol: program. *)

    | MenhirState496 : ((('s, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_clause_hd_term _menhir_cell0_FAMILY_MINUS, _menhir_box_program) _menhir_state
      (** State 496.
        Stack shape : attributes clause_hd_term FAMILY_MINUS.
        Start symbol: program. *)

    | MenhirState498 : ((('s, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_clause_hd_term _menhir_cell0_FAMILY_LT, _menhir_box_program) _menhir_state
      (** State 498.
        Stack shape : attributes clause_hd_term FAMILY_LT.
        Start symbol: program. *)

    | MenhirState500 : ((('s, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_clause_hd_term _menhir_cell0_FAMILY_GT, _menhir_box_program) _menhir_state
      (** State 500.
        Stack shape : attributes clause_hd_term FAMILY_GT.
        Start symbol: program. *)

    | MenhirState502 : ((('s, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_clause_hd_term _menhir_cell0_FAMILY_EXP, _menhir_box_program) _menhir_state
      (** State 502.
        Stack shape : attributes clause_hd_term FAMILY_EXP.
        Start symbol: program. *)

    | MenhirState504 : ((('s, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_clause_hd_term _menhir_cell0_FAMILY_EQ, _menhir_box_program) _menhir_state
      (** State 504.
        Stack shape : attributes clause_hd_term FAMILY_EQ.
        Start symbol: program. *)

    | MenhirState506 : ((('s, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_clause_hd_term _menhir_cell0_FAMILY_BTICK, _menhir_box_program) _menhir_state
      (** State 506.
        Stack shape : attributes clause_hd_term FAMILY_BTICK.
        Start symbol: program. *)

    | MenhirState508 : ((('s, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_clause_hd_term _menhir_cell0_FAMILY_AND, _menhir_box_program) _menhir_state
      (** State 508.
        Stack shape : attributes clause_hd_term FAMILY_AND.
        Start symbol: program. *)

    | MenhirState510 : ((('s, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_clause_hd_term _menhir_cell0_EQ2, _menhir_box_program) _menhir_state
      (** State 510.
        Stack shape : attributes clause_hd_term EQ2.
        Start symbol: program. *)

    | MenhirState512 : ((('s, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_clause_hd_term _menhir_cell0_EQ, _menhir_box_program) _menhir_state
      (** State 512.
        Stack shape : attributes clause_hd_term EQ.
        Start symbol: program. *)

    | MenhirState514 : ((('s, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_clause_hd_term _menhir_cell0_DIV, _menhir_box_program) _menhir_state
      (** State 514.
        Stack shape : attributes clause_hd_term DIV.
        Start symbol: program. *)

    | MenhirState516 : ((('s, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_clause_hd_term _menhir_cell0_DARROW, _menhir_box_program) _menhir_state
      (** State 516.
        Stack shape : attributes clause_hd_term DARROW.
        Start symbol: program. *)

    | MenhirState518 : ((('s, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_clause_hd_term _menhir_cell0_CONS, _menhir_box_program) _menhir_state
      (** State 518.
        Stack shape : attributes clause_hd_term CONS.
        Start symbol: program. *)

    | MenhirState520 : ((('s, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_clause_hd_term _menhir_cell0_CONJ2, _menhir_box_program) _menhir_state
      (** State 520.
        Stack shape : attributes clause_hd_term CONJ2.
        Start symbol: program. *)

    | MenhirState522 : ((('s, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_clause_hd_term _menhir_cell0_CONJ, _menhir_box_program) _menhir_state
      (** State 522.
        Stack shape : attributes clause_hd_term CONJ.
        Start symbol: program. *)

    | MenhirState524 : ((('s, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_clause_hd_term _menhir_cell0_ARROW, _menhir_box_program) _menhir_state
      (** State 524.
        Stack shape : attributes clause_hd_term ARROW.
        Start symbol: program. *)

    | MenhirState528 : (('s, _menhir_box_program) _menhir_cell1_accumulate, _menhir_box_program) _menhir_state
      (** State 528.
        Stack shape : accumulate.
        Start symbol: program. *)

    | MenhirState533 : (('s, _menhir_box_program) _menhir_cell1_filename _menhir_cell0_CONJ, _menhir_box_program) _menhir_state
      (** State 533.
        Stack shape : filename CONJ.
        Start symbol: program. *)

  
  and ('s, 'r) _menhir_cell1_abbrevform = 
    | MenhirCell1_abbrevform of 's * ('s, 'r) _menhir_state * (Ast.Func.t * Ast.Func.t list)
  
  and ('s, 'r) _menhir_cell1_accumulate = 
    | MenhirCell1_accumulate of 's * ('s, 'r) _menhir_state * (string) * Lexing.position
  
  and ('s, 'r) _menhir_cell1_attribute = 
    | MenhirCell1_attribute of 's * ('s, 'r) _menhir_state * (Ast.raw_attribute) * Lexing.position
  
  and ('s, 'r) _menhir_cell1_attributes = 
    | MenhirCell1_attributes of 's * ('s, 'r) _menhir_state * (Ast.raw_attribute list) * Lexing.position * Lexing.position
  
  and ('s, 'r) _menhir_cell1_atype_term = 
    | MenhirCell1_atype_term of 's * ('s, 'r) _menhir_state * (Ast.Term.t) * Lexing.position
  
  and ('s, 'r) _menhir_cell1_clause_hd_term = 
    | MenhirCell1_clause_hd_term of 's * ('s, 'r) _menhir_state * (Ast.Term.t) * Lexing.position * Lexing.position
  
  and ('s, 'r) _menhir_cell1_closed_term = 
    | MenhirCell1_closed_term of 's * ('s, 'r) _menhir_state * (Ast.Term.t) * Lexing.position * Lexing.position
  
  and ('s, 'r) _menhir_cell1_constant = 
    | MenhirCell1_constant of 's * ('s, 'r) _menhir_state * (Ast.Func.t) * Lexing.position * Lexing.position
  
  and ('s, 'r) _menhir_cell1_decl = 
    | MenhirCell1_decl of 's * ('s, 'r) _menhir_state * (Ast.Program.decl)
  
  and ('s, 'r) _menhir_cell1_filename = 
    | MenhirCell1_filename of 's * ('s, 'r) _menhir_state * (string)
  
  and ('s, 'r) _menhir_cell1_head_term = 
    | MenhirCell1_head_term of 's * ('s, 'r) _menhir_state * (Ast.Term.t) * Lexing.position * Lexing.position
  
  and ('s, 'r) _menhir_cell1_i_o = 
    | MenhirCell1_i_o of 's * ('s, 'r) _menhir_state * (bool)
  
  and ('s, 'r) _menhir_cell1_indexing = 
    | MenhirCell1_indexing of 's * ('s, 'r) _menhir_state * (int)
  
  and ('s, 'r) _menhir_cell1_list_sequent_ = 
    | MenhirCell1_list_sequent_ of 's * ('s, 'r) _menhir_state * (Ast.Chr.sequent list)
  
  and ('s, 'r) _menhir_cell1_nonempty_list_closed_term_ = 
    | MenhirCell1_nonempty_list_closed_term_ of 's * ('s, 'r) _menhir_state * (Ast.Term.t list)
  
  and 's _menhir_cell0_option_CONJ_ = 
    | MenhirCell0_option_CONJ_ of 's * (unit option)
  
  and 's _menhir_cell0_option_preceded_BIND_nonempty_list_sequent___ = 
    | MenhirCell0_option_preceded_BIND_nonempty_list_sequent___ of 's * (Ast.Chr.sequent list option)
  
  and 's _menhir_cell0_option_preceded_PIPE_term__ = 
    | MenhirCell0_option_preceded_PIPE_term__ of 's * (Ast.Term.t option)
  
  and ('s, 'r) _menhir_cell1_pred_item = 
    | MenhirCell1_pred_item of 's * ('s, 'r) _menhir_state * (bool * Ast.Term.t) * Lexing.position
  
  and ('s, 'r) _menhir_cell1_separated_nonempty_list_CONJ_constant_ = 
    | MenhirCell1_separated_nonempty_list_CONJ_constant_ of 's * ('s, 'r) _menhir_state * (Ast.Func.t list) * Lexing.position
  
  and ('s, 'r) _menhir_cell1_sequent = 
    | MenhirCell1_sequent of 's * ('s, 'r) _menhir_state * (Ast.Chr.sequent) * Lexing.position
  
  and ('s, 'r) _menhir_cell1_subtrie = 
    | MenhirCell1_subtrie of 's * ('s, 'r) _menhir_state * ((string * string) list)
  
  and ('s, 'r) _menhir_cell1_term = 
    | MenhirCell1_term of 's * ('s, 'r) _menhir_state * (Ast.Term.t) * Lexing.position * Lexing.position
  
  and ('s, 'r) _menhir_cell1_term_noconj = 
    | MenhirCell1_term_noconj of 's * ('s, 'r) _menhir_state * (Ast.Term.t) * Lexing.position * Lexing.position
  
  and ('s, 'r) _menhir_cell1_type_term = 
    | MenhirCell1_type_term of 's * ('s, 'r) _menhir_state * (Ast.Term.t) * Lexing.position * Lexing.position
  
  and 's _menhir_cell0_ARROW = 
    | MenhirCell0_ARROW of 's * Lexing.position * Lexing.position
  
  and ('s, 'r) _menhir_cell1_BIND = 
    | MenhirCell1_BIND of 's * ('s, 'r) _menhir_state * Lexing.position * Lexing.position
  
  and 's _menhir_cell0_BIND = 
    | MenhirCell0_BIND of 's * Lexing.position * Lexing.position
  
  and ('s, 'r) _menhir_cell1_CLOSED = 
    | MenhirCell1_CLOSED of 's * ('s, 'r) _menhir_state * Lexing.position
  
  and ('s, 'r) _menhir_cell1_COLON = 
    | MenhirCell1_COLON of 's * ('s, 'r) _menhir_state * Lexing.position
  
  and 's _menhir_cell0_COLON = 
    | MenhirCell0_COLON of 's * Lexing.position
  
  and 's _menhir_cell0_CONJ = 
    | MenhirCell0_CONJ of 's * Lexing.position * Lexing.position
  
  and 's _menhir_cell0_CONJ2 = 
    | MenhirCell0_CONJ2 of 's * Lexing.position * Lexing.position
  
  and 's _menhir_cell0_CONS = 
    | MenhirCell0_CONS of 's * Lexing.position * Lexing.position
  
  and ('s, 'r) _menhir_cell1_CONSTRAINT = 
    | MenhirCell1_CONSTRAINT of 's * ('s, 'r) _menhir_state * Lexing.position
  
  and 's _menhir_cell0_DARROW = 
    | MenhirCell0_DARROW of 's * Lexing.position * Lexing.position
  
  and 's _menhir_cell0_DIV = 
    | MenhirCell0_DIV of 's * Lexing.position * Lexing.position
  
  and 's _menhir_cell0_EQ = 
    | MenhirCell0_EQ of 's * Lexing.position * Lexing.position
  
  and 's _menhir_cell0_EQ2 = 
    | MenhirCell0_EQ2 of 's * Lexing.position * Lexing.position
  
  and ('s, 'r) _menhir_cell1_EXPORTDEF = 
    | MenhirCell1_EXPORTDEF of 's * ('s, 'r) _menhir_state * Lexing.position
  
  and 's _menhir_cell0_FAMILY_AND = 
    | MenhirCell0_FAMILY_AND of 's * (
# 85 "src/parser/tokens.mly"
       (string)
# 1104 "src/parser/grammar.ml"
  ) * Lexing.position * Lexing.position
  
  and 's _menhir_cell0_FAMILY_BTICK = 
    | MenhirCell0_FAMILY_BTICK of 's * (
# 81 "src/parser/tokens.mly"
       (string)
# 1111 "src/parser/grammar.ml"
  ) * Lexing.position * Lexing.position
  
  and 's _menhir_cell0_FAMILY_EQ = 
    | MenhirCell0_FAMILY_EQ of 's * (
# 79 "src/parser/tokens.mly"
       (string)
# 1118 "src/parser/grammar.ml"
  ) * Lexing.position * Lexing.position
  
  and 's _menhir_cell0_FAMILY_EXP = 
    | MenhirCell0_FAMILY_EXP of 's * (
# 76 "src/parser/tokens.mly"
       (string)
# 1125 "src/parser/grammar.ml"
  ) * Lexing.position * Lexing.position
  
  and 's _menhir_cell0_FAMILY_GT = 
    | MenhirCell0_FAMILY_GT of 's * (
# 78 "src/parser/tokens.mly"
       (string)
# 1132 "src/parser/grammar.ml"
  ) * Lexing.position * Lexing.position
  
  and 's _menhir_cell0_FAMILY_LT = 
    | MenhirCell0_FAMILY_LT of 's * (
# 77 "src/parser/tokens.mly"
       (string)
# 1139 "src/parser/grammar.ml"
  ) * Lexing.position * Lexing.position
  
  and 's _menhir_cell0_FAMILY_MINUS = 
    | MenhirCell0_FAMILY_MINUS of 's * (
# 75 "src/parser/tokens.mly"
       (string)
# 1146 "src/parser/grammar.ml"
  ) * Lexing.position * Lexing.position
  
  and 's _menhir_cell0_FAMILY_OR = 
    | MenhirCell0_FAMILY_OR of 's * (
# 86 "src/parser/tokens.mly"
       (string)
# 1153 "src/parser/grammar.ml"
  ) * Lexing.position * Lexing.position
  
  and 's _menhir_cell0_FAMILY_PLUS = 
    | MenhirCell0_FAMILY_PLUS of 's * (
# 73 "src/parser/tokens.mly"
       (string)
# 1160 "src/parser/grammar.ml"
  ) * Lexing.position * Lexing.position
  
  and 's _menhir_cell0_FAMILY_SHARP = 
    | MenhirCell0_FAMILY_SHARP of 's * (
# 83 "src/parser/tokens.mly"
       (string)
# 1167 "src/parser/grammar.ml"
  ) * Lexing.position * Lexing.position
  
  and 's _menhir_cell0_FAMILY_TICK = 
    | MenhirCell0_FAMILY_TICK of 's * (
# 82 "src/parser/tokens.mly"
       (string)
# 1174 "src/parser/grammar.ml"
  ) * Lexing.position * Lexing.position
  
  and ('s, 'r) _menhir_cell1_FAMILY_TILDE = 
    | MenhirCell1_FAMILY_TILDE of 's * ('s, 'r) _menhir_state * (
# 84 "src/parser/tokens.mly"
       (string)
# 1181 "src/parser/grammar.ml"
  ) * Lexing.position * Lexing.position
  
  and 's _menhir_cell0_FAMILY_TIMES = 
    | MenhirCell0_FAMILY_TIMES of 's * (
# 74 "src/parser/tokens.mly"
       (string)
# 1188 "src/parser/grammar.ml"
  ) * Lexing.position * Lexing.position
  
  and ('s, 'r) _menhir_cell1_FIXITY = 
    | MenhirCell1_FIXITY of 's * ('s, 'r) _menhir_state * (
# 54 "src/parser/tokens.mly"
       (string)
# 1195 "src/parser/grammar.ml"
  ) * Lexing.position
  
  and 's _menhir_cell0_FULLSTOP = 
    | MenhirCell0_FULLSTOP of 's * Lexing.position
  
  and ('s, 'r) _menhir_cell1_INDEX = 
    | MenhirCell1_INDEX of 's * ('s, 'r) _menhir_state * Lexing.position * Lexing.position
  
  and ('s, 'r) _menhir_cell1_IO_COLON = 
    | MenhirCell1_IO_COLON of 's * ('s, 'r) _menhir_state * (
# 21 "src/parser/tokens.mly"
       (char)
# 1208 "src/parser/grammar.ml"
  )
  
  and 's _menhir_cell0_IS = 
    | MenhirCell0_IS of 's * Lexing.position * Lexing.position
  
  and ('s, 'r) _menhir_cell1_KIND = 
    | MenhirCell1_KIND of 's * ('s, 'r) _menhir_state * Lexing.position
  
  and ('s, 'r) _menhir_cell1_LBRACKET = 
    | MenhirCell1_LBRACKET of 's * ('s, 'r) _menhir_state * Lexing.position
  
  and ('s, 'r) _menhir_cell1_LCURLY = 
    | MenhirCell1_LCURLY of 's * ('s, 'r) _menhir_state * Lexing.position * Lexing.position
  
  and 's _menhir_cell0_LCURLY = 
    | MenhirCell0_LCURLY of 's * Lexing.position * Lexing.position
  
  and ('s, 'r) _menhir_cell1_LOCAL = 
    | MenhirCell1_LOCAL of 's * ('s, 'r) _menhir_state
  
  and ('s, 'r) _menhir_cell1_LOCALKIND = 
    | MenhirCell1_LOCALKIND of 's * ('s, 'r) _menhir_state * Lexing.position
  
  and ('s, 'r) _menhir_cell1_LPAREN = 
    | MenhirCell1_LPAREN of 's * ('s, 'r) _menhir_state * Lexing.position
  
  and 's _menhir_cell0_LPAREN = 
    | MenhirCell0_LPAREN of 's * Lexing.position
  
  and ('s, 'r) _menhir_cell1_MACRO = 
    | MenhirCell1_MACRO of 's * ('s, 'r) _menhir_state * Lexing.position
  
  and 's _menhir_cell0_MINUS = 
    | MenhirCell0_MINUS of 's * Lexing.position * Lexing.position
  
  and 's _menhir_cell0_MINUSi = 
    | MenhirCell0_MINUSi of 's * Lexing.position * Lexing.position
  
  and 's _menhir_cell0_MINUSr = 
    | MenhirCell0_MINUSr of 's * Lexing.position * Lexing.position
  
  and 's _menhir_cell0_MINUSs = 
    | MenhirCell0_MINUSs of 's * Lexing.position * Lexing.position
  
  and 's _menhir_cell0_MOD = 
    | MenhirCell0_MOD of 's * Lexing.position * Lexing.position
  
  and ('s, 'r) _menhir_cell1_MODE = 
    | MenhirCell1_MODE of 's * ('s, 'r) _menhir_state * Lexing.position
  
  and ('s, 'r) _menhir_cell1_MODULE = 
    | MenhirCell1_MODULE of 's * ('s, 'r) _menhir_state * Lexing.position
  
  and ('s, 'r) _menhir_cell1_NAMESPACE = 
    | MenhirCell1_NAMESPACE of 's * ('s, 'r) _menhir_state * Lexing.position
  
  and 's _menhir_cell0_OR = 
    | MenhirCell0_OR of 's * Lexing.position * Lexing.position
  
  and ('s, 'r) _menhir_cell1_PIPE = 
    | MenhirCell1_PIPE of 's * ('s, 'r) _menhir_state
  
  and ('s, 'r) _menhir_cell1_PRED = 
    | MenhirCell1_PRED of 's * ('s, 'r) _menhir_state * Lexing.position
  
  and 's _menhir_cell0_QDASH = 
    | MenhirCell0_QDASH of 's * Lexing.position * Lexing.position
  
  and ('s, 'r) _menhir_cell1_RULE = 
    | MenhirCell1_RULE of 's * ('s, 'r) _menhir_state * Lexing.position
  
  and ('s, 'r) _menhir_cell1_SHORTEN = 
    | MenhirCell1_SHORTEN of 's * ('s, 'r) _menhir_state * Lexing.position
  
  and ('s, 'r) _menhir_cell1_SIG = 
    | MenhirCell1_SIG of 's * ('s, 'r) _menhir_state * Lexing.position
  
  and 's _menhir_cell0_SLASH = 
    | MenhirCell0_SLASH of 's * Lexing.position * Lexing.position
  
  and ('s, 'r) _menhir_cell1_TYPE = 
    | MenhirCell1_TYPE of 's * ('s, 'r) _menhir_state * Lexing.position * Lexing.position
  
  and ('s, 'r) _menhir_cell1_TYPEABBREV = 
    | MenhirCell1_TYPEABBREV of 's * ('s, 'r) _menhir_state * Lexing.position
  
  and ('s, 'r) _menhir_cell1_USEONLY = 
    | MenhirCell1_USEONLY of 's * ('s, 'r) _menhir_state * Lexing.position
  
  and 's _menhir_cell0_VDASH = 
    | MenhirCell0_VDASH of 's * Lexing.position * Lexing.position
  
  and _menhir_box_program = 
    | MenhirBox_program of (Ast.Program.t) [@@unboxed]
  
  and _menhir_box_prefix_SYMB = 
    | MenhirBox_prefix_SYMB of (Ast.Func.t) [@@unboxed]
  
  and _menhir_box_postfix_SYMB = 
    | MenhirBox_postfix_SYMB of (Ast.Func.t) [@@unboxed]
  
  and _menhir_box_infix_SYMB = 
    | MenhirBox_infix_SYMB of (Ast.Func.t) [@@unboxed]
  
  and _menhir_box_goal = 
    | MenhirBox_goal of (Ast.Goal.t) [@@unboxed]
  
  let _menhir_action_005 =
    fun c ->
      (
# 225 "src/parser/grammar.mly"
               ( c, [] )
# 1321 "src/parser/grammar.ml"
       : (Ast.Func.t * Ast.Func.t list))
  
  let _menhir_action_006 =
    fun args hd ->
      (
# 226 "src/parser/grammar.mly"
                                                                ( hd, args  )
# 1329 "src/parser/grammar.ml"
       : (Ast.Func.t * Ast.Func.t list))
  
  let _menhir_action_007 =
    fun () ->
      (
# 143 "src/parser/grammar.mly"
             ( ".elpi" )
# 1337 "src/parser/grammar.ml"
       : (string))
  
  let _menhir_action_008 =
    fun () ->
      (
# 144 "src/parser/grammar.mly"
         ( ".mod" )
# 1345 "src/parser/grammar.ml"
       : (string))
  
  let _menhir_action_009 =
    fun () ->
      (
# 145 "src/parser/grammar.mly"
            ( ".sig" )
# 1353 "src/parser/grammar.ml"
       : (string))
  
  let _menhir_action_010 =
    fun () ->
      (
# 146 "src/parser/grammar.mly"
          ( ".sig" )
# 1361 "src/parser/grammar.ml"
       : (string))
  
  let _menhir_action_011 =
    fun s ->
      (
# 293 "src/parser/grammar.mly"
                 ( If s )
# 1369 "src/parser/grammar.ml"
       : (Ast.raw_attribute))
  
  let _menhir_action_012 =
    fun s ->
      (
# 294 "src/parser/grammar.mly"
                    ( Name s )
# 1377 "src/parser/grammar.ml"
       : (Ast.raw_attribute))
  
  let _menhir_action_013 =
    fun s ->
      (
# 295 "src/parser/grammar.mly"
                    ( After s )
# 1385 "src/parser/grammar.ml"
       : (Ast.raw_attribute))
  
  let _menhir_action_014 =
    fun s ->
      (
# 296 "src/parser/grammar.mly"
                     ( Before s )
# 1393 "src/parser/grammar.ml"
       : (Ast.raw_attribute))
  
  let _menhir_action_015 =
    fun s ->
      (
# 297 "src/parser/grammar.mly"
                      ( Replace s )
# 1401 "src/parser/grammar.ml"
       : (Ast.raw_attribute))
  
  let _menhir_action_016 =
    fun () ->
      (
# 298 "src/parser/grammar.mly"
           ( External )
# 1409 "src/parser/grammar.ml"
       : (Ast.raw_attribute))
  
  let _menhir_action_017 =
    fun l ->
      (
# 299 "src/parser/grammar.mly"
                                                      ( Index l )
# 1417 "src/parser/grammar.ml"
       : (Ast.raw_attribute))
  
  let _menhir_action_018 =
    fun () ->
      (
# 288 "src/parser/grammar.mly"
  ( [] )
# 1425 "src/parser/grammar.ml"
       : (Ast.raw_attribute list))
  
  let _menhir_action_019 =
    fun () ->
      (
# 289 "src/parser/grammar.mly"
           ( [ External ] )
# 1433 "src/parser/grammar.ml"
       : (Ast.raw_attribute list))
  
  let _menhir_action_020 =
    fun l ->
      (
# 290 "src/parser/grammar.mly"
                                                       ( l )
# 1441 "src/parser/grammar.ml"
       : (Ast.raw_attribute list))
  
  let _menhir_action_021 =
    fun c ->
      (
# 186 "src/parser/grammar.mly"
             ( mkC (cstring.Util.CData.cin c) )
# 1449 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_022 =
    fun c ->
      (
# 187 "src/parser/grammar.mly"
               ( Const (fix_church c) )
# 1457 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_023 =
    fun t ->
      (
# 188 "src/parser/grammar.mly"
                                ( t )
# 1465 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_024 =
    fun _endpos_bind_ _startpos_bind_ b bind ->
      let _loc_bind_ = (_startpos_bind_, _endpos_bind_) in
      (
# 344 "src/parser/grammar.mly"
                        ( (loc _loc_bind_, b) )
# 1474 "src/parser/grammar.ml"
       : (Ast.Loc.t * Ast.Term.t))
  
  let _menhir_action_025 =
    fun b t ->
      (
# 341 "src/parser/grammar.mly"
                                ( mkLam (Func.show t) (snd b) )
# 1482 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_026 =
    fun b t ->
      (
# 347 "src/parser/grammar.mly"
                               ( mkLam (Func.show t) b )
# 1490 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_027 =
    fun _endpos_attributes_ _endpos_new_goal_ _startpos__2_ _startpos_attributes_ attributes guard new_goal to_match to_remove ->
      let _endpos = _endpos_new_goal_ in
      let _symbolstartpos = if _startpos_attributes_ != _endpos_attributes_ then
        _startpos_attributes_
      else
        _startpos__2_ in
      let _sloc = (_symbolstartpos, _endpos) in
      (
# 157 "src/parser/grammar.mly"
                                    (
    { Chr.to_match; to_remove = Util.option_default [] to_remove; guard; new_goal; attributes; loc=(loc _sloc) }
  )
# 1506 "src/parser/grammar.ml"
       : (Ast.raw_attribute list Ast.Chr.t))
  
  let _menhir_action_028 =
    fun _endpos_attributes_ _endpos_body_ _startpos_attributes_ _startpos_body_ attributes body ->
      let _endpos = _endpos_body_ in
      let _symbolstartpos = if _startpos_attributes_ != _endpos_attributes_ then
        _startpos_attributes_
      else
        _startpos_body_ in
      let _sloc = (_symbolstartpos, _endpos) in
      (
# 274 "src/parser/grammar.mly"
                                                  (
    { Clause.loc = loc _sloc;
      attributes;
      body;
    }
  )
# 1525 "src/parser/grammar.ml"
       : ((Ast.Term.t, Ast.raw_attribute list) Ast.Clause.t))
  
  let _menhir_action_029 =
    fun _endpos_attributes_ _endpos_r_ _startpos_attributes_ _startpos_l_ attributes l r ->
      let _endpos = _endpos_r_ in
      let _symbolstartpos = if _startpos_attributes_ != _endpos_attributes_ then
        _startpos_attributes_
      else
        _startpos_l_ in
      let _sloc = (_symbolstartpos, _endpos) in
      (
# 280 "src/parser/grammar.mly"
                                                               ( 
    { Clause.loc = loc _sloc;
      attributes;
      body = App(Const Func.rimplf,[l;r])
    }
)
# 1544 "src/parser/grammar.ml"
       : ((Ast.Term.t, Ast.raw_attribute list) Ast.Clause.t))
  
  let _menhir_action_030 =
    fun t ->
      (
# 375 "src/parser/grammar.mly"
               ( Const t )
# 1552 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_031 =
    fun t ->
      (
# 376 "src/parser/grammar.mly"
                           ( t )
# 1560 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_032 =
    fun _endpos_hd_ _startpos_hd_ args b hd ->
      let _loc_hd_ = (_startpos_hd_, _endpos_hd_) in
      (
# 379 "src/parser/grammar.mly"
                                                                             (
    let args = binder args b in
    let t = mkApp (loc _loc_hd_) (hd :: args) in
    desugar_multi_binder (loc _loc_hd_) t
)
# 1573 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_033 =
    fun _endpos_r_ _startpos_l_ l r s ->
      let s =
        let x = 
# 441 "src/parser/grammar.mly"
                   ( Func.from_string s )
# 1582 "src/parser/grammar.ml"
         in
        
# 437 "src/parser/grammar.mly"
                       ( x )
# 1587 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 384 "src/parser/grammar.mly"
                                                  ( mkApp (loc _loc) [Const s;l;r] )
# 1596 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_034 =
    fun _endpos_r_ _startpos_l_ l r s ->
      let s =
        let x = 
# 442 "src/parser/grammar.mly"
                   ( Func.from_string s )
# 1605 "src/parser/grammar.ml"
         in
        
# 437 "src/parser/grammar.mly"
                       ( x )
# 1610 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 384 "src/parser/grammar.mly"
                                                  ( mkApp (loc _loc) [Const s;l;r] )
# 1619 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_035 =
    fun _endpos_r_ _startpos_l_ l r s ->
      let s =
        let x = 
# 443 "src/parser/grammar.mly"
                   ( Func.from_string s )
# 1628 "src/parser/grammar.ml"
         in
        
# 437 "src/parser/grammar.mly"
                       ( x )
# 1633 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 384 "src/parser/grammar.mly"
                                                  ( mkApp (loc _loc) [Const s;l;r] )
# 1642 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_036 =
    fun _endpos_r_ _startpos_l_ l r s ->
      let s =
        let x = 
# 444 "src/parser/grammar.mly"
                   ( Func.from_string s )
# 1651 "src/parser/grammar.ml"
         in
        
# 437 "src/parser/grammar.mly"
                       ( x )
# 1656 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 384 "src/parser/grammar.mly"
                                                  ( mkApp (loc _loc) [Const s;l;r] )
# 1665 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_037 =
    fun _endpos_r_ _startpos_l_ l r s ->
      let s =
        let x = 
# 445 "src/parser/grammar.mly"
                   ( Func.from_string s )
# 1674 "src/parser/grammar.ml"
         in
        
# 437 "src/parser/grammar.mly"
                       ( x )
# 1679 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 384 "src/parser/grammar.mly"
                                                  ( mkApp (loc _loc) [Const s;l;r] )
# 1688 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_038 =
    fun _endpos_r_ _startpos_l_ l r s ->
      let s =
        let x = 
# 446 "src/parser/grammar.mly"
                   ( Func.from_string s )
# 1697 "src/parser/grammar.ml"
         in
        
# 437 "src/parser/grammar.mly"
                       ( x )
# 1702 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 384 "src/parser/grammar.mly"
                                                  ( mkApp (loc _loc) [Const s;l;r] )
# 1711 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_039 =
    fun _endpos_r_ _startpos_l_ l r s ->
      let s =
        let x = 
# 447 "src/parser/grammar.mly"
                   ( Func.from_string s )
# 1720 "src/parser/grammar.ml"
         in
        
# 437 "src/parser/grammar.mly"
                       ( x )
# 1725 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 384 "src/parser/grammar.mly"
                                                  ( mkApp (loc _loc) [Const s;l;r] )
# 1734 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_040 =
    fun _endpos_r_ _startpos_l_ l r s ->
      let s =
        let x = 
# 448 "src/parser/grammar.mly"
                   ( Func.from_string s )
# 1743 "src/parser/grammar.ml"
         in
        
# 437 "src/parser/grammar.mly"
                       ( x )
# 1748 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 384 "src/parser/grammar.mly"
                                                  ( mkApp (loc _loc) [Const s;l;r] )
# 1757 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_041 =
    fun _endpos_r_ _startpos_l_ l r s ->
      let s =
        let x = 
# 449 "src/parser/grammar.mly"
                  ( Func.from_string s )
# 1766 "src/parser/grammar.ml"
         in
        
# 437 "src/parser/grammar.mly"
                       ( x )
# 1771 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 384 "src/parser/grammar.mly"
                                                  ( mkApp (loc _loc) [Const s;l;r] )
# 1780 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_042 =
    fun _endpos_r_ _startpos_l_ l r s ->
      let s =
        let x = 
# 450 "src/parser/grammar.mly"
                   ( Func.from_string s )
# 1789 "src/parser/grammar.ml"
         in
        
# 437 "src/parser/grammar.mly"
                       ( x )
# 1794 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 384 "src/parser/grammar.mly"
                                                  ( mkApp (loc _loc) [Const s;l;r] )
# 1803 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_043 =
    fun _endpos_r_ _startpos_l_ l r s ->
      let s =
        let x = 
# 451 "src/parser/grammar.mly"
                   ( Func.from_string s )
# 1812 "src/parser/grammar.ml"
         in
        
# 437 "src/parser/grammar.mly"
                       ( x )
# 1817 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 384 "src/parser/grammar.mly"
                                                  ( mkApp (loc _loc) [Const s;l;r] )
# 1826 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_044 =
    fun _endpos_r_ _startpos_l_ l r s ->
      let s =
        let x = 
# 452 "src/parser/grammar.mly"
                   ( Func.from_string s )
# 1835 "src/parser/grammar.ml"
         in
        
# 437 "src/parser/grammar.mly"
                       ( x )
# 1840 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 384 "src/parser/grammar.mly"
                                                  ( mkApp (loc _loc) [Const s;l;r] )
# 1849 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_045 =
    fun _endpos_r_ _startpos_l_ l r ->
      let s =
        let x =
          let x = 
# 455 "src/parser/grammar.mly"
         ( Func.consf )
# 1859 "src/parser/grammar.ml"
           in
          
# 473 "src/parser/grammar.mly"
                                          ( x )
# 1864 "src/parser/grammar.ml"
          
        in
        
# 438 "src/parser/grammar.mly"
                                   ( x )
# 1870 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 384 "src/parser/grammar.mly"
                                                  ( mkApp (loc _loc) [Const s;l;r] )
# 1879 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_046 =
    fun _endpos_r_ _startpos_l_ l r ->
      let s =
        let x =
          let x = 
# 456 "src/parser/grammar.mly"
         ( Func.eqf )
# 1889 "src/parser/grammar.ml"
           in
          
# 473 "src/parser/grammar.mly"
                                          ( x )
# 1894 "src/parser/grammar.ml"
          
        in
        
# 438 "src/parser/grammar.mly"
                                   ( x )
# 1900 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 384 "src/parser/grammar.mly"
                                                  ( mkApp (loc _loc) [Const s;l;r] )
# 1909 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_047 =
    fun _endpos_r_ _startpos_l_ l r ->
      let s =
        let x =
          let x = 
# 457 "src/parser/grammar.mly"
         ( Func.from_string "-" )
# 1919 "src/parser/grammar.ml"
           in
          
# 473 "src/parser/grammar.mly"
                                          ( x )
# 1924 "src/parser/grammar.ml"
          
        in
        
# 438 "src/parser/grammar.mly"
                                   ( x )
# 1930 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 384 "src/parser/grammar.mly"
                                                  ( mkApp (loc _loc) [Const s;l;r] )
# 1939 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_048 =
    fun _endpos_r_ _startpos_l_ l r ->
      let s =
        let x =
          let x = 
# 458 "src/parser/grammar.mly"
         ( Func.from_string "r-" )
# 1949 "src/parser/grammar.ml"
           in
          
# 473 "src/parser/grammar.mly"
                                          ( x )
# 1954 "src/parser/grammar.ml"
          
        in
        
# 438 "src/parser/grammar.mly"
                                   ( x )
# 1960 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 384 "src/parser/grammar.mly"
                                                  ( mkApp (loc _loc) [Const s;l;r] )
# 1969 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_049 =
    fun _endpos_r_ _startpos_l_ l r ->
      let s =
        let x =
          let x = 
# 459 "src/parser/grammar.mly"
         ( Func.from_string "i-" )
# 1979 "src/parser/grammar.ml"
           in
          
# 473 "src/parser/grammar.mly"
                                          ( x )
# 1984 "src/parser/grammar.ml"
          
        in
        
# 438 "src/parser/grammar.mly"
                                   ( x )
# 1990 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 384 "src/parser/grammar.mly"
                                                  ( mkApp (loc _loc) [Const s;l;r] )
# 1999 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_050 =
    fun _endpos_r_ _startpos_l_ l r ->
      let s =
        let x =
          let x = 
# 460 "src/parser/grammar.mly"
         ( Func.from_string "s-" )
# 2009 "src/parser/grammar.ml"
           in
          
# 473 "src/parser/grammar.mly"
                                          ( x )
# 2014 "src/parser/grammar.ml"
          
        in
        
# 438 "src/parser/grammar.mly"
                                   ( x )
# 2020 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 384 "src/parser/grammar.mly"
                                                  ( mkApp (loc _loc) [Const s;l;r] )
# 2029 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_051 =
    fun _endpos_r_ _startpos_l_ l r ->
      let s =
        let x =
          let x = 
# 461 "src/parser/grammar.mly"
         ( Func.from_string "==" )
# 2039 "src/parser/grammar.ml"
           in
          
# 473 "src/parser/grammar.mly"
                                          ( x )
# 2044 "src/parser/grammar.ml"
          
        in
        
# 438 "src/parser/grammar.mly"
                                   ( x )
# 2050 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 384 "src/parser/grammar.mly"
                                                  ( mkApp (loc _loc) [Const s;l;r] )
# 2059 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_052 =
    fun _endpos_r_ _startpos_l_ l r ->
      let s =
        let x =
          let x = 
# 462 "src/parser/grammar.mly"
         ( Func.orf )
# 2069 "src/parser/grammar.ml"
           in
          
# 473 "src/parser/grammar.mly"
                                          ( x )
# 2074 "src/parser/grammar.ml"
          
        in
        
# 438 "src/parser/grammar.mly"
                                   ( x )
# 2080 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 384 "src/parser/grammar.mly"
                                                  ( mkApp (loc _loc) [Const s;l;r] )
# 2089 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_053 =
    fun _endpos_r_ _startpos_l_ l r ->
      let s =
        let x =
          let x = 
# 463 "src/parser/grammar.mly"
         ( Func.isf )
# 2099 "src/parser/grammar.ml"
           in
          
# 473 "src/parser/grammar.mly"
                                          ( x )
# 2104 "src/parser/grammar.ml"
          
        in
        
# 438 "src/parser/grammar.mly"
                                   ( x )
# 2110 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 384 "src/parser/grammar.mly"
                                                  ( mkApp (loc _loc) [Const s;l;r] )
# 2119 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_054 =
    fun _endpos_r_ _startpos_l_ l r ->
      let s =
        let x =
          let x = 
# 464 "src/parser/grammar.mly"
         ( Func.from_string "mod" )
# 2129 "src/parser/grammar.ml"
           in
          
# 473 "src/parser/grammar.mly"
                                          ( x )
# 2134 "src/parser/grammar.ml"
          
        in
        
# 438 "src/parser/grammar.mly"
                                   ( x )
# 2140 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 384 "src/parser/grammar.mly"
                                                  ( mkApp (loc _loc) [Const s;l;r] )
# 2149 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_055 =
    fun _endpos_r_ _startpos_l_ l r ->
      let s =
        let x =
          let x = 
# 465 "src/parser/grammar.mly"
         ( Func.from_string "div" )
# 2159 "src/parser/grammar.ml"
           in
          
# 473 "src/parser/grammar.mly"
                                          ( x )
# 2164 "src/parser/grammar.ml"
          
        in
        
# 438 "src/parser/grammar.mly"
                                   ( x )
# 2170 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 384 "src/parser/grammar.mly"
                                                  ( mkApp (loc _loc) [Const s;l;r] )
# 2179 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_056 =
    fun _endpos_r_ _startpos_l_ l r ->
      let s =
        let x =
          let x = 
# 466 "src/parser/grammar.mly"
         ( Func.arrowf )
# 2189 "src/parser/grammar.ml"
           in
          
# 473 "src/parser/grammar.mly"
                                          ( x )
# 2194 "src/parser/grammar.ml"
          
        in
        
# 438 "src/parser/grammar.mly"
                                   ( x )
# 2200 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 384 "src/parser/grammar.mly"
                                                  ( mkApp (loc _loc) [Const s;l;r] )
# 2209 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_057 =
    fun _endpos_r_ _startpos_l_ l r ->
      let s =
        let x =
          let x = 
# 467 "src/parser/grammar.mly"
         ( Func.implf )
# 2219 "src/parser/grammar.ml"
           in
          
# 473 "src/parser/grammar.mly"
                                          ( x )
# 2224 "src/parser/grammar.ml"
          
        in
        
# 438 "src/parser/grammar.mly"
                                   ( x )
# 2230 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 384 "src/parser/grammar.mly"
                                                  ( mkApp (loc _loc) [Const s;l;r] )
# 2239 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_058 =
    fun _endpos_r_ _startpos_l_ l r ->
      let s =
        let x =
          let x = 
# 468 "src/parser/grammar.mly"
         ( Func.sequentf )
# 2249 "src/parser/grammar.ml"
           in
          
# 473 "src/parser/grammar.mly"
                                          ( x )
# 2254 "src/parser/grammar.ml"
          
        in
        
# 438 "src/parser/grammar.mly"
                                   ( x )
# 2260 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 384 "src/parser/grammar.mly"
                                                  ( mkApp (loc _loc) [Const s;l;r] )
# 2269 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_059 =
    fun _endpos_r_ _startpos_l_ l r ->
      let s =
        let x =
          let x = 
# 469 "src/parser/grammar.mly"
         ( Func.from_string "/" )
# 2279 "src/parser/grammar.ml"
           in
          
# 473 "src/parser/grammar.mly"
                                          ( x )
# 2284 "src/parser/grammar.ml"
          
        in
        
# 438 "src/parser/grammar.mly"
                                   ( x )
# 2290 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 384 "src/parser/grammar.mly"
                                                  ( mkApp (loc _loc) [Const s;l;r] )
# 2299 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_060 =
    fun _endpos_r_ _startpos_l_ l r ->
      let s =
        let x =
          let x = 
# 470 "src/parser/grammar.mly"
         ( Func.andf )
# 2309 "src/parser/grammar.ml"
           in
          
# 473 "src/parser/grammar.mly"
                                          ( x )
# 2314 "src/parser/grammar.ml"
          
        in
        
# 438 "src/parser/grammar.mly"
                                   ( x )
# 2320 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 384 "src/parser/grammar.mly"
                                                  ( mkApp (loc _loc) [Const s;l;r] )
# 2329 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_061 =
    fun _endpos_r_ _startpos_l_ l r ->
      let s =
        let x = 
# 474 "src/parser/grammar.mly"
         ( Func.andf )
# 2338 "src/parser/grammar.ml"
         in
        
# 438 "src/parser/grammar.mly"
                                   ( x )
# 2343 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 384 "src/parser/grammar.mly"
                                                  ( mkApp (loc _loc) [Const s;l;r] )
# 2352 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_062 =
    fun r s ->
      let s =
        let x = 
# 485 "src/parser/grammar.mly"
                   ( Func.from_string s )
# 2361 "src/parser/grammar.ml"
         in
        
# 423 "src/parser/grammar.mly"
                        ( x )
# 2366 "src/parser/grammar.ml"
        
      in
      (
# 385 "src/parser/grammar.mly"
                       ( App(Const s,[r]) )
# 2372 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_063 =
    fun l s ->
      let s =
        let x = 
# 488 "src/parser/grammar.mly"
                   ( Func.from_string s )
# 2381 "src/parser/grammar.ml"
         in
        
# 426 "src/parser/grammar.mly"
                         ( x )
# 2386 "src/parser/grammar.ml"
        
      in
      (
# 386 "src/parser/grammar.mly"
                                   ( App(Const s,[l]) )
# 2392 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_064 =
    fun t ->
      (
# 371 "src/parser/grammar.mly"
                          ( t )
# 2400 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_065 =
    fun t ->
      (
# 372 "src/parser/grammar.mly"
                            ( t )
# 2408 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_066 =
    fun x ->
      (
# 316 "src/parser/grammar.mly"
              ( mkC (cint.Util.CData.cin x))
# 2416 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_067 =
    fun x ->
      (
# 317 "src/parser/grammar.mly"
            ( mkC (cfloat.Util.CData.cin x))
# 2424 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_068 =
    fun x ->
      (
# 318 "src/parser/grammar.mly"
             ( mkC (cstring.Util.CData.cin x))
# 2432 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_069 =
    fun _endpos_x_ _startpos_x_ x ->
      let _endpos = _endpos_x_ in
      let _startpos = _startpos_x_ in
      let _loc = (_startpos, _endpos) in
      (
# 319 "src/parser/grammar.mly"
             ( mkQuoted (loc _loc) x )
# 2443 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_070 =
    fun c t ->
      (
# 320 "src/parser/grammar.mly"
                                         ( App(mkCon "as",[t;c]) )
# 2451 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_071 =
    fun l ->
      (
# 321 "src/parser/grammar.mly"
                           ( mkSeq l )
# 2459 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_072 =
    fun l ->
      (
# 322 "src/parser/grammar.mly"
                                  (  mkSeq l )
# 2467 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_073 =
    fun t ->
      (
# 323 "src/parser/grammar.mly"
                           ( App (Const Func.spillf,[t]) )
# 2475 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_074 =
    fun t ->
      (
# 324 "src/parser/grammar.mly"
                ( t )
# 2483 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_075 =
    fun c ->
      (
# 389 "src/parser/grammar.mly"
               (
    if c = "nil" then Func.nilf
    else if c = "cons" then Func.consf
    else Func.from_string c )
# 2494 "src/parser/grammar.ml"
       : (Ast.Func.t))
  
  let _menhir_action_076 =
    fun () ->
      (
# 393 "src/parser/grammar.mly"
     ( Func.from_string "if" )
# 2502 "src/parser/grammar.ml"
       : (Ast.Func.t))
  
  let _menhir_action_077 =
    fun () ->
      (
# 394 "src/parser/grammar.mly"
       ( Func.from_string "name" )
# 2510 "src/parser/grammar.ml"
       : (Ast.Func.t))
  
  let _menhir_action_078 =
    fun () ->
      (
# 395 "src/parser/grammar.mly"
         ( Func.from_string "before" )
# 2518 "src/parser/grammar.ml"
       : (Ast.Func.t))
  
  let _menhir_action_079 =
    fun () ->
      (
# 396 "src/parser/grammar.mly"
        ( Func.from_string "after" )
# 2526 "src/parser/grammar.ml"
       : (Ast.Func.t))
  
  let _menhir_action_080 =
    fun () ->
      (
# 397 "src/parser/grammar.mly"
          ( Func.from_string "replace" )
# 2534 "src/parser/grammar.ml"
       : (Ast.Func.t))
  
  let _menhir_action_081 =
    fun () ->
      (
# 398 "src/parser/grammar.mly"
        ( Func.from_string "index" )
# 2542 "src/parser/grammar.ml"
       : (Ast.Func.t))
  
  let _menhir_action_082 =
    fun c ->
      (
# 399 "src/parser/grammar.mly"
         ( Func.from_string @@ String.make 1 c )
# 2550 "src/parser/grammar.ml"
       : (Ast.Func.t))
  
  let _menhir_action_083 =
    fun () ->
      (
# 400 "src/parser/grammar.mly"
      ( Func.cutf )
# 2558 "src/parser/grammar.ml"
       : (Ast.Func.t))
  
  let _menhir_action_084 =
    fun () ->
      (
# 401 "src/parser/grammar.mly"
     ( Func.pif )
# 2566 "src/parser/grammar.ml"
       : (Ast.Func.t))
  
  let _menhir_action_085 =
    fun () ->
      (
# 402 "src/parser/grammar.mly"
        ( Func.sigmaf )
# 2574 "src/parser/grammar.ml"
       : (Ast.Func.t))
  
  let _menhir_action_086 =
    fun () ->
      (
# 403 "src/parser/grammar.mly"
          ( Func.dummyname )
# 2582 "src/parser/grammar.ml"
       : (Ast.Func.t))
  
  let _menhir_action_087 =
    fun s ->
      (
# 404 "src/parser/grammar.mly"
                                  ( s )
# 2590 "src/parser/grammar.ml"
       : (Ast.Func.t))
  
  let _menhir_action_088 =
    fun () ->
      (
# 405 "src/parser/grammar.mly"
                      ( Func.from_string "as" )
# 2598 "src/parser/grammar.ml"
       : (Ast.Func.t))
  
  let _menhir_action_089 =
    fun () ->
      (
# 406 "src/parser/grammar.mly"
      ( Func.nilf )
# 2606 "src/parser/grammar.ml"
       : (Ast.Func.t))
  
  let _menhir_action_090 =
    fun c ->
      (
# 118 "src/parser/grammar.mly"
                       ( Program.Clause c )
# 2614 "src/parser/grammar.ml"
       : (Ast.Program.decl))
  
  let _menhir_action_091 =
    fun r ->
      (
# 119 "src/parser/grammar.mly"
                         ( Program.Chr r )
# 2622 "src/parser/grammar.ml"
       : (Ast.Program.decl))
  
  let _menhir_action_092 =
    fun p ->
      (
# 120 "src/parser/grammar.mly"
                     ( Program.Pred (snd p, fst p) )
# 2630 "src/parser/grammar.ml"
       : (Ast.Program.decl))
  
  let _menhir_action_093 =
    fun t ->
      (
# 121 "src/parser/grammar.mly"
                      ( Program.Type t )
# 2638 "src/parser/grammar.ml"
       : (Ast.Program.decl))
  
  let _menhir_action_094 =
    fun t ->
      (
# 122 "src/parser/grammar.mly"
                     ( Program.Type t )
# 2646 "src/parser/grammar.ml"
       : (Ast.Program.decl))
  
  let _menhir_action_095 =
    fun m ->
      (
# 123 "src/parser/grammar.mly"
                     ( Program.Mode [m] )
# 2654 "src/parser/grammar.ml"
       : (Ast.Program.decl))
  
  let _menhir_action_096 =
    fun m ->
      (
# 124 "src/parser/grammar.mly"
                      ( Program.Macro m )
# 2662 "src/parser/grammar.ml"
       : (Ast.Program.decl))
  
  let _menhir_action_097 =
    fun _endpos__3_ _startpos__1_ cl ->
      let _endpos = _endpos__3_ in
      let _symbolstartpos = _startpos__1_ in
      let _sloc = (_symbolstartpos, _endpos) in
      (
# 125 "src/parser/grammar.mly"
                                          ( Program.Constraint(loc _sloc, cl) )
# 2673 "src/parser/grammar.ml"
       : (Ast.Program.decl))
  
  let _menhir_action_098 =
    fun _endpos__3_ _startpos__1_ c ->
      let _endpos = _endpos__3_ in
      let _symbolstartpos = _startpos__1_ in
      let _sloc = (_symbolstartpos, _endpos) in
      (
# 126 "src/parser/grammar.mly"
                                  ( Program.Namespace(loc _sloc, c ))
# 2684 "src/parser/grammar.ml"
       : (Ast.Program.decl))
  
  let _menhir_action_099 =
    fun _endpos__3_ _startpos__1_ s ->
      let _endpos = _endpos__3_ in
      let _symbolstartpos = _startpos__1_ in
      let _sloc = (_symbolstartpos, _endpos) in
      (
# 127 "src/parser/grammar.mly"
                                 ( Program.Shorten(loc _sloc, s) )
# 2695 "src/parser/grammar.ml"
       : (Ast.Program.decl))
  
  let _menhir_action_100 =
    fun a ->
      (
# 128 "src/parser/grammar.mly"
                           ( Program.TypeAbbreviation a )
# 2703 "src/parser/grammar.ml"
       : (Ast.Program.decl))
  
  let _menhir_action_101 =
    fun _endpos__1_ _startpos__1_ ->
      let _endpos = _endpos__1_ in
      let _symbolstartpos = _startpos__1_ in
      let _sloc = (_symbolstartpos, _endpos) in
      (
# 129 "src/parser/grammar.mly"
         ( Program.Begin (loc _sloc) )
# 2714 "src/parser/grammar.ml"
       : (Ast.Program.decl))
  
  let _menhir_action_102 =
    fun _endpos__1_ _startpos__1_ ->
      let _endpos = _endpos__1_ in
      let _symbolstartpos = _startpos__1_ in
      let _sloc = (_symbolstartpos, _endpos) in
      (
# 130 "src/parser/grammar.mly"
         ( Program.End (loc _sloc) )
# 2725 "src/parser/grammar.ml"
       : (Ast.Program.decl))
  
  let _menhir_action_103 =
    fun _endpos__3_ _startpos_ext_ ext l ->
      let _endpos = _endpos__3_ in
      let _symbolstartpos = _startpos_ext_ in
      let _sloc = (_symbolstartpos, _endpos) in
      (
# 131 "src/parser/grammar.mly"
                                                                         (
    Program.Accumulated(loc _sloc,List.(concat (map (fun x ->
      let cwd = Filename.dirname (loc _sloc).source_name in
      C.parse_file ~cwd (x ^ ext)) l)))
  )
# 2740 "src/parser/grammar.ml"
       : (Ast.Program.decl))
  
  let _menhir_action_104 =
    fun l ->
      (
# 136 "src/parser/grammar.mly"
                                                                                 (
    Program.Local l
  )
# 2750 "src/parser/grammar.ml"
       : (Ast.Program.decl))
  
  let _menhir_action_105 =
    fun _endpos__2_ _startpos__1_ ->
      let _endpos = _endpos__2_ in
      let _symbolstartpos = _startpos__1_ in
      let _sloc = (_symbolstartpos, _endpos) in
      (
# 139 "src/parser/grammar.mly"
                    ( Program.Ignored (loc _sloc) )
# 2761 "src/parser/grammar.ml"
       : (Ast.Program.decl))
  
  let _menhir_action_106 =
    fun _endpos__2_ _startpos_f_ f ->
      let _endpos = _endpos__2_ in
      let _startpos = _startpos_f_ in
      let _loc = (_startpos, _endpos) in
      (
# 140 "src/parser/grammar.mly"
                       ( error_mixfix (loc _loc) )
# 2772 "src/parser/grammar.ml"
       : (Ast.Program.decl))
  
  let _menhir_action_107 =
    fun c ->
      (
# 149 "src/parser/grammar.mly"
               ( Func.show c )
# 2780 "src/parser/grammar.ml"
       : (string))
  
  let _menhir_action_108 =
    fun s ->
      (
# 150 "src/parser/grammar.mly"
             ( s )
# 2788 "src/parser/grammar.ml"
       : (string))
  
  let _menhir_action_109 =
    fun _endpos_c_ _startpos_c_ c f i ->
      let _loc_c_ = (_startpos_c_, _endpos_c_) in
      (
# 241 "src/parser/grammar.mly"
                                        ( (fixity_of_string f,c,i,loc _loc_c_) )
# 2797 "src/parser/grammar.ml"
       : (Elpi_lexer_config.Lexer_config.fixity * Ast.Func.t * int * Ast.Loc.t))
  
  let _menhir_action_110 =
    fun _endpos_c_ _startpos_c_ c f i ->
      let _loc_c_ = (_startpos_c_, _endpos_c_) in
      (
# 242 "src/parser/grammar.mly"
                                           ( (fixity_of_string f,c,i,loc _loc_c_) )
# 2806 "src/parser/grammar.ml"
       : (Elpi_lexer_config.Lexer_config.fixity * Ast.Func.t * int * Ast.Loc.t))
  
  let _menhir_action_111 =
    fun _endpos__2_ _startpos_g_ g ->
      let _endpos = _endpos__2_ in
      let _symbolstartpos = _startpos_g_ in
      let _sloc = (_symbolstartpos, _endpos) in
      (
# 270 "src/parser/grammar.mly"
                ( ( loc _sloc , g ) )
# 2817 "src/parser/grammar.ml"
       : (Ast.Goal.t))
  
  let _menhir_action_112 =
    fun _endpos__2_ _startpos_g_ g ->
      let _endpos = _endpos__2_ in
      let _symbolstartpos = _startpos_g_ in
      let _sloc = (_symbolstartpos, _endpos) in
      (
# 271 "src/parser/grammar.mly"
                     ( ( loc _sloc , g ) )
# 2828 "src/parser/grammar.ml"
       : (Ast.Goal.t))
  
  let _menhir_action_113 =
    fun t ->
      (
# 327 "src/parser/grammar.mly"
               ( Const t )
# 2836 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_114 =
    fun t ->
      (
# 328 "src/parser/grammar.mly"
                           ( t )
# 2844 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_115 =
    fun io ->
      (
# 204 "src/parser/grammar.mly"
          ( mode_of_IO io )
# 2852 "src/parser/grammar.ml"
       : (bool))
  
  let _menhir_action_116 =
    fun _endpos__2_ _startpos__1_ ->
      let _endpos = _endpos__2_ in
      let _symbolstartpos = _startpos__1_ in
      let _sloc = (_symbolstartpos, _endpos) in
      (
# 238 "src/parser/grammar.mly"
  ( Program.Ignored (loc _sloc) )
# 2863 "src/parser/grammar.ml"
       : (Ast.Program.decl))
  
  let _menhir_action_117 =
    fun _endpos__2_ _startpos__1_ ->
      let _endpos = _endpos__2_ in
      let _symbolstartpos = _startpos__1_ in
      let _sloc = (_symbolstartpos, _endpos) in
      (
# 238 "src/parser/grammar.mly"
  ( Program.Ignored (loc _sloc) )
# 2874 "src/parser/grammar.ml"
       : (Ast.Program.decl))
  
  let _menhir_action_118 =
    fun _endpos__2_ _startpos__1_ ->
      let _endpos = _endpos__2_ in
      let _symbolstartpos = _startpos__1_ in
      let _sloc = (_symbolstartpos, _endpos) in
      (
# 238 "src/parser/grammar.mly"
  ( Program.Ignored (loc _sloc) )
# 2885 "src/parser/grammar.ml"
       : (Ast.Program.decl))
  
  let _menhir_action_119 =
    fun _endpos__3_ _startpos__1_ ->
      let _endpos = _endpos__3_ in
      let _symbolstartpos = _startpos__1_ in
      let _sloc = (_symbolstartpos, _endpos) in
      (
# 238 "src/parser/grammar.mly"
  ( Program.Ignored (loc _sloc) )
# 2896 "src/parser/grammar.ml"
       : (Ast.Program.decl))
  
  let _menhir_action_120 =
    fun _endpos__2_ _startpos__1_ ->
      let _endpos = _endpos__2_ in
      let _symbolstartpos = _startpos__1_ in
      let _sloc = (_symbolstartpos, _endpos) in
      (
# 238 "src/parser/grammar.mly"
  ( Program.Ignored (loc _sloc) )
# 2907 "src/parser/grammar.ml"
       : (Ast.Program.decl))
  
  let _menhir_action_121 =
    fun _endpos__2_ _startpos__1_ ->
      let _endpos = _endpos__2_ in
      let _symbolstartpos = _startpos__1_ in
      let _sloc = (_symbolstartpos, _endpos) in
      (
# 238 "src/parser/grammar.mly"
  ( Program.Ignored (loc _sloc) )
# 2918 "src/parser/grammar.ml"
       : (Ast.Program.decl))
  
  let _menhir_action_122 =
    fun _endpos__3_ _startpos__1_ ->
      let _endpos = _endpos__3_ in
      let _symbolstartpos = _startpos__1_ in
      let _sloc = (_symbolstartpos, _endpos) in
      (
# 238 "src/parser/grammar.mly"
  ( Program.Ignored (loc _sloc) )
# 2929 "src/parser/grammar.ml"
       : (Ast.Program.decl))
  
  let _menhir_action_123 =
    fun _endpos__2_ _startpos__1_ ->
      let _endpos = _endpos__2_ in
      let _symbolstartpos = _startpos__1_ in
      let _sloc = (_symbolstartpos, _endpos) in
      (
# 238 "src/parser/grammar.mly"
  ( Program.Ignored (loc _sloc) )
# 2940 "src/parser/grammar.ml"
       : (Ast.Program.decl))
  
  let _menhir_action_124 =
    fun () ->
      (
# 302 "src/parser/grammar.mly"
          ( 0 )
# 2948 "src/parser/grammar.ml"
       : (int))
  
  let _menhir_action_125 =
    fun i ->
      (
# 303 "src/parser/grammar.mly"
              ( i )
# 2956 "src/parser/grammar.ml"
       : (int))
  
  let _menhir_action_126 =
    fun s ->
      let x =
        let x = 
# 441 "src/parser/grammar.mly"
                   ( Func.from_string s )
# 2965 "src/parser/grammar.ml"
         in
        
# 429 "src/parser/grammar.mly"
                       ( x )
# 2970 "src/parser/grammar.ml"
        
      in
      (
# 414 "src/parser/grammar.mly"
            ( x )
# 2976 "src/parser/grammar.ml"
       : (Ast.Func.t))
  
  let _menhir_action_127 =
    fun s ->
      let x =
        let x = 
# 442 "src/parser/grammar.mly"
                   ( Func.from_string s )
# 2985 "src/parser/grammar.ml"
         in
        
# 429 "src/parser/grammar.mly"
                       ( x )
# 2990 "src/parser/grammar.ml"
        
      in
      (
# 414 "src/parser/grammar.mly"
            ( x )
# 2996 "src/parser/grammar.ml"
       : (Ast.Func.t))
  
  let _menhir_action_128 =
    fun s ->
      let x =
        let x = 
# 443 "src/parser/grammar.mly"
                   ( Func.from_string s )
# 3005 "src/parser/grammar.ml"
         in
        
# 429 "src/parser/grammar.mly"
                       ( x )
# 3010 "src/parser/grammar.ml"
        
      in
      (
# 414 "src/parser/grammar.mly"
            ( x )
# 3016 "src/parser/grammar.ml"
       : (Ast.Func.t))
  
  let _menhir_action_129 =
    fun s ->
      let x =
        let x = 
# 444 "src/parser/grammar.mly"
                   ( Func.from_string s )
# 3025 "src/parser/grammar.ml"
         in
        
# 429 "src/parser/grammar.mly"
                       ( x )
# 3030 "src/parser/grammar.ml"
        
      in
      (
# 414 "src/parser/grammar.mly"
            ( x )
# 3036 "src/parser/grammar.ml"
       : (Ast.Func.t))
  
  let _menhir_action_130 =
    fun s ->
      let x =
        let x = 
# 445 "src/parser/grammar.mly"
                   ( Func.from_string s )
# 3045 "src/parser/grammar.ml"
         in
        
# 429 "src/parser/grammar.mly"
                       ( x )
# 3050 "src/parser/grammar.ml"
        
      in
      (
# 414 "src/parser/grammar.mly"
            ( x )
# 3056 "src/parser/grammar.ml"
       : (Ast.Func.t))
  
  let _menhir_action_131 =
    fun s ->
      let x =
        let x = 
# 446 "src/parser/grammar.mly"
                   ( Func.from_string s )
# 3065 "src/parser/grammar.ml"
         in
        
# 429 "src/parser/grammar.mly"
                       ( x )
# 3070 "src/parser/grammar.ml"
        
      in
      (
# 414 "src/parser/grammar.mly"
            ( x )
# 3076 "src/parser/grammar.ml"
       : (Ast.Func.t))
  
  let _menhir_action_132 =
    fun s ->
      let x =
        let x = 
# 447 "src/parser/grammar.mly"
                   ( Func.from_string s )
# 3085 "src/parser/grammar.ml"
         in
        
# 429 "src/parser/grammar.mly"
                       ( x )
# 3090 "src/parser/grammar.ml"
        
      in
      (
# 414 "src/parser/grammar.mly"
            ( x )
# 3096 "src/parser/grammar.ml"
       : (Ast.Func.t))
  
  let _menhir_action_133 =
    fun s ->
      let x =
        let x = 
# 448 "src/parser/grammar.mly"
                   ( Func.from_string s )
# 3105 "src/parser/grammar.ml"
         in
        
# 429 "src/parser/grammar.mly"
                       ( x )
# 3110 "src/parser/grammar.ml"
        
      in
      (
# 414 "src/parser/grammar.mly"
            ( x )
# 3116 "src/parser/grammar.ml"
       : (Ast.Func.t))
  
  let _menhir_action_134 =
    fun s ->
      let x =
        let x = 
# 449 "src/parser/grammar.mly"
                  ( Func.from_string s )
# 3125 "src/parser/grammar.ml"
         in
        
# 429 "src/parser/grammar.mly"
                       ( x )
# 3130 "src/parser/grammar.ml"
        
      in
      (
# 414 "src/parser/grammar.mly"
            ( x )
# 3136 "src/parser/grammar.ml"
       : (Ast.Func.t))
  
  let _menhir_action_135 =
    fun s ->
      let x =
        let x = 
# 450 "src/parser/grammar.mly"
                   ( Func.from_string s )
# 3145 "src/parser/grammar.ml"
         in
        
# 429 "src/parser/grammar.mly"
                       ( x )
# 3150 "src/parser/grammar.ml"
        
      in
      (
# 414 "src/parser/grammar.mly"
            ( x )
# 3156 "src/parser/grammar.ml"
       : (Ast.Func.t))
  
  let _menhir_action_136 =
    fun s ->
      let x =
        let x = 
# 451 "src/parser/grammar.mly"
                   ( Func.from_string s )
# 3165 "src/parser/grammar.ml"
         in
        
# 429 "src/parser/grammar.mly"
                       ( x )
# 3170 "src/parser/grammar.ml"
        
      in
      (
# 414 "src/parser/grammar.mly"
            ( x )
# 3176 "src/parser/grammar.ml"
       : (Ast.Func.t))
  
  let _menhir_action_137 =
    fun s ->
      let x =
        let x = 
# 452 "src/parser/grammar.mly"
                   ( Func.from_string s )
# 3185 "src/parser/grammar.ml"
         in
        
# 429 "src/parser/grammar.mly"
                       ( x )
# 3190 "src/parser/grammar.ml"
        
      in
      (
# 414 "src/parser/grammar.mly"
            ( x )
# 3196 "src/parser/grammar.ml"
       : (Ast.Func.t))
  
  let _menhir_action_138 =
    fun () ->
      let x =
        let x =
          let x =
            let x = 
# 455 "src/parser/grammar.mly"
         ( Func.consf )
# 3207 "src/parser/grammar.ml"
             in
            
# 473 "src/parser/grammar.mly"
                                          ( x )
# 3212 "src/parser/grammar.ml"
            
          in
          
# 481 "src/parser/grammar.mly"
                                   ( x )
# 3218 "src/parser/grammar.ml"
          
        in
        
# 430 "src/parser/grammar.mly"
                           ( x )
# 3224 "src/parser/grammar.ml"
        
      in
      (
# 414 "src/parser/grammar.mly"
            ( x )
# 3230 "src/parser/grammar.ml"
       : (Ast.Func.t))
  
  let _menhir_action_139 =
    fun () ->
      let x =
        let x =
          let x =
            let x = 
# 456 "src/parser/grammar.mly"
         ( Func.eqf )
# 3241 "src/parser/grammar.ml"
             in
            
# 473 "src/parser/grammar.mly"
                                          ( x )
# 3246 "src/parser/grammar.ml"
            
          in
          
# 481 "src/parser/grammar.mly"
                                   ( x )
# 3252 "src/parser/grammar.ml"
          
        in
        
# 430 "src/parser/grammar.mly"
                           ( x )
# 3258 "src/parser/grammar.ml"
        
      in
      (
# 414 "src/parser/grammar.mly"
            ( x )
# 3264 "src/parser/grammar.ml"
       : (Ast.Func.t))
  
  let _menhir_action_140 =
    fun () ->
      let x =
        let x =
          let x =
            let x = 
# 457 "src/parser/grammar.mly"
         ( Func.from_string "-" )
# 3275 "src/parser/grammar.ml"
             in
            
# 473 "src/parser/grammar.mly"
                                          ( x )
# 3280 "src/parser/grammar.ml"
            
          in
          
# 481 "src/parser/grammar.mly"
                                   ( x )
# 3286 "src/parser/grammar.ml"
          
        in
        
# 430 "src/parser/grammar.mly"
                           ( x )
# 3292 "src/parser/grammar.ml"
        
      in
      (
# 414 "src/parser/grammar.mly"
            ( x )
# 3298 "src/parser/grammar.ml"
       : (Ast.Func.t))
  
  let _menhir_action_141 =
    fun () ->
      let x =
        let x =
          let x =
            let x = 
# 458 "src/parser/grammar.mly"
         ( Func.from_string "r-" )
# 3309 "src/parser/grammar.ml"
             in
            
# 473 "src/parser/grammar.mly"
                                          ( x )
# 3314 "src/parser/grammar.ml"
            
          in
          
# 481 "src/parser/grammar.mly"
                                   ( x )
# 3320 "src/parser/grammar.ml"
          
        in
        
# 430 "src/parser/grammar.mly"
                           ( x )
# 3326 "src/parser/grammar.ml"
        
      in
      (
# 414 "src/parser/grammar.mly"
            ( x )
# 3332 "src/parser/grammar.ml"
       : (Ast.Func.t))
  
  let _menhir_action_142 =
    fun () ->
      let x =
        let x =
          let x =
            let x = 
# 459 "src/parser/grammar.mly"
         ( Func.from_string "i-" )
# 3343 "src/parser/grammar.ml"
             in
            
# 473 "src/parser/grammar.mly"
                                          ( x )
# 3348 "src/parser/grammar.ml"
            
          in
          
# 481 "src/parser/grammar.mly"
                                   ( x )
# 3354 "src/parser/grammar.ml"
          
        in
        
# 430 "src/parser/grammar.mly"
                           ( x )
# 3360 "src/parser/grammar.ml"
        
      in
      (
# 414 "src/parser/grammar.mly"
            ( x )
# 3366 "src/parser/grammar.ml"
       : (Ast.Func.t))
  
  let _menhir_action_143 =
    fun () ->
      let x =
        let x =
          let x =
            let x = 
# 460 "src/parser/grammar.mly"
         ( Func.from_string "s-" )
# 3377 "src/parser/grammar.ml"
             in
            
# 473 "src/parser/grammar.mly"
                                          ( x )
# 3382 "src/parser/grammar.ml"
            
          in
          
# 481 "src/parser/grammar.mly"
                                   ( x )
# 3388 "src/parser/grammar.ml"
          
        in
        
# 430 "src/parser/grammar.mly"
                           ( x )
# 3394 "src/parser/grammar.ml"
        
      in
      (
# 414 "src/parser/grammar.mly"
            ( x )
# 3400 "src/parser/grammar.ml"
       : (Ast.Func.t))
  
  let _menhir_action_144 =
    fun () ->
      let x =
        let x =
          let x =
            let x = 
# 461 "src/parser/grammar.mly"
         ( Func.from_string "==" )
# 3411 "src/parser/grammar.ml"
             in
            
# 473 "src/parser/grammar.mly"
                                          ( x )
# 3416 "src/parser/grammar.ml"
            
          in
          
# 481 "src/parser/grammar.mly"
                                   ( x )
# 3422 "src/parser/grammar.ml"
          
        in
        
# 430 "src/parser/grammar.mly"
                           ( x )
# 3428 "src/parser/grammar.ml"
        
      in
      (
# 414 "src/parser/grammar.mly"
            ( x )
# 3434 "src/parser/grammar.ml"
       : (Ast.Func.t))
  
  let _menhir_action_145 =
    fun () ->
      let x =
        let x =
          let x =
            let x = 
# 462 "src/parser/grammar.mly"
         ( Func.orf )
# 3445 "src/parser/grammar.ml"
             in
            
# 473 "src/parser/grammar.mly"
                                          ( x )
# 3450 "src/parser/grammar.ml"
            
          in
          
# 481 "src/parser/grammar.mly"
                                   ( x )
# 3456 "src/parser/grammar.ml"
          
        in
        
# 430 "src/parser/grammar.mly"
                           ( x )
# 3462 "src/parser/grammar.ml"
        
      in
      (
# 414 "src/parser/grammar.mly"
            ( x )
# 3468 "src/parser/grammar.ml"
       : (Ast.Func.t))
  
  let _menhir_action_146 =
    fun () ->
      let x =
        let x =
          let x =
            let x = 
# 463 "src/parser/grammar.mly"
         ( Func.isf )
# 3479 "src/parser/grammar.ml"
             in
            
# 473 "src/parser/grammar.mly"
                                          ( x )
# 3484 "src/parser/grammar.ml"
            
          in
          
# 481 "src/parser/grammar.mly"
                                   ( x )
# 3490 "src/parser/grammar.ml"
          
        in
        
# 430 "src/parser/grammar.mly"
                           ( x )
# 3496 "src/parser/grammar.ml"
        
      in
      (
# 414 "src/parser/grammar.mly"
            ( x )
# 3502 "src/parser/grammar.ml"
       : (Ast.Func.t))
  
  let _menhir_action_147 =
    fun () ->
      let x =
        let x =
          let x =
            let x = 
# 464 "src/parser/grammar.mly"
         ( Func.from_string "mod" )
# 3513 "src/parser/grammar.ml"
             in
            
# 473 "src/parser/grammar.mly"
                                          ( x )
# 3518 "src/parser/grammar.ml"
            
          in
          
# 481 "src/parser/grammar.mly"
                                   ( x )
# 3524 "src/parser/grammar.ml"
          
        in
        
# 430 "src/parser/grammar.mly"
                           ( x )
# 3530 "src/parser/grammar.ml"
        
      in
      (
# 414 "src/parser/grammar.mly"
            ( x )
# 3536 "src/parser/grammar.ml"
       : (Ast.Func.t))
  
  let _menhir_action_148 =
    fun () ->
      let x =
        let x =
          let x =
            let x = 
# 465 "src/parser/grammar.mly"
         ( Func.from_string "div" )
# 3547 "src/parser/grammar.ml"
             in
            
# 473 "src/parser/grammar.mly"
                                          ( x )
# 3552 "src/parser/grammar.ml"
            
          in
          
# 481 "src/parser/grammar.mly"
                                   ( x )
# 3558 "src/parser/grammar.ml"
          
        in
        
# 430 "src/parser/grammar.mly"
                           ( x )
# 3564 "src/parser/grammar.ml"
        
      in
      (
# 414 "src/parser/grammar.mly"
            ( x )
# 3570 "src/parser/grammar.ml"
       : (Ast.Func.t))
  
  let _menhir_action_149 =
    fun () ->
      let x =
        let x =
          let x =
            let x = 
# 466 "src/parser/grammar.mly"
         ( Func.arrowf )
# 3581 "src/parser/grammar.ml"
             in
            
# 473 "src/parser/grammar.mly"
                                          ( x )
# 3586 "src/parser/grammar.ml"
            
          in
          
# 481 "src/parser/grammar.mly"
                                   ( x )
# 3592 "src/parser/grammar.ml"
          
        in
        
# 430 "src/parser/grammar.mly"
                           ( x )
# 3598 "src/parser/grammar.ml"
        
      in
      (
# 414 "src/parser/grammar.mly"
            ( x )
# 3604 "src/parser/grammar.ml"
       : (Ast.Func.t))
  
  let _menhir_action_150 =
    fun () ->
      let x =
        let x =
          let x =
            let x = 
# 467 "src/parser/grammar.mly"
         ( Func.implf )
# 3615 "src/parser/grammar.ml"
             in
            
# 473 "src/parser/grammar.mly"
                                          ( x )
# 3620 "src/parser/grammar.ml"
            
          in
          
# 481 "src/parser/grammar.mly"
                                   ( x )
# 3626 "src/parser/grammar.ml"
          
        in
        
# 430 "src/parser/grammar.mly"
                           ( x )
# 3632 "src/parser/grammar.ml"
        
      in
      (
# 414 "src/parser/grammar.mly"
            ( x )
# 3638 "src/parser/grammar.ml"
       : (Ast.Func.t))
  
  let _menhir_action_151 =
    fun () ->
      let x =
        let x =
          let x =
            let x = 
# 468 "src/parser/grammar.mly"
         ( Func.sequentf )
# 3649 "src/parser/grammar.ml"
             in
            
# 473 "src/parser/grammar.mly"
                                          ( x )
# 3654 "src/parser/grammar.ml"
            
          in
          
# 481 "src/parser/grammar.mly"
                                   ( x )
# 3660 "src/parser/grammar.ml"
          
        in
        
# 430 "src/parser/grammar.mly"
                           ( x )
# 3666 "src/parser/grammar.ml"
        
      in
      (
# 414 "src/parser/grammar.mly"
            ( x )
# 3672 "src/parser/grammar.ml"
       : (Ast.Func.t))
  
  let _menhir_action_152 =
    fun () ->
      let x =
        let x =
          let x =
            let x = 
# 469 "src/parser/grammar.mly"
         ( Func.from_string "/" )
# 3683 "src/parser/grammar.ml"
             in
            
# 473 "src/parser/grammar.mly"
                                          ( x )
# 3688 "src/parser/grammar.ml"
            
          in
          
# 481 "src/parser/grammar.mly"
                                   ( x )
# 3694 "src/parser/grammar.ml"
          
        in
        
# 430 "src/parser/grammar.mly"
                           ( x )
# 3700 "src/parser/grammar.ml"
        
      in
      (
# 414 "src/parser/grammar.mly"
            ( x )
# 3706 "src/parser/grammar.ml"
       : (Ast.Func.t))
  
  let _menhir_action_153 =
    fun () ->
      let x =
        let x =
          let x =
            let x = 
# 470 "src/parser/grammar.mly"
         ( Func.andf )
# 3717 "src/parser/grammar.ml"
             in
            
# 473 "src/parser/grammar.mly"
                                          ( x )
# 3722 "src/parser/grammar.ml"
            
          in
          
# 481 "src/parser/grammar.mly"
                                   ( x )
# 3728 "src/parser/grammar.ml"
          
        in
        
# 430 "src/parser/grammar.mly"
                           ( x )
# 3734 "src/parser/grammar.ml"
        
      in
      (
# 414 "src/parser/grammar.mly"
            ( x )
# 3740 "src/parser/grammar.ml"
       : (Ast.Func.t))
  
  let _menhir_action_154 =
    fun () ->
      let x =
        let x =
          let x = 
# 474 "src/parser/grammar.mly"
         ( Func.andf )
# 3750 "src/parser/grammar.ml"
           in
          
# 481 "src/parser/grammar.mly"
                                   ( x )
# 3755 "src/parser/grammar.ml"
          
        in
        
# 430 "src/parser/grammar.mly"
                           ( x )
# 3761 "src/parser/grammar.ml"
        
      in
      (
# 414 "src/parser/grammar.mly"
            ( x )
# 3767 "src/parser/grammar.ml"
       : (Ast.Func.t))
  
  let _menhir_action_155 =
    fun () ->
      let x =
        let x = 
# 482 "src/parser/grammar.mly"
         ( Func.rimplf )
# 3776 "src/parser/grammar.ml"
         in
        
# 430 "src/parser/grammar.mly"
                           ( x )
# 3781 "src/parser/grammar.ml"
        
      in
      (
# 414 "src/parser/grammar.mly"
            ( x )
# 3787 "src/parser/grammar.ml"
       : (Ast.Func.t))
  
  let _menhir_action_156 =
    fun _endpos_k_ _startpos__1_ k names ->
      let _endpos = _endpos_k_ in
      let _symbolstartpos = _startpos__1_ in
      let _sloc = (_symbolstartpos, _endpos) in
      (
# 174 "src/parser/grammar.mly"
                                                                      (
    names |> List.map (fun n->
     { Type.loc=loc _sloc; attributes=[]; name =  n; ty = k })
  )
# 3801 "src/parser/grammar.ml"
       : (Ast.raw_attribute list Ast.Type.t list))
  
  let _menhir_action_157 =
    fun () ->
      (
# 196 "src/parser/grammar.mly"
       ( mkCon "type" )
# 3809 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_158 =
    fun _endpos_hd_ _startpos_hd_ hd t ->
      let _loc_hd_ = (_startpos_hd_, _endpos_hd_) in
      (
# 197 "src/parser/grammar.mly"
                                  ( mkApp (loc _loc_hd_) [mkCon "->"; mkCon "type"; t] )
# 3818 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_159 =
    fun () ->
      (
# 208 "<standard.mly>"
    ( [] )
# 3826 "src/parser/grammar.ml"
       : (Ast.Func.t list))
  
  let _menhir_action_160 =
    fun x xs ->
      (
# 210 "<standard.mly>"
    ( x :: xs )
# 3834 "src/parser/grammar.ml"
       : (Ast.Func.t list))
  
  let _menhir_action_161 =
    fun () ->
      (
# 208 "<standard.mly>"
    ( [] )
# 3842 "src/parser/grammar.ml"
       : (Ast.Chr.sequent list))
  
  let _menhir_action_162 =
    fun x xs ->
      (
# 210 "<standard.mly>"
    ( x :: xs )
# 3850 "src/parser/grammar.ml"
       : (Ast.Chr.sequent list))
  
  let _menhir_action_163 =
    fun () ->
      (
# 331 "src/parser/grammar.mly"
           ( [mkNil] )
# 3858 "src/parser/grammar.ml"
       : (Ast.Term.t list))
  
  let _menhir_action_164 =
    fun x ->
      (
# 332 "src/parser/grammar.mly"
                            ( [x;mkNil] )
# 3866 "src/parser/grammar.ml"
       : (Ast.Term.t list))
  
  let _menhir_action_165 =
    fun x xs ->
      (
# 333 "src/parser/grammar.mly"
                                         ( x :: xs )
# 3874 "src/parser/grammar.ml"
       : (Ast.Term.t list))
  
  let _menhir_action_166 =
    fun x ->
      (
# 336 "src/parser/grammar.mly"
                                  ( [x] )
# 3882 "src/parser/grammar.ml"
       : (Ast.Term.t list))
  
  let _menhir_action_167 =
    fun x xs ->
      (
# 337 "src/parser/grammar.mly"
                                                    ( [x;xs] )
# 3890 "src/parser/grammar.ml"
       : (Ast.Term.t list))
  
  let _menhir_action_168 =
    fun x xs ->
      (
# 338 "src/parser/grammar.mly"
                                              ( x :: xs )
# 3898 "src/parser/grammar.ml"
       : (Ast.Term.t list))
  
  let _menhir_action_169 =
    fun () ->
      (
# 139 "<standard.mly>"
    ( [] )
# 3906 "src/parser/grammar.ml"
       : ((bool * Ast.Term.t) list))
  
  let _menhir_action_170 =
    fun x ->
      (
# 141 "<standard.mly>"
    ( x )
# 3914 "src/parser/grammar.ml"
       : ((bool * Ast.Term.t) list))
  
  let _menhir_action_171 =
    fun _endpos_b_ _startpos__1_ b m ->
      let _endpos = _endpos_b_ in
      let _symbolstartpos = _startpos__1_ in
      let _sloc = (_symbolstartpos, _endpos) in
      (
# 207 "src/parser/grammar.mly"
                                   (
  let name, body = desugar_macro (loc _sloc) m b in
  { Macro.loc = loc _sloc; name; body }
)
# 3928 "src/parser/grammar.ml"
       : ((Ast.Func.t, Ast.Term.t) Ast.Macro.t))
  
  let _menhir_action_172 =
    fun s ->
      let x =
        let x = 
# 441 "src/parser/grammar.mly"
                   ( Func.from_string s )
# 3937 "src/parser/grammar.ml"
         in
        
# 429 "src/parser/grammar.mly"
                       ( x )
# 3942 "src/parser/grammar.ml"
        
      in
      (
# 409 "src/parser/grammar.mly"
            ( x )
# 3948 "src/parser/grammar.ml"
       : (Ast.Func.t))
  
  let _menhir_action_173 =
    fun s ->
      let x =
        let x = 
# 442 "src/parser/grammar.mly"
                   ( Func.from_string s )
# 3957 "src/parser/grammar.ml"
         in
        
# 429 "src/parser/grammar.mly"
                       ( x )
# 3962 "src/parser/grammar.ml"
        
      in
      (
# 409 "src/parser/grammar.mly"
            ( x )
# 3968 "src/parser/grammar.ml"
       : (Ast.Func.t))
  
  let _menhir_action_174 =
    fun s ->
      let x =
        let x = 
# 443 "src/parser/grammar.mly"
                   ( Func.from_string s )
# 3977 "src/parser/grammar.ml"
         in
        
# 429 "src/parser/grammar.mly"
                       ( x )
# 3982 "src/parser/grammar.ml"
        
      in
      (
# 409 "src/parser/grammar.mly"
            ( x )
# 3988 "src/parser/grammar.ml"
       : (Ast.Func.t))
  
  let _menhir_action_175 =
    fun s ->
      let x =
        let x = 
# 444 "src/parser/grammar.mly"
                   ( Func.from_string s )
# 3997 "src/parser/grammar.ml"
         in
        
# 429 "src/parser/grammar.mly"
                       ( x )
# 4002 "src/parser/grammar.ml"
        
      in
      (
# 409 "src/parser/grammar.mly"
            ( x )
# 4008 "src/parser/grammar.ml"
       : (Ast.Func.t))
  
  let _menhir_action_176 =
    fun s ->
      let x =
        let x = 
# 445 "src/parser/grammar.mly"
                   ( Func.from_string s )
# 4017 "src/parser/grammar.ml"
         in
        
# 429 "src/parser/grammar.mly"
                       ( x )
# 4022 "src/parser/grammar.ml"
        
      in
      (
# 409 "src/parser/grammar.mly"
            ( x )
# 4028 "src/parser/grammar.ml"
       : (Ast.Func.t))
  
  let _menhir_action_177 =
    fun s ->
      let x =
        let x = 
# 446 "src/parser/grammar.mly"
                   ( Func.from_string s )
# 4037 "src/parser/grammar.ml"
         in
        
# 429 "src/parser/grammar.mly"
                       ( x )
# 4042 "src/parser/grammar.ml"
        
      in
      (
# 409 "src/parser/grammar.mly"
            ( x )
# 4048 "src/parser/grammar.ml"
       : (Ast.Func.t))
  
  let _menhir_action_178 =
    fun s ->
      let x =
        let x = 
# 447 "src/parser/grammar.mly"
                   ( Func.from_string s )
# 4057 "src/parser/grammar.ml"
         in
        
# 429 "src/parser/grammar.mly"
                       ( x )
# 4062 "src/parser/grammar.ml"
        
      in
      (
# 409 "src/parser/grammar.mly"
            ( x )
# 4068 "src/parser/grammar.ml"
       : (Ast.Func.t))
  
  let _menhir_action_179 =
    fun s ->
      let x =
        let x = 
# 448 "src/parser/grammar.mly"
                   ( Func.from_string s )
# 4077 "src/parser/grammar.ml"
         in
        
# 429 "src/parser/grammar.mly"
                       ( x )
# 4082 "src/parser/grammar.ml"
        
      in
      (
# 409 "src/parser/grammar.mly"
            ( x )
# 4088 "src/parser/grammar.ml"
       : (Ast.Func.t))
  
  let _menhir_action_180 =
    fun s ->
      let x =
        let x = 
# 449 "src/parser/grammar.mly"
                  ( Func.from_string s )
# 4097 "src/parser/grammar.ml"
         in
        
# 429 "src/parser/grammar.mly"
                       ( x )
# 4102 "src/parser/grammar.ml"
        
      in
      (
# 409 "src/parser/grammar.mly"
            ( x )
# 4108 "src/parser/grammar.ml"
       : (Ast.Func.t))
  
  let _menhir_action_181 =
    fun s ->
      let x =
        let x = 
# 450 "src/parser/grammar.mly"
                   ( Func.from_string s )
# 4117 "src/parser/grammar.ml"
         in
        
# 429 "src/parser/grammar.mly"
                       ( x )
# 4122 "src/parser/grammar.ml"
        
      in
      (
# 409 "src/parser/grammar.mly"
            ( x )
# 4128 "src/parser/grammar.ml"
       : (Ast.Func.t))
  
  let _menhir_action_182 =
    fun s ->
      let x =
        let x = 
# 451 "src/parser/grammar.mly"
                   ( Func.from_string s )
# 4137 "src/parser/grammar.ml"
         in
        
# 429 "src/parser/grammar.mly"
                       ( x )
# 4142 "src/parser/grammar.ml"
        
      in
      (
# 409 "src/parser/grammar.mly"
            ( x )
# 4148 "src/parser/grammar.ml"
       : (Ast.Func.t))
  
  let _menhir_action_183 =
    fun s ->
      let x =
        let x = 
# 452 "src/parser/grammar.mly"
                   ( Func.from_string s )
# 4157 "src/parser/grammar.ml"
         in
        
# 429 "src/parser/grammar.mly"
                       ( x )
# 4162 "src/parser/grammar.ml"
        
      in
      (
# 409 "src/parser/grammar.mly"
            ( x )
# 4168 "src/parser/grammar.ml"
       : (Ast.Func.t))
  
  let _menhir_action_184 =
    fun () ->
      let x =
        let x =
          let x =
            let x = 
# 455 "src/parser/grammar.mly"
         ( Func.consf )
# 4179 "src/parser/grammar.ml"
             in
            
# 473 "src/parser/grammar.mly"
                                          ( x )
# 4184 "src/parser/grammar.ml"
            
          in
          
# 481 "src/parser/grammar.mly"
                                   ( x )
# 4190 "src/parser/grammar.ml"
          
        in
        
# 430 "src/parser/grammar.mly"
                           ( x )
# 4196 "src/parser/grammar.ml"
        
      in
      (
# 409 "src/parser/grammar.mly"
            ( x )
# 4202 "src/parser/grammar.ml"
       : (Ast.Func.t))
  
  let _menhir_action_185 =
    fun () ->
      let x =
        let x =
          let x =
            let x = 
# 456 "src/parser/grammar.mly"
         ( Func.eqf )
# 4213 "src/parser/grammar.ml"
             in
            
# 473 "src/parser/grammar.mly"
                                          ( x )
# 4218 "src/parser/grammar.ml"
            
          in
          
# 481 "src/parser/grammar.mly"
                                   ( x )
# 4224 "src/parser/grammar.ml"
          
        in
        
# 430 "src/parser/grammar.mly"
                           ( x )
# 4230 "src/parser/grammar.ml"
        
      in
      (
# 409 "src/parser/grammar.mly"
            ( x )
# 4236 "src/parser/grammar.ml"
       : (Ast.Func.t))
  
  let _menhir_action_186 =
    fun () ->
      let x =
        let x =
          let x =
            let x = 
# 457 "src/parser/grammar.mly"
         ( Func.from_string "-" )
# 4247 "src/parser/grammar.ml"
             in
            
# 473 "src/parser/grammar.mly"
                                          ( x )
# 4252 "src/parser/grammar.ml"
            
          in
          
# 481 "src/parser/grammar.mly"
                                   ( x )
# 4258 "src/parser/grammar.ml"
          
        in
        
# 430 "src/parser/grammar.mly"
                           ( x )
# 4264 "src/parser/grammar.ml"
        
      in
      (
# 409 "src/parser/grammar.mly"
            ( x )
# 4270 "src/parser/grammar.ml"
       : (Ast.Func.t))
  
  let _menhir_action_187 =
    fun () ->
      let x =
        let x =
          let x =
            let x = 
# 458 "src/parser/grammar.mly"
         ( Func.from_string "r-" )
# 4281 "src/parser/grammar.ml"
             in
            
# 473 "src/parser/grammar.mly"
                                          ( x )
# 4286 "src/parser/grammar.ml"
            
          in
          
# 481 "src/parser/grammar.mly"
                                   ( x )
# 4292 "src/parser/grammar.ml"
          
        in
        
# 430 "src/parser/grammar.mly"
                           ( x )
# 4298 "src/parser/grammar.ml"
        
      in
      (
# 409 "src/parser/grammar.mly"
            ( x )
# 4304 "src/parser/grammar.ml"
       : (Ast.Func.t))
  
  let _menhir_action_188 =
    fun () ->
      let x =
        let x =
          let x =
            let x = 
# 459 "src/parser/grammar.mly"
         ( Func.from_string "i-" )
# 4315 "src/parser/grammar.ml"
             in
            
# 473 "src/parser/grammar.mly"
                                          ( x )
# 4320 "src/parser/grammar.ml"
            
          in
          
# 481 "src/parser/grammar.mly"
                                   ( x )
# 4326 "src/parser/grammar.ml"
          
        in
        
# 430 "src/parser/grammar.mly"
                           ( x )
# 4332 "src/parser/grammar.ml"
        
      in
      (
# 409 "src/parser/grammar.mly"
            ( x )
# 4338 "src/parser/grammar.ml"
       : (Ast.Func.t))
  
  let _menhir_action_189 =
    fun () ->
      let x =
        let x =
          let x =
            let x = 
# 460 "src/parser/grammar.mly"
         ( Func.from_string "s-" )
# 4349 "src/parser/grammar.ml"
             in
            
# 473 "src/parser/grammar.mly"
                                          ( x )
# 4354 "src/parser/grammar.ml"
            
          in
          
# 481 "src/parser/grammar.mly"
                                   ( x )
# 4360 "src/parser/grammar.ml"
          
        in
        
# 430 "src/parser/grammar.mly"
                           ( x )
# 4366 "src/parser/grammar.ml"
        
      in
      (
# 409 "src/parser/grammar.mly"
            ( x )
# 4372 "src/parser/grammar.ml"
       : (Ast.Func.t))
  
  let _menhir_action_190 =
    fun () ->
      let x =
        let x =
          let x =
            let x = 
# 461 "src/parser/grammar.mly"
         ( Func.from_string "==" )
# 4383 "src/parser/grammar.ml"
             in
            
# 473 "src/parser/grammar.mly"
                                          ( x )
# 4388 "src/parser/grammar.ml"
            
          in
          
# 481 "src/parser/grammar.mly"
                                   ( x )
# 4394 "src/parser/grammar.ml"
          
        in
        
# 430 "src/parser/grammar.mly"
                           ( x )
# 4400 "src/parser/grammar.ml"
        
      in
      (
# 409 "src/parser/grammar.mly"
            ( x )
# 4406 "src/parser/grammar.ml"
       : (Ast.Func.t))
  
  let _menhir_action_191 =
    fun () ->
      let x =
        let x =
          let x =
            let x = 
# 462 "src/parser/grammar.mly"
         ( Func.orf )
# 4417 "src/parser/grammar.ml"
             in
            
# 473 "src/parser/grammar.mly"
                                          ( x )
# 4422 "src/parser/grammar.ml"
            
          in
          
# 481 "src/parser/grammar.mly"
                                   ( x )
# 4428 "src/parser/grammar.ml"
          
        in
        
# 430 "src/parser/grammar.mly"
                           ( x )
# 4434 "src/parser/grammar.ml"
        
      in
      (
# 409 "src/parser/grammar.mly"
            ( x )
# 4440 "src/parser/grammar.ml"
       : (Ast.Func.t))
  
  let _menhir_action_192 =
    fun () ->
      let x =
        let x =
          let x =
            let x = 
# 463 "src/parser/grammar.mly"
         ( Func.isf )
# 4451 "src/parser/grammar.ml"
             in
            
# 473 "src/parser/grammar.mly"
                                          ( x )
# 4456 "src/parser/grammar.ml"
            
          in
          
# 481 "src/parser/grammar.mly"
                                   ( x )
# 4462 "src/parser/grammar.ml"
          
        in
        
# 430 "src/parser/grammar.mly"
                           ( x )
# 4468 "src/parser/grammar.ml"
        
      in
      (
# 409 "src/parser/grammar.mly"
            ( x )
# 4474 "src/parser/grammar.ml"
       : (Ast.Func.t))
  
  let _menhir_action_193 =
    fun () ->
      let x =
        let x =
          let x =
            let x = 
# 464 "src/parser/grammar.mly"
         ( Func.from_string "mod" )
# 4485 "src/parser/grammar.ml"
             in
            
# 473 "src/parser/grammar.mly"
                                          ( x )
# 4490 "src/parser/grammar.ml"
            
          in
          
# 481 "src/parser/grammar.mly"
                                   ( x )
# 4496 "src/parser/grammar.ml"
          
        in
        
# 430 "src/parser/grammar.mly"
                           ( x )
# 4502 "src/parser/grammar.ml"
        
      in
      (
# 409 "src/parser/grammar.mly"
            ( x )
# 4508 "src/parser/grammar.ml"
       : (Ast.Func.t))
  
  let _menhir_action_194 =
    fun () ->
      let x =
        let x =
          let x =
            let x = 
# 465 "src/parser/grammar.mly"
         ( Func.from_string "div" )
# 4519 "src/parser/grammar.ml"
             in
            
# 473 "src/parser/grammar.mly"
                                          ( x )
# 4524 "src/parser/grammar.ml"
            
          in
          
# 481 "src/parser/grammar.mly"
                                   ( x )
# 4530 "src/parser/grammar.ml"
          
        in
        
# 430 "src/parser/grammar.mly"
                           ( x )
# 4536 "src/parser/grammar.ml"
        
      in
      (
# 409 "src/parser/grammar.mly"
            ( x )
# 4542 "src/parser/grammar.ml"
       : (Ast.Func.t))
  
  let _menhir_action_195 =
    fun () ->
      let x =
        let x =
          let x =
            let x = 
# 466 "src/parser/grammar.mly"
         ( Func.arrowf )
# 4553 "src/parser/grammar.ml"
             in
            
# 473 "src/parser/grammar.mly"
                                          ( x )
# 4558 "src/parser/grammar.ml"
            
          in
          
# 481 "src/parser/grammar.mly"
                                   ( x )
# 4564 "src/parser/grammar.ml"
          
        in
        
# 430 "src/parser/grammar.mly"
                           ( x )
# 4570 "src/parser/grammar.ml"
        
      in
      (
# 409 "src/parser/grammar.mly"
            ( x )
# 4576 "src/parser/grammar.ml"
       : (Ast.Func.t))
  
  let _menhir_action_196 =
    fun () ->
      let x =
        let x =
          let x =
            let x = 
# 467 "src/parser/grammar.mly"
         ( Func.implf )
# 4587 "src/parser/grammar.ml"
             in
            
# 473 "src/parser/grammar.mly"
                                          ( x )
# 4592 "src/parser/grammar.ml"
            
          in
          
# 481 "src/parser/grammar.mly"
                                   ( x )
# 4598 "src/parser/grammar.ml"
          
        in
        
# 430 "src/parser/grammar.mly"
                           ( x )
# 4604 "src/parser/grammar.ml"
        
      in
      (
# 409 "src/parser/grammar.mly"
            ( x )
# 4610 "src/parser/grammar.ml"
       : (Ast.Func.t))
  
  let _menhir_action_197 =
    fun () ->
      let x =
        let x =
          let x =
            let x = 
# 468 "src/parser/grammar.mly"
         ( Func.sequentf )
# 4621 "src/parser/grammar.ml"
             in
            
# 473 "src/parser/grammar.mly"
                                          ( x )
# 4626 "src/parser/grammar.ml"
            
          in
          
# 481 "src/parser/grammar.mly"
                                   ( x )
# 4632 "src/parser/grammar.ml"
          
        in
        
# 430 "src/parser/grammar.mly"
                           ( x )
# 4638 "src/parser/grammar.ml"
        
      in
      (
# 409 "src/parser/grammar.mly"
            ( x )
# 4644 "src/parser/grammar.ml"
       : (Ast.Func.t))
  
  let _menhir_action_198 =
    fun () ->
      let x =
        let x =
          let x =
            let x = 
# 469 "src/parser/grammar.mly"
         ( Func.from_string "/" )
# 4655 "src/parser/grammar.ml"
             in
            
# 473 "src/parser/grammar.mly"
                                          ( x )
# 4660 "src/parser/grammar.ml"
            
          in
          
# 481 "src/parser/grammar.mly"
                                   ( x )
# 4666 "src/parser/grammar.ml"
          
        in
        
# 430 "src/parser/grammar.mly"
                           ( x )
# 4672 "src/parser/grammar.ml"
        
      in
      (
# 409 "src/parser/grammar.mly"
            ( x )
# 4678 "src/parser/grammar.ml"
       : (Ast.Func.t))
  
  let _menhir_action_199 =
    fun () ->
      let x =
        let x =
          let x =
            let x = 
# 470 "src/parser/grammar.mly"
         ( Func.andf )
# 4689 "src/parser/grammar.ml"
             in
            
# 473 "src/parser/grammar.mly"
                                          ( x )
# 4694 "src/parser/grammar.ml"
            
          in
          
# 481 "src/parser/grammar.mly"
                                   ( x )
# 4700 "src/parser/grammar.ml"
          
        in
        
# 430 "src/parser/grammar.mly"
                           ( x )
# 4706 "src/parser/grammar.ml"
        
      in
      (
# 409 "src/parser/grammar.mly"
            ( x )
# 4712 "src/parser/grammar.ml"
       : (Ast.Func.t))
  
  let _menhir_action_200 =
    fun () ->
      let x =
        let x =
          let x = 
# 474 "src/parser/grammar.mly"
         ( Func.andf )
# 4722 "src/parser/grammar.ml"
           in
          
# 481 "src/parser/grammar.mly"
                                   ( x )
# 4727 "src/parser/grammar.ml"
          
        in
        
# 430 "src/parser/grammar.mly"
                           ( x )
# 4733 "src/parser/grammar.ml"
        
      in
      (
# 409 "src/parser/grammar.mly"
            ( x )
# 4739 "src/parser/grammar.ml"
       : (Ast.Func.t))
  
  let _menhir_action_201 =
    fun () ->
      let x =
        let x = 
# 482 "src/parser/grammar.mly"
         ( Func.rimplf )
# 4748 "src/parser/grammar.ml"
         in
        
# 430 "src/parser/grammar.mly"
                           ( x )
# 4753 "src/parser/grammar.ml"
        
      in
      (
# 409 "src/parser/grammar.mly"
            ( x )
# 4759 "src/parser/grammar.ml"
       : (Ast.Func.t))
  
  let _menhir_action_202 =
    fun s ->
      let x =
        let x = 
# 485 "src/parser/grammar.mly"
                   ( Func.from_string s )
# 4768 "src/parser/grammar.ml"
         in
        
# 423 "src/parser/grammar.mly"
                        ( x )
# 4773 "src/parser/grammar.ml"
        
      in
      (
# 410 "src/parser/grammar.mly"
             ( x )
# 4779 "src/parser/grammar.ml"
       : (Ast.Func.t))
  
  let _menhir_action_203 =
    fun s ->
      let x =
        let x = 
# 488 "src/parser/grammar.mly"
                   ( Func.from_string s )
# 4788 "src/parser/grammar.ml"
         in
        
# 426 "src/parser/grammar.mly"
                         ( x )
# 4793 "src/parser/grammar.ml"
        
      in
      (
# 411 "src/parser/grammar.mly"
              ( x )
# 4799 "src/parser/grammar.ml"
       : (Ast.Func.t))
  
  let _menhir_action_204 =
    fun _endpos__5_ _startpos__1_ c l ->
      let _endpos = _endpos__5_ in
      let _symbolstartpos = _startpos__1_ in
      let _sloc = (_symbolstartpos, _endpos) in
      (
# 200 "src/parser/grammar.mly"
                                                             (
    { Mode.name = c; args = l; loc = loc _sloc } 
)
# 4812 "src/parser/grammar.ml"
       : (Ast.Func.t Ast.Mode.t))
  
  let _menhir_action_205 =
    fun x ->
      (
# 218 "<standard.mly>"
    ( [ x ] )
# 4820 "src/parser/grammar.ml"
       : (Ast.Term.t list))
  
  let _menhir_action_206 =
    fun x xs ->
      (
# 220 "<standard.mly>"
    ( x :: xs )
# 4828 "src/parser/grammar.ml"
       : (Ast.Term.t list))
  
  let _menhir_action_207 =
    fun x ->
      (
# 218 "<standard.mly>"
    ( [ x ] )
# 4836 "src/parser/grammar.ml"
       : (Ast.Term.t list))
  
  let _menhir_action_208 =
    fun x xs ->
      (
# 220 "<standard.mly>"
    ( x :: xs )
# 4844 "src/parser/grammar.ml"
       : (Ast.Term.t list))
  
  let _menhir_action_209 =
    fun x ->
      (
# 218 "<standard.mly>"
    ( [ x ] )
# 4852 "src/parser/grammar.ml"
       : (Ast.Func.t list))
  
  let _menhir_action_210 =
    fun x xs ->
      (
# 220 "<standard.mly>"
    ( x :: xs )
# 4860 "src/parser/grammar.ml"
       : (Ast.Func.t list))
  
  let _menhir_action_211 =
    fun x ->
      (
# 218 "<standard.mly>"
    ( [ x ] )
# 4868 "src/parser/grammar.ml"
       : (bool list))
  
  let _menhir_action_212 =
    fun x xs ->
      (
# 220 "<standard.mly>"
    ( x :: xs )
# 4876 "src/parser/grammar.ml"
       : (bool list))
  
  let _menhir_action_213 =
    fun x ->
      (
# 218 "<standard.mly>"
    ( [ x ] )
# 4884 "src/parser/grammar.ml"
       : (int list))
  
  let _menhir_action_214 =
    fun x xs ->
      (
# 220 "<standard.mly>"
    ( x :: xs )
# 4892 "src/parser/grammar.ml"
       : (int list))
  
  let _menhir_action_215 =
    fun x ->
      (
# 218 "<standard.mly>"
    ( [ x ] )
# 4900 "src/parser/grammar.ml"
       : (Ast.Chr.sequent list))
  
  let _menhir_action_216 =
    fun x xs ->
      (
# 220 "<standard.mly>"
    ( x :: xs )
# 4908 "src/parser/grammar.ml"
       : (Ast.Chr.sequent list))
  
  let _menhir_action_217 =
    fun _endpos_hd_ _startpos_hd_ args b hd ->
      let _loc_hd_ = (_startpos_hd_, _endpos_hd_) in
      (
# 350 "src/parser/grammar.mly"
                                                                             (
    let args = binder args b in
    let t = mkApp (loc _loc_hd_) (hd :: args) in
    desugar_multi_binder (loc _loc_hd_) t
)
# 4921 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_218 =
    fun _endpos_r_ _startpos_l_ l r s ->
      let s =
        let x = 
# 441 "src/parser/grammar.mly"
                   ( Func.from_string s )
# 4930 "src/parser/grammar.ml"
         in
        
# 429 "src/parser/grammar.mly"
                       ( x )
# 4935 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 355 "src/parser/grammar.mly"
                                 ( mkApp (loc _loc) [Const s;l;r] )
# 4944 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_219 =
    fun _endpos_r_ _startpos_l_ l r s ->
      let s =
        let x = 
# 442 "src/parser/grammar.mly"
                   ( Func.from_string s )
# 4953 "src/parser/grammar.ml"
         in
        
# 429 "src/parser/grammar.mly"
                       ( x )
# 4958 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 355 "src/parser/grammar.mly"
                                 ( mkApp (loc _loc) [Const s;l;r] )
# 4967 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_220 =
    fun _endpos_r_ _startpos_l_ l r s ->
      let s =
        let x = 
# 443 "src/parser/grammar.mly"
                   ( Func.from_string s )
# 4976 "src/parser/grammar.ml"
         in
        
# 429 "src/parser/grammar.mly"
                       ( x )
# 4981 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 355 "src/parser/grammar.mly"
                                 ( mkApp (loc _loc) [Const s;l;r] )
# 4990 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_221 =
    fun _endpos_r_ _startpos_l_ l r s ->
      let s =
        let x = 
# 444 "src/parser/grammar.mly"
                   ( Func.from_string s )
# 4999 "src/parser/grammar.ml"
         in
        
# 429 "src/parser/grammar.mly"
                       ( x )
# 5004 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 355 "src/parser/grammar.mly"
                                 ( mkApp (loc _loc) [Const s;l;r] )
# 5013 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_222 =
    fun _endpos_r_ _startpos_l_ l r s ->
      let s =
        let x = 
# 445 "src/parser/grammar.mly"
                   ( Func.from_string s )
# 5022 "src/parser/grammar.ml"
         in
        
# 429 "src/parser/grammar.mly"
                       ( x )
# 5027 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 355 "src/parser/grammar.mly"
                                 ( mkApp (loc _loc) [Const s;l;r] )
# 5036 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_223 =
    fun _endpos_r_ _startpos_l_ l r s ->
      let s =
        let x = 
# 446 "src/parser/grammar.mly"
                   ( Func.from_string s )
# 5045 "src/parser/grammar.ml"
         in
        
# 429 "src/parser/grammar.mly"
                       ( x )
# 5050 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 355 "src/parser/grammar.mly"
                                 ( mkApp (loc _loc) [Const s;l;r] )
# 5059 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_224 =
    fun _endpos_r_ _startpos_l_ l r s ->
      let s =
        let x = 
# 447 "src/parser/grammar.mly"
                   ( Func.from_string s )
# 5068 "src/parser/grammar.ml"
         in
        
# 429 "src/parser/grammar.mly"
                       ( x )
# 5073 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 355 "src/parser/grammar.mly"
                                 ( mkApp (loc _loc) [Const s;l;r] )
# 5082 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_225 =
    fun _endpos_r_ _startpos_l_ l r s ->
      let s =
        let x = 
# 448 "src/parser/grammar.mly"
                   ( Func.from_string s )
# 5091 "src/parser/grammar.ml"
         in
        
# 429 "src/parser/grammar.mly"
                       ( x )
# 5096 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 355 "src/parser/grammar.mly"
                                 ( mkApp (loc _loc) [Const s;l;r] )
# 5105 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_226 =
    fun _endpos_r_ _startpos_l_ l r s ->
      let s =
        let x = 
# 449 "src/parser/grammar.mly"
                  ( Func.from_string s )
# 5114 "src/parser/grammar.ml"
         in
        
# 429 "src/parser/grammar.mly"
                       ( x )
# 5119 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 355 "src/parser/grammar.mly"
                                 ( mkApp (loc _loc) [Const s;l;r] )
# 5128 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_227 =
    fun _endpos_r_ _startpos_l_ l r s ->
      let s =
        let x = 
# 450 "src/parser/grammar.mly"
                   ( Func.from_string s )
# 5137 "src/parser/grammar.ml"
         in
        
# 429 "src/parser/grammar.mly"
                       ( x )
# 5142 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 355 "src/parser/grammar.mly"
                                 ( mkApp (loc _loc) [Const s;l;r] )
# 5151 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_228 =
    fun _endpos_r_ _startpos_l_ l r s ->
      let s =
        let x = 
# 451 "src/parser/grammar.mly"
                   ( Func.from_string s )
# 5160 "src/parser/grammar.ml"
         in
        
# 429 "src/parser/grammar.mly"
                       ( x )
# 5165 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 355 "src/parser/grammar.mly"
                                 ( mkApp (loc _loc) [Const s;l;r] )
# 5174 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_229 =
    fun _endpos_r_ _startpos_l_ l r s ->
      let s =
        let x = 
# 452 "src/parser/grammar.mly"
                   ( Func.from_string s )
# 5183 "src/parser/grammar.ml"
         in
        
# 429 "src/parser/grammar.mly"
                       ( x )
# 5188 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 355 "src/parser/grammar.mly"
                                 ( mkApp (loc _loc) [Const s;l;r] )
# 5197 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_230 =
    fun _endpos_r_ _startpos_l_ l r ->
      let s =
        let x =
          let x =
            let x = 
# 455 "src/parser/grammar.mly"
         ( Func.consf )
# 5208 "src/parser/grammar.ml"
             in
            
# 473 "src/parser/grammar.mly"
                                          ( x )
# 5213 "src/parser/grammar.ml"
            
          in
          
# 481 "src/parser/grammar.mly"
                                   ( x )
# 5219 "src/parser/grammar.ml"
          
        in
        
# 430 "src/parser/grammar.mly"
                           ( x )
# 5225 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 355 "src/parser/grammar.mly"
                                 ( mkApp (loc _loc) [Const s;l;r] )
# 5234 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_231 =
    fun _endpos_r_ _startpos_l_ l r ->
      let s =
        let x =
          let x =
            let x = 
# 456 "src/parser/grammar.mly"
         ( Func.eqf )
# 5245 "src/parser/grammar.ml"
             in
            
# 473 "src/parser/grammar.mly"
                                          ( x )
# 5250 "src/parser/grammar.ml"
            
          in
          
# 481 "src/parser/grammar.mly"
                                   ( x )
# 5256 "src/parser/grammar.ml"
          
        in
        
# 430 "src/parser/grammar.mly"
                           ( x )
# 5262 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 355 "src/parser/grammar.mly"
                                 ( mkApp (loc _loc) [Const s;l;r] )
# 5271 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_232 =
    fun _endpos_r_ _startpos_l_ l r ->
      let s =
        let x =
          let x =
            let x = 
# 457 "src/parser/grammar.mly"
         ( Func.from_string "-" )
# 5282 "src/parser/grammar.ml"
             in
            
# 473 "src/parser/grammar.mly"
                                          ( x )
# 5287 "src/parser/grammar.ml"
            
          in
          
# 481 "src/parser/grammar.mly"
                                   ( x )
# 5293 "src/parser/grammar.ml"
          
        in
        
# 430 "src/parser/grammar.mly"
                           ( x )
# 5299 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 355 "src/parser/grammar.mly"
                                 ( mkApp (loc _loc) [Const s;l;r] )
# 5308 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_233 =
    fun _endpos_r_ _startpos_l_ l r ->
      let s =
        let x =
          let x =
            let x = 
# 458 "src/parser/grammar.mly"
         ( Func.from_string "r-" )
# 5319 "src/parser/grammar.ml"
             in
            
# 473 "src/parser/grammar.mly"
                                          ( x )
# 5324 "src/parser/grammar.ml"
            
          in
          
# 481 "src/parser/grammar.mly"
                                   ( x )
# 5330 "src/parser/grammar.ml"
          
        in
        
# 430 "src/parser/grammar.mly"
                           ( x )
# 5336 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 355 "src/parser/grammar.mly"
                                 ( mkApp (loc _loc) [Const s;l;r] )
# 5345 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_234 =
    fun _endpos_r_ _startpos_l_ l r ->
      let s =
        let x =
          let x =
            let x = 
# 459 "src/parser/grammar.mly"
         ( Func.from_string "i-" )
# 5356 "src/parser/grammar.ml"
             in
            
# 473 "src/parser/grammar.mly"
                                          ( x )
# 5361 "src/parser/grammar.ml"
            
          in
          
# 481 "src/parser/grammar.mly"
                                   ( x )
# 5367 "src/parser/grammar.ml"
          
        in
        
# 430 "src/parser/grammar.mly"
                           ( x )
# 5373 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 355 "src/parser/grammar.mly"
                                 ( mkApp (loc _loc) [Const s;l;r] )
# 5382 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_235 =
    fun _endpos_r_ _startpos_l_ l r ->
      let s =
        let x =
          let x =
            let x = 
# 460 "src/parser/grammar.mly"
         ( Func.from_string "s-" )
# 5393 "src/parser/grammar.ml"
             in
            
# 473 "src/parser/grammar.mly"
                                          ( x )
# 5398 "src/parser/grammar.ml"
            
          in
          
# 481 "src/parser/grammar.mly"
                                   ( x )
# 5404 "src/parser/grammar.ml"
          
        in
        
# 430 "src/parser/grammar.mly"
                           ( x )
# 5410 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 355 "src/parser/grammar.mly"
                                 ( mkApp (loc _loc) [Const s;l;r] )
# 5419 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_236 =
    fun _endpos_r_ _startpos_l_ l r ->
      let s =
        let x =
          let x =
            let x = 
# 461 "src/parser/grammar.mly"
         ( Func.from_string "==" )
# 5430 "src/parser/grammar.ml"
             in
            
# 473 "src/parser/grammar.mly"
                                          ( x )
# 5435 "src/parser/grammar.ml"
            
          in
          
# 481 "src/parser/grammar.mly"
                                   ( x )
# 5441 "src/parser/grammar.ml"
          
        in
        
# 430 "src/parser/grammar.mly"
                           ( x )
# 5447 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 355 "src/parser/grammar.mly"
                                 ( mkApp (loc _loc) [Const s;l;r] )
# 5456 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_237 =
    fun _endpos_r_ _startpos_l_ l r ->
      let s =
        let x =
          let x =
            let x = 
# 462 "src/parser/grammar.mly"
         ( Func.orf )
# 5467 "src/parser/grammar.ml"
             in
            
# 473 "src/parser/grammar.mly"
                                          ( x )
# 5472 "src/parser/grammar.ml"
            
          in
          
# 481 "src/parser/grammar.mly"
                                   ( x )
# 5478 "src/parser/grammar.ml"
          
        in
        
# 430 "src/parser/grammar.mly"
                           ( x )
# 5484 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 355 "src/parser/grammar.mly"
                                 ( mkApp (loc _loc) [Const s;l;r] )
# 5493 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_238 =
    fun _endpos_r_ _startpos_l_ l r ->
      let s =
        let x =
          let x =
            let x = 
# 463 "src/parser/grammar.mly"
         ( Func.isf )
# 5504 "src/parser/grammar.ml"
             in
            
# 473 "src/parser/grammar.mly"
                                          ( x )
# 5509 "src/parser/grammar.ml"
            
          in
          
# 481 "src/parser/grammar.mly"
                                   ( x )
# 5515 "src/parser/grammar.ml"
          
        in
        
# 430 "src/parser/grammar.mly"
                           ( x )
# 5521 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 355 "src/parser/grammar.mly"
                                 ( mkApp (loc _loc) [Const s;l;r] )
# 5530 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_239 =
    fun _endpos_r_ _startpos_l_ l r ->
      let s =
        let x =
          let x =
            let x = 
# 464 "src/parser/grammar.mly"
         ( Func.from_string "mod" )
# 5541 "src/parser/grammar.ml"
             in
            
# 473 "src/parser/grammar.mly"
                                          ( x )
# 5546 "src/parser/grammar.ml"
            
          in
          
# 481 "src/parser/grammar.mly"
                                   ( x )
# 5552 "src/parser/grammar.ml"
          
        in
        
# 430 "src/parser/grammar.mly"
                           ( x )
# 5558 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 355 "src/parser/grammar.mly"
                                 ( mkApp (loc _loc) [Const s;l;r] )
# 5567 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_240 =
    fun _endpos_r_ _startpos_l_ l r ->
      let s =
        let x =
          let x =
            let x = 
# 465 "src/parser/grammar.mly"
         ( Func.from_string "div" )
# 5578 "src/parser/grammar.ml"
             in
            
# 473 "src/parser/grammar.mly"
                                          ( x )
# 5583 "src/parser/grammar.ml"
            
          in
          
# 481 "src/parser/grammar.mly"
                                   ( x )
# 5589 "src/parser/grammar.ml"
          
        in
        
# 430 "src/parser/grammar.mly"
                           ( x )
# 5595 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 355 "src/parser/grammar.mly"
                                 ( mkApp (loc _loc) [Const s;l;r] )
# 5604 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_241 =
    fun _endpos_r_ _startpos_l_ l r ->
      let s =
        let x =
          let x =
            let x = 
# 466 "src/parser/grammar.mly"
         ( Func.arrowf )
# 5615 "src/parser/grammar.ml"
             in
            
# 473 "src/parser/grammar.mly"
                                          ( x )
# 5620 "src/parser/grammar.ml"
            
          in
          
# 481 "src/parser/grammar.mly"
                                   ( x )
# 5626 "src/parser/grammar.ml"
          
        in
        
# 430 "src/parser/grammar.mly"
                           ( x )
# 5632 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 355 "src/parser/grammar.mly"
                                 ( mkApp (loc _loc) [Const s;l;r] )
# 5641 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_242 =
    fun _endpos_r_ _startpos_l_ l r ->
      let s =
        let x =
          let x =
            let x = 
# 467 "src/parser/grammar.mly"
         ( Func.implf )
# 5652 "src/parser/grammar.ml"
             in
            
# 473 "src/parser/grammar.mly"
                                          ( x )
# 5657 "src/parser/grammar.ml"
            
          in
          
# 481 "src/parser/grammar.mly"
                                   ( x )
# 5663 "src/parser/grammar.ml"
          
        in
        
# 430 "src/parser/grammar.mly"
                           ( x )
# 5669 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 355 "src/parser/grammar.mly"
                                 ( mkApp (loc _loc) [Const s;l;r] )
# 5678 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_243 =
    fun _endpos_r_ _startpos_l_ l r ->
      let s =
        let x =
          let x =
            let x = 
# 468 "src/parser/grammar.mly"
         ( Func.sequentf )
# 5689 "src/parser/grammar.ml"
             in
            
# 473 "src/parser/grammar.mly"
                                          ( x )
# 5694 "src/parser/grammar.ml"
            
          in
          
# 481 "src/parser/grammar.mly"
                                   ( x )
# 5700 "src/parser/grammar.ml"
          
        in
        
# 430 "src/parser/grammar.mly"
                           ( x )
# 5706 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 355 "src/parser/grammar.mly"
                                 ( mkApp (loc _loc) [Const s;l;r] )
# 5715 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_244 =
    fun _endpos_r_ _startpos_l_ l r ->
      let s =
        let x =
          let x =
            let x = 
# 469 "src/parser/grammar.mly"
         ( Func.from_string "/" )
# 5726 "src/parser/grammar.ml"
             in
            
# 473 "src/parser/grammar.mly"
                                          ( x )
# 5731 "src/parser/grammar.ml"
            
          in
          
# 481 "src/parser/grammar.mly"
                                   ( x )
# 5737 "src/parser/grammar.ml"
          
        in
        
# 430 "src/parser/grammar.mly"
                           ( x )
# 5743 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 355 "src/parser/grammar.mly"
                                 ( mkApp (loc _loc) [Const s;l;r] )
# 5752 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_245 =
    fun _endpos_r_ _startpos_l_ l r ->
      let s =
        let x =
          let x =
            let x = 
# 470 "src/parser/grammar.mly"
         ( Func.andf )
# 5763 "src/parser/grammar.ml"
             in
            
# 473 "src/parser/grammar.mly"
                                          ( x )
# 5768 "src/parser/grammar.ml"
            
          in
          
# 481 "src/parser/grammar.mly"
                                   ( x )
# 5774 "src/parser/grammar.ml"
          
        in
        
# 430 "src/parser/grammar.mly"
                           ( x )
# 5780 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 355 "src/parser/grammar.mly"
                                 ( mkApp (loc _loc) [Const s;l;r] )
# 5789 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_246 =
    fun _endpos_r_ _startpos_l_ l r ->
      let s =
        let x =
          let x = 
# 474 "src/parser/grammar.mly"
         ( Func.andf )
# 5799 "src/parser/grammar.ml"
           in
          
# 481 "src/parser/grammar.mly"
                                   ( x )
# 5804 "src/parser/grammar.ml"
          
        in
        
# 430 "src/parser/grammar.mly"
                           ( x )
# 5810 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 355 "src/parser/grammar.mly"
                                 ( mkApp (loc _loc) [Const s;l;r] )
# 5819 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_247 =
    fun _endpos_r_ _startpos_l_ l r ->
      let s =
        let x = 
# 482 "src/parser/grammar.mly"
         ( Func.rimplf )
# 5828 "src/parser/grammar.ml"
         in
        
# 430 "src/parser/grammar.mly"
                           ( x )
# 5833 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 355 "src/parser/grammar.mly"
                                 ( mkApp (loc _loc) [Const s;l;r] )
# 5842 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_248 =
    fun r s ->
      let s =
        let x = 
# 485 "src/parser/grammar.mly"
                   ( Func.from_string s )
# 5851 "src/parser/grammar.ml"
         in
        
# 423 "src/parser/grammar.mly"
                        ( x )
# 5856 "src/parser/grammar.ml"
        
      in
      (
# 356 "src/parser/grammar.mly"
                       ( App(Const s,[r]) )
# 5862 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_249 =
    fun l s ->
      let s =
        let x = 
# 488 "src/parser/grammar.mly"
                   ( Func.from_string s )
# 5871 "src/parser/grammar.ml"
         in
        
# 426 "src/parser/grammar.mly"
                         ( x )
# 5876 "src/parser/grammar.ml"
        
      in
      (
# 357 "src/parser/grammar.mly"
                         ( App(Const s,[l]) )
# 5882 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_250 =
    fun _endpos_hd_ _startpos_hd_ args b hd ->
      let _loc_hd_ = (_startpos_hd_, _endpos_hd_) in
      (
# 360 "src/parser/grammar.mly"
                                                                             (
    let args = binder args b in
    let t = mkApp (loc _loc_hd_) (hd :: args) in
    desugar_multi_binder (loc _loc_hd_) t
)
# 5895 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_251 =
    fun _endpos_r_ _startpos_l_ l r s ->
      let s =
        let x = 
# 441 "src/parser/grammar.mly"
                   ( Func.from_string s )
# 5904 "src/parser/grammar.ml"
         in
        
# 433 "src/parser/grammar.mly"
                       ( x )
# 5909 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 365 "src/parser/grammar.mly"
                                                      ( mkApp (loc _loc) [Const s;l;r] )
# 5918 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_252 =
    fun _endpos_r_ _startpos_l_ l r s ->
      let s =
        let x = 
# 442 "src/parser/grammar.mly"
                   ( Func.from_string s )
# 5927 "src/parser/grammar.ml"
         in
        
# 433 "src/parser/grammar.mly"
                       ( x )
# 5932 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 365 "src/parser/grammar.mly"
                                                      ( mkApp (loc _loc) [Const s;l;r] )
# 5941 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_253 =
    fun _endpos_r_ _startpos_l_ l r s ->
      let s =
        let x = 
# 443 "src/parser/grammar.mly"
                   ( Func.from_string s )
# 5950 "src/parser/grammar.ml"
         in
        
# 433 "src/parser/grammar.mly"
                       ( x )
# 5955 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 365 "src/parser/grammar.mly"
                                                      ( mkApp (loc _loc) [Const s;l;r] )
# 5964 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_254 =
    fun _endpos_r_ _startpos_l_ l r s ->
      let s =
        let x = 
# 444 "src/parser/grammar.mly"
                   ( Func.from_string s )
# 5973 "src/parser/grammar.ml"
         in
        
# 433 "src/parser/grammar.mly"
                       ( x )
# 5978 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 365 "src/parser/grammar.mly"
                                                      ( mkApp (loc _loc) [Const s;l;r] )
# 5987 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_255 =
    fun _endpos_r_ _startpos_l_ l r s ->
      let s =
        let x = 
# 445 "src/parser/grammar.mly"
                   ( Func.from_string s )
# 5996 "src/parser/grammar.ml"
         in
        
# 433 "src/parser/grammar.mly"
                       ( x )
# 6001 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 365 "src/parser/grammar.mly"
                                                      ( mkApp (loc _loc) [Const s;l;r] )
# 6010 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_256 =
    fun _endpos_r_ _startpos_l_ l r s ->
      let s =
        let x = 
# 446 "src/parser/grammar.mly"
                   ( Func.from_string s )
# 6019 "src/parser/grammar.ml"
         in
        
# 433 "src/parser/grammar.mly"
                       ( x )
# 6024 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 365 "src/parser/grammar.mly"
                                                      ( mkApp (loc _loc) [Const s;l;r] )
# 6033 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_257 =
    fun _endpos_r_ _startpos_l_ l r s ->
      let s =
        let x = 
# 447 "src/parser/grammar.mly"
                   ( Func.from_string s )
# 6042 "src/parser/grammar.ml"
         in
        
# 433 "src/parser/grammar.mly"
                       ( x )
# 6047 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 365 "src/parser/grammar.mly"
                                                      ( mkApp (loc _loc) [Const s;l;r] )
# 6056 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_258 =
    fun _endpos_r_ _startpos_l_ l r s ->
      let s =
        let x = 
# 448 "src/parser/grammar.mly"
                   ( Func.from_string s )
# 6065 "src/parser/grammar.ml"
         in
        
# 433 "src/parser/grammar.mly"
                       ( x )
# 6070 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 365 "src/parser/grammar.mly"
                                                      ( mkApp (loc _loc) [Const s;l;r] )
# 6079 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_259 =
    fun _endpos_r_ _startpos_l_ l r s ->
      let s =
        let x = 
# 449 "src/parser/grammar.mly"
                  ( Func.from_string s )
# 6088 "src/parser/grammar.ml"
         in
        
# 433 "src/parser/grammar.mly"
                       ( x )
# 6093 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 365 "src/parser/grammar.mly"
                                                      ( mkApp (loc _loc) [Const s;l;r] )
# 6102 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_260 =
    fun _endpos_r_ _startpos_l_ l r s ->
      let s =
        let x = 
# 450 "src/parser/grammar.mly"
                   ( Func.from_string s )
# 6111 "src/parser/grammar.ml"
         in
        
# 433 "src/parser/grammar.mly"
                       ( x )
# 6116 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 365 "src/parser/grammar.mly"
                                                      ( mkApp (loc _loc) [Const s;l;r] )
# 6125 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_261 =
    fun _endpos_r_ _startpos_l_ l r s ->
      let s =
        let x = 
# 451 "src/parser/grammar.mly"
                   ( Func.from_string s )
# 6134 "src/parser/grammar.ml"
         in
        
# 433 "src/parser/grammar.mly"
                       ( x )
# 6139 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 365 "src/parser/grammar.mly"
                                                      ( mkApp (loc _loc) [Const s;l;r] )
# 6148 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_262 =
    fun _endpos_r_ _startpos_l_ l r s ->
      let s =
        let x = 
# 452 "src/parser/grammar.mly"
                   ( Func.from_string s )
# 6157 "src/parser/grammar.ml"
         in
        
# 433 "src/parser/grammar.mly"
                       ( x )
# 6162 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 365 "src/parser/grammar.mly"
                                                      ( mkApp (loc _loc) [Const s;l;r] )
# 6171 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_263 =
    fun _endpos_r_ _startpos_l_ l r ->
      let s =
        let x =
          let x = 
# 455 "src/parser/grammar.mly"
         ( Func.consf )
# 6181 "src/parser/grammar.ml"
           in
          
# 477 "src/parser/grammar.mly"
                                          ( x )
# 6186 "src/parser/grammar.ml"
          
        in
        
# 434 "src/parser/grammar.mly"
                                  ( x )
# 6192 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 365 "src/parser/grammar.mly"
                                                      ( mkApp (loc _loc) [Const s;l;r] )
# 6201 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_264 =
    fun _endpos_r_ _startpos_l_ l r ->
      let s =
        let x =
          let x = 
# 456 "src/parser/grammar.mly"
         ( Func.eqf )
# 6211 "src/parser/grammar.ml"
           in
          
# 477 "src/parser/grammar.mly"
                                          ( x )
# 6216 "src/parser/grammar.ml"
          
        in
        
# 434 "src/parser/grammar.mly"
                                  ( x )
# 6222 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 365 "src/parser/grammar.mly"
                                                      ( mkApp (loc _loc) [Const s;l;r] )
# 6231 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_265 =
    fun _endpos_r_ _startpos_l_ l r ->
      let s =
        let x =
          let x = 
# 457 "src/parser/grammar.mly"
         ( Func.from_string "-" )
# 6241 "src/parser/grammar.ml"
           in
          
# 477 "src/parser/grammar.mly"
                                          ( x )
# 6246 "src/parser/grammar.ml"
          
        in
        
# 434 "src/parser/grammar.mly"
                                  ( x )
# 6252 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 365 "src/parser/grammar.mly"
                                                      ( mkApp (loc _loc) [Const s;l;r] )
# 6261 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_266 =
    fun _endpos_r_ _startpos_l_ l r ->
      let s =
        let x =
          let x = 
# 458 "src/parser/grammar.mly"
         ( Func.from_string "r-" )
# 6271 "src/parser/grammar.ml"
           in
          
# 477 "src/parser/grammar.mly"
                                          ( x )
# 6276 "src/parser/grammar.ml"
          
        in
        
# 434 "src/parser/grammar.mly"
                                  ( x )
# 6282 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 365 "src/parser/grammar.mly"
                                                      ( mkApp (loc _loc) [Const s;l;r] )
# 6291 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_267 =
    fun _endpos_r_ _startpos_l_ l r ->
      let s =
        let x =
          let x = 
# 459 "src/parser/grammar.mly"
         ( Func.from_string "i-" )
# 6301 "src/parser/grammar.ml"
           in
          
# 477 "src/parser/grammar.mly"
                                          ( x )
# 6306 "src/parser/grammar.ml"
          
        in
        
# 434 "src/parser/grammar.mly"
                                  ( x )
# 6312 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 365 "src/parser/grammar.mly"
                                                      ( mkApp (loc _loc) [Const s;l;r] )
# 6321 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_268 =
    fun _endpos_r_ _startpos_l_ l r ->
      let s =
        let x =
          let x = 
# 460 "src/parser/grammar.mly"
         ( Func.from_string "s-" )
# 6331 "src/parser/grammar.ml"
           in
          
# 477 "src/parser/grammar.mly"
                                          ( x )
# 6336 "src/parser/grammar.ml"
          
        in
        
# 434 "src/parser/grammar.mly"
                                  ( x )
# 6342 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 365 "src/parser/grammar.mly"
                                                      ( mkApp (loc _loc) [Const s;l;r] )
# 6351 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_269 =
    fun _endpos_r_ _startpos_l_ l r ->
      let s =
        let x =
          let x = 
# 461 "src/parser/grammar.mly"
         ( Func.from_string "==" )
# 6361 "src/parser/grammar.ml"
           in
          
# 477 "src/parser/grammar.mly"
                                          ( x )
# 6366 "src/parser/grammar.ml"
          
        in
        
# 434 "src/parser/grammar.mly"
                                  ( x )
# 6372 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 365 "src/parser/grammar.mly"
                                                      ( mkApp (loc _loc) [Const s;l;r] )
# 6381 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_270 =
    fun _endpos_r_ _startpos_l_ l r ->
      let s =
        let x =
          let x = 
# 462 "src/parser/grammar.mly"
         ( Func.orf )
# 6391 "src/parser/grammar.ml"
           in
          
# 477 "src/parser/grammar.mly"
                                          ( x )
# 6396 "src/parser/grammar.ml"
          
        in
        
# 434 "src/parser/grammar.mly"
                                  ( x )
# 6402 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 365 "src/parser/grammar.mly"
                                                      ( mkApp (loc _loc) [Const s;l;r] )
# 6411 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_271 =
    fun _endpos_r_ _startpos_l_ l r ->
      let s =
        let x =
          let x = 
# 463 "src/parser/grammar.mly"
         ( Func.isf )
# 6421 "src/parser/grammar.ml"
           in
          
# 477 "src/parser/grammar.mly"
                                          ( x )
# 6426 "src/parser/grammar.ml"
          
        in
        
# 434 "src/parser/grammar.mly"
                                  ( x )
# 6432 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 365 "src/parser/grammar.mly"
                                                      ( mkApp (loc _loc) [Const s;l;r] )
# 6441 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_272 =
    fun _endpos_r_ _startpos_l_ l r ->
      let s =
        let x =
          let x = 
# 464 "src/parser/grammar.mly"
         ( Func.from_string "mod" )
# 6451 "src/parser/grammar.ml"
           in
          
# 477 "src/parser/grammar.mly"
                                          ( x )
# 6456 "src/parser/grammar.ml"
          
        in
        
# 434 "src/parser/grammar.mly"
                                  ( x )
# 6462 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 365 "src/parser/grammar.mly"
                                                      ( mkApp (loc _loc) [Const s;l;r] )
# 6471 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_273 =
    fun _endpos_r_ _startpos_l_ l r ->
      let s =
        let x =
          let x = 
# 465 "src/parser/grammar.mly"
         ( Func.from_string "div" )
# 6481 "src/parser/grammar.ml"
           in
          
# 477 "src/parser/grammar.mly"
                                          ( x )
# 6486 "src/parser/grammar.ml"
          
        in
        
# 434 "src/parser/grammar.mly"
                                  ( x )
# 6492 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 365 "src/parser/grammar.mly"
                                                      ( mkApp (loc _loc) [Const s;l;r] )
# 6501 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_274 =
    fun _endpos_r_ _startpos_l_ l r ->
      let s =
        let x =
          let x = 
# 466 "src/parser/grammar.mly"
         ( Func.arrowf )
# 6511 "src/parser/grammar.ml"
           in
          
# 477 "src/parser/grammar.mly"
                                          ( x )
# 6516 "src/parser/grammar.ml"
          
        in
        
# 434 "src/parser/grammar.mly"
                                  ( x )
# 6522 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 365 "src/parser/grammar.mly"
                                                      ( mkApp (loc _loc) [Const s;l;r] )
# 6531 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_275 =
    fun _endpos_r_ _startpos_l_ l r ->
      let s =
        let x =
          let x = 
# 467 "src/parser/grammar.mly"
         ( Func.implf )
# 6541 "src/parser/grammar.ml"
           in
          
# 477 "src/parser/grammar.mly"
                                          ( x )
# 6546 "src/parser/grammar.ml"
          
        in
        
# 434 "src/parser/grammar.mly"
                                  ( x )
# 6552 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 365 "src/parser/grammar.mly"
                                                      ( mkApp (loc _loc) [Const s;l;r] )
# 6561 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_276 =
    fun _endpos_r_ _startpos_l_ l r ->
      let s =
        let x =
          let x = 
# 468 "src/parser/grammar.mly"
         ( Func.sequentf )
# 6571 "src/parser/grammar.ml"
           in
          
# 477 "src/parser/grammar.mly"
                                          ( x )
# 6576 "src/parser/grammar.ml"
          
        in
        
# 434 "src/parser/grammar.mly"
                                  ( x )
# 6582 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 365 "src/parser/grammar.mly"
                                                      ( mkApp (loc _loc) [Const s;l;r] )
# 6591 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_277 =
    fun _endpos_r_ _startpos_l_ l r ->
      let s =
        let x =
          let x = 
# 469 "src/parser/grammar.mly"
         ( Func.from_string "/" )
# 6601 "src/parser/grammar.ml"
           in
          
# 477 "src/parser/grammar.mly"
                                          ( x )
# 6606 "src/parser/grammar.ml"
          
        in
        
# 434 "src/parser/grammar.mly"
                                  ( x )
# 6612 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 365 "src/parser/grammar.mly"
                                                      ( mkApp (loc _loc) [Const s;l;r] )
# 6621 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_278 =
    fun _endpos_r_ _startpos_l_ l r ->
      let s =
        let x =
          let x = 
# 470 "src/parser/grammar.mly"
         ( Func.andf )
# 6631 "src/parser/grammar.ml"
           in
          
# 477 "src/parser/grammar.mly"
                                          ( x )
# 6636 "src/parser/grammar.ml"
          
        in
        
# 434 "src/parser/grammar.mly"
                                  ( x )
# 6642 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 365 "src/parser/grammar.mly"
                                                      ( mkApp (loc _loc) [Const s;l;r] )
# 6651 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_279 =
    fun _endpos_r_ _startpos_l_ l r ->
      let s =
        let x = 
# 478 "src/parser/grammar.mly"
         ( Func.rimplf )
# 6660 "src/parser/grammar.ml"
         in
        
# 434 "src/parser/grammar.mly"
                                  ( x )
# 6665 "src/parser/grammar.ml"
        
      in
      let _endpos = _endpos_r_ in
      let _startpos = _startpos_l_ in
      let _loc = (_startpos, _endpos) in
      (
# 365 "src/parser/grammar.mly"
                                                      ( mkApp (loc _loc) [Const s;l;r] )
# 6674 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_280 =
    fun r s ->
      let s =
        let x = 
# 485 "src/parser/grammar.mly"
                   ( Func.from_string s )
# 6683 "src/parser/grammar.ml"
         in
        
# 423 "src/parser/grammar.mly"
                        ( x )
# 6688 "src/parser/grammar.ml"
        
      in
      (
# 366 "src/parser/grammar.mly"
                              ( App(Const s,[r]) )
# 6694 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_281 =
    fun l s ->
      let s =
        let x = 
# 488 "src/parser/grammar.mly"
                   ( Func.from_string s )
# 6703 "src/parser/grammar.ml"
         in
        
# 426 "src/parser/grammar.mly"
                         ( x )
# 6708 "src/parser/grammar.ml"
        
      in
      (
# 367 "src/parser/grammar.mly"
                                ( App(Const s,[l]) )
# 6714 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_282 =
    fun () ->
      (
# 111 "<standard.mly>"
    ( None )
# 6722 "src/parser/grammar.ml"
       : (unit option))
  
  let _menhir_action_283 =
    fun x ->
      (
# 113 "<standard.mly>"
    ( Some x )
# 6730 "src/parser/grammar.ml"
       : (unit option))
  
  let _menhir_action_284 =
    fun () ->
      (
# 111 "<standard.mly>"
    ( None )
# 6738 "src/parser/grammar.ml"
       : ((Ast.Loc.t * Ast.Term.t) option))
  
  let _menhir_action_285 =
    fun x ->
      (
# 113 "<standard.mly>"
    ( Some x )
# 6746 "src/parser/grammar.ml"
       : ((Ast.Loc.t * Ast.Term.t) option))
  
  let _menhir_action_286 =
    fun () ->
      (
# 111 "<standard.mly>"
    ( None )
# 6754 "src/parser/grammar.ml"
       : (Ast.Chr.sequent list option))
  
  let _menhir_action_287 =
    fun x ->
      let x = 
# 180 "<standard.mly>"
    ( x )
# 6762 "src/parser/grammar.ml"
       in
      (
# 113 "<standard.mly>"
    ( Some x )
# 6767 "src/parser/grammar.ml"
       : (Ast.Chr.sequent list option))
  
  let _menhir_action_288 =
    fun () ->
      (
# 111 "<standard.mly>"
    ( None )
# 6775 "src/parser/grammar.ml"
       : (Ast.Chr.sequent option))
  
  let _menhir_action_289 =
    fun x ->
      let x = 
# 180 "<standard.mly>"
    ( x )
# 6783 "src/parser/grammar.ml"
       in
      (
# 113 "<standard.mly>"
    ( Some x )
# 6788 "src/parser/grammar.ml"
       : (Ast.Chr.sequent option))
  
  let _menhir_action_290 =
    fun () ->
      (
# 111 "<standard.mly>"
    ( None )
# 6796 "src/parser/grammar.ml"
       : (Ast.Term.t option))
  
  let _menhir_action_291 =
    fun x ->
      let x = 
# 180 "<standard.mly>"
    ( x )
# 6804 "src/parser/grammar.ml"
       in
      (
# 113 "<standard.mly>"
    ( Some x )
# 6809 "src/parser/grammar.ml"
       : (Ast.Term.t option))
  
  let _menhir_action_292 =
    fun () ->
      (
# 111 "<standard.mly>"
    ( None )
# 6817 "src/parser/grammar.ml"
       : (Ast.Term.t option))
  
  let _menhir_action_293 =
    fun x ->
      (
# 113 "<standard.mly>"
    ( Some x )
# 6825 "src/parser/grammar.ml"
       : (Ast.Term.t option))
  
  let _menhir_action_294 =
    fun s ->
      let x =
        let x = 
# 488 "src/parser/grammar.mly"
                   ( Func.from_string s )
# 6834 "src/parser/grammar.ml"
         in
        
# 426 "src/parser/grammar.mly"
                         ( x )
# 6839 "src/parser/grammar.ml"
        
      in
      (
# 420 "src/parser/grammar.mly"
              ( x )
# 6845 "src/parser/grammar.ml"
       : (Ast.Func.t))
  
  let _menhir_action_295 =
    fun _endpos_attributes_ _endpos_c_ _endpos_xs_ _startpos__2_ _startpos_attributes_ _startpos_c_ attributes c xs ->
      let args = 
# 229 "<standard.mly>"
    ( xs )
# 6853 "src/parser/grammar.ml"
       in
      let _endpos_args_ = _endpos_xs_ in
      let _endpos = _endpos_args_ in
      let _symbolstartpos = if _startpos_attributes_ != _endpos_attributes_ then
        _startpos_attributes_
      else
        _startpos__2_ in
      let _loc_c_ = (_startpos_c_, _endpos_c_) in
      let _sloc = (_symbolstartpos, _endpos) in
      (
# 163 "src/parser/grammar.mly"
                                                              (
   let name = c in
   { Mode.loc=loc _sloc; name; args = List.map fst args },
   { Type.loc=loc _sloc; attributes; name;
     ty = List.fold_right (fun (_,t) ty ->
       mkApp (loc _loc_c_) [mkCon "->";t;ty]) args (mkCon "prop") }
 )
# 6872 "src/parser/grammar.ml"
       : (Ast.Func.t Ast.Mode.t * Ast.raw_attribute list Ast.Type.t))
  
  let _menhir_action_296 =
    fun io ty ->
      (
# 171 "src/parser/grammar.mly"
                                ( (mode_of_IO io,ty) )
# 6880 "src/parser/grammar.ml"
       : (bool * Ast.Term.t))
  
  let _menhir_action_297 =
    fun s ->
      let x =
        let x = 
# 485 "src/parser/grammar.mly"
                   ( Func.from_string s )
# 6889 "src/parser/grammar.ml"
         in
        
# 423 "src/parser/grammar.mly"
                        ( x )
# 6894 "src/parser/grammar.ml"
        
      in
      (
# 417 "src/parser/grammar.mly"
             ( x )
# 6900 "src/parser/grammar.ml"
       : (Ast.Func.t))
  
  let _menhir_action_298 =
    fun () ->
      (
# 114 "src/parser/grammar.mly"
      ( [] )
# 6908 "src/parser/grammar.ml"
       : (Ast.Program.t))
  
  let _menhir_action_299 =
    fun d p ->
      (
# 115 "src/parser/grammar.mly"
                        ( d :: p )
# 6916 "src/parser/grammar.ml"
       : (Ast.Program.t))
  
  let _menhir_action_300 =
    fun x ->
      (
# 238 "<standard.mly>"
    ( [ x ] )
# 6924 "src/parser/grammar.ml"
       : (Ast.raw_attribute list))
  
  let _menhir_action_301 =
    fun x xs ->
      (
# 240 "<standard.mly>"
    ( x :: xs )
# 6932 "src/parser/grammar.ml"
       : (Ast.raw_attribute list))
  
  let _menhir_action_302 =
    fun x ->
      (
# 238 "<standard.mly>"
    ( [ x ] )
# 6940 "src/parser/grammar.ml"
       : (Ast.Func.t list))
  
  let _menhir_action_303 =
    fun x xs ->
      (
# 240 "<standard.mly>"
    ( x :: xs )
# 6948 "src/parser/grammar.ml"
       : (Ast.Func.t list))
  
  let _menhir_action_304 =
    fun x ->
      (
# 238 "<standard.mly>"
    ( [ x ] )
# 6956 "src/parser/grammar.ml"
       : (string list))
  
  let _menhir_action_305 =
    fun x xs ->
      (
# 240 "<standard.mly>"
    ( x :: xs )
# 6964 "src/parser/grammar.ml"
       : (string list))
  
  let _menhir_action_306 =
    fun x ->
      (
# 238 "<standard.mly>"
    ( [ x ] )
# 6972 "src/parser/grammar.ml"
       : ((string * string) list list))
  
  let _menhir_action_307 =
    fun x xs ->
      (
# 240 "<standard.mly>"
    ( x :: xs )
# 6980 "src/parser/grammar.ml"
       : ((string * string) list list))
  
  let _menhir_action_308 =
    fun x ->
      (
# 238 "<standard.mly>"
    ( [ x ] )
# 6988 "src/parser/grammar.ml"
       : ((bool * Ast.Term.t) list))
  
  let _menhir_action_309 =
    fun x xs ->
      (
# 240 "<standard.mly>"
    ( x :: xs )
# 6996 "src/parser/grammar.ml"
       : ((bool * Ast.Term.t) list))
  
  let _menhir_action_310 =
    fun t ->
      (
# 260 "src/parser/grammar.mly"
                  (
    let context, conclusion = decode_sequent t in
    { Chr.eigen = underscore (); context; conclusion }
  )
# 7007 "src/parser/grammar.ml"
       : (Ast.Chr.sequent))
  
  let _menhir_action_311 =
    fun c t ->
      (
# 264 "src/parser/grammar.mly"
                                                (
    let context, conclusion = decode_sequent t in
    { Chr.eigen = Const c; context; conclusion }
  )
# 7018 "src/parser/grammar.ml"
       : (Ast.Chr.sequent))
  
  let _menhir_action_312 =
    fun l ->
      (
# 245 "src/parser/grammar.mly"
           (
     List.map Func.(fun (x,y) -> from_string x, from_string y) l
  )
# 7028 "src/parser/grammar.ml"
       : ((Ast.Func.t * Ast.Func.t) list))
  
  let _menhir_action_313 =
    fun name ->
      (
# 254 "src/parser/grammar.mly"
                  ( [Func.show name, Func.show name] )
# 7036 "src/parser/grammar.ml"
       : ((string * string) list))
  
  let _menhir_action_314 =
    fun l prefix ->
      (
# 255 "src/parser/grammar.mly"
                                                                                         (
    List.map (fun (p,x) -> Func.show prefix ^ "." ^ p, x) (List.flatten l)
)
# 7046 "src/parser/grammar.ml"
       : ((string * string) list))
  
  let _menhir_action_315 =
    fun t ->
      (
# 306 "src/parser/grammar.mly"
                ( t )
# 7054 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_316 =
    fun t ->
      (
# 307 "src/parser/grammar.mly"
                  ( t )
# 7062 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_317 =
    fun t ->
      (
# 308 "src/parser/grammar.mly"
                  ( t )
# 7070 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_318 =
    fun t ->
      (
# 311 "src/parser/grammar.mly"
                       ( t )
# 7078 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_319 =
    fun t ->
      (
# 312 "src/parser/grammar.mly"
                         ( t )
# 7086 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_320 =
    fun t ->
      (
# 313 "src/parser/grammar.mly"
                  ( t )
# 7094 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_321 =
    fun c l ->
      (
# 250 "src/parser/grammar.mly"
                                                                                    (
    List.map (fun (p,x) -> Func.show c ^ "." ^ p, x) (List.flatten l)
)
# 7104 "src/parser/grammar.ml"
       : ((string * string) list))
  
  let _menhir_action_322 =
    fun _endpos_attributes_ _endpos_t_ _startpos__2_ _startpos_attributes_ attributes names t ->
      let _endpos = _endpos_t_ in
      let _symbolstartpos = if _startpos_attributes_ != _endpos_attributes_ then
        _startpos_attributes_
      else
        _startpos__2_ in
      let _sloc = (_symbolstartpos, _endpos) in
      (
# 180 "src/parser/grammar.mly"
                                                                      (
    names |> List.map (fun n->
     { Type.loc=loc _sloc; attributes; name = n; ty = t })
  )
# 7121 "src/parser/grammar.ml"
       : (Ast.raw_attribute list Ast.Type.t list))
  
  let _menhir_action_323 =
    fun c ->
      (
# 190 "src/parser/grammar.mly"
               ( Const (fix_church c) )
# 7129 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_324 =
    fun _endpos_hd_ _startpos_hd_ args hd ->
      let _loc_hd_ = (_startpos_hd_, _endpos_hd_) in
      (
# 191 "src/parser/grammar.mly"
                                                  ( mkAppF (loc _loc_hd_) hd args )
# 7138 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_325 =
    fun _endpos_hd_ _startpos_hd_ hd t ->
      let _loc_hd_ = (_startpos_hd_, _endpos_hd_) in
      (
# 192 "src/parser/grammar.mly"
                                       ( mkApp (loc _loc_hd_) [mkCon "->"; hd; t] )
# 7147 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_326 =
    fun t ->
      (
# 193 "src/parser/grammar.mly"
                                ( t )
# 7155 "src/parser/grammar.ml"
       : (Ast.Term.t))
  
  let _menhir_action_327 =
    fun _endpos_t_ _startpos__1_ a t ->
      let _endpos = _endpos_t_ in
      let _symbolstartpos = _startpos__1_ in
      let _sloc = (_symbolstartpos, _endpos) in
      (
# 213 "src/parser/grammar.mly"
                                            (
    let name, args = a in
    let args = List.map Func.show args in
    let nparams = List.length args in
    let value = List.fold_right mkLam args t in
    { TypeAbbreviation.name = name;
      nparams = nparams;
      value = value;
      loc = loc _sloc }
  )
# 7175 "src/parser/grammar.ml"
       : (Ast.Func.t Ast.TypeAbbreviation.t))
  
  let _menhir_print_token : token -> string =
    fun _tok ->
      match _tok with
      | Elpi_lexer_config.Tokens.ACCUMULATE ->
          "ACCUMULATE"
      | Elpi_lexer_config.Tokens.ACCUM_SIG ->
          "ACCUM_SIG"
      | Elpi_lexer_config.Tokens.AFTER ->
          "AFTER"
      | Elpi_lexer_config.Tokens.ARROW ->
          "ARROW"
      | Elpi_lexer_config.Tokens.AS ->
          "AS"
      | Elpi_lexer_config.Tokens.BEFORE ->
          "BEFORE"
      | Elpi_lexer_config.Tokens.BIND ->
          "BIND"
      | Elpi_lexer_config.Tokens.CLOSED ->
          "CLOSED"
      | Elpi_lexer_config.Tokens.COLON ->
          "COLON"
      | Elpi_lexer_config.Tokens.CONJ ->
          "CONJ"
      | Elpi_lexer_config.Tokens.CONJ2 ->
          "CONJ2"
      | Elpi_lexer_config.Tokens.CONS ->
          "CONS"
      | Elpi_lexer_config.Tokens.CONSTANT _ ->
          "CONSTANT"
      | Elpi_lexer_config.Tokens.CONSTRAINT ->
          "CONSTRAINT"
      | Elpi_lexer_config.Tokens.CUT ->
          "CUT"
      | Elpi_lexer_config.Tokens.DARROW ->
          "DARROW"
      | Elpi_lexer_config.Tokens.DIV ->
          "DIV"
      | Elpi_lexer_config.Tokens.EOF ->
          "EOF"
      | Elpi_lexer_config.Tokens.EQ ->
          "EQ"
      | Elpi_lexer_config.Tokens.EQ2 ->
          "EQ2"
      | Elpi_lexer_config.Tokens.EXPORTDEF ->
          "EXPORTDEF"
      | Elpi_lexer_config.Tokens.EXTERNAL ->
          "EXTERNAL"
      | Elpi_lexer_config.Tokens.FAMILY_AND _ ->
          "FAMILY_AND"
      | Elpi_lexer_config.Tokens.FAMILY_BTICK _ ->
          "FAMILY_BTICK"
      | Elpi_lexer_config.Tokens.FAMILY_EQ _ ->
          "FAMILY_EQ"
      | Elpi_lexer_config.Tokens.FAMILY_EXP _ ->
          "FAMILY_EXP"
      | Elpi_lexer_config.Tokens.FAMILY_GT _ ->
          "FAMILY_GT"
      | Elpi_lexer_config.Tokens.FAMILY_LT _ ->
          "FAMILY_LT"
      | Elpi_lexer_config.Tokens.FAMILY_MINUS _ ->
          "FAMILY_MINUS"
      | Elpi_lexer_config.Tokens.FAMILY_OR _ ->
          "FAMILY_OR"
      | Elpi_lexer_config.Tokens.FAMILY_PLUS _ ->
          "FAMILY_PLUS"
      | Elpi_lexer_config.Tokens.FAMILY_QMARK _ ->
          "FAMILY_QMARK"
      | Elpi_lexer_config.Tokens.FAMILY_SHARP _ ->
          "FAMILY_SHARP"
      | Elpi_lexer_config.Tokens.FAMILY_TICK _ ->
          "FAMILY_TICK"
      | Elpi_lexer_config.Tokens.FAMILY_TILDE _ ->
          "FAMILY_TILDE"
      | Elpi_lexer_config.Tokens.FAMILY_TIMES _ ->
          "FAMILY_TIMES"
      | Elpi_lexer_config.Tokens.FIXITY _ ->
          "FIXITY"
      | Elpi_lexer_config.Tokens.FLOAT _ ->
          "FLOAT"
      | Elpi_lexer_config.Tokens.FRESHUV ->
          "FRESHUV"
      | Elpi_lexer_config.Tokens.FULLSTOP ->
          "FULLSTOP"
      | Elpi_lexer_config.Tokens.IF ->
          "IF"
      | Elpi_lexer_config.Tokens.IFF ->
          "IFF"
      | Elpi_lexer_config.Tokens.IMPORT ->
          "IMPORT"
      | Elpi_lexer_config.Tokens.INDEX ->
          "INDEX"
      | Elpi_lexer_config.Tokens.INTEGER _ ->
          "INTEGER"
      | Elpi_lexer_config.Tokens.IO _ ->
          "IO"
      | Elpi_lexer_config.Tokens.IO_COLON _ ->
          "IO_COLON"
      | Elpi_lexer_config.Tokens.IS ->
          "IS"
      | Elpi_lexer_config.Tokens.KIND ->
          "KIND"
      | Elpi_lexer_config.Tokens.LBRACKET ->
          "LBRACKET"
      | Elpi_lexer_config.Tokens.LCURLY ->
          "LCURLY"
      | Elpi_lexer_config.Tokens.LOCAL ->
          "LOCAL"
      | Elpi_lexer_config.Tokens.LOCALKIND ->
          "LOCALKIND"
      | Elpi_lexer_config.Tokens.LPAREN ->
          "LPAREN"
      | Elpi_lexer_config.Tokens.MACRO ->
          "MACRO"
      | Elpi_lexer_config.Tokens.MINUS ->
          "MINUS"
      | Elpi_lexer_config.Tokens.MINUSi ->
          "MINUSi"
      | Elpi_lexer_config.Tokens.MINUSr ->
          "MINUSr"
      | Elpi_lexer_config.Tokens.MINUSs ->
          "MINUSs"
      | Elpi_lexer_config.Tokens.MOD ->
          "MOD"
      | Elpi_lexer_config.Tokens.MODE ->
          "MODE"
      | Elpi_lexer_config.Tokens.MODULE ->
          "MODULE"
      | Elpi_lexer_config.Tokens.NAME ->
          "NAME"
      | Elpi_lexer_config.Tokens.NAMESPACE ->
          "NAMESPACE"
      | Elpi_lexer_config.Tokens.NIL ->
          "NIL"
      | Elpi_lexer_config.Tokens.OR ->
          "OR"
      | Elpi_lexer_config.Tokens.PI ->
          "PI"
      | Elpi_lexer_config.Tokens.PIPE ->
          "PIPE"
      | Elpi_lexer_config.Tokens.PRED ->
          "PRED"
      | Elpi_lexer_config.Tokens.QDASH ->
          "QDASH"
      | Elpi_lexer_config.Tokens.QUOTED _ ->
          "QUOTED"
      | Elpi_lexer_config.Tokens.RBRACKET ->
          "RBRACKET"
      | Elpi_lexer_config.Tokens.RCURLY ->
          "RCURLY"
      | Elpi_lexer_config.Tokens.REPLACE ->
          "REPLACE"
      | Elpi_lexer_config.Tokens.RPAREN ->
          "RPAREN"
      | Elpi_lexer_config.Tokens.RULE ->
          "RULE"
      | Elpi_lexer_config.Tokens.SHORTEN ->
          "SHORTEN"
      | Elpi_lexer_config.Tokens.SIG ->
          "SIG"
      | Elpi_lexer_config.Tokens.SIGMA ->
          "SIGMA"
      | Elpi_lexer_config.Tokens.SLASH ->
          "SLASH"
      | Elpi_lexer_config.Tokens.STRING _ ->
          "STRING"
      | Elpi_lexer_config.Tokens.TYPE ->
          "TYPE"
      | Elpi_lexer_config.Tokens.TYPEABBREV ->
          "TYPEABBREV"
      | Elpi_lexer_config.Tokens.USEONLY ->
          "USEONLY"
      | Elpi_lexer_config.Tokens.USE_SIG ->
          "USE_SIG"
      | Elpi_lexer_config.Tokens.VDASH ->
          "VDASH"
  
  let _menhir_fail : unit -> 'a =
    fun () ->
      Printf.eprintf "Internal failure -- please contact the parser generator's developers.\n%!";
      assert false
  
  include struct
    
    [@@@ocaml.warning "-4-37-39"]
    
    let rec _menhir_run_401_spec_268 : type  ttv_stack. ttv_stack -> _ -> _menhir_box_program =
      fun _menhir_stack _v ->
        MenhirBox_program _v
    
    let rec _menhir_run_415 : type  ttv_stack. (ttv_stack, _menhir_box_program) _menhir_cell1_decl -> _ -> _menhir_box_program =
      fun _menhir_stack _v ->
        let MenhirCell1_decl (_menhir_stack, _menhir_s, d) = _menhir_stack in
        let p = _v in
        let _v = _menhir_action_299 d p in
        _menhir_goto_program _menhir_stack _v _menhir_s
    
    and _menhir_goto_program : type  ttv_stack. ttv_stack -> _ -> (ttv_stack, _menhir_box_program) _menhir_state -> _menhir_box_program =
      fun _menhir_stack _v _menhir_s ->
        match _menhir_s with
        | MenhirState414 ->
            _menhir_run_415 _menhir_stack _v
        | MenhirState268 ->
            _menhir_run_401_spec_268 _menhir_stack _v
        | _ ->
            _menhir_fail ()
    
    let rec _menhir_goto_goal : type  ttv_stack. ttv_stack -> _ -> _menhir_box_goal =
      fun _menhir_stack _v ->
        MenhirBox_goal _v
    
    let rec _menhir_run_053_spec_000 : type  ttv_stack. ttv_stack -> _ -> _ -> _ -> _ -> _ -> _ -> _menhir_box_goal =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_317 t in
        _menhir_run_226 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v MenhirState000 _tok
    
    and _menhir_run_226 : type  ttv_stack. ttv_stack -> _ -> _ -> _ -> _ -> _ -> (ttv_stack, _menhir_box_goal) _menhir_state -> _ -> _menhir_box_goal =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.VDASH ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_056 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.SLASH ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.QDASH ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_114 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.OR ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_072 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MOD ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_074 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSs ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_076 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSr ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_082 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSi ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_084 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_086 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.IS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_088 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FULLSTOP ->
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let (_endpos__2_, _startpos_g_, g) = (_endpos_0, _startpos, _v) in
            let _v = _menhir_action_112 _endpos__2_ _startpos_g_ g in
            _menhir_goto_goal _menhir_stack _v
        | Elpi_lexer_config.Tokens.FAMILY_TIMES _v_1 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_078 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_TICK _v_2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_090 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_3 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_4 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_041 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_PLUS _v_5 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_092 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_6 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_7 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer _v_7
        | Elpi_lexer_config.Tokens.FAMILY_LT _v_8 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_098 _menhir_stack _menhir_lexbuf _menhir_lexer _v_8
        | Elpi_lexer_config.Tokens.FAMILY_GT _v_9 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_100 _menhir_stack _menhir_lexbuf _menhir_lexer _v_9
        | Elpi_lexer_config.Tokens.FAMILY_EXP _v_10 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_094 _menhir_stack _menhir_lexbuf _menhir_lexer _v_10
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_11 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer _v_11
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_12 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer _v_12
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_13 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer _v_13
        | Elpi_lexer_config.Tokens.EQ2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_102 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.EQ ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_104 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.EOF ->
            let _endpos_14 = _menhir_lexbuf.Lexing.lex_curr_p in
            let (_endpos__2_, _startpos_g_, g) = (_endpos_14, _startpos, _v) in
            let _v = _menhir_action_111 _endpos__2_ _startpos_g_ g in
            _menhir_goto_goal _menhir_stack _v
        | Elpi_lexer_config.Tokens.DIV ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_080 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.DARROW ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_106 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_096 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONJ2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_108 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONJ ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_110 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.ARROW ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_112 _menhir_stack _menhir_lexbuf _menhir_lexer
        | _ ->
            _eRR 226
    
    and _menhir_run_056 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell0_VDASH (_menhir_stack, _startpos, _endpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v ->
            let _startpos_0 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_1 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_1, _startpos_0, _v) in
            let _v = _menhir_action_068 x in
            _menhir_run_053_spec_056 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.SIGMA ->
            let _startpos_2 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_3 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_3, _startpos_2) in
            let _v = _menhir_action_085 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState056 _tok
        | Elpi_lexer_config.Tokens.REPLACE ->
            let _startpos_4 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_5 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_5, _startpos_4) in
            let _v = _menhir_action_080 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState056 _tok
        | Elpi_lexer_config.Tokens.QUOTED _v ->
            let _startpos_6 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_7 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_7, _startpos_6, _v) in
            let _v = _menhir_action_069 _endpos_x_ _startpos_x_ x in
            _menhir_run_053_spec_056 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.PI ->
            let _startpos_8 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_9 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_9, _startpos_8) in
            let _v = _menhir_action_084 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState056 _tok
        | Elpi_lexer_config.Tokens.NIL ->
            let _startpos_10 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_11 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_11, _startpos_10) in
            let _v = _menhir_action_089 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState056 _tok
        | Elpi_lexer_config.Tokens.NAME ->
            let _startpos_12 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_13 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_13, _startpos_12) in
            let _v = _menhir_action_077 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState056 _tok
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState056
        | Elpi_lexer_config.Tokens.LCURLY ->
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState056
        | Elpi_lexer_config.Tokens.LBRACKET ->
            _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState056
        | Elpi_lexer_config.Tokens.IO _v ->
            let _startpos_14 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_15 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_15, _startpos_14, _v) in
            let _v = _menhir_action_082 c in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState056 _tok
        | Elpi_lexer_config.Tokens.INTEGER _v ->
            let _startpos_16 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_17 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_17, _startpos_16, _v) in
            let _v = _menhir_action_066 x in
            _menhir_run_053_spec_056 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.INDEX ->
            let _startpos_18 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_19 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_19, _startpos_18) in
            let _v = _menhir_action_081 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState056 _tok
        | Elpi_lexer_config.Tokens.IF ->
            let _startpos_20 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_21 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_21, _startpos_20) in
            let _v = _menhir_action_076 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState056 _tok
        | Elpi_lexer_config.Tokens.FRESHUV ->
            let _startpos_22 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_23 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_23, _startpos_22) in
            let _v = _menhir_action_086 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState056 _tok
        | Elpi_lexer_config.Tokens.FLOAT _v ->
            let _startpos_24 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_25 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_25, _startpos_24, _v) in
            let _v = _menhir_action_067 x in
            _menhir_run_053_spec_056 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_TILDE _v ->
            _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState056
        | Elpi_lexer_config.Tokens.CUT ->
            let _startpos_26 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_27 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_27, _startpos_26) in
            let _v = _menhir_action_083 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState056 _tok
        | Elpi_lexer_config.Tokens.CONSTANT _v ->
            let _startpos_28 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_29 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_29, _startpos_28, _v) in
            let _v = _menhir_action_075 c in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState056 _tok
        | Elpi_lexer_config.Tokens.BEFORE ->
            let _startpos_30 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_31 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_31, _startpos_30) in
            let _v = _menhir_action_078 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState056 _tok
        | Elpi_lexer_config.Tokens.AFTER ->
            let _startpos_32 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_33 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_33, _startpos_32) in
            let _v = _menhir_action_079 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState056 _tok
        | _ ->
            _eRR 56
    
    and _menhir_run_053_spec_056 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term _menhir_cell0_VDASH -> _ -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_317 t in
        _menhir_run_057 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v MenhirState056 _tok
    
    and _menhir_run_057 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_term _menhir_cell0_VDASH as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.SLASH ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.OR ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_072 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MOD ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_074 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSs ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_076 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSr ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_082 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSi ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_084 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_086 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.IS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_088 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FAMILY_TIMES _v_0 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_078 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_TICK _v_1 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_090 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_3 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_041 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_PLUS _v_4 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_092 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_5 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_6 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.FAMILY_LT _v_7 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_098 _menhir_stack _menhir_lexbuf _menhir_lexer _v_7
        | Elpi_lexer_config.Tokens.FAMILY_GT _v_8 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_100 _menhir_stack _menhir_lexbuf _menhir_lexer _v_8
        | Elpi_lexer_config.Tokens.FAMILY_EXP _v_9 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_094 _menhir_stack _menhir_lexbuf _menhir_lexer _v_9
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_10 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer _v_10
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_11 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer _v_11
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_12 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer _v_12
        | Elpi_lexer_config.Tokens.EQ2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_102 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.EQ ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_104 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.DIV ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_080 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.DARROW ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_106 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_096 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONJ2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_108 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONJ ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_110 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.ARROW ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_112 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.AS | Elpi_lexer_config.Tokens.EOF | Elpi_lexer_config.Tokens.FULLSTOP | Elpi_lexer_config.Tokens.IFF | Elpi_lexer_config.Tokens.PIPE | Elpi_lexer_config.Tokens.RBRACKET | Elpi_lexer_config.Tokens.RCURLY | Elpi_lexer_config.Tokens.RPAREN ->
            let MenhirCell0_VDASH (_menhir_stack, _, _) = _menhir_stack in
            let MenhirCell1_term (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_247 _endpos_r_ _startpos_l_ l r in
            _menhir_goto_open_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 57
    
    and _menhir_run_058 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell0_SLASH (_menhir_stack, _startpos, _endpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v ->
            let _startpos_0 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_1 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_1, _startpos_0, _v) in
            let _v = _menhir_action_068 x in
            _menhir_run_053_spec_058 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.SIGMA ->
            let _startpos_2 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_3 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_3, _startpos_2) in
            let _v = _menhir_action_085 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState058 _tok
        | Elpi_lexer_config.Tokens.REPLACE ->
            let _startpos_4 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_5 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_5, _startpos_4) in
            let _v = _menhir_action_080 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState058 _tok
        | Elpi_lexer_config.Tokens.QUOTED _v ->
            let _startpos_6 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_7 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_7, _startpos_6, _v) in
            let _v = _menhir_action_069 _endpos_x_ _startpos_x_ x in
            _menhir_run_053_spec_058 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.PI ->
            let _startpos_8 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_9 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_9, _startpos_8) in
            let _v = _menhir_action_084 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState058 _tok
        | Elpi_lexer_config.Tokens.NIL ->
            let _startpos_10 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_11 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_11, _startpos_10) in
            let _v = _menhir_action_089 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState058 _tok
        | Elpi_lexer_config.Tokens.NAME ->
            let _startpos_12 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_13 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_13, _startpos_12) in
            let _v = _menhir_action_077 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState058 _tok
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState058
        | Elpi_lexer_config.Tokens.LCURLY ->
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState058
        | Elpi_lexer_config.Tokens.LBRACKET ->
            _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState058
        | Elpi_lexer_config.Tokens.IO _v ->
            let _startpos_14 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_15 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_15, _startpos_14, _v) in
            let _v = _menhir_action_082 c in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState058 _tok
        | Elpi_lexer_config.Tokens.INTEGER _v ->
            let _startpos_16 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_17 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_17, _startpos_16, _v) in
            let _v = _menhir_action_066 x in
            _menhir_run_053_spec_058 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.INDEX ->
            let _startpos_18 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_19 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_19, _startpos_18) in
            let _v = _menhir_action_081 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState058 _tok
        | Elpi_lexer_config.Tokens.IF ->
            let _startpos_20 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_21 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_21, _startpos_20) in
            let _v = _menhir_action_076 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState058 _tok
        | Elpi_lexer_config.Tokens.FRESHUV ->
            let _startpos_22 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_23 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_23, _startpos_22) in
            let _v = _menhir_action_086 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState058 _tok
        | Elpi_lexer_config.Tokens.FLOAT _v ->
            let _startpos_24 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_25 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_25, _startpos_24, _v) in
            let _v = _menhir_action_067 x in
            _menhir_run_053_spec_058 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_TILDE _v ->
            _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState058
        | Elpi_lexer_config.Tokens.CUT ->
            let _startpos_26 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_27 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_27, _startpos_26) in
            let _v = _menhir_action_083 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState058 _tok
        | Elpi_lexer_config.Tokens.CONSTANT _v ->
            let _startpos_28 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_29 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_29, _startpos_28, _v) in
            let _v = _menhir_action_075 c in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState058 _tok
        | Elpi_lexer_config.Tokens.BEFORE ->
            let _startpos_30 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_31 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_31, _startpos_30) in
            let _v = _menhir_action_078 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState058 _tok
        | Elpi_lexer_config.Tokens.AFTER ->
            let _startpos_32 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_33 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_33, _startpos_32) in
            let _v = _menhir_action_079 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState058 _tok
        | _ ->
            _eRR 58
    
    and _menhir_run_053_spec_058 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term _menhir_cell0_SLASH -> _ -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_317 t in
        _menhir_run_059 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v MenhirState058 _tok
    
    and _menhir_run_059 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_term _menhir_cell0_SLASH as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_0 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_1 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_041 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_3 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_4 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_5 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_6 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.AS | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.CONS | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.DIV | Elpi_lexer_config.Tokens.EOF | Elpi_lexer_config.Tokens.EQ | Elpi_lexer_config.Tokens.EQ2 | Elpi_lexer_config.Tokens.FAMILY_EXP _ | Elpi_lexer_config.Tokens.FAMILY_GT _ | Elpi_lexer_config.Tokens.FAMILY_LT _ | Elpi_lexer_config.Tokens.FAMILY_PLUS _ | Elpi_lexer_config.Tokens.FAMILY_TICK _ | Elpi_lexer_config.Tokens.FAMILY_TIMES _ | Elpi_lexer_config.Tokens.FULLSTOP | Elpi_lexer_config.Tokens.IFF | Elpi_lexer_config.Tokens.IS | Elpi_lexer_config.Tokens.MINUS | Elpi_lexer_config.Tokens.MINUSi | Elpi_lexer_config.Tokens.MINUSr | Elpi_lexer_config.Tokens.MINUSs | Elpi_lexer_config.Tokens.MOD | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.PIPE | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.RBRACKET | Elpi_lexer_config.Tokens.RCURLY | Elpi_lexer_config.Tokens.RPAREN | Elpi_lexer_config.Tokens.SLASH | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_SLASH (_menhir_stack, _, _) = _menhir_stack in
            let MenhirCell1_term (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_244 _endpos_r_ _startpos_l_ l r in
            _menhir_goto_open_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 59
    
    and _menhir_run_060 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell0_FAMILY_SHARP (_menhir_stack, _v, _startpos, _endpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v_0 ->
            let _startpos_1 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_2 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_2, _startpos_1, _v_0) in
            let _v = _menhir_action_068 x in
            _menhir_run_053_spec_060 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.SIGMA ->
            let _startpos_4 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_5 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_5, _startpos_4) in
            let _v = _menhir_action_085 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState060 _tok
        | Elpi_lexer_config.Tokens.REPLACE ->
            let _startpos_7 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_8 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_8, _startpos_7) in
            let _v = _menhir_action_080 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState060 _tok
        | Elpi_lexer_config.Tokens.QUOTED _v_10 ->
            let _startpos_11 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_12 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_12, _startpos_11, _v_10) in
            let _v = _menhir_action_069 _endpos_x_ _startpos_x_ x in
            _menhir_run_053_spec_060 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.PI ->
            let _startpos_14 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_15 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_15, _startpos_14) in
            let _v = _menhir_action_084 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState060 _tok
        | Elpi_lexer_config.Tokens.NIL ->
            let _startpos_17 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_18 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_18, _startpos_17) in
            let _v = _menhir_action_089 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState060 _tok
        | Elpi_lexer_config.Tokens.NAME ->
            let _startpos_20 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_21 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_21, _startpos_20) in
            let _v = _menhir_action_077 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState060 _tok
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState060
        | Elpi_lexer_config.Tokens.LCURLY ->
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState060
        | Elpi_lexer_config.Tokens.LBRACKET ->
            _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState060
        | Elpi_lexer_config.Tokens.IO _v_23 ->
            let _startpos_24 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_25 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_25, _startpos_24, _v_23) in
            let _v = _menhir_action_082 c in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState060 _tok
        | Elpi_lexer_config.Tokens.INTEGER _v_27 ->
            let _startpos_28 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_29 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_29, _startpos_28, _v_27) in
            let _v = _menhir_action_066 x in
            _menhir_run_053_spec_060 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.INDEX ->
            let _startpos_31 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_32 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_32, _startpos_31) in
            let _v = _menhir_action_081 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState060 _tok
        | Elpi_lexer_config.Tokens.IF ->
            let _startpos_34 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_35 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_35, _startpos_34) in
            let _v = _menhir_action_076 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState060 _tok
        | Elpi_lexer_config.Tokens.FRESHUV ->
            let _startpos_37 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_38 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_38, _startpos_37) in
            let _v = _menhir_action_086 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState060 _tok
        | Elpi_lexer_config.Tokens.FLOAT _v_40 ->
            let _startpos_41 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_42 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_42, _startpos_41, _v_40) in
            let _v = _menhir_action_067 x in
            _menhir_run_053_spec_060 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_TILDE _v_44 ->
            _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer _v_44 MenhirState060
        | Elpi_lexer_config.Tokens.CUT ->
            let _startpos_45 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_46 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_46, _startpos_45) in
            let _v = _menhir_action_083 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState060 _tok
        | Elpi_lexer_config.Tokens.CONSTANT _v_48 ->
            let _startpos_49 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_50 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_50, _startpos_49, _v_48) in
            let _v = _menhir_action_075 c in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState060 _tok
        | Elpi_lexer_config.Tokens.BEFORE ->
            let _startpos_52 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_53 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_53, _startpos_52) in
            let _v = _menhir_action_078 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState060 _tok
        | Elpi_lexer_config.Tokens.AFTER ->
            let _startpos_55 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_56 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_56, _startpos_55) in
            let _v = _menhir_action_079 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState060 _tok
        | _ ->
            _eRR 60
    
    and _menhir_run_053_spec_060 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term _menhir_cell0_FAMILY_SHARP -> _ -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_317 t in
        _menhir_run_061 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v MenhirState060 _tok
    
    and _menhir_run_061 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_term _menhir_cell0_FAMILY_SHARP as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_0 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_041 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.AS | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.CONS | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.DIV | Elpi_lexer_config.Tokens.EOF | Elpi_lexer_config.Tokens.EQ | Elpi_lexer_config.Tokens.EQ2 | Elpi_lexer_config.Tokens.FAMILY_AND _ | Elpi_lexer_config.Tokens.FAMILY_BTICK _ | Elpi_lexer_config.Tokens.FAMILY_EQ _ | Elpi_lexer_config.Tokens.FAMILY_EXP _ | Elpi_lexer_config.Tokens.FAMILY_GT _ | Elpi_lexer_config.Tokens.FAMILY_LT _ | Elpi_lexer_config.Tokens.FAMILY_MINUS _ | Elpi_lexer_config.Tokens.FAMILY_OR _ | Elpi_lexer_config.Tokens.FAMILY_PLUS _ | Elpi_lexer_config.Tokens.FAMILY_SHARP _ | Elpi_lexer_config.Tokens.FAMILY_TICK _ | Elpi_lexer_config.Tokens.FAMILY_TIMES _ | Elpi_lexer_config.Tokens.FULLSTOP | Elpi_lexer_config.Tokens.IFF | Elpi_lexer_config.Tokens.IS | Elpi_lexer_config.Tokens.MINUS | Elpi_lexer_config.Tokens.MINUSi | Elpi_lexer_config.Tokens.MINUSr | Elpi_lexer_config.Tokens.MINUSs | Elpi_lexer_config.Tokens.MOD | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.PIPE | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.RBRACKET | Elpi_lexer_config.Tokens.RCURLY | Elpi_lexer_config.Tokens.RPAREN | Elpi_lexer_config.Tokens.SLASH | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_FAMILY_SHARP (_menhir_stack, s, _, _) = _menhir_stack in
            let MenhirCell1_term (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_227 _endpos_r_ _startpos_l_ l r s in
            _menhir_goto_open_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 61
    
    and _menhir_run_041 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        let MenhirCell1_term (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
        let (_endpos_s_, s) = (_endpos, _v) in
        let _v = _menhir_action_249 l s in
        _menhir_goto_open_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_s_ _startpos_l_ _v _menhir_s _tok
    
    and _menhir_goto_open_term : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_315 t in
        _menhir_goto_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v _menhir_s _tok
    
    and _menhir_goto_term : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match _menhir_s with
        | MenhirState524 ->
            _menhir_run_525 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState522 ->
            _menhir_run_523 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState520 ->
            _menhir_run_521 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState518 ->
            _menhir_run_519 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState516 ->
            _menhir_run_517 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState514 ->
            _menhir_run_515 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState512 ->
            _menhir_run_513 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState510 ->
            _menhir_run_511 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState508 ->
            _menhir_run_509 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState506 ->
            _menhir_run_507 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState504 ->
            _menhir_run_505 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState502 ->
            _menhir_run_503 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState500 ->
            _menhir_run_501 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState498 ->
            _menhir_run_499 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState496 ->
            _menhir_run_497 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState494 ->
            _menhir_run_495 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState492 ->
            _menhir_run_493 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState489 ->
            _menhir_run_490 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState487 ->
            _menhir_run_488 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState485 ->
            _menhir_run_486 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState483 ->
            _menhir_run_484 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState481 ->
            _menhir_run_482 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState479 ->
            _menhir_run_480 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState477 ->
            _menhir_run_478 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState475 ->
            _menhir_run_476 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState473 ->
            _menhir_run_474 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState471 ->
            _menhir_run_472 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState469 ->
            _menhir_run_470 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState467 ->
            _menhir_run_468 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState465 ->
            _menhir_run_466 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState458 ->
            _menhir_run_459 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState455 ->
            _menhir_run_456 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState439 ->
            _menhir_run_440 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState427 ->
            _menhir_run_428 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState337 ->
            _menhir_run_338 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState335 ->
            _menhir_run_336 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState000 ->
            _menhir_run_226 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState221 ->
            _menhir_run_222 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState425 ->
            _menhir_run_219 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState008 ->
            _menhir_run_219 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState018 ->
            _menhir_run_192 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState118 ->
            _menhir_run_119 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState114 ->
            _menhir_run_115 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState112 ->
            _menhir_run_113 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState110 ->
            _menhir_run_111 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState108 ->
            _menhir_run_109 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState106 ->
            _menhir_run_107 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState104 ->
            _menhir_run_105 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState102 ->
            _menhir_run_103 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState100 ->
            _menhir_run_101 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState098 ->
            _menhir_run_099 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState096 ->
            _menhir_run_097 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState094 ->
            _menhir_run_095 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState092 ->
            _menhir_run_093 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState090 ->
            _menhir_run_091 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState088 ->
            _menhir_run_089 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState086 ->
            _menhir_run_087 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState084 ->
            _menhir_run_085 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState082 ->
            _menhir_run_083 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState080 ->
            _menhir_run_081 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState078 ->
            _menhir_run_079 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState076 ->
            _menhir_run_077 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState074 ->
            _menhir_run_075 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState072 ->
            _menhir_run_073 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState070 ->
            _menhir_run_071 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState068 ->
            _menhir_run_069 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState066 ->
            _menhir_run_067 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState064 ->
            _menhir_run_065 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState062 ->
            _menhir_run_063 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState060 ->
            _menhir_run_061 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState058 ->
            _menhir_run_059 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState056 ->
            _menhir_run_057 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState038 ->
            _menhir_run_055 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState196 ->
            _menhir_run_040 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState039 ->
            _menhir_run_040 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_525 : type  ttv_stack. (((ttv_stack, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_clause_hd_term _menhir_cell0_ARROW as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.SLASH ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MOD ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_074 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSs ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_076 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSr ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_082 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSi ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_084 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_086 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.IS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_088 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FAMILY_TIMES _v_0 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_078 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_TICK _v_1 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_090 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_3 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_041 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_PLUS _v_4 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_092 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_5 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_6 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.FAMILY_LT _v_7 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_098 _menhir_stack _menhir_lexbuf _menhir_lexer _v_7
        | Elpi_lexer_config.Tokens.FAMILY_GT _v_8 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_100 _menhir_stack _menhir_lexbuf _menhir_lexer _v_8
        | Elpi_lexer_config.Tokens.FAMILY_EXP _v_9 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_094 _menhir_stack _menhir_lexbuf _menhir_lexer _v_9
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_10 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer _v_10
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_11 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer _v_11
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_12 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer _v_12
        | Elpi_lexer_config.Tokens.EQ2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_102 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.EQ ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_104 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.DIV ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_080 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.DARROW ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_106 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_096 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.ARROW ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_112 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.FULLSTOP | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_ARROW (_menhir_stack, _, _) = _menhir_stack in
            let MenhirCell1_clause_hd_term (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_056 _endpos_r_ _startpos_l_ l r in
            _menhir_goto_clause_hd_open_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 525
    
    and _menhir_run_074 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell0_MOD (_menhir_stack, _startpos, _endpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v ->
            let _startpos_0 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_1 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_1, _startpos_0, _v) in
            let _v = _menhir_action_068 x in
            _menhir_run_053_spec_074 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.SIGMA ->
            let _startpos_2 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_3 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_3, _startpos_2) in
            let _v = _menhir_action_085 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState074 _tok
        | Elpi_lexer_config.Tokens.REPLACE ->
            let _startpos_4 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_5 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_5, _startpos_4) in
            let _v = _menhir_action_080 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState074 _tok
        | Elpi_lexer_config.Tokens.QUOTED _v ->
            let _startpos_6 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_7 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_7, _startpos_6, _v) in
            let _v = _menhir_action_069 _endpos_x_ _startpos_x_ x in
            _menhir_run_053_spec_074 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.PI ->
            let _startpos_8 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_9 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_9, _startpos_8) in
            let _v = _menhir_action_084 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState074 _tok
        | Elpi_lexer_config.Tokens.NIL ->
            let _startpos_10 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_11 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_11, _startpos_10) in
            let _v = _menhir_action_089 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState074 _tok
        | Elpi_lexer_config.Tokens.NAME ->
            let _startpos_12 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_13 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_13, _startpos_12) in
            let _v = _menhir_action_077 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState074 _tok
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState074
        | Elpi_lexer_config.Tokens.LCURLY ->
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState074
        | Elpi_lexer_config.Tokens.LBRACKET ->
            _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState074
        | Elpi_lexer_config.Tokens.IO _v ->
            let _startpos_14 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_15 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_15, _startpos_14, _v) in
            let _v = _menhir_action_082 c in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState074 _tok
        | Elpi_lexer_config.Tokens.INTEGER _v ->
            let _startpos_16 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_17 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_17, _startpos_16, _v) in
            let _v = _menhir_action_066 x in
            _menhir_run_053_spec_074 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.INDEX ->
            let _startpos_18 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_19 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_19, _startpos_18) in
            let _v = _menhir_action_081 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState074 _tok
        | Elpi_lexer_config.Tokens.IF ->
            let _startpos_20 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_21 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_21, _startpos_20) in
            let _v = _menhir_action_076 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState074 _tok
        | Elpi_lexer_config.Tokens.FRESHUV ->
            let _startpos_22 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_23 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_23, _startpos_22) in
            let _v = _menhir_action_086 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState074 _tok
        | Elpi_lexer_config.Tokens.FLOAT _v ->
            let _startpos_24 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_25 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_25, _startpos_24, _v) in
            let _v = _menhir_action_067 x in
            _menhir_run_053_spec_074 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_TILDE _v ->
            _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState074
        | Elpi_lexer_config.Tokens.CUT ->
            let _startpos_26 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_27 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_27, _startpos_26) in
            let _v = _menhir_action_083 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState074 _tok
        | Elpi_lexer_config.Tokens.CONSTANT _v ->
            let _startpos_28 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_29 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_29, _startpos_28, _v) in
            let _v = _menhir_action_075 c in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState074 _tok
        | Elpi_lexer_config.Tokens.BEFORE ->
            let _startpos_30 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_31 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_31, _startpos_30) in
            let _v = _menhir_action_078 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState074 _tok
        | Elpi_lexer_config.Tokens.AFTER ->
            let _startpos_32 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_33 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_33, _startpos_32) in
            let _v = _menhir_action_079 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState074 _tok
        | _ ->
            _eRR 74
    
    and _menhir_run_053_spec_074 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term _menhir_cell0_MOD -> _ -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_317 t in
        _menhir_run_075 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v MenhirState074 _tok
    
    and _menhir_run_075 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_term _menhir_cell0_MOD as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_0 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_1 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_041 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_3 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_4 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_5 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_6 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.AS | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.CONS | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.DIV | Elpi_lexer_config.Tokens.EOF | Elpi_lexer_config.Tokens.EQ | Elpi_lexer_config.Tokens.EQ2 | Elpi_lexer_config.Tokens.FAMILY_EXP _ | Elpi_lexer_config.Tokens.FAMILY_GT _ | Elpi_lexer_config.Tokens.FAMILY_LT _ | Elpi_lexer_config.Tokens.FAMILY_PLUS _ | Elpi_lexer_config.Tokens.FAMILY_TICK _ | Elpi_lexer_config.Tokens.FAMILY_TIMES _ | Elpi_lexer_config.Tokens.FULLSTOP | Elpi_lexer_config.Tokens.IFF | Elpi_lexer_config.Tokens.IS | Elpi_lexer_config.Tokens.MINUS | Elpi_lexer_config.Tokens.MINUSi | Elpi_lexer_config.Tokens.MINUSr | Elpi_lexer_config.Tokens.MINUSs | Elpi_lexer_config.Tokens.MOD | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.PIPE | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.RBRACKET | Elpi_lexer_config.Tokens.RCURLY | Elpi_lexer_config.Tokens.RPAREN | Elpi_lexer_config.Tokens.SLASH | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_MOD (_menhir_stack, _, _) = _menhir_stack in
            let MenhirCell1_term (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_239 _endpos_r_ _startpos_l_ l r in
            _menhir_goto_open_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 75
    
    and _menhir_run_062 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell0_FAMILY_OR (_menhir_stack, _v, _startpos, _endpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v_0 ->
            let _startpos_1 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_2 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_2, _startpos_1, _v_0) in
            let _v = _menhir_action_068 x in
            _menhir_run_053_spec_062 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.SIGMA ->
            let _startpos_4 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_5 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_5, _startpos_4) in
            let _v = _menhir_action_085 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState062 _tok
        | Elpi_lexer_config.Tokens.REPLACE ->
            let _startpos_7 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_8 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_8, _startpos_7) in
            let _v = _menhir_action_080 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState062 _tok
        | Elpi_lexer_config.Tokens.QUOTED _v_10 ->
            let _startpos_11 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_12 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_12, _startpos_11, _v_10) in
            let _v = _menhir_action_069 _endpos_x_ _startpos_x_ x in
            _menhir_run_053_spec_062 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.PI ->
            let _startpos_14 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_15 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_15, _startpos_14) in
            let _v = _menhir_action_084 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState062 _tok
        | Elpi_lexer_config.Tokens.NIL ->
            let _startpos_17 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_18 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_18, _startpos_17) in
            let _v = _menhir_action_089 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState062 _tok
        | Elpi_lexer_config.Tokens.NAME ->
            let _startpos_20 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_21 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_21, _startpos_20) in
            let _v = _menhir_action_077 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState062 _tok
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState062
        | Elpi_lexer_config.Tokens.LCURLY ->
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState062
        | Elpi_lexer_config.Tokens.LBRACKET ->
            _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState062
        | Elpi_lexer_config.Tokens.IO _v_23 ->
            let _startpos_24 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_25 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_25, _startpos_24, _v_23) in
            let _v = _menhir_action_082 c in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState062 _tok
        | Elpi_lexer_config.Tokens.INTEGER _v_27 ->
            let _startpos_28 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_29 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_29, _startpos_28, _v_27) in
            let _v = _menhir_action_066 x in
            _menhir_run_053_spec_062 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.INDEX ->
            let _startpos_31 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_32 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_32, _startpos_31) in
            let _v = _menhir_action_081 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState062 _tok
        | Elpi_lexer_config.Tokens.IF ->
            let _startpos_34 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_35 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_35, _startpos_34) in
            let _v = _menhir_action_076 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState062 _tok
        | Elpi_lexer_config.Tokens.FRESHUV ->
            let _startpos_37 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_38 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_38, _startpos_37) in
            let _v = _menhir_action_086 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState062 _tok
        | Elpi_lexer_config.Tokens.FLOAT _v_40 ->
            let _startpos_41 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_42 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_42, _startpos_41, _v_40) in
            let _v = _menhir_action_067 x in
            _menhir_run_053_spec_062 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_TILDE _v_44 ->
            _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer _v_44 MenhirState062
        | Elpi_lexer_config.Tokens.CUT ->
            let _startpos_45 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_46 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_46, _startpos_45) in
            let _v = _menhir_action_083 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState062 _tok
        | Elpi_lexer_config.Tokens.CONSTANT _v_48 ->
            let _startpos_49 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_50 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_50, _startpos_49, _v_48) in
            let _v = _menhir_action_075 c in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState062 _tok
        | Elpi_lexer_config.Tokens.BEFORE ->
            let _startpos_52 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_53 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_53, _startpos_52) in
            let _v = _menhir_action_078 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState062 _tok
        | Elpi_lexer_config.Tokens.AFTER ->
            let _startpos_55 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_56 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_56, _startpos_55) in
            let _v = _menhir_action_079 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState062 _tok
        | _ ->
            _eRR 62
    
    and _menhir_run_053_spec_062 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term _menhir_cell0_FAMILY_OR -> _ -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_317 t in
        _menhir_run_063 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v MenhirState062 _tok
    
    and _menhir_run_063 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_term _menhir_cell0_FAMILY_OR as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_0 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_1 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_041 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_3 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.AS | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.CONS | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.DIV | Elpi_lexer_config.Tokens.EOF | Elpi_lexer_config.Tokens.EQ | Elpi_lexer_config.Tokens.EQ2 | Elpi_lexer_config.Tokens.FAMILY_BTICK _ | Elpi_lexer_config.Tokens.FAMILY_EQ _ | Elpi_lexer_config.Tokens.FAMILY_EXP _ | Elpi_lexer_config.Tokens.FAMILY_GT _ | Elpi_lexer_config.Tokens.FAMILY_LT _ | Elpi_lexer_config.Tokens.FAMILY_MINUS _ | Elpi_lexer_config.Tokens.FAMILY_PLUS _ | Elpi_lexer_config.Tokens.FAMILY_TICK _ | Elpi_lexer_config.Tokens.FAMILY_TIMES _ | Elpi_lexer_config.Tokens.FULLSTOP | Elpi_lexer_config.Tokens.IFF | Elpi_lexer_config.Tokens.IS | Elpi_lexer_config.Tokens.MINUS | Elpi_lexer_config.Tokens.MINUSi | Elpi_lexer_config.Tokens.MINUSr | Elpi_lexer_config.Tokens.MINUSs | Elpi_lexer_config.Tokens.MOD | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.PIPE | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.RBRACKET | Elpi_lexer_config.Tokens.RCURLY | Elpi_lexer_config.Tokens.RPAREN | Elpi_lexer_config.Tokens.SLASH | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_FAMILY_OR (_menhir_stack, s, _, _) = _menhir_stack in
            let MenhirCell1_term (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_226 _endpos_r_ _startpos_l_ l r s in
            _menhir_goto_open_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 63
    
    and _menhir_run_064 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell0_FAMILY_AND (_menhir_stack, _v, _startpos, _endpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v_0 ->
            let _startpos_1 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_2 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_2, _startpos_1, _v_0) in
            let _v = _menhir_action_068 x in
            _menhir_run_053_spec_064 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.SIGMA ->
            let _startpos_4 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_5 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_5, _startpos_4) in
            let _v = _menhir_action_085 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState064 _tok
        | Elpi_lexer_config.Tokens.REPLACE ->
            let _startpos_7 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_8 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_8, _startpos_7) in
            let _v = _menhir_action_080 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState064 _tok
        | Elpi_lexer_config.Tokens.QUOTED _v_10 ->
            let _startpos_11 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_12 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_12, _startpos_11, _v_10) in
            let _v = _menhir_action_069 _endpos_x_ _startpos_x_ x in
            _menhir_run_053_spec_064 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.PI ->
            let _startpos_14 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_15 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_15, _startpos_14) in
            let _v = _menhir_action_084 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState064 _tok
        | Elpi_lexer_config.Tokens.NIL ->
            let _startpos_17 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_18 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_18, _startpos_17) in
            let _v = _menhir_action_089 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState064 _tok
        | Elpi_lexer_config.Tokens.NAME ->
            let _startpos_20 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_21 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_21, _startpos_20) in
            let _v = _menhir_action_077 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState064 _tok
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState064
        | Elpi_lexer_config.Tokens.LCURLY ->
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState064
        | Elpi_lexer_config.Tokens.LBRACKET ->
            _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState064
        | Elpi_lexer_config.Tokens.IO _v_23 ->
            let _startpos_24 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_25 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_25, _startpos_24, _v_23) in
            let _v = _menhir_action_082 c in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState064 _tok
        | Elpi_lexer_config.Tokens.INTEGER _v_27 ->
            let _startpos_28 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_29 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_29, _startpos_28, _v_27) in
            let _v = _menhir_action_066 x in
            _menhir_run_053_spec_064 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.INDEX ->
            let _startpos_31 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_32 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_32, _startpos_31) in
            let _v = _menhir_action_081 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState064 _tok
        | Elpi_lexer_config.Tokens.IF ->
            let _startpos_34 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_35 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_35, _startpos_34) in
            let _v = _menhir_action_076 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState064 _tok
        | Elpi_lexer_config.Tokens.FRESHUV ->
            let _startpos_37 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_38 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_38, _startpos_37) in
            let _v = _menhir_action_086 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState064 _tok
        | Elpi_lexer_config.Tokens.FLOAT _v_40 ->
            let _startpos_41 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_42 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_42, _startpos_41, _v_40) in
            let _v = _menhir_action_067 x in
            _menhir_run_053_spec_064 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_TILDE _v_44 ->
            _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer _v_44 MenhirState064
        | Elpi_lexer_config.Tokens.CUT ->
            let _startpos_45 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_46 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_46, _startpos_45) in
            let _v = _menhir_action_083 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState064 _tok
        | Elpi_lexer_config.Tokens.CONSTANT _v_48 ->
            let _startpos_49 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_50 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_50, _startpos_49, _v_48) in
            let _v = _menhir_action_075 c in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState064 _tok
        | Elpi_lexer_config.Tokens.BEFORE ->
            let _startpos_52 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_53 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_53, _startpos_52) in
            let _v = _menhir_action_078 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState064 _tok
        | Elpi_lexer_config.Tokens.AFTER ->
            let _startpos_55 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_56 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_56, _startpos_55) in
            let _v = _menhir_action_079 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState064 _tok
        | _ ->
            _eRR 64
    
    and _menhir_run_053_spec_064 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term _menhir_cell0_FAMILY_AND -> _ -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_317 t in
        _menhir_run_065 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v MenhirState064 _tok
    
    and _menhir_run_065 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_term _menhir_cell0_FAMILY_AND as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_0 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_1 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_041 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.AS | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.CONS | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.DIV | Elpi_lexer_config.Tokens.EOF | Elpi_lexer_config.Tokens.EQ | Elpi_lexer_config.Tokens.EQ2 | Elpi_lexer_config.Tokens.FAMILY_BTICK _ | Elpi_lexer_config.Tokens.FAMILY_EQ _ | Elpi_lexer_config.Tokens.FAMILY_EXP _ | Elpi_lexer_config.Tokens.FAMILY_GT _ | Elpi_lexer_config.Tokens.FAMILY_LT _ | Elpi_lexer_config.Tokens.FAMILY_MINUS _ | Elpi_lexer_config.Tokens.FAMILY_OR _ | Elpi_lexer_config.Tokens.FAMILY_PLUS _ | Elpi_lexer_config.Tokens.FAMILY_TICK _ | Elpi_lexer_config.Tokens.FAMILY_TIMES _ | Elpi_lexer_config.Tokens.FULLSTOP | Elpi_lexer_config.Tokens.IFF | Elpi_lexer_config.Tokens.IS | Elpi_lexer_config.Tokens.MINUS | Elpi_lexer_config.Tokens.MINUSi | Elpi_lexer_config.Tokens.MINUSr | Elpi_lexer_config.Tokens.MINUSs | Elpi_lexer_config.Tokens.MOD | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.PIPE | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.RBRACKET | Elpi_lexer_config.Tokens.RCURLY | Elpi_lexer_config.Tokens.RPAREN | Elpi_lexer_config.Tokens.SLASH | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_FAMILY_AND (_menhir_stack, s, _, _) = _menhir_stack in
            let MenhirCell1_term (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_225 _endpos_r_ _startpos_l_ l r s in
            _menhir_goto_open_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 65
    
    and _menhir_run_051 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.BIND ->
            let _menhir_stack = MenhirCell1_constant (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState051
        | Elpi_lexer_config.Tokens.AFTER | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.AS | Elpi_lexer_config.Tokens.BEFORE | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.CONS | Elpi_lexer_config.Tokens.CONSTANT _ | Elpi_lexer_config.Tokens.CUT | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.DIV | Elpi_lexer_config.Tokens.EOF | Elpi_lexer_config.Tokens.EQ | Elpi_lexer_config.Tokens.EQ2 | Elpi_lexer_config.Tokens.FAMILY_AND _ | Elpi_lexer_config.Tokens.FAMILY_BTICK _ | Elpi_lexer_config.Tokens.FAMILY_EQ _ | Elpi_lexer_config.Tokens.FAMILY_EXP _ | Elpi_lexer_config.Tokens.FAMILY_GT _ | Elpi_lexer_config.Tokens.FAMILY_LT _ | Elpi_lexer_config.Tokens.FAMILY_MINUS _ | Elpi_lexer_config.Tokens.FAMILY_OR _ | Elpi_lexer_config.Tokens.FAMILY_PLUS _ | Elpi_lexer_config.Tokens.FAMILY_QMARK _ | Elpi_lexer_config.Tokens.FAMILY_SHARP _ | Elpi_lexer_config.Tokens.FAMILY_TICK _ | Elpi_lexer_config.Tokens.FAMILY_TIMES _ | Elpi_lexer_config.Tokens.FLOAT _ | Elpi_lexer_config.Tokens.FRESHUV | Elpi_lexer_config.Tokens.FULLSTOP | Elpi_lexer_config.Tokens.IF | Elpi_lexer_config.Tokens.IFF | Elpi_lexer_config.Tokens.INDEX | Elpi_lexer_config.Tokens.INTEGER _ | Elpi_lexer_config.Tokens.IO _ | Elpi_lexer_config.Tokens.IS | Elpi_lexer_config.Tokens.LBRACKET | Elpi_lexer_config.Tokens.LCURLY | Elpi_lexer_config.Tokens.LPAREN | Elpi_lexer_config.Tokens.MINUS | Elpi_lexer_config.Tokens.MINUSi | Elpi_lexer_config.Tokens.MINUSr | Elpi_lexer_config.Tokens.MINUSs | Elpi_lexer_config.Tokens.MOD | Elpi_lexer_config.Tokens.NAME | Elpi_lexer_config.Tokens.NIL | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.PI | Elpi_lexer_config.Tokens.PIPE | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.QUOTED _ | Elpi_lexer_config.Tokens.RBRACKET | Elpi_lexer_config.Tokens.RCURLY | Elpi_lexer_config.Tokens.REPLACE | Elpi_lexer_config.Tokens.RPAREN | Elpi_lexer_config.Tokens.SIGMA | Elpi_lexer_config.Tokens.SLASH | Elpi_lexer_config.Tokens.STRING _ | Elpi_lexer_config.Tokens.VDASH ->
            let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
            let _v = _menhir_action_113 t in
            _menhir_goto_head_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v _menhir_s _tok
        | _ ->
            _eRR 51
    
    and _menhir_run_038 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell1_BIND (_menhir_stack, _menhir_s, _startpos, _endpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v ->
            let _startpos_0 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_1 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_1, _startpos_0, _v) in
            let _v = _menhir_action_068 x in
            _menhir_run_053_spec_038 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.SIGMA ->
            let _startpos_2 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_3 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_3, _startpos_2) in
            let _v = _menhir_action_085 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState038 _tok
        | Elpi_lexer_config.Tokens.REPLACE ->
            let _startpos_4 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_5 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_5, _startpos_4) in
            let _v = _menhir_action_080 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState038 _tok
        | Elpi_lexer_config.Tokens.QUOTED _v ->
            let _startpos_6 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_7 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_7, _startpos_6, _v) in
            let _v = _menhir_action_069 _endpos_x_ _startpos_x_ x in
            _menhir_run_053_spec_038 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.PI ->
            let _startpos_8 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_9 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_9, _startpos_8) in
            let _v = _menhir_action_084 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState038 _tok
        | Elpi_lexer_config.Tokens.NIL ->
            let _startpos_10 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_11 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_11, _startpos_10) in
            let _v = _menhir_action_089 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState038 _tok
        | Elpi_lexer_config.Tokens.NAME ->
            let _startpos_12 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_13 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_13, _startpos_12) in
            let _v = _menhir_action_077 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState038 _tok
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState038
        | Elpi_lexer_config.Tokens.LCURLY ->
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState038
        | Elpi_lexer_config.Tokens.LBRACKET ->
            _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState038
        | Elpi_lexer_config.Tokens.IO _v ->
            let _startpos_14 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_15 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_15, _startpos_14, _v) in
            let _v = _menhir_action_082 c in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState038 _tok
        | Elpi_lexer_config.Tokens.INTEGER _v ->
            let _startpos_16 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_17 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_17, _startpos_16, _v) in
            let _v = _menhir_action_066 x in
            _menhir_run_053_spec_038 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.INDEX ->
            let _startpos_18 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_19 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_19, _startpos_18) in
            let _v = _menhir_action_081 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState038 _tok
        | Elpi_lexer_config.Tokens.IF ->
            let _startpos_20 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_21 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_21, _startpos_20) in
            let _v = _menhir_action_076 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState038 _tok
        | Elpi_lexer_config.Tokens.FRESHUV ->
            let _startpos_22 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_23 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_23, _startpos_22) in
            let _v = _menhir_action_086 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState038 _tok
        | Elpi_lexer_config.Tokens.FLOAT _v ->
            let _startpos_24 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_25 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_25, _startpos_24, _v) in
            let _v = _menhir_action_067 x in
            _menhir_run_053_spec_038 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_TILDE _v ->
            _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState038
        | Elpi_lexer_config.Tokens.CUT ->
            let _startpos_26 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_27 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_27, _startpos_26) in
            let _v = _menhir_action_083 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState038 _tok
        | Elpi_lexer_config.Tokens.CONSTANT _v ->
            let _startpos_28 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_29 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_29, _startpos_28, _v) in
            let _v = _menhir_action_075 c in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState038 _tok
        | Elpi_lexer_config.Tokens.BEFORE ->
            let _startpos_30 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_31 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_31, _startpos_30) in
            let _v = _menhir_action_078 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState038 _tok
        | Elpi_lexer_config.Tokens.AFTER ->
            let _startpos_32 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_33 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_33, _startpos_32) in
            let _v = _menhir_action_079 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState038 _tok
        | _ ->
            _eRR 38
    
    and _menhir_run_053_spec_038 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_BIND -> _ -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_317 t in
        _menhir_run_055 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v MenhirState038 _tok
    
    and _menhir_run_055 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_BIND as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.VDASH ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_056 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.SLASH ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.QDASH ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_114 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.OR ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_072 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MOD ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_074 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSs ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_076 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSr ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_082 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSi ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_084 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_086 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.IS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_088 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FAMILY_TIMES _v_0 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_078 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_TICK _v_1 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_090 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_3 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_041 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_PLUS _v_4 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_092 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_5 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_6 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.FAMILY_LT _v_7 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_098 _menhir_stack _menhir_lexbuf _menhir_lexer _v_7
        | Elpi_lexer_config.Tokens.FAMILY_GT _v_8 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_100 _menhir_stack _menhir_lexbuf _menhir_lexer _v_8
        | Elpi_lexer_config.Tokens.FAMILY_EXP _v_9 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_094 _menhir_stack _menhir_lexbuf _menhir_lexer _v_9
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_10 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer _v_10
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_11 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer _v_11
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_12 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer _v_12
        | Elpi_lexer_config.Tokens.EQ2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_102 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.EQ ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_104 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.DIV ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_080 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.DARROW ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_106 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_096 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONJ2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_108 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONJ ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_110 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.ARROW ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_112 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.AS | Elpi_lexer_config.Tokens.EOF | Elpi_lexer_config.Tokens.FULLSTOP | Elpi_lexer_config.Tokens.IFF | Elpi_lexer_config.Tokens.PIPE | Elpi_lexer_config.Tokens.RBRACKET | Elpi_lexer_config.Tokens.RCURLY | Elpi_lexer_config.Tokens.RPAREN ->
            let MenhirCell1_BIND (_menhir_stack, _menhir_s, _startpos_bind_, _endpos_bind_) = _menhir_stack in
            let (_endpos_b_, b, bind) = (_endpos, _v, ()) in
            let _v = _menhir_action_024 _endpos_bind_ _startpos_bind_ b bind in
            _menhir_goto_binder_body _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_b_ _v _menhir_s _tok
        | _ ->
            _eRR 55
    
    and _menhir_run_114 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell0_QDASH (_menhir_stack, _startpos, _endpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v ->
            let _startpos_0 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_1 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_1, _startpos_0, _v) in
            let _v = _menhir_action_068 x in
            _menhir_run_053_spec_114 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.SIGMA ->
            let _startpos_2 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_3 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_3, _startpos_2) in
            let _v = _menhir_action_085 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState114 _tok
        | Elpi_lexer_config.Tokens.REPLACE ->
            let _startpos_4 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_5 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_5, _startpos_4) in
            let _v = _menhir_action_080 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState114 _tok
        | Elpi_lexer_config.Tokens.QUOTED _v ->
            let _startpos_6 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_7 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_7, _startpos_6, _v) in
            let _v = _menhir_action_069 _endpos_x_ _startpos_x_ x in
            _menhir_run_053_spec_114 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.PI ->
            let _startpos_8 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_9 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_9, _startpos_8) in
            let _v = _menhir_action_084 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState114 _tok
        | Elpi_lexer_config.Tokens.NIL ->
            let _startpos_10 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_11 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_11, _startpos_10) in
            let _v = _menhir_action_089 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState114 _tok
        | Elpi_lexer_config.Tokens.NAME ->
            let _startpos_12 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_13 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_13, _startpos_12) in
            let _v = _menhir_action_077 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState114 _tok
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState114
        | Elpi_lexer_config.Tokens.LCURLY ->
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState114
        | Elpi_lexer_config.Tokens.LBRACKET ->
            _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState114
        | Elpi_lexer_config.Tokens.IO _v ->
            let _startpos_14 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_15 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_15, _startpos_14, _v) in
            let _v = _menhir_action_082 c in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState114 _tok
        | Elpi_lexer_config.Tokens.INTEGER _v ->
            let _startpos_16 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_17 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_17, _startpos_16, _v) in
            let _v = _menhir_action_066 x in
            _menhir_run_053_spec_114 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.INDEX ->
            let _startpos_18 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_19 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_19, _startpos_18) in
            let _v = _menhir_action_081 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState114 _tok
        | Elpi_lexer_config.Tokens.IF ->
            let _startpos_20 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_21 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_21, _startpos_20) in
            let _v = _menhir_action_076 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState114 _tok
        | Elpi_lexer_config.Tokens.FRESHUV ->
            let _startpos_22 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_23 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_23, _startpos_22) in
            let _v = _menhir_action_086 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState114 _tok
        | Elpi_lexer_config.Tokens.FLOAT _v ->
            let _startpos_24 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_25 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_25, _startpos_24, _v) in
            let _v = _menhir_action_067 x in
            _menhir_run_053_spec_114 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_TILDE _v ->
            _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState114
        | Elpi_lexer_config.Tokens.CUT ->
            let _startpos_26 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_27 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_27, _startpos_26) in
            let _v = _menhir_action_083 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState114 _tok
        | Elpi_lexer_config.Tokens.CONSTANT _v ->
            let _startpos_28 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_29 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_29, _startpos_28, _v) in
            let _v = _menhir_action_075 c in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState114 _tok
        | Elpi_lexer_config.Tokens.BEFORE ->
            let _startpos_30 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_31 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_31, _startpos_30) in
            let _v = _menhir_action_078 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState114 _tok
        | Elpi_lexer_config.Tokens.AFTER ->
            let _startpos_32 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_33 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_33, _startpos_32) in
            let _v = _menhir_action_079 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState114 _tok
        | _ ->
            _eRR 114
    
    and _menhir_run_053_spec_114 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term _menhir_cell0_QDASH -> _ -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_317 t in
        _menhir_run_115 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v MenhirState114 _tok
    
    and _menhir_run_115 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_term _menhir_cell0_QDASH as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.SLASH ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.OR ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_072 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MOD ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_074 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSs ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_076 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSr ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_082 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSi ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_084 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_086 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.IS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_088 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FAMILY_TIMES _v_0 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_078 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_TICK _v_1 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_090 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_3 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_041 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_PLUS _v_4 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_092 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_5 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_6 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.FAMILY_LT _v_7 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_098 _menhir_stack _menhir_lexbuf _menhir_lexer _v_7
        | Elpi_lexer_config.Tokens.FAMILY_GT _v_8 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_100 _menhir_stack _menhir_lexbuf _menhir_lexer _v_8
        | Elpi_lexer_config.Tokens.FAMILY_EXP _v_9 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_094 _menhir_stack _menhir_lexbuf _menhir_lexer _v_9
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_10 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer _v_10
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_11 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer _v_11
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_12 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer _v_12
        | Elpi_lexer_config.Tokens.EQ2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_102 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.EQ ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_104 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.DIV ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_080 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.DARROW ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_106 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_096 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONJ2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_108 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONJ ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_110 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.ARROW ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_112 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.AS | Elpi_lexer_config.Tokens.EOF | Elpi_lexer_config.Tokens.FULLSTOP | Elpi_lexer_config.Tokens.IFF | Elpi_lexer_config.Tokens.PIPE | Elpi_lexer_config.Tokens.RBRACKET | Elpi_lexer_config.Tokens.RCURLY | Elpi_lexer_config.Tokens.RPAREN ->
            let MenhirCell0_QDASH (_menhir_stack, _, _) = _menhir_stack in
            let MenhirCell1_term (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_243 _endpos_r_ _startpos_l_ l r in
            _menhir_goto_open_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 115
    
    and _menhir_run_072 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell0_OR (_menhir_stack, _startpos, _endpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v ->
            let _startpos_0 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_1 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_1, _startpos_0, _v) in
            let _v = _menhir_action_068 x in
            _menhir_run_053_spec_072 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.SIGMA ->
            let _startpos_2 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_3 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_3, _startpos_2) in
            let _v = _menhir_action_085 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState072 _tok
        | Elpi_lexer_config.Tokens.REPLACE ->
            let _startpos_4 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_5 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_5, _startpos_4) in
            let _v = _menhir_action_080 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState072 _tok
        | Elpi_lexer_config.Tokens.QUOTED _v ->
            let _startpos_6 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_7 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_7, _startpos_6, _v) in
            let _v = _menhir_action_069 _endpos_x_ _startpos_x_ x in
            _menhir_run_053_spec_072 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.PI ->
            let _startpos_8 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_9 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_9, _startpos_8) in
            let _v = _menhir_action_084 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState072 _tok
        | Elpi_lexer_config.Tokens.NIL ->
            let _startpos_10 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_11 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_11, _startpos_10) in
            let _v = _menhir_action_089 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState072 _tok
        | Elpi_lexer_config.Tokens.NAME ->
            let _startpos_12 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_13 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_13, _startpos_12) in
            let _v = _menhir_action_077 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState072 _tok
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState072
        | Elpi_lexer_config.Tokens.LCURLY ->
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState072
        | Elpi_lexer_config.Tokens.LBRACKET ->
            _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState072
        | Elpi_lexer_config.Tokens.IO _v ->
            let _startpos_14 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_15 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_15, _startpos_14, _v) in
            let _v = _menhir_action_082 c in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState072 _tok
        | Elpi_lexer_config.Tokens.INTEGER _v ->
            let _startpos_16 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_17 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_17, _startpos_16, _v) in
            let _v = _menhir_action_066 x in
            _menhir_run_053_spec_072 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.INDEX ->
            let _startpos_18 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_19 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_19, _startpos_18) in
            let _v = _menhir_action_081 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState072 _tok
        | Elpi_lexer_config.Tokens.IF ->
            let _startpos_20 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_21 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_21, _startpos_20) in
            let _v = _menhir_action_076 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState072 _tok
        | Elpi_lexer_config.Tokens.FRESHUV ->
            let _startpos_22 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_23 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_23, _startpos_22) in
            let _v = _menhir_action_086 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState072 _tok
        | Elpi_lexer_config.Tokens.FLOAT _v ->
            let _startpos_24 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_25 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_25, _startpos_24, _v) in
            let _v = _menhir_action_067 x in
            _menhir_run_053_spec_072 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_TILDE _v ->
            _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState072
        | Elpi_lexer_config.Tokens.CUT ->
            let _startpos_26 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_27 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_27, _startpos_26) in
            let _v = _menhir_action_083 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState072 _tok
        | Elpi_lexer_config.Tokens.CONSTANT _v ->
            let _startpos_28 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_29 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_29, _startpos_28, _v) in
            let _v = _menhir_action_075 c in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState072 _tok
        | Elpi_lexer_config.Tokens.BEFORE ->
            let _startpos_30 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_31 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_31, _startpos_30) in
            let _v = _menhir_action_078 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState072 _tok
        | Elpi_lexer_config.Tokens.AFTER ->
            let _startpos_32 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_33 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_33, _startpos_32) in
            let _v = _menhir_action_079 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState072 _tok
        | _ ->
            _eRR 72
    
    and _menhir_run_053_spec_072 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term _menhir_cell0_OR -> _ -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_317 t in
        _menhir_run_073 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v MenhirState072 _tok
    
    and _menhir_run_073 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_term _menhir_cell0_OR as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.SLASH ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.OR ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_072 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MOD ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_074 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSs ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_076 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSr ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_082 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSi ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_084 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_086 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.IS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_088 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FAMILY_TIMES _v_0 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_078 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_TICK _v_1 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_090 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_3 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_041 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_PLUS _v_4 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_092 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_5 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_6 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.FAMILY_LT _v_7 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_098 _menhir_stack _menhir_lexbuf _menhir_lexer _v_7
        | Elpi_lexer_config.Tokens.FAMILY_GT _v_8 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_100 _menhir_stack _menhir_lexbuf _menhir_lexer _v_8
        | Elpi_lexer_config.Tokens.FAMILY_EXP _v_9 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_094 _menhir_stack _menhir_lexbuf _menhir_lexer _v_9
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_10 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer _v_10
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_11 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer _v_11
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_12 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer _v_12
        | Elpi_lexer_config.Tokens.EQ2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_102 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.EQ ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_104 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.DIV ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_080 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.DARROW ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_106 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_096 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONJ2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_108 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONJ ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_110 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.ARROW ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_112 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.AS | Elpi_lexer_config.Tokens.EOF | Elpi_lexer_config.Tokens.FULLSTOP | Elpi_lexer_config.Tokens.IFF | Elpi_lexer_config.Tokens.PIPE | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.RBRACKET | Elpi_lexer_config.Tokens.RCURLY | Elpi_lexer_config.Tokens.RPAREN | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_OR (_menhir_stack, _, _) = _menhir_stack in
            let MenhirCell1_term (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_237 _endpos_r_ _startpos_l_ l r in
            _menhir_goto_open_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 73
    
    and _menhir_run_076 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell0_MINUSs (_menhir_stack, _startpos, _endpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v ->
            let _startpos_0 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_1 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_1, _startpos_0, _v) in
            let _v = _menhir_action_068 x in
            _menhir_run_053_spec_076 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.SIGMA ->
            let _startpos_2 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_3 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_3, _startpos_2) in
            let _v = _menhir_action_085 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState076 _tok
        | Elpi_lexer_config.Tokens.REPLACE ->
            let _startpos_4 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_5 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_5, _startpos_4) in
            let _v = _menhir_action_080 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState076 _tok
        | Elpi_lexer_config.Tokens.QUOTED _v ->
            let _startpos_6 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_7 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_7, _startpos_6, _v) in
            let _v = _menhir_action_069 _endpos_x_ _startpos_x_ x in
            _menhir_run_053_spec_076 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.PI ->
            let _startpos_8 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_9 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_9, _startpos_8) in
            let _v = _menhir_action_084 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState076 _tok
        | Elpi_lexer_config.Tokens.NIL ->
            let _startpos_10 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_11 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_11, _startpos_10) in
            let _v = _menhir_action_089 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState076 _tok
        | Elpi_lexer_config.Tokens.NAME ->
            let _startpos_12 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_13 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_13, _startpos_12) in
            let _v = _menhir_action_077 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState076 _tok
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState076
        | Elpi_lexer_config.Tokens.LCURLY ->
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState076
        | Elpi_lexer_config.Tokens.LBRACKET ->
            _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState076
        | Elpi_lexer_config.Tokens.IO _v ->
            let _startpos_14 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_15 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_15, _startpos_14, _v) in
            let _v = _menhir_action_082 c in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState076 _tok
        | Elpi_lexer_config.Tokens.INTEGER _v ->
            let _startpos_16 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_17 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_17, _startpos_16, _v) in
            let _v = _menhir_action_066 x in
            _menhir_run_053_spec_076 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.INDEX ->
            let _startpos_18 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_19 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_19, _startpos_18) in
            let _v = _menhir_action_081 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState076 _tok
        | Elpi_lexer_config.Tokens.IF ->
            let _startpos_20 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_21 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_21, _startpos_20) in
            let _v = _menhir_action_076 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState076 _tok
        | Elpi_lexer_config.Tokens.FRESHUV ->
            let _startpos_22 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_23 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_23, _startpos_22) in
            let _v = _menhir_action_086 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState076 _tok
        | Elpi_lexer_config.Tokens.FLOAT _v ->
            let _startpos_24 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_25 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_25, _startpos_24, _v) in
            let _v = _menhir_action_067 x in
            _menhir_run_053_spec_076 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_TILDE _v ->
            _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState076
        | Elpi_lexer_config.Tokens.CUT ->
            let _startpos_26 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_27 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_27, _startpos_26) in
            let _v = _menhir_action_083 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState076 _tok
        | Elpi_lexer_config.Tokens.CONSTANT _v ->
            let _startpos_28 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_29 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_29, _startpos_28, _v) in
            let _v = _menhir_action_075 c in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState076 _tok
        | Elpi_lexer_config.Tokens.BEFORE ->
            let _startpos_30 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_31 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_31, _startpos_30) in
            let _v = _menhir_action_078 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState076 _tok
        | Elpi_lexer_config.Tokens.AFTER ->
            let _startpos_32 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_33 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_33, _startpos_32) in
            let _v = _menhir_action_079 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState076 _tok
        | _ ->
            _eRR 76
    
    and _menhir_run_053_spec_076 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term _menhir_cell0_MINUSs -> _ -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_317 t in
        _menhir_run_077 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v MenhirState076 _tok
    
    and _menhir_run_077 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_term _menhir_cell0_MINUSs as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.SLASH ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MOD ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_074 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FAMILY_TIMES _v_0 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_078 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_1 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_041 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_3 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_4 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_5 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_6 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_7 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer _v_7
        | Elpi_lexer_config.Tokens.DIV ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_080 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.AS | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.CONS | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.EOF | Elpi_lexer_config.Tokens.EQ | Elpi_lexer_config.Tokens.EQ2 | Elpi_lexer_config.Tokens.FAMILY_EXP _ | Elpi_lexer_config.Tokens.FAMILY_GT _ | Elpi_lexer_config.Tokens.FAMILY_LT _ | Elpi_lexer_config.Tokens.FAMILY_PLUS _ | Elpi_lexer_config.Tokens.FAMILY_TICK _ | Elpi_lexer_config.Tokens.FULLSTOP | Elpi_lexer_config.Tokens.IFF | Elpi_lexer_config.Tokens.IS | Elpi_lexer_config.Tokens.MINUS | Elpi_lexer_config.Tokens.MINUSi | Elpi_lexer_config.Tokens.MINUSr | Elpi_lexer_config.Tokens.MINUSs | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.PIPE | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.RBRACKET | Elpi_lexer_config.Tokens.RCURLY | Elpi_lexer_config.Tokens.RPAREN | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_MINUSs (_menhir_stack, _, _) = _menhir_stack in
            let MenhirCell1_term (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_235 _endpos_r_ _startpos_l_ l r in
            _menhir_goto_open_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 77
    
    and _menhir_run_078 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell0_FAMILY_TIMES (_menhir_stack, _v, _startpos, _endpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v_0 ->
            let _startpos_1 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_2 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_2, _startpos_1, _v_0) in
            let _v = _menhir_action_068 x in
            _menhir_run_053_spec_078 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.SIGMA ->
            let _startpos_4 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_5 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_5, _startpos_4) in
            let _v = _menhir_action_085 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState078 _tok
        | Elpi_lexer_config.Tokens.REPLACE ->
            let _startpos_7 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_8 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_8, _startpos_7) in
            let _v = _menhir_action_080 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState078 _tok
        | Elpi_lexer_config.Tokens.QUOTED _v_10 ->
            let _startpos_11 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_12 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_12, _startpos_11, _v_10) in
            let _v = _menhir_action_069 _endpos_x_ _startpos_x_ x in
            _menhir_run_053_spec_078 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.PI ->
            let _startpos_14 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_15 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_15, _startpos_14) in
            let _v = _menhir_action_084 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState078 _tok
        | Elpi_lexer_config.Tokens.NIL ->
            let _startpos_17 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_18 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_18, _startpos_17) in
            let _v = _menhir_action_089 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState078 _tok
        | Elpi_lexer_config.Tokens.NAME ->
            let _startpos_20 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_21 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_21, _startpos_20) in
            let _v = _menhir_action_077 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState078 _tok
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState078
        | Elpi_lexer_config.Tokens.LCURLY ->
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState078
        | Elpi_lexer_config.Tokens.LBRACKET ->
            _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState078
        | Elpi_lexer_config.Tokens.IO _v_23 ->
            let _startpos_24 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_25 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_25, _startpos_24, _v_23) in
            let _v = _menhir_action_082 c in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState078 _tok
        | Elpi_lexer_config.Tokens.INTEGER _v_27 ->
            let _startpos_28 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_29 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_29, _startpos_28, _v_27) in
            let _v = _menhir_action_066 x in
            _menhir_run_053_spec_078 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.INDEX ->
            let _startpos_31 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_32 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_32, _startpos_31) in
            let _v = _menhir_action_081 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState078 _tok
        | Elpi_lexer_config.Tokens.IF ->
            let _startpos_34 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_35 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_35, _startpos_34) in
            let _v = _menhir_action_076 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState078 _tok
        | Elpi_lexer_config.Tokens.FRESHUV ->
            let _startpos_37 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_38 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_38, _startpos_37) in
            let _v = _menhir_action_086 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState078 _tok
        | Elpi_lexer_config.Tokens.FLOAT _v_40 ->
            let _startpos_41 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_42 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_42, _startpos_41, _v_40) in
            let _v = _menhir_action_067 x in
            _menhir_run_053_spec_078 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_TILDE _v_44 ->
            _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer _v_44 MenhirState078
        | Elpi_lexer_config.Tokens.CUT ->
            let _startpos_45 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_46 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_46, _startpos_45) in
            let _v = _menhir_action_083 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState078 _tok
        | Elpi_lexer_config.Tokens.CONSTANT _v_48 ->
            let _startpos_49 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_50 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_50, _startpos_49, _v_48) in
            let _v = _menhir_action_075 c in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState078 _tok
        | Elpi_lexer_config.Tokens.BEFORE ->
            let _startpos_52 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_53 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_53, _startpos_52) in
            let _v = _menhir_action_078 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState078 _tok
        | Elpi_lexer_config.Tokens.AFTER ->
            let _startpos_55 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_56 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_56, _startpos_55) in
            let _v = _menhir_action_079 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState078 _tok
        | _ ->
            _eRR 78
    
    and _menhir_run_053_spec_078 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term _menhir_cell0_FAMILY_TIMES -> _ -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_317 t in
        _menhir_run_079 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v MenhirState078 _tok
    
    and _menhir_run_079 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_term _menhir_cell0_FAMILY_TIMES as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_0 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_1 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_041 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_3 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_4 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_5 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_6 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.AS | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.CONS | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.DIV | Elpi_lexer_config.Tokens.EOF | Elpi_lexer_config.Tokens.EQ | Elpi_lexer_config.Tokens.EQ2 | Elpi_lexer_config.Tokens.FAMILY_EXP _ | Elpi_lexer_config.Tokens.FAMILY_GT _ | Elpi_lexer_config.Tokens.FAMILY_LT _ | Elpi_lexer_config.Tokens.FAMILY_PLUS _ | Elpi_lexer_config.Tokens.FAMILY_TICK _ | Elpi_lexer_config.Tokens.FAMILY_TIMES _ | Elpi_lexer_config.Tokens.FULLSTOP | Elpi_lexer_config.Tokens.IFF | Elpi_lexer_config.Tokens.IS | Elpi_lexer_config.Tokens.MINUS | Elpi_lexer_config.Tokens.MINUSi | Elpi_lexer_config.Tokens.MINUSr | Elpi_lexer_config.Tokens.MINUSs | Elpi_lexer_config.Tokens.MOD | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.PIPE | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.RBRACKET | Elpi_lexer_config.Tokens.RCURLY | Elpi_lexer_config.Tokens.RPAREN | Elpi_lexer_config.Tokens.SLASH | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_FAMILY_TIMES (_menhir_stack, s, _, _) = _menhir_stack in
            let MenhirCell1_term (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_219 _endpos_r_ _startpos_l_ l r s in
            _menhir_goto_open_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 79
    
    and _menhir_run_066 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell0_FAMILY_MINUS (_menhir_stack, _v, _startpos, _endpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v_0 ->
            let _startpos_1 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_2 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_2, _startpos_1, _v_0) in
            let _v = _menhir_action_068 x in
            _menhir_run_053_spec_066 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.SIGMA ->
            let _startpos_4 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_5 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_5, _startpos_4) in
            let _v = _menhir_action_085 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState066 _tok
        | Elpi_lexer_config.Tokens.REPLACE ->
            let _startpos_7 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_8 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_8, _startpos_7) in
            let _v = _menhir_action_080 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState066 _tok
        | Elpi_lexer_config.Tokens.QUOTED _v_10 ->
            let _startpos_11 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_12 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_12, _startpos_11, _v_10) in
            let _v = _menhir_action_069 _endpos_x_ _startpos_x_ x in
            _menhir_run_053_spec_066 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.PI ->
            let _startpos_14 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_15 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_15, _startpos_14) in
            let _v = _menhir_action_084 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState066 _tok
        | Elpi_lexer_config.Tokens.NIL ->
            let _startpos_17 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_18 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_18, _startpos_17) in
            let _v = _menhir_action_089 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState066 _tok
        | Elpi_lexer_config.Tokens.NAME ->
            let _startpos_20 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_21 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_21, _startpos_20) in
            let _v = _menhir_action_077 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState066 _tok
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState066
        | Elpi_lexer_config.Tokens.LCURLY ->
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState066
        | Elpi_lexer_config.Tokens.LBRACKET ->
            _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState066
        | Elpi_lexer_config.Tokens.IO _v_23 ->
            let _startpos_24 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_25 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_25, _startpos_24, _v_23) in
            let _v = _menhir_action_082 c in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState066 _tok
        | Elpi_lexer_config.Tokens.INTEGER _v_27 ->
            let _startpos_28 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_29 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_29, _startpos_28, _v_27) in
            let _v = _menhir_action_066 x in
            _menhir_run_053_spec_066 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.INDEX ->
            let _startpos_31 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_32 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_32, _startpos_31) in
            let _v = _menhir_action_081 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState066 _tok
        | Elpi_lexer_config.Tokens.IF ->
            let _startpos_34 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_35 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_35, _startpos_34) in
            let _v = _menhir_action_076 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState066 _tok
        | Elpi_lexer_config.Tokens.FRESHUV ->
            let _startpos_37 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_38 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_38, _startpos_37) in
            let _v = _menhir_action_086 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState066 _tok
        | Elpi_lexer_config.Tokens.FLOAT _v_40 ->
            let _startpos_41 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_42 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_42, _startpos_41, _v_40) in
            let _v = _menhir_action_067 x in
            _menhir_run_053_spec_066 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_TILDE _v_44 ->
            _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer _v_44 MenhirState066
        | Elpi_lexer_config.Tokens.CUT ->
            let _startpos_45 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_46 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_46, _startpos_45) in
            let _v = _menhir_action_083 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState066 _tok
        | Elpi_lexer_config.Tokens.CONSTANT _v_48 ->
            let _startpos_49 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_50 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_50, _startpos_49, _v_48) in
            let _v = _menhir_action_075 c in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState066 _tok
        | Elpi_lexer_config.Tokens.BEFORE ->
            let _startpos_52 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_53 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_53, _startpos_52) in
            let _v = _menhir_action_078 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState066 _tok
        | Elpi_lexer_config.Tokens.AFTER ->
            let _startpos_55 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_56 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_56, _startpos_55) in
            let _v = _menhir_action_079 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState066 _tok
        | _ ->
            _eRR 66
    
    and _menhir_run_053_spec_066 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term _menhir_cell0_FAMILY_MINUS -> _ -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_317 t in
        _menhir_run_067 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v MenhirState066 _tok
    
    and _menhir_run_067 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_term _menhir_cell0_FAMILY_MINUS as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_0 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_1 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_041 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_3 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_4 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_5 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_6 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.AS | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.CONS | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.DIV | Elpi_lexer_config.Tokens.EOF | Elpi_lexer_config.Tokens.EQ | Elpi_lexer_config.Tokens.EQ2 | Elpi_lexer_config.Tokens.FAMILY_EXP _ | Elpi_lexer_config.Tokens.FAMILY_GT _ | Elpi_lexer_config.Tokens.FAMILY_LT _ | Elpi_lexer_config.Tokens.FAMILY_PLUS _ | Elpi_lexer_config.Tokens.FAMILY_TICK _ | Elpi_lexer_config.Tokens.FAMILY_TIMES _ | Elpi_lexer_config.Tokens.FULLSTOP | Elpi_lexer_config.Tokens.IFF | Elpi_lexer_config.Tokens.IS | Elpi_lexer_config.Tokens.MINUS | Elpi_lexer_config.Tokens.MINUSi | Elpi_lexer_config.Tokens.MINUSr | Elpi_lexer_config.Tokens.MINUSs | Elpi_lexer_config.Tokens.MOD | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.PIPE | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.RBRACKET | Elpi_lexer_config.Tokens.RCURLY | Elpi_lexer_config.Tokens.RPAREN | Elpi_lexer_config.Tokens.SLASH | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_FAMILY_MINUS (_menhir_stack, s, _, _) = _menhir_stack in
            let MenhirCell1_term (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_220 _endpos_r_ _startpos_l_ l r s in
            _menhir_goto_open_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 67
    
    and _menhir_run_068 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell0_FAMILY_EQ (_menhir_stack, _v, _startpos, _endpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v_0 ->
            let _startpos_1 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_2 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_2, _startpos_1, _v_0) in
            let _v = _menhir_action_068 x in
            _menhir_run_053_spec_068 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.SIGMA ->
            let _startpos_4 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_5 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_5, _startpos_4) in
            let _v = _menhir_action_085 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState068 _tok
        | Elpi_lexer_config.Tokens.REPLACE ->
            let _startpos_7 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_8 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_8, _startpos_7) in
            let _v = _menhir_action_080 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState068 _tok
        | Elpi_lexer_config.Tokens.QUOTED _v_10 ->
            let _startpos_11 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_12 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_12, _startpos_11, _v_10) in
            let _v = _menhir_action_069 _endpos_x_ _startpos_x_ x in
            _menhir_run_053_spec_068 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.PI ->
            let _startpos_14 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_15 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_15, _startpos_14) in
            let _v = _menhir_action_084 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState068 _tok
        | Elpi_lexer_config.Tokens.NIL ->
            let _startpos_17 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_18 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_18, _startpos_17) in
            let _v = _menhir_action_089 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState068 _tok
        | Elpi_lexer_config.Tokens.NAME ->
            let _startpos_20 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_21 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_21, _startpos_20) in
            let _v = _menhir_action_077 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState068 _tok
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState068
        | Elpi_lexer_config.Tokens.LCURLY ->
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState068
        | Elpi_lexer_config.Tokens.LBRACKET ->
            _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState068
        | Elpi_lexer_config.Tokens.IO _v_23 ->
            let _startpos_24 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_25 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_25, _startpos_24, _v_23) in
            let _v = _menhir_action_082 c in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState068 _tok
        | Elpi_lexer_config.Tokens.INTEGER _v_27 ->
            let _startpos_28 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_29 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_29, _startpos_28, _v_27) in
            let _v = _menhir_action_066 x in
            _menhir_run_053_spec_068 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.INDEX ->
            let _startpos_31 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_32 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_32, _startpos_31) in
            let _v = _menhir_action_081 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState068 _tok
        | Elpi_lexer_config.Tokens.IF ->
            let _startpos_34 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_35 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_35, _startpos_34) in
            let _v = _menhir_action_076 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState068 _tok
        | Elpi_lexer_config.Tokens.FRESHUV ->
            let _startpos_37 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_38 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_38, _startpos_37) in
            let _v = _menhir_action_086 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState068 _tok
        | Elpi_lexer_config.Tokens.FLOAT _v_40 ->
            let _startpos_41 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_42 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_42, _startpos_41, _v_40) in
            let _v = _menhir_action_067 x in
            _menhir_run_053_spec_068 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_TILDE _v_44 ->
            _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer _v_44 MenhirState068
        | Elpi_lexer_config.Tokens.CUT ->
            let _startpos_45 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_46 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_46, _startpos_45) in
            let _v = _menhir_action_083 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState068 _tok
        | Elpi_lexer_config.Tokens.CONSTANT _v_48 ->
            let _startpos_49 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_50 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_50, _startpos_49, _v_48) in
            let _v = _menhir_action_075 c in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState068 _tok
        | Elpi_lexer_config.Tokens.BEFORE ->
            let _startpos_52 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_53 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_53, _startpos_52) in
            let _v = _menhir_action_078 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState068 _tok
        | Elpi_lexer_config.Tokens.AFTER ->
            let _startpos_55 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_56 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_56, _startpos_55) in
            let _v = _menhir_action_079 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState068 _tok
        | _ ->
            _eRR 68
    
    and _menhir_run_053_spec_068 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term _menhir_cell0_FAMILY_EQ -> _ -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_317 t in
        _menhir_run_069 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v MenhirState068 _tok
    
    and _menhir_run_069 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_term _menhir_cell0_FAMILY_EQ as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_0 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_1 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_041 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_3 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_4 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.AS | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.CONS | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.DIV | Elpi_lexer_config.Tokens.EOF | Elpi_lexer_config.Tokens.EQ | Elpi_lexer_config.Tokens.EQ2 | Elpi_lexer_config.Tokens.FAMILY_BTICK _ | Elpi_lexer_config.Tokens.FAMILY_EXP _ | Elpi_lexer_config.Tokens.FAMILY_GT _ | Elpi_lexer_config.Tokens.FAMILY_LT _ | Elpi_lexer_config.Tokens.FAMILY_MINUS _ | Elpi_lexer_config.Tokens.FAMILY_PLUS _ | Elpi_lexer_config.Tokens.FAMILY_TICK _ | Elpi_lexer_config.Tokens.FAMILY_TIMES _ | Elpi_lexer_config.Tokens.FULLSTOP | Elpi_lexer_config.Tokens.IFF | Elpi_lexer_config.Tokens.IS | Elpi_lexer_config.Tokens.MINUS | Elpi_lexer_config.Tokens.MINUSi | Elpi_lexer_config.Tokens.MINUSr | Elpi_lexer_config.Tokens.MINUSs | Elpi_lexer_config.Tokens.MOD | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.PIPE | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.RBRACKET | Elpi_lexer_config.Tokens.RCURLY | Elpi_lexer_config.Tokens.RPAREN | Elpi_lexer_config.Tokens.SLASH | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_FAMILY_EQ (_menhir_stack, s, _, _) = _menhir_stack in
            let MenhirCell1_term (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_224 _endpos_r_ _startpos_l_ l r s in
            _menhir_goto_open_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 69
    
    and _menhir_run_008 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_LPAREN (_menhir_stack, _menhir_s, _startpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.VDASH ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_201 () in
            _menhir_run_224 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.STRING _v ->
            let _startpos_1 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos, _startpos_1, _v) in
            let _v = _menhir_action_068 x in
            _menhir_run_053_spec_008 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.SLASH ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_198 () in
            _menhir_run_224 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.SIGMA ->
            let _startpos_3 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_3) in
            let _v = _menhir_action_085 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState008 _tok
        | Elpi_lexer_config.Tokens.REPLACE ->
            let _startpos_4 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_4) in
            let _v = _menhir_action_080 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState008 _tok
        | Elpi_lexer_config.Tokens.QUOTED _v ->
            let _startpos_5 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos, _startpos_5, _v) in
            let _v = _menhir_action_069 _endpos_x_ _startpos_x_ x in
            _menhir_run_053_spec_008 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.QDASH ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_197 () in
            _menhir_run_224 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.PI ->
            let _startpos_7 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_7) in
            let _v = _menhir_action_084 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState008 _tok
        | Elpi_lexer_config.Tokens.OR ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_191 () in
            _menhir_run_224 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.NIL ->
            let _startpos_9 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_9) in
            let _v = _menhir_action_089 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState008 _tok
        | Elpi_lexer_config.Tokens.NAME ->
            let _startpos_10 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_10) in
            let _v = _menhir_action_077 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState008 _tok
        | Elpi_lexer_config.Tokens.MOD ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_193 () in
            _menhir_run_224 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.MINUSs ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_189 () in
            _menhir_run_224 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.MINUSr ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_187 () in
            _menhir_run_224 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.MINUSi ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_188 () in
            _menhir_run_224 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.MINUS ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_186 () in
            _menhir_run_224 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState008
        | Elpi_lexer_config.Tokens.LCURLY ->
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState008
        | Elpi_lexer_config.Tokens.LBRACKET ->
            _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState008
        | Elpi_lexer_config.Tokens.IS ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_192 () in
            _menhir_run_224 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.IO _v ->
            let _startpos_17 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos, _startpos_17, _v) in
            let _v = _menhir_action_082 c in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState008 _tok
        | Elpi_lexer_config.Tokens.INTEGER _v ->
            let _startpos_18 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos, _startpos_18, _v) in
            let _v = _menhir_action_066 x in
            _menhir_run_053_spec_008 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.INDEX ->
            let _startpos_19 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_19) in
            let _v = _menhir_action_081 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState008 _tok
        | Elpi_lexer_config.Tokens.IF ->
            let _startpos_20 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_20) in
            let _v = _menhir_action_076 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState008 _tok
        | Elpi_lexer_config.Tokens.FRESHUV ->
            let _startpos_21 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_21) in
            let _v = _menhir_action_086 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState008 _tok
        | Elpi_lexer_config.Tokens.FLOAT _v ->
            let _startpos_22 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos, _startpos_22, _v) in
            let _v = _menhir_action_067 x in
            _menhir_run_053_spec_008 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_TIMES _v ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let s = _v in
            let _v = _menhir_action_173 s in
            _menhir_run_224 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_TILDE _v ->
            _menhir_run_196 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState008
        | Elpi_lexer_config.Tokens.FAMILY_TICK _v ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let s = _v in
            let _v = _menhir_action_183 s in
            _menhir_run_224 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let s = _v in
            let _v = _menhir_action_181 s in
            _menhir_run_224 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let s = _v in
            let _v = _menhir_action_203 s in
            _menhir_run_224 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_PLUS _v ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let s = _v in
            let _v = _menhir_action_172 s in
            _menhir_run_224 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_OR _v ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let s = _v in
            let _v = _menhir_action_180 s in
            _menhir_run_224 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let s = _v in
            let _v = _menhir_action_174 s in
            _menhir_run_224 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_LT _v ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let s = _v in
            let _v = _menhir_action_176 s in
            _menhir_run_224 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_GT _v ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let s = _v in
            let _v = _menhir_action_177 s in
            _menhir_run_224 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_EXP _v ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let s = _v in
            let _v = _menhir_action_175 s in
            _menhir_run_224 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let s = _v in
            let _v = _menhir_action_178 s in
            _menhir_run_224 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let s = _v in
            let _v = _menhir_action_182 s in
            _menhir_run_224 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_AND _v ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let s = _v in
            let _v = _menhir_action_179 s in
            _menhir_run_224 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.EQ2 ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_190 () in
            _menhir_run_224 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.EQ ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_185 () in
            _menhir_run_224 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.DIV ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_194 () in
            _menhir_run_224 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.DARROW ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_196 () in
            _menhir_run_224 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.CUT ->
            let _startpos_40 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_40) in
            let _v = _menhir_action_083 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState008 _tok
        | Elpi_lexer_config.Tokens.CONSTANT _v ->
            let _startpos_41 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos, _startpos_41, _v) in
            let _v = _menhir_action_075 c in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState008 _tok
        | Elpi_lexer_config.Tokens.CONS ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_184 () in
            _menhir_run_224 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.CONJ2 ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_199 () in
            _menhir_run_224 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.CONJ ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_200 () in
            _menhir_run_224 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.BEFORE ->
            let _startpos_45 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_45) in
            let _v = _menhir_action_078 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState008 _tok
        | Elpi_lexer_config.Tokens.AS ->
            _menhir_run_216 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.ARROW ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_195 () in
            _menhir_run_224 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.AFTER ->
            let _startpos_47 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_47) in
            let _v = _menhir_action_079 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState008 _tok
        | _ ->
            _eRR 8
    
    and _menhir_run_224 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_LPAREN -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.RPAREN ->
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let MenhirCell1_LPAREN (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
            let (s, _endpos__3_) = (_v, _endpos_0) in
            let _v = _menhir_action_087 s in
            _menhir_goto_constant _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__3_ _startpos__1_ _v _menhir_s _tok
        | _ ->
            _eRR 224
    
    and _menhir_goto_constant : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match _menhir_s with
        | MenhirState528 ->
            _menhir_run_535_spec_528 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | MenhirState533 ->
            _menhir_run_535_spec_533 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | MenhirState420 ->
            _menhir_run_463 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState445 ->
            _menhir_run_446 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState425 ->
            _menhir_run_426 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState367 ->
            _menhir_run_367 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState364 ->
            _menhir_run_367 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState354 ->
            _menhir_run_357 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState328 ->
            _menhir_run_329 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState325 ->
            _menhir_run_326 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _tok
        | MenhirState322 ->
            _menhir_run_323 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | MenhirState310 ->
            _menhir_run_314 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState316 ->
            _menhir_run_314 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState312 ->
            _menhir_run_314 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState304 ->
            _menhir_run_308 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState302 ->
            _menhir_run_303 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _tok
        | MenhirState292 ->
            _menhir_run_299_spec_292 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | MenhirState297 ->
            _menhir_run_297 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState294 ->
            _menhir_run_297 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState293 ->
            _menhir_run_294 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState421 ->
            _menhir_run_289 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState393 ->
            _menhir_run_289 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState360 ->
            _menhir_run_289 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState347 ->
            _menhir_run_289 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState341 ->
            _menhir_run_289 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState339 ->
            _menhir_run_289 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState290 ->
            _menhir_run_289 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState270 ->
            _menhir_run_289 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState286 ->
            _menhir_run_285_spec_286 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState279 ->
            _menhir_run_285_spec_279 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState447 ->
            _menhir_run_279 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState422 ->
            _menhir_run_279 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState361 ->
            _menhir_run_279 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState342 ->
            _menhir_run_279 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState300 ->
            _menhir_run_279 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState273 ->
            _menhir_run_279 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState274 ->
            _menhir_run_279 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState281 ->
            _menhir_run_279 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState277 ->
            _menhir_run_279 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState019 ->
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState187 ->
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState184 ->
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState021 ->
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState180 ->
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState123 ->
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState139 ->
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState175 ->
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState177 ->
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState173 ->
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState171 ->
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState169 ->
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState167 ->
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState165 ->
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState155 ->
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState163 ->
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState157 ->
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState161 ->
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState159 ->
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState153 ->
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState151 ->
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState149 ->
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState143 ->
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState147 ->
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState145 ->
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState141 ->
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState125 ->
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState133 ->
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState137 ->
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState135 ->
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState129 ->
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState131 ->
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState127 ->
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState028 ->
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState524 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState522 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState520 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState518 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState516 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState514 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState512 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState510 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState508 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState506 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState504 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState502 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState500 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState498 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState496 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState494 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState492 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState489 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState487 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState485 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState483 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState481 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState479 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState477 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState475 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState473 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState471 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState469 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState467 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState465 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState458 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState455 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState439 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState427 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState335 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState337 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState000 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState008 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState221 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState196 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState018 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState118 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState038 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState114 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState056 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState072 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState108 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState110 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState112 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState106 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState104 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState102 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState100 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState098 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState088 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState096 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState090 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState094 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState092 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState086 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState084 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState082 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState076 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState080 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState078 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState074 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState058 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState066 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState070 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState068 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState062 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState064 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState060 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState039 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState460 ->
            _menhir_run_048_spec_460 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState424 ->
            _menhir_run_048_spec_424 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState442 ->
            _menhir_run_048_spec_442 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState434 ->
            _menhir_run_048_spec_434 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState435 ->
            _menhir_run_048_spec_435 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState430 ->
            _menhir_run_048_spec_430 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState036 ->
            _menhir_run_048_spec_036 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState049 ->
            _menhir_run_048_spec_049 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState043 ->
            _menhir_run_048_spec_043 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_535_spec_528 : type  ttv_stack. (ttv_stack, _menhir_box_program) _menhir_cell1_accumulate -> _ -> _ -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok ->
        let c = _v in
        let _v = _menhir_action_107 c in
        _menhir_run_532 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState528 _tok
    
    and _menhir_run_532 : type  ttv_stack. ttv_stack -> _ -> _ -> _ -> (ttv_stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.CONJ ->
            let _menhir_stack = MenhirCell1_filename (_menhir_stack, _menhir_s, _v) in
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell0_CONJ (_menhir_stack, _startpos, _endpos) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Elpi_lexer_config.Tokens.STRING _v_0 ->
                let _tok = _menhir_lexer _menhir_lexbuf in
                let s = _v_0 in
                let _v = _menhir_action_108 s in
                _menhir_run_532 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState533 _tok
            | Elpi_lexer_config.Tokens.SIGMA ->
                let _tok = _menhir_lexer _menhir_lexbuf in
                let _v = _menhir_action_085 () in
                _menhir_run_535_spec_533 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
            | Elpi_lexer_config.Tokens.REPLACE ->
                let _tok = _menhir_lexer _menhir_lexbuf in
                let _v = _menhir_action_080 () in
                _menhir_run_535_spec_533 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
            | Elpi_lexer_config.Tokens.PI ->
                let _tok = _menhir_lexer _menhir_lexbuf in
                let _v = _menhir_action_084 () in
                _menhir_run_535_spec_533 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
            | Elpi_lexer_config.Tokens.NIL ->
                let _tok = _menhir_lexer _menhir_lexbuf in
                let _v = _menhir_action_089 () in
                _menhir_run_535_spec_533 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
            | Elpi_lexer_config.Tokens.NAME ->
                let _tok = _menhir_lexer _menhir_lexbuf in
                let _v = _menhir_action_077 () in
                _menhir_run_535_spec_533 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
            | Elpi_lexer_config.Tokens.LPAREN ->
                _menhir_run_271 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState533
            | Elpi_lexer_config.Tokens.IO _v_19 ->
                let _tok = _menhir_lexer _menhir_lexbuf in
                let c = _v_19 in
                let _v = _menhir_action_082 c in
                _menhir_run_535_spec_533 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
            | Elpi_lexer_config.Tokens.INDEX ->
                let _tok = _menhir_lexer _menhir_lexbuf in
                let _v = _menhir_action_081 () in
                _menhir_run_535_spec_533 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
            | Elpi_lexer_config.Tokens.IF ->
                let _tok = _menhir_lexer _menhir_lexbuf in
                let _v = _menhir_action_076 () in
                _menhir_run_535_spec_533 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
            | Elpi_lexer_config.Tokens.FRESHUV ->
                let _tok = _menhir_lexer _menhir_lexbuf in
                let _v = _menhir_action_086 () in
                _menhir_run_535_spec_533 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
            | Elpi_lexer_config.Tokens.CUT ->
                let _tok = _menhir_lexer _menhir_lexbuf in
                let _v = _menhir_action_083 () in
                _menhir_run_535_spec_533 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
            | Elpi_lexer_config.Tokens.CONSTANT _v_35 ->
                let _tok = _menhir_lexer _menhir_lexbuf in
                let c = _v_35 in
                let _v = _menhir_action_075 c in
                _menhir_run_535_spec_533 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
            | Elpi_lexer_config.Tokens.BEFORE ->
                let _tok = _menhir_lexer _menhir_lexbuf in
                let _v = _menhir_action_078 () in
                _menhir_run_535_spec_533 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
            | Elpi_lexer_config.Tokens.AFTER ->
                let _tok = _menhir_lexer _menhir_lexbuf in
                let _v = _menhir_action_079 () in
                _menhir_run_535_spec_533 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
            | _ ->
                _eRR 533)
        | Elpi_lexer_config.Tokens.FULLSTOP ->
            let x = _v in
            let _v = _menhir_action_304 x in
            _menhir_goto_separated_nonempty_list_CONJ_filename_ _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | _ ->
            _eRR 532
    
    and _menhir_run_535_spec_533 : type  ttv_stack. (ttv_stack, _menhir_box_program) _menhir_cell1_filename _menhir_cell0_CONJ -> _ -> _ -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok ->
        let c = _v in
        let _v = _menhir_action_107 c in
        _menhir_run_532 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState533 _tok
    
    and _menhir_run_271 : type  ttv_stack. ttv_stack -> _ -> _ -> (ttv_stack, _menhir_box_program) _menhir_state -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_LPAREN (_menhir_stack, _menhir_s, _startpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.VDASH ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_201 () in
            _menhir_run_224 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.SLASH ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_198 () in
            _menhir_run_224 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.QDASH ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_197 () in
            _menhir_run_224 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.OR ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_191 () in
            _menhir_run_224 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.MOD ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_193 () in
            _menhir_run_224 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.MINUSs ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_189 () in
            _menhir_run_224 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.MINUSr ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_187 () in
            _menhir_run_224 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.MINUSi ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_188 () in
            _menhir_run_224 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.MINUS ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_186 () in
            _menhir_run_224 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.IS ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_192 () in
            _menhir_run_224 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_TIMES _v ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let s = _v in
            let _v = _menhir_action_173 s in
            _menhir_run_224 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_TILDE _v ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let s = _v in
            let _v = _menhir_action_202 s in
            _menhir_run_224 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_TICK _v ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let s = _v in
            let _v = _menhir_action_183 s in
            _menhir_run_224 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let s = _v in
            let _v = _menhir_action_181 s in
            _menhir_run_224 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let s = _v in
            let _v = _menhir_action_203 s in
            _menhir_run_224 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_PLUS _v ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let s = _v in
            let _v = _menhir_action_172 s in
            _menhir_run_224 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_OR _v ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let s = _v in
            let _v = _menhir_action_180 s in
            _menhir_run_224 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let s = _v in
            let _v = _menhir_action_174 s in
            _menhir_run_224 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_LT _v ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let s = _v in
            let _v = _menhir_action_176 s in
            _menhir_run_224 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_GT _v ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let s = _v in
            let _v = _menhir_action_177 s in
            _menhir_run_224 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_EXP _v ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let s = _v in
            let _v = _menhir_action_175 s in
            _menhir_run_224 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let s = _v in
            let _v = _menhir_action_178 s in
            _menhir_run_224 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let s = _v in
            let _v = _menhir_action_182 s in
            _menhir_run_224 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_AND _v ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let s = _v in
            let _v = _menhir_action_179 s in
            _menhir_run_224 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.EQ2 ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_190 () in
            _menhir_run_224 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.EQ ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_185 () in
            _menhir_run_224 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.DIV ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_194 () in
            _menhir_run_224 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.DARROW ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_196 () in
            _menhir_run_224 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.CONS ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_184 () in
            _menhir_run_224 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.CONJ2 ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_199 () in
            _menhir_run_224 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.CONJ ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_200 () in
            _menhir_run_224 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.AS ->
            _menhir_run_216 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.ARROW ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_195 () in
            _menhir_run_224 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | _ ->
            _eRR 271
    
    and _menhir_run_216 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_LPAREN -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer ->
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.RPAREN ->
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let MenhirCell1_LPAREN (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
            let _endpos__3_ = _endpos in
            let _v = _menhir_action_088 () in
            _menhir_goto_constant _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__3_ _startpos__1_ _v _menhir_s _tok
        | _ ->
            _eRR 216
    
    and _menhir_goto_separated_nonempty_list_CONJ_filename_ : type  ttv_stack. ttv_stack -> _ -> _ -> _ -> (ttv_stack, _menhir_box_program) _menhir_state -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s ->
        match _menhir_s with
        | MenhirState533 ->
            _menhir_run_534 _menhir_stack _menhir_lexbuf _menhir_lexer _v
        | MenhirState528 ->
            _menhir_run_530 _menhir_stack _menhir_lexbuf _menhir_lexer _v
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_534 : type  ttv_stack. (ttv_stack, _menhir_box_program) _menhir_cell1_filename _menhir_cell0_CONJ -> _ -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let MenhirCell0_CONJ (_menhir_stack, _, _) = _menhir_stack in
        let MenhirCell1_filename (_menhir_stack, _menhir_s, x) = _menhir_stack in
        let xs = _v in
        let _v = _menhir_action_305 x xs in
        _menhir_goto_separated_nonempty_list_CONJ_filename_ _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
    
    and _menhir_run_530 : type  ttv_stack. (ttv_stack, _menhir_box_program) _menhir_cell1_accumulate -> _ -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        let MenhirCell1_accumulate (_menhir_stack, _menhir_s, ext, _startpos_ext_) = _menhir_stack in
        let (_endpos__3_, l) = (_endpos, _v) in
        let _v = _menhir_action_103 _endpos__3_ _startpos_ext_ ext l in
        _menhir_goto_decl _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
    
    and _menhir_goto_decl : type  ttv_stack. ttv_stack -> _ -> _ -> _ -> _ -> (ttv_stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        _menhir_run_414 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
    
    and _menhir_run_414 : type  ttv_stack. ttv_stack -> _ -> _ -> _ -> _ -> (ttv_stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_decl (_menhir_stack, _menhir_s, _v) in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.USE_SIG ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _startpos__1_ = _startpos in
            let _v = _menhir_action_010 () in
            _menhir_run_528 _menhir_stack _menhir_lexbuf _menhir_lexer _startpos__1_ _v MenhirState414 _tok
        | Elpi_lexer_config.Tokens.USEONLY ->
            _menhir_run_270 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState414
        | Elpi_lexer_config.Tokens.TYPEABBREV ->
            _menhir_run_292 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState414
        | Elpi_lexer_config.Tokens.SIG ->
            _menhir_run_302 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState414
        | Elpi_lexer_config.Tokens.SHORTEN ->
            _menhir_run_304 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState414
        | Elpi_lexer_config.Tokens.RCURLY ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos) in
            let _v = _menhir_action_102 _endpos__1_ _startpos__1_ in
            _menhir_run_414 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v MenhirState414 _tok
        | Elpi_lexer_config.Tokens.NAMESPACE ->
            _menhir_run_322 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState414
        | Elpi_lexer_config.Tokens.MODULE ->
            _menhir_run_325 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState414
        | Elpi_lexer_config.Tokens.MODE ->
            _menhir_run_327 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState414
        | Elpi_lexer_config.Tokens.MACRO ->
            _menhir_run_335 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState414
        | Elpi_lexer_config.Tokens.LOCALKIND ->
            _menhir_run_339 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState414
        | Elpi_lexer_config.Tokens.LOCAL ->
            _menhir_run_341 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState414
        | Elpi_lexer_config.Tokens.LCURLY ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos) in
            let _v = _menhir_action_101 _endpos__1_ _startpos__1_ in
            _menhir_run_414 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v MenhirState414 _tok
        | Elpi_lexer_config.Tokens.KIND ->
            _menhir_run_347 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState414
        | Elpi_lexer_config.Tokens.IMPORT ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _startpos__1_ = _startpos in
            let _v = _menhir_action_008 () in
            _menhir_run_528 _menhir_stack _menhir_lexbuf _menhir_lexer _startpos__1_ _v MenhirState414 _tok
        | Elpi_lexer_config.Tokens.FIXITY _v_4 ->
            _menhir_run_354 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4 MenhirState414
        | Elpi_lexer_config.Tokens.EXTERNAL ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos) in
            let _v = _menhir_action_019 () in
            _menhir_run_420 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState414 _tok
        | Elpi_lexer_config.Tokens.EXPORTDEF ->
            _menhir_run_360 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState414
        | Elpi_lexer_config.Tokens.EOF ->
            let _v = _menhir_action_298 () in
            _menhir_run_415 _menhir_stack _v
        | Elpi_lexer_config.Tokens.CONSTRAINT ->
            _menhir_run_364 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState414
        | Elpi_lexer_config.Tokens.COLON ->
            _menhir_run_369 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState414
        | Elpi_lexer_config.Tokens.CLOSED ->
            _menhir_run_393 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState414
        | Elpi_lexer_config.Tokens.ACCUM_SIG ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _startpos__1_ = _startpos in
            let _v = _menhir_action_009 () in
            _menhir_run_528 _menhir_stack _menhir_lexbuf _menhir_lexer _startpos__1_ _v MenhirState414 _tok
        | Elpi_lexer_config.Tokens.ACCUMULATE ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _startpos__1_ = _startpos in
            let _v = _menhir_action_007 () in
            _menhir_run_528 _menhir_stack _menhir_lexbuf _menhir_lexer _startpos__1_ _v MenhirState414 _tok
        | Elpi_lexer_config.Tokens.AFTER | Elpi_lexer_config.Tokens.BEFORE | Elpi_lexer_config.Tokens.CONSTANT _ | Elpi_lexer_config.Tokens.CUT | Elpi_lexer_config.Tokens.FAMILY_TILDE _ | Elpi_lexer_config.Tokens.FRESHUV | Elpi_lexer_config.Tokens.IF | Elpi_lexer_config.Tokens.INDEX | Elpi_lexer_config.Tokens.IO _ | Elpi_lexer_config.Tokens.LPAREN | Elpi_lexer_config.Tokens.NAME | Elpi_lexer_config.Tokens.NIL | Elpi_lexer_config.Tokens.PI | Elpi_lexer_config.Tokens.PRED | Elpi_lexer_config.Tokens.REPLACE | Elpi_lexer_config.Tokens.RULE | Elpi_lexer_config.Tokens.SIGMA | Elpi_lexer_config.Tokens.TYPE ->
            let _v = _menhir_action_018 () in
            _menhir_run_420 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _endpos _v MenhirState414 _tok
        | _ ->
            _eRR 414
    
    and _menhir_run_528 : type  ttv_stack. ttv_stack -> _ -> _ -> _ -> _ -> (ttv_stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _startpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_accumulate (_menhir_stack, _menhir_s, _v, _startpos) in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v_0 ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let s = _v_0 in
            let _v = _menhir_action_108 s in
            _menhir_run_532 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState528 _tok
        | Elpi_lexer_config.Tokens.SIGMA ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_085 () in
            _menhir_run_535_spec_528 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.REPLACE ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_080 () in
            _menhir_run_535_spec_528 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.PI ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_084 () in
            _menhir_run_535_spec_528 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.NIL ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_089 () in
            _menhir_run_535_spec_528 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.NAME ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_077 () in
            _menhir_run_535_spec_528 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_271 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState528
        | Elpi_lexer_config.Tokens.IO _v_13 ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let c = _v_13 in
            let _v = _menhir_action_082 c in
            _menhir_run_535_spec_528 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.INDEX ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_081 () in
            _menhir_run_535_spec_528 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.IF ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_076 () in
            _menhir_run_535_spec_528 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.FRESHUV ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_086 () in
            _menhir_run_535_spec_528 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.CUT ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_083 () in
            _menhir_run_535_spec_528 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.CONSTANT _v_24 ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let c = _v_24 in
            let _v = _menhir_action_075 c in
            _menhir_run_535_spec_528 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.BEFORE ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_078 () in
            _menhir_run_535_spec_528 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.AFTER ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_079 () in
            _menhir_run_535_spec_528 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | _ ->
            _eRR 528
    
    and _menhir_run_270 : type  ttv_stack. ttv_stack -> _ -> _ -> (ttv_stack, _menhir_box_program) _menhir_state -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_USEONLY (_menhir_stack, _menhir_s, _startpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.SIGMA ->
            let _startpos_0 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_0) in
            let _v = _menhir_action_085 () in
            _menhir_run_289 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState270 _tok
        | Elpi_lexer_config.Tokens.REPLACE ->
            let _startpos_1 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_1) in
            let _v = _menhir_action_080 () in
            _menhir_run_289 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState270 _tok
        | Elpi_lexer_config.Tokens.PI ->
            let _startpos_2 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_2) in
            let _v = _menhir_action_084 () in
            _menhir_run_289 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState270 _tok
        | Elpi_lexer_config.Tokens.NIL ->
            let _startpos_3 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_3) in
            let _v = _menhir_action_089 () in
            _menhir_run_289 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState270 _tok
        | Elpi_lexer_config.Tokens.NAME ->
            let _startpos_4 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_4) in
            let _v = _menhir_action_077 () in
            _menhir_run_289 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState270 _tok
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_271 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState270
        | Elpi_lexer_config.Tokens.IO _v ->
            let _startpos_5 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos, _startpos_5, _v) in
            let _v = _menhir_action_082 c in
            _menhir_run_289 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState270 _tok
        | Elpi_lexer_config.Tokens.INDEX ->
            let _startpos_6 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_6) in
            let _v = _menhir_action_081 () in
            _menhir_run_289 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState270 _tok
        | Elpi_lexer_config.Tokens.IF ->
            let _startpos_7 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_7) in
            let _v = _menhir_action_076 () in
            _menhir_run_289 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState270 _tok
        | Elpi_lexer_config.Tokens.FRESHUV ->
            let _startpos_8 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_8) in
            let _v = _menhir_action_086 () in
            _menhir_run_289 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState270 _tok
        | Elpi_lexer_config.Tokens.CUT ->
            let _startpos_9 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_9) in
            let _v = _menhir_action_083 () in
            _menhir_run_289 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState270 _tok
        | Elpi_lexer_config.Tokens.CONSTANT _v ->
            let _startpos_10 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos, _startpos_10, _v) in
            let _v = _menhir_action_075 c in
            _menhir_run_289 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState270 _tok
        | Elpi_lexer_config.Tokens.BEFORE ->
            let _startpos_11 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_11) in
            let _v = _menhir_action_078 () in
            _menhir_run_289 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState270 _tok
        | Elpi_lexer_config.Tokens.AFTER ->
            let _startpos_12 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_12) in
            let _v = _menhir_action_079 () in
            _menhir_run_289 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState270 _tok
        | _ ->
            _eRR 270
    
    and _menhir_run_289 : type  ttv_stack. ttv_stack -> _ -> _ -> _ -> _ -> _ -> (ttv_stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.CONJ ->
            let _menhir_stack = MenhirCell1_constant (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos_0 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_1 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell0_CONJ (_menhir_stack, _startpos_0, _endpos_1) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Elpi_lexer_config.Tokens.SIGMA ->
                let _startpos_2 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_3 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_3, _startpos_2) in
                let _v = _menhir_action_085 () in
                _menhir_run_289 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState290 _tok
            | Elpi_lexer_config.Tokens.REPLACE ->
                let _startpos_5 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_6 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_6, _startpos_5) in
                let _v = _menhir_action_080 () in
                _menhir_run_289 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState290 _tok
            | Elpi_lexer_config.Tokens.PI ->
                let _startpos_8 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_9 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_9, _startpos_8) in
                let _v = _menhir_action_084 () in
                _menhir_run_289 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState290 _tok
            | Elpi_lexer_config.Tokens.NIL ->
                let _startpos_11 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_12 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_12, _startpos_11) in
                let _v = _menhir_action_089 () in
                _menhir_run_289 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState290 _tok
            | Elpi_lexer_config.Tokens.NAME ->
                let _startpos_14 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_15 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_15, _startpos_14) in
                let _v = _menhir_action_077 () in
                _menhir_run_289 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState290 _tok
            | Elpi_lexer_config.Tokens.LPAREN ->
                _menhir_run_271 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState290
            | Elpi_lexer_config.Tokens.IO _v_17 ->
                let _startpos_18 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_19 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_c_, _startpos_c_, c) = (_endpos_19, _startpos_18, _v_17) in
                let _v = _menhir_action_082 c in
                _menhir_run_289 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState290 _tok
            | Elpi_lexer_config.Tokens.INDEX ->
                let _startpos_21 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_22 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_22, _startpos_21) in
                let _v = _menhir_action_081 () in
                _menhir_run_289 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState290 _tok
            | Elpi_lexer_config.Tokens.IF ->
                let _startpos_24 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_25 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_25, _startpos_24) in
                let _v = _menhir_action_076 () in
                _menhir_run_289 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState290 _tok
            | Elpi_lexer_config.Tokens.FRESHUV ->
                let _startpos_27 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_28 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_28, _startpos_27) in
                let _v = _menhir_action_086 () in
                _menhir_run_289 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState290 _tok
            | Elpi_lexer_config.Tokens.CUT ->
                let _startpos_30 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_31 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_31, _startpos_30) in
                let _v = _menhir_action_083 () in
                _menhir_run_289 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState290 _tok
            | Elpi_lexer_config.Tokens.CONSTANT _v_33 ->
                let _startpos_34 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_35 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_c_, _startpos_c_, c) = (_endpos_35, _startpos_34, _v_33) in
                let _v = _menhir_action_075 c in
                _menhir_run_289 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState290 _tok
            | Elpi_lexer_config.Tokens.BEFORE ->
                let _startpos_37 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_38 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_38, _startpos_37) in
                let _v = _menhir_action_078 () in
                _menhir_run_289 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState290 _tok
            | Elpi_lexer_config.Tokens.AFTER ->
                let _startpos_40 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_41 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_41, _startpos_40) in
                let _v = _menhir_action_079 () in
                _menhir_run_289 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState290 _tok
            | _ ->
                _eRR 290)
        | Elpi_lexer_config.Tokens.AFTER | Elpi_lexer_config.Tokens.BEFORE | Elpi_lexer_config.Tokens.CONSTANT _ | Elpi_lexer_config.Tokens.CUT | Elpi_lexer_config.Tokens.FRESHUV | Elpi_lexer_config.Tokens.FULLSTOP | Elpi_lexer_config.Tokens.IF | Elpi_lexer_config.Tokens.INDEX | Elpi_lexer_config.Tokens.IO _ | Elpi_lexer_config.Tokens.LPAREN | Elpi_lexer_config.Tokens.NAME | Elpi_lexer_config.Tokens.NIL | Elpi_lexer_config.Tokens.PI | Elpi_lexer_config.Tokens.REPLACE | Elpi_lexer_config.Tokens.SIGMA | Elpi_lexer_config.Tokens.TYPE ->
            let (_endpos_x_, x) = (_endpos, _v) in
            let _v = _menhir_action_302 x in
            _menhir_goto_separated_nonempty_list_CONJ_constant_ _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _v _menhir_s _tok
        | _ ->
            _eRR 289
    
    and _menhir_goto_separated_nonempty_list_CONJ_constant_ : type  ttv_stack. ttv_stack -> _ -> _ -> _ -> _ -> (ttv_stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        match _menhir_s with
        | MenhirState421 ->
            _menhir_run_422 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState393 ->
            _menhir_run_394 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _tok
        | MenhirState360 ->
            _menhir_run_361 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState347 ->
            _menhir_run_348 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState341 ->
            _menhir_run_342 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState339 ->
            _menhir_run_340 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _tok
        | MenhirState290 ->
            _menhir_run_291 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState270 ->
            _menhir_run_273 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_422 : type  ttv_stack. (((ttv_stack, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_TYPE as 'stack) -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_separated_nonempty_list_CONJ_constant_ (_menhir_stack, _menhir_s, _v, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.SIGMA ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_0, _startpos) in
            let _v = _menhir_action_085 () in
            _menhir_run_279 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState422 _tok
        | Elpi_lexer_config.Tokens.REPLACE ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_2 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_2, _startpos) in
            let _v = _menhir_action_080 () in
            _menhir_run_279 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState422 _tok
        | Elpi_lexer_config.Tokens.PI ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_4 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_4, _startpos) in
            let _v = _menhir_action_084 () in
            _menhir_run_279 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState422 _tok
        | Elpi_lexer_config.Tokens.NIL ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_6 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_6, _startpos) in
            let _v = _menhir_action_089 () in
            _menhir_run_279 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState422 _tok
        | Elpi_lexer_config.Tokens.NAME ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_8 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_8, _startpos) in
            let _v = _menhir_action_077 () in
            _menhir_run_279 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState422 _tok
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_274 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState422
        | Elpi_lexer_config.Tokens.IO _v_10 ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_11 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_11, _startpos, _v_10) in
            let _v = _menhir_action_082 c in
            _menhir_run_279 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState422 _tok
        | Elpi_lexer_config.Tokens.INDEX ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_13 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_13, _startpos) in
            let _v = _menhir_action_081 () in
            _menhir_run_279 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState422 _tok
        | Elpi_lexer_config.Tokens.IF ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_15 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_15, _startpos) in
            let _v = _menhir_action_076 () in
            _menhir_run_279 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState422 _tok
        | Elpi_lexer_config.Tokens.FRESHUV ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_17 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_17, _startpos) in
            let _v = _menhir_action_086 () in
            _menhir_run_279 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState422 _tok
        | Elpi_lexer_config.Tokens.CUT ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_19 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_19, _startpos) in
            let _v = _menhir_action_083 () in
            _menhir_run_279 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState422 _tok
        | Elpi_lexer_config.Tokens.CONSTANT _v_21 ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_22 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_22, _startpos, _v_21) in
            let _v = _menhir_action_075 c in
            _menhir_run_279 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState422 _tok
        | Elpi_lexer_config.Tokens.BEFORE ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_24 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_24, _startpos) in
            let _v = _menhir_action_078 () in
            _menhir_run_279 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState422 _tok
        | Elpi_lexer_config.Tokens.AFTER ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_26 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_26, _startpos) in
            let _v = _menhir_action_079 () in
            _menhir_run_279 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState422 _tok
        | _ ->
            _eRR 422
    
    and _menhir_run_279 : type  ttv_stack. ttv_stack -> _ -> _ -> _ -> _ -> _ -> (ttv_stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v_0 ->
            let _menhir_stack = MenhirCell1_constant (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _endpos_2 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, c) = (_endpos_2, _v_0) in
            let _v = _menhir_action_021 c in
            _menhir_run_286 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _v MenhirState279 _tok
        | Elpi_lexer_config.Tokens.SIGMA ->
            let _menhir_stack = MenhirCell1_constant (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _endpos_5 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _endpos__1_ = _endpos_5 in
            let _v = _menhir_action_085 () in
            _menhir_run_285_spec_279 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _v _tok
        | Elpi_lexer_config.Tokens.REPLACE ->
            let _menhir_stack = MenhirCell1_constant (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _endpos_8 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _endpos__1_ = _endpos_8 in
            let _v = _menhir_action_080 () in
            _menhir_run_285_spec_279 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _v _tok
        | Elpi_lexer_config.Tokens.PI ->
            let _menhir_stack = MenhirCell1_constant (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _endpos_11 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _endpos__1_ = _endpos_11 in
            let _v = _menhir_action_084 () in
            _menhir_run_285_spec_279 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _v _tok
        | Elpi_lexer_config.Tokens.NIL ->
            let _menhir_stack = MenhirCell1_constant (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _endpos_14 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _endpos__1_ = _endpos_14 in
            let _v = _menhir_action_089 () in
            _menhir_run_285_spec_279 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _v _tok
        | Elpi_lexer_config.Tokens.NAME ->
            let _menhir_stack = MenhirCell1_constant (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _endpos_17 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _endpos__1_ = _endpos_17 in
            let _v = _menhir_action_077 () in
            _menhir_run_285_spec_279 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _v _tok
        | Elpi_lexer_config.Tokens.LPAREN ->
            let _menhir_stack = MenhirCell1_constant (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_281 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState279
        | Elpi_lexer_config.Tokens.IO _v_19 ->
            let _menhir_stack = MenhirCell1_constant (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _endpos_21 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, c) = (_endpos_21, _v_19) in
            let _v = _menhir_action_082 c in
            _menhir_run_285_spec_279 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _v _tok
        | Elpi_lexer_config.Tokens.INDEX ->
            let _menhir_stack = MenhirCell1_constant (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _endpos_24 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _endpos__1_ = _endpos_24 in
            let _v = _menhir_action_081 () in
            _menhir_run_285_spec_279 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _v _tok
        | Elpi_lexer_config.Tokens.IF ->
            let _menhir_stack = MenhirCell1_constant (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _endpos_27 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _endpos__1_ = _endpos_27 in
            let _v = _menhir_action_076 () in
            _menhir_run_285_spec_279 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _v _tok
        | Elpi_lexer_config.Tokens.FRESHUV ->
            let _menhir_stack = MenhirCell1_constant (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _endpos_30 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _endpos__1_ = _endpos_30 in
            let _v = _menhir_action_086 () in
            _menhir_run_285_spec_279 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _v _tok
        | Elpi_lexer_config.Tokens.CUT ->
            let _menhir_stack = MenhirCell1_constant (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _endpos_33 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _endpos__1_ = _endpos_33 in
            let _v = _menhir_action_083 () in
            _menhir_run_285_spec_279 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _v _tok
        | Elpi_lexer_config.Tokens.CONSTANT _v_35 ->
            let _menhir_stack = MenhirCell1_constant (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _endpos_37 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, c) = (_endpos_37, _v_35) in
            let _v = _menhir_action_075 c in
            _menhir_run_285_spec_279 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _v _tok
        | Elpi_lexer_config.Tokens.BEFORE ->
            let _menhir_stack = MenhirCell1_constant (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _endpos_40 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _endpos__1_ = _endpos_40 in
            let _v = _menhir_action_078 () in
            _menhir_run_285_spec_279 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _v _tok
        | Elpi_lexer_config.Tokens.AFTER ->
            let _menhir_stack = MenhirCell1_constant (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _endpos_43 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _endpos__1_ = _endpos_43 in
            let _v = _menhir_action_079 () in
            _menhir_run_285_spec_279 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _v _tok
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.FULLSTOP | Elpi_lexer_config.Tokens.IO_COLON _ | Elpi_lexer_config.Tokens.RPAREN ->
            let (_endpos_c_, _startpos_c_, c) = (_endpos, _startpos, _v) in
            let _v = _menhir_action_323 c in
            _menhir_goto_type_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v _menhir_s _tok
        | _ ->
            _eRR 279
    
    and _menhir_run_286 : type  ttv_stack. ttv_stack -> _ -> _ -> _ -> _ -> (ttv_stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v_0 ->
            let _menhir_stack = MenhirCell1_atype_term (_menhir_stack, _menhir_s, _v, _endpos) in
            let _endpos_1 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, c) = (_endpos_1, _v_0) in
            let _v = _menhir_action_021 c in
            _menhir_run_286 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _v MenhirState286 _tok
        | Elpi_lexer_config.Tokens.SIGMA ->
            let _menhir_stack = MenhirCell1_atype_term (_menhir_stack, _menhir_s, _v, _endpos) in
            let _endpos_3 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _endpos__1_ = _endpos_3 in
            let _v = _menhir_action_085 () in
            _menhir_run_285_spec_286 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _v _tok
        | Elpi_lexer_config.Tokens.REPLACE ->
            let _menhir_stack = MenhirCell1_atype_term (_menhir_stack, _menhir_s, _v, _endpos) in
            let _endpos_5 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _endpos__1_ = _endpos_5 in
            let _v = _menhir_action_080 () in
            _menhir_run_285_spec_286 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _v _tok
        | Elpi_lexer_config.Tokens.PI ->
            let _menhir_stack = MenhirCell1_atype_term (_menhir_stack, _menhir_s, _v, _endpos) in
            let _endpos_7 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _endpos__1_ = _endpos_7 in
            let _v = _menhir_action_084 () in
            _menhir_run_285_spec_286 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _v _tok
        | Elpi_lexer_config.Tokens.NIL ->
            let _menhir_stack = MenhirCell1_atype_term (_menhir_stack, _menhir_s, _v, _endpos) in
            let _endpos_9 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _endpos__1_ = _endpos_9 in
            let _v = _menhir_action_089 () in
            _menhir_run_285_spec_286 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _v _tok
        | Elpi_lexer_config.Tokens.NAME ->
            let _menhir_stack = MenhirCell1_atype_term (_menhir_stack, _menhir_s, _v, _endpos) in
            let _endpos_11 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _endpos__1_ = _endpos_11 in
            let _v = _menhir_action_077 () in
            _menhir_run_285_spec_286 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _v _tok
        | Elpi_lexer_config.Tokens.LPAREN ->
            let _menhir_stack = MenhirCell1_atype_term (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_281 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState286
        | Elpi_lexer_config.Tokens.IO _v_13 ->
            let _menhir_stack = MenhirCell1_atype_term (_menhir_stack, _menhir_s, _v, _endpos) in
            let _endpos_14 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, c) = (_endpos_14, _v_13) in
            let _v = _menhir_action_082 c in
            _menhir_run_285_spec_286 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _v _tok
        | Elpi_lexer_config.Tokens.INDEX ->
            let _menhir_stack = MenhirCell1_atype_term (_menhir_stack, _menhir_s, _v, _endpos) in
            let _endpos_16 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _endpos__1_ = _endpos_16 in
            let _v = _menhir_action_081 () in
            _menhir_run_285_spec_286 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _v _tok
        | Elpi_lexer_config.Tokens.IF ->
            let _menhir_stack = MenhirCell1_atype_term (_menhir_stack, _menhir_s, _v, _endpos) in
            let _endpos_18 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _endpos__1_ = _endpos_18 in
            let _v = _menhir_action_076 () in
            _menhir_run_285_spec_286 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _v _tok
        | Elpi_lexer_config.Tokens.FRESHUV ->
            let _menhir_stack = MenhirCell1_atype_term (_menhir_stack, _menhir_s, _v, _endpos) in
            let _endpos_20 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _endpos__1_ = _endpos_20 in
            let _v = _menhir_action_086 () in
            _menhir_run_285_spec_286 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _v _tok
        | Elpi_lexer_config.Tokens.CUT ->
            let _menhir_stack = MenhirCell1_atype_term (_menhir_stack, _menhir_s, _v, _endpos) in
            let _endpos_22 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _endpos__1_ = _endpos_22 in
            let _v = _menhir_action_083 () in
            _menhir_run_285_spec_286 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _v _tok
        | Elpi_lexer_config.Tokens.CONSTANT _v_24 ->
            let _menhir_stack = MenhirCell1_atype_term (_menhir_stack, _menhir_s, _v, _endpos) in
            let _endpos_25 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, c) = (_endpos_25, _v_24) in
            let _v = _menhir_action_075 c in
            _menhir_run_285_spec_286 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _v _tok
        | Elpi_lexer_config.Tokens.BEFORE ->
            let _menhir_stack = MenhirCell1_atype_term (_menhir_stack, _menhir_s, _v, _endpos) in
            let _endpos_27 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _endpos__1_ = _endpos_27 in
            let _v = _menhir_action_078 () in
            _menhir_run_285_spec_286 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _v _tok
        | Elpi_lexer_config.Tokens.AFTER ->
            let _menhir_stack = MenhirCell1_atype_term (_menhir_stack, _menhir_s, _v, _endpos) in
            let _endpos_29 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _endpos__1_ = _endpos_29 in
            let _v = _menhir_action_079 () in
            _menhir_run_285_spec_286 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _v _tok
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.FULLSTOP | Elpi_lexer_config.Tokens.IO_COLON _ | Elpi_lexer_config.Tokens.RPAREN ->
            let (_endpos_x_, x) = (_endpos, _v) in
            let _v = _menhir_action_205 x in
            _menhir_goto_nonempty_list_atype_term_ _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _v _menhir_s _tok
        | _ ->
            _eRR 286
    
    and _menhir_run_285_spec_286 : type  ttv_stack. (ttv_stack, _menhir_box_program) _menhir_cell1_atype_term -> _ -> _ -> _ -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let (_endpos_c_, c) = (_endpos, _v) in
        let _v = _menhir_action_022 c in
        _menhir_run_286 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _v MenhirState286 _tok
    
    and _menhir_run_281 : type  ttv_stack. ttv_stack -> _ -> _ -> (ttv_stack, _menhir_box_program) _menhir_state -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_LPAREN (_menhir_stack, _menhir_s, _startpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.VDASH ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_201 () in
            _menhir_run_224 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.SLASH ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_198 () in
            _menhir_run_224 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.SIGMA ->
            let _startpos_2 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_2) in
            let _v = _menhir_action_085 () in
            _menhir_run_279 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState281 _tok
        | Elpi_lexer_config.Tokens.REPLACE ->
            let _startpos_3 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_3) in
            let _v = _menhir_action_080 () in
            _menhir_run_279 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState281 _tok
        | Elpi_lexer_config.Tokens.QDASH ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_197 () in
            _menhir_run_224 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.PI ->
            let _startpos_5 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_5) in
            let _v = _menhir_action_084 () in
            _menhir_run_279 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState281 _tok
        | Elpi_lexer_config.Tokens.OR ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_191 () in
            _menhir_run_224 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.NIL ->
            let _startpos_7 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_7) in
            let _v = _menhir_action_089 () in
            _menhir_run_279 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState281 _tok
        | Elpi_lexer_config.Tokens.NAME ->
            let _startpos_8 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_8) in
            let _v = _menhir_action_077 () in
            _menhir_run_279 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState281 _tok
        | Elpi_lexer_config.Tokens.MOD ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_193 () in
            _menhir_run_224 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.MINUSs ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_189 () in
            _menhir_run_224 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.MINUSr ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_187 () in
            _menhir_run_224 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.MINUSi ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_188 () in
            _menhir_run_224 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.MINUS ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_186 () in
            _menhir_run_224 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_274 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState281
        | Elpi_lexer_config.Tokens.IS ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_192 () in
            _menhir_run_224 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.IO _v ->
            let _startpos_15 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos, _startpos_15, _v) in
            let _v = _menhir_action_082 c in
            _menhir_run_279 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState281 _tok
        | Elpi_lexer_config.Tokens.INDEX ->
            let _startpos_16 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_16) in
            let _v = _menhir_action_081 () in
            _menhir_run_279 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState281 _tok
        | Elpi_lexer_config.Tokens.IF ->
            let _startpos_17 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_17) in
            let _v = _menhir_action_076 () in
            _menhir_run_279 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState281 _tok
        | Elpi_lexer_config.Tokens.FRESHUV ->
            let _startpos_18 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_18) in
            let _v = _menhir_action_086 () in
            _menhir_run_279 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState281 _tok
        | Elpi_lexer_config.Tokens.FAMILY_TIMES _v ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let s = _v in
            let _v = _menhir_action_173 s in
            _menhir_run_224 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_TILDE _v ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let s = _v in
            let _v = _menhir_action_202 s in
            _menhir_run_224 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_TICK _v ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let s = _v in
            let _v = _menhir_action_183 s in
            _menhir_run_224 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let s = _v in
            let _v = _menhir_action_181 s in
            _menhir_run_224 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let s = _v in
            let _v = _menhir_action_203 s in
            _menhir_run_224 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_PLUS _v ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let s = _v in
            let _v = _menhir_action_172 s in
            _menhir_run_224 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_OR _v ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let s = _v in
            let _v = _menhir_action_180 s in
            _menhir_run_224 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let s = _v in
            let _v = _menhir_action_174 s in
            _menhir_run_224 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_LT _v ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let s = _v in
            let _v = _menhir_action_176 s in
            _menhir_run_224 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_GT _v ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let s = _v in
            let _v = _menhir_action_177 s in
            _menhir_run_224 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_EXP _v ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let s = _v in
            let _v = _menhir_action_175 s in
            _menhir_run_224 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let s = _v in
            let _v = _menhir_action_178 s in
            _menhir_run_224 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let s = _v in
            let _v = _menhir_action_182 s in
            _menhir_run_224 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_AND _v ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let s = _v in
            let _v = _menhir_action_179 s in
            _menhir_run_224 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.EQ2 ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_190 () in
            _menhir_run_224 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.EQ ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_185 () in
            _menhir_run_224 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.DIV ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_194 () in
            _menhir_run_224 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.DARROW ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_196 () in
            _menhir_run_224 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.CUT ->
            let _startpos_37 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_37) in
            let _v = _menhir_action_083 () in
            _menhir_run_279 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState281 _tok
        | Elpi_lexer_config.Tokens.CONSTANT _v ->
            let _startpos_38 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos, _startpos_38, _v) in
            let _v = _menhir_action_075 c in
            _menhir_run_279 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState281 _tok
        | Elpi_lexer_config.Tokens.CONS ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_184 () in
            _menhir_run_224 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.CONJ2 ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_199 () in
            _menhir_run_224 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.CONJ ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_200 () in
            _menhir_run_224 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.BEFORE ->
            let _startpos_42 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_42) in
            let _v = _menhir_action_078 () in
            _menhir_run_279 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState281 _tok
        | Elpi_lexer_config.Tokens.AS ->
            _menhir_run_216 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.ARROW ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_195 () in
            _menhir_run_224 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.AFTER ->
            let _startpos_44 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_44) in
            let _v = _menhir_action_079 () in
            _menhir_run_279 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState281 _tok
        | _ ->
            _eRR 281
    
    and _menhir_run_274 : type  ttv_stack. ttv_stack -> _ -> _ -> (ttv_stack, _menhir_box_program) _menhir_state -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_LPAREN (_menhir_stack, _menhir_s, _startpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.VDASH ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_201 () in
            _menhir_run_224 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.SLASH ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_198 () in
            _menhir_run_224 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.SIGMA ->
            let _startpos_2 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_2) in
            let _v = _menhir_action_085 () in
            _menhir_run_279 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState274 _tok
        | Elpi_lexer_config.Tokens.REPLACE ->
            let _startpos_3 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_3) in
            let _v = _menhir_action_080 () in
            _menhir_run_279 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState274 _tok
        | Elpi_lexer_config.Tokens.QDASH ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_197 () in
            _menhir_run_224 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.PI ->
            let _startpos_5 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_5) in
            let _v = _menhir_action_084 () in
            _menhir_run_279 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState274 _tok
        | Elpi_lexer_config.Tokens.OR ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_191 () in
            _menhir_run_224 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.NIL ->
            let _startpos_7 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_7) in
            let _v = _menhir_action_089 () in
            _menhir_run_279 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState274 _tok
        | Elpi_lexer_config.Tokens.NAME ->
            let _startpos_8 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_8) in
            let _v = _menhir_action_077 () in
            _menhir_run_279 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState274 _tok
        | Elpi_lexer_config.Tokens.MOD ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_193 () in
            _menhir_run_224 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.MINUSs ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_189 () in
            _menhir_run_224 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.MINUSr ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_187 () in
            _menhir_run_224 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.MINUSi ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_188 () in
            _menhir_run_224 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.MINUS ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_186 () in
            _menhir_run_224 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_274 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState274
        | Elpi_lexer_config.Tokens.IS ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_192 () in
            _menhir_run_224 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.IO _v ->
            let _startpos_15 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos, _startpos_15, _v) in
            let _v = _menhir_action_082 c in
            _menhir_run_279 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState274 _tok
        | Elpi_lexer_config.Tokens.INDEX ->
            let _startpos_16 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_16) in
            let _v = _menhir_action_081 () in
            _menhir_run_279 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState274 _tok
        | Elpi_lexer_config.Tokens.IF ->
            let _startpos_17 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_17) in
            let _v = _menhir_action_076 () in
            _menhir_run_279 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState274 _tok
        | Elpi_lexer_config.Tokens.FRESHUV ->
            let _startpos_18 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_18) in
            let _v = _menhir_action_086 () in
            _menhir_run_279 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState274 _tok
        | Elpi_lexer_config.Tokens.FAMILY_TIMES _v ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let s = _v in
            let _v = _menhir_action_173 s in
            _menhir_run_224 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_TILDE _v ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let s = _v in
            let _v = _menhir_action_202 s in
            _menhir_run_224 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_TICK _v ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let s = _v in
            let _v = _menhir_action_183 s in
            _menhir_run_224 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let s = _v in
            let _v = _menhir_action_181 s in
            _menhir_run_224 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let s = _v in
            let _v = _menhir_action_203 s in
            _menhir_run_224 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_PLUS _v ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let s = _v in
            let _v = _menhir_action_172 s in
            _menhir_run_224 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_OR _v ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let s = _v in
            let _v = _menhir_action_180 s in
            _menhir_run_224 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let s = _v in
            let _v = _menhir_action_174 s in
            _menhir_run_224 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_LT _v ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let s = _v in
            let _v = _menhir_action_176 s in
            _menhir_run_224 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_GT _v ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let s = _v in
            let _v = _menhir_action_177 s in
            _menhir_run_224 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_EXP _v ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let s = _v in
            let _v = _menhir_action_175 s in
            _menhir_run_224 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let s = _v in
            let _v = _menhir_action_178 s in
            _menhir_run_224 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let s = _v in
            let _v = _menhir_action_182 s in
            _menhir_run_224 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_AND _v ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let s = _v in
            let _v = _menhir_action_179 s in
            _menhir_run_224 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.EQ2 ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_190 () in
            _menhir_run_224 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.EQ ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_185 () in
            _menhir_run_224 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.DIV ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_194 () in
            _menhir_run_224 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.DARROW ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_196 () in
            _menhir_run_224 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.CUT ->
            let _startpos_37 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_37) in
            let _v = _menhir_action_083 () in
            _menhir_run_279 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState274 _tok
        | Elpi_lexer_config.Tokens.CONSTANT _v ->
            let _startpos_38 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos, _startpos_38, _v) in
            let _v = _menhir_action_075 c in
            _menhir_run_279 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState274 _tok
        | Elpi_lexer_config.Tokens.CONS ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_184 () in
            _menhir_run_224 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.CONJ2 ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_199 () in
            _menhir_run_224 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.CONJ ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_200 () in
            _menhir_run_224 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.BEFORE ->
            let _startpos_42 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_42) in
            let _v = _menhir_action_078 () in
            _menhir_run_279 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState274 _tok
        | Elpi_lexer_config.Tokens.AS ->
            _menhir_run_216 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.ARROW ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_195 () in
            _menhir_run_224 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.AFTER ->
            let _startpos_44 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_44) in
            let _v = _menhir_action_079 () in
            _menhir_run_279 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState274 _tok
        | _ ->
            _eRR 274
    
    and _menhir_goto_nonempty_list_atype_term_ : type  ttv_stack. ttv_stack -> _ -> _ -> _ -> _ -> (ttv_stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        match _menhir_s with
        | MenhirState286 ->
            _menhir_run_287 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState279 ->
            _menhir_run_284 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_287 : type  ttv_stack. (ttv_stack, _menhir_box_program) _menhir_cell1_atype_term -> _ -> _ -> _ -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let MenhirCell1_atype_term (_menhir_stack, _menhir_s, x, _) = _menhir_stack in
        let (_endpos_xs_, xs) = (_endpos, _v) in
        let _v = _menhir_action_206 x xs in
        _menhir_goto_nonempty_list_atype_term_ _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_xs_ _v _menhir_s _tok
    
    and _menhir_run_284 : type  ttv_stack. (ttv_stack, _menhir_box_program) _menhir_cell1_constant -> _ -> _ -> _ -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let MenhirCell1_constant (_menhir_stack, _menhir_s, hd, _startpos_hd_, _endpos_hd_) = _menhir_stack in
        let (_endpos_args_, args) = (_endpos, _v) in
        let _v = _menhir_action_324 _endpos_hd_ _startpos_hd_ args hd in
        _menhir_goto_type_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_args_ _startpos_hd_ _v _menhir_s _tok
    
    and _menhir_goto_type_term : type  ttv_stack. ttv_stack -> _ -> _ -> _ -> _ -> _ -> (ttv_stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match _menhir_s with
        | MenhirState447 ->
            _menhir_run_448 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState422 ->
            _menhir_run_423 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState361 ->
            _menhir_run_362 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState342 ->
            _menhir_run_343 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState300 ->
            _menhir_run_301 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState273 ->
            _menhir_run_288 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState281 ->
            _menhir_run_282 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState277 ->
            _menhir_run_278 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState274 ->
            _menhir_run_275 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_448 : type  ttv_stack. ((ttv_stack, _menhir_box_program) _menhir_cell1_IO_COLON as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.ARROW ->
            let _menhir_stack = MenhirCell1_type_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_277 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.FULLSTOP | Elpi_lexer_config.Tokens.IO_COLON _ ->
            let MenhirCell1_IO_COLON (_menhir_stack, _menhir_s, io) = _menhir_stack in
            let (_endpos_ty_, ty) = (_endpos, _v) in
            let _v = _menhir_action_296 io ty in
            let _endpos = _endpos_ty_ in
            (match (_tok : MenhirBasics.token) with
            | Elpi_lexer_config.Tokens.CONJ ->
                let _menhir_stack = MenhirCell1_pred_item (_menhir_stack, _menhir_s, _v, _endpos) in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let x = () in
                let _v = _menhir_action_283 x in
                _menhir_goto_option_CONJ_ _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
            | Elpi_lexer_config.Tokens.IO_COLON _ ->
                let _menhir_stack = MenhirCell1_pred_item (_menhir_stack, _menhir_s, _v, _endpos) in
                let _v = _menhir_action_282 () in
                _menhir_goto_option_CONJ_ _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
            | Elpi_lexer_config.Tokens.FULLSTOP ->
                let (_endpos_x_, x) = (_endpos, _v) in
                let _v = _menhir_action_308 x in
                _menhir_goto_separated_nonempty_list_option_CONJ__pred_item_ _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _v _menhir_s
            | _ ->
                _menhir_fail ())
        | _ ->
            _eRR 448
    
    and _menhir_run_277 : type  ttv_stack. (ttv_stack, _menhir_box_program) _menhir_cell1_type_term -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell0_ARROW (_menhir_stack, _startpos, _endpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.SIGMA ->
            let _startpos_0 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_1 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_1, _startpos_0) in
            let _v = _menhir_action_085 () in
            _menhir_run_279 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState277 _tok
        | Elpi_lexer_config.Tokens.REPLACE ->
            let _startpos_2 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_3 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_3, _startpos_2) in
            let _v = _menhir_action_080 () in
            _menhir_run_279 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState277 _tok
        | Elpi_lexer_config.Tokens.PI ->
            let _startpos_4 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_5 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_5, _startpos_4) in
            let _v = _menhir_action_084 () in
            _menhir_run_279 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState277 _tok
        | Elpi_lexer_config.Tokens.NIL ->
            let _startpos_6 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_7 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_7, _startpos_6) in
            let _v = _menhir_action_089 () in
            _menhir_run_279 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState277 _tok
        | Elpi_lexer_config.Tokens.NAME ->
            let _startpos_8 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_9 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_9, _startpos_8) in
            let _v = _menhir_action_077 () in
            _menhir_run_279 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState277 _tok
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_274 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState277
        | Elpi_lexer_config.Tokens.IO _v ->
            let _startpos_10 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_11 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_11, _startpos_10, _v) in
            let _v = _menhir_action_082 c in
            _menhir_run_279 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState277 _tok
        | Elpi_lexer_config.Tokens.INDEX ->
            let _startpos_12 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_13 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_13, _startpos_12) in
            let _v = _menhir_action_081 () in
            _menhir_run_279 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState277 _tok
        | Elpi_lexer_config.Tokens.IF ->
            let _startpos_14 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_15 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_15, _startpos_14) in
            let _v = _menhir_action_076 () in
            _menhir_run_279 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState277 _tok
        | Elpi_lexer_config.Tokens.FRESHUV ->
            let _startpos_16 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_17 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_17, _startpos_16) in
            let _v = _menhir_action_086 () in
            _menhir_run_279 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState277 _tok
        | Elpi_lexer_config.Tokens.CUT ->
            let _startpos_18 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_19 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_19, _startpos_18) in
            let _v = _menhir_action_083 () in
            _menhir_run_279 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState277 _tok
        | Elpi_lexer_config.Tokens.CONSTANT _v ->
            let _startpos_20 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_21 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_21, _startpos_20, _v) in
            let _v = _menhir_action_075 c in
            _menhir_run_279 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState277 _tok
        | Elpi_lexer_config.Tokens.BEFORE ->
            let _startpos_22 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_23 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_23, _startpos_22) in
            let _v = _menhir_action_078 () in
            _menhir_run_279 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState277 _tok
        | Elpi_lexer_config.Tokens.AFTER ->
            let _startpos_24 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_25 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_25, _startpos_24) in
            let _v = _menhir_action_079 () in
            _menhir_run_279 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState277 _tok
        | _ ->
            _eRR 277
    
    and _menhir_goto_option_CONJ_ : type  ttv_stack. (ttv_stack, _menhir_box_program) _menhir_cell1_pred_item -> _ -> _ -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok ->
        let _menhir_stack = MenhirCell0_option_CONJ_ (_menhir_stack, _v) in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.IO_COLON _v_0 ->
            _menhir_run_447 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0 MenhirState452
        | _ ->
            _eRR 452
    
    and _menhir_run_447 : type  ttv_stack. ttv_stack -> _ -> _ -> _ -> (ttv_stack, _menhir_box_program) _menhir_state -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s ->
        let _menhir_stack = MenhirCell1_IO_COLON (_menhir_stack, _menhir_s, _v) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.SIGMA ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos) in
            let _v = _menhir_action_085 () in
            _menhir_run_279 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState447 _tok
        | Elpi_lexer_config.Tokens.REPLACE ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos) in
            let _v = _menhir_action_080 () in
            _menhir_run_279 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState447 _tok
        | Elpi_lexer_config.Tokens.PI ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos) in
            let _v = _menhir_action_084 () in
            _menhir_run_279 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState447 _tok
        | Elpi_lexer_config.Tokens.NIL ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos) in
            let _v = _menhir_action_089 () in
            _menhir_run_279 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState447 _tok
        | Elpi_lexer_config.Tokens.NAME ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos) in
            let _v = _menhir_action_077 () in
            _menhir_run_279 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState447 _tok
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_274 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState447
        | Elpi_lexer_config.Tokens.IO _v_5 ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos, _startpos, _v_5) in
            let _v = _menhir_action_082 c in
            _menhir_run_279 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState447 _tok
        | Elpi_lexer_config.Tokens.INDEX ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos) in
            let _v = _menhir_action_081 () in
            _menhir_run_279 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState447 _tok
        | Elpi_lexer_config.Tokens.IF ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos) in
            let _v = _menhir_action_076 () in
            _menhir_run_279 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState447 _tok
        | Elpi_lexer_config.Tokens.FRESHUV ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos) in
            let _v = _menhir_action_086 () in
            _menhir_run_279 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState447 _tok
        | Elpi_lexer_config.Tokens.CUT ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos) in
            let _v = _menhir_action_083 () in
            _menhir_run_279 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState447 _tok
        | Elpi_lexer_config.Tokens.CONSTANT _v_11 ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos, _startpos, _v_11) in
            let _v = _menhir_action_075 c in
            _menhir_run_279 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState447 _tok
        | Elpi_lexer_config.Tokens.BEFORE ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos) in
            let _v = _menhir_action_078 () in
            _menhir_run_279 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState447 _tok
        | Elpi_lexer_config.Tokens.AFTER ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos) in
            let _v = _menhir_action_079 () in
            _menhir_run_279 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState447 _tok
        | _ ->
            _eRR 447
    
    and _menhir_goto_separated_nonempty_list_option_CONJ__pred_item_ : type  ttv_stack. ttv_stack -> _ -> _ -> _ -> _ -> (ttv_stack, _menhir_box_program) _menhir_state -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s ->
        match _menhir_s with
        | MenhirState452 ->
            _menhir_run_453 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v
        | MenhirState446 ->
            _menhir_run_449_spec_446 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_453 : type  ttv_stack. (ttv_stack, _menhir_box_program) _menhir_cell1_pred_item _menhir_cell0_option_CONJ_ -> _ -> _ -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v ->
        let MenhirCell0_option_CONJ_ (_menhir_stack, _) = _menhir_stack in
        let MenhirCell1_pred_item (_menhir_stack, _menhir_s, x, _) = _menhir_stack in
        let (_endpos_xs_, xs) = (_endpos, _v) in
        let _v = _menhir_action_309 x xs in
        _menhir_goto_separated_nonempty_list_option_CONJ__pred_item_ _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_xs_ _v _menhir_s
    
    and _menhir_run_449_spec_446 : type  ttv_stack. (((ttv_stack, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_PRED, _menhir_box_program) _menhir_cell1_constant -> _ -> _ -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v ->
        let (_endpos_x_, x) = (_endpos, _v) in
        let _v = _menhir_action_170 x in
        _menhir_run_454 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _v
    
    and _menhir_run_454 : type  ttv_stack. (((ttv_stack, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_PRED, _menhir_box_program) _menhir_cell1_constant -> _ -> _ -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v ->
        let MenhirCell1_constant (_menhir_stack, _, c, _startpos_c_, _endpos_c_) = _menhir_stack in
        let MenhirCell1_PRED (_menhir_stack, _, _startpos__2_) = _menhir_stack in
        let MenhirCell1_attributes (_menhir_stack, _menhir_s, attributes, _startpos_attributes_, _endpos_attributes_) = _menhir_stack in
        let (_endpos_xs_, xs) = (_endpos, _v) in
        let _v = _menhir_action_295 _endpos_attributes_ _endpos_c_ _endpos_xs_ _startpos__2_ _startpos_attributes_ _startpos_c_ attributes c xs in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        let p = _v in
        let _v = _menhir_action_092 p in
        _menhir_goto_decl _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
    
    and _menhir_run_423 : type  ttv_stack. ((((ttv_stack, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_TYPE, _menhir_box_program) _menhir_cell1_separated_nonempty_list_CONJ_constant_ as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.ARROW ->
            let _menhir_stack = MenhirCell1_type_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_277 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FULLSTOP ->
            let MenhirCell1_separated_nonempty_list_CONJ_constant_ (_menhir_stack, _, names, _) = _menhir_stack in
            let MenhirCell1_TYPE (_menhir_stack, _, _startpos__2_, _) = _menhir_stack in
            let MenhirCell1_attributes (_menhir_stack, _menhir_s, attributes, _startpos_attributes_, _endpos_attributes_) = _menhir_stack in
            let (_endpos_t_, t) = (_endpos, _v) in
            let _v = _menhir_action_322 _endpos_attributes_ _endpos_t_ _startpos__2_ _startpos_attributes_ attributes names t in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let t = _v in
            let _v = _menhir_action_093 t in
            _menhir_goto_decl _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | _ ->
            _eRR 423
    
    and _menhir_run_362 : type  ttv_stack. (((ttv_stack, _menhir_box_program) _menhir_cell1_EXPORTDEF, _menhir_box_program) _menhir_cell1_separated_nonempty_list_CONJ_constant_ as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.ARROW ->
            let _menhir_stack = MenhirCell1_type_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_277 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FULLSTOP ->
            let MenhirCell1_separated_nonempty_list_CONJ_constant_ (_menhir_stack, _, _, _) = _menhir_stack in
            let MenhirCell1_EXPORTDEF (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
            let _endpos__3_ = _endpos in
            let _ = _menhir_action_119 _endpos__3_ _startpos__1_ in
            _menhir_goto_ignored _menhir_stack _menhir_lexbuf _menhir_lexer _startpos__1_ _menhir_s _tok
        | _ ->
            _eRR 362
    
    and _menhir_goto_ignored : type  ttv_stack. ttv_stack -> _ -> _ -> _ -> (ttv_stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _startpos _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.FULLSTOP ->
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_startpos__1_, _endpos__2_) = (_startpos, _endpos) in
            let _v = _menhir_action_105 _endpos__2_ _startpos__1_ in
            _menhir_goto_decl _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | _ ->
            _eRR 410
    
    and _menhir_run_343 : type  ttv_stack. (((ttv_stack, _menhir_box_program) _menhir_cell1_LOCAL, _menhir_box_program) _menhir_cell1_separated_nonempty_list_CONJ_constant_ as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.ARROW ->
            let _menhir_stack = MenhirCell1_type_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_277 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FULLSTOP ->
            let x = _v in
            let _ = _menhir_action_293 x in
            _menhir_run_344 _menhir_stack _menhir_lexbuf _menhir_lexer
        | _ ->
            _eRR 343
    
    and _menhir_run_344 : type  ttv_stack. ((ttv_stack, _menhir_box_program) _menhir_cell1_LOCAL, _menhir_box_program) _menhir_cell1_separated_nonempty_list_CONJ_constant_ -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer ->
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        let MenhirCell1_separated_nonempty_list_CONJ_constant_ (_menhir_stack, _, l, _) = _menhir_stack in
        let MenhirCell1_LOCAL (_menhir_stack, _menhir_s) = _menhir_stack in
        let _v = _menhir_action_104 l in
        _menhir_goto_decl _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
    
    and _menhir_run_301 : type  ttv_stack. (((ttv_stack, _menhir_box_program) _menhir_cell1_TYPEABBREV, _menhir_box_program) _menhir_cell1_abbrevform as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.ARROW ->
            let _menhir_stack = MenhirCell1_type_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_277 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FULLSTOP ->
            let MenhirCell1_abbrevform (_menhir_stack, _, a) = _menhir_stack in
            let MenhirCell1_TYPEABBREV (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
            let (_endpos_t_, t) = (_endpos, _v) in
            let _v = _menhir_action_327 _endpos_t_ _startpos__1_ a t in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let a = _v in
            let _v = _menhir_action_100 a in
            _menhir_goto_decl _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | _ ->
            _eRR 301
    
    and _menhir_run_288 : type  ttv_stack. (((ttv_stack, _menhir_box_program) _menhir_cell1_USEONLY, _menhir_box_program) _menhir_cell1_separated_nonempty_list_CONJ_constant_ as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.ARROW ->
            let _menhir_stack = MenhirCell1_type_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_277 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FULLSTOP ->
            let MenhirCell1_separated_nonempty_list_CONJ_constant_ (_menhir_stack, _, _, _) = _menhir_stack in
            let MenhirCell1_USEONLY (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
            let _endpos__3_ = _endpos in
            let _ = _menhir_action_122 _endpos__3_ _startpos__1_ in
            _menhir_goto_ignored _menhir_stack _menhir_lexbuf _menhir_lexer _startpos__1_ _menhir_s _tok
        | _ ->
            _eRR 288
    
    and _menhir_run_282 : type  ttv_stack. ((ttv_stack, _menhir_box_program) _menhir_cell1_LPAREN as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.RPAREN ->
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let MenhirCell1_LPAREN (_menhir_stack, _menhir_s, _) = _menhir_stack in
            let (_endpos__3_, t) = (_endpos_0, _v) in
            let _v = _menhir_action_023 t in
            _menhir_run_286 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__3_ _v _menhir_s _tok
        | Elpi_lexer_config.Tokens.ARROW ->
            let _menhir_stack = MenhirCell1_type_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_277 _menhir_stack _menhir_lexbuf _menhir_lexer
        | _ ->
            _eRR 282
    
    and _menhir_run_278 : type  ttv_stack. ((ttv_stack, _menhir_box_program) _menhir_cell1_type_term _menhir_cell0_ARROW as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.ARROW ->
            let _menhir_stack = MenhirCell1_type_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_277 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.FULLSTOP | Elpi_lexer_config.Tokens.IO_COLON _ | Elpi_lexer_config.Tokens.RPAREN ->
            let MenhirCell0_ARROW (_menhir_stack, _, _) = _menhir_stack in
            let MenhirCell1_type_term (_menhir_stack, _menhir_s, hd, _startpos_hd_, _endpos_hd_) = _menhir_stack in
            let (_endpos_t_, t) = (_endpos, _v) in
            let _v = _menhir_action_325 _endpos_hd_ _startpos_hd_ hd t in
            _menhir_goto_type_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_hd_ _v _menhir_s _tok
        | _ ->
            _eRR 278
    
    and _menhir_run_275 : type  ttv_stack. ((ttv_stack, _menhir_box_program) _menhir_cell1_LPAREN as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.RPAREN ->
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let MenhirCell1_LPAREN (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
            let (_endpos__3_, t) = (_endpos_0, _v) in
            let _v = _menhir_action_326 t in
            _menhir_goto_type_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__3_ _startpos__1_ _v _menhir_s _tok
        | Elpi_lexer_config.Tokens.ARROW ->
            let _menhir_stack = MenhirCell1_type_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_277 _menhir_stack _menhir_lexbuf _menhir_lexer
        | _ ->
            _eRR 275
    
    and _menhir_run_285_spec_279 : type  ttv_stack. (ttv_stack, _menhir_box_program) _menhir_cell1_constant -> _ -> _ -> _ -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let (_endpos_c_, c) = (_endpos, _v) in
        let _v = _menhir_action_022 c in
        _menhir_run_286 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _v MenhirState279 _tok
    
    and _menhir_run_394 : type  ttv_stack. (ttv_stack, _menhir_box_program) _menhir_cell1_CLOSED -> _ -> _ -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _tok ->
        let MenhirCell1_CLOSED (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
        let _endpos__2_ = _endpos in
        let _ = _menhir_action_123 _endpos__2_ _startpos__1_ in
        _menhir_goto_ignored _menhir_stack _menhir_lexbuf _menhir_lexer _startpos__1_ _menhir_s _tok
    
    and _menhir_run_361 : type  ttv_stack. ((ttv_stack, _menhir_box_program) _menhir_cell1_EXPORTDEF as 'stack) -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.SIGMA ->
            let _menhir_stack = MenhirCell1_separated_nonempty_list_CONJ_constant_ (_menhir_stack, _menhir_s, _v, _endpos) in
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_0, _startpos) in
            let _v = _menhir_action_085 () in
            _menhir_run_279 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState361 _tok
        | Elpi_lexer_config.Tokens.REPLACE ->
            let _menhir_stack = MenhirCell1_separated_nonempty_list_CONJ_constant_ (_menhir_stack, _menhir_s, _v, _endpos) in
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_2 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_2, _startpos) in
            let _v = _menhir_action_080 () in
            _menhir_run_279 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState361 _tok
        | Elpi_lexer_config.Tokens.PI ->
            let _menhir_stack = MenhirCell1_separated_nonempty_list_CONJ_constant_ (_menhir_stack, _menhir_s, _v, _endpos) in
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_4 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_4, _startpos) in
            let _v = _menhir_action_084 () in
            _menhir_run_279 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState361 _tok
        | Elpi_lexer_config.Tokens.NIL ->
            let _menhir_stack = MenhirCell1_separated_nonempty_list_CONJ_constant_ (_menhir_stack, _menhir_s, _v, _endpos) in
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_6 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_6, _startpos) in
            let _v = _menhir_action_089 () in
            _menhir_run_279 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState361 _tok
        | Elpi_lexer_config.Tokens.NAME ->
            let _menhir_stack = MenhirCell1_separated_nonempty_list_CONJ_constant_ (_menhir_stack, _menhir_s, _v, _endpos) in
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_8 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_8, _startpos) in
            let _v = _menhir_action_077 () in
            _menhir_run_279 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState361 _tok
        | Elpi_lexer_config.Tokens.LPAREN ->
            let _menhir_stack = MenhirCell1_separated_nonempty_list_CONJ_constant_ (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_274 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState361
        | Elpi_lexer_config.Tokens.IO _v_10 ->
            let _menhir_stack = MenhirCell1_separated_nonempty_list_CONJ_constant_ (_menhir_stack, _menhir_s, _v, _endpos) in
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_11 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_11, _startpos, _v_10) in
            let _v = _menhir_action_082 c in
            _menhir_run_279 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState361 _tok
        | Elpi_lexer_config.Tokens.INDEX ->
            let _menhir_stack = MenhirCell1_separated_nonempty_list_CONJ_constant_ (_menhir_stack, _menhir_s, _v, _endpos) in
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_13 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_13, _startpos) in
            let _v = _menhir_action_081 () in
            _menhir_run_279 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState361 _tok
        | Elpi_lexer_config.Tokens.IF ->
            let _menhir_stack = MenhirCell1_separated_nonempty_list_CONJ_constant_ (_menhir_stack, _menhir_s, _v, _endpos) in
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_15 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_15, _startpos) in
            let _v = _menhir_action_076 () in
            _menhir_run_279 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState361 _tok
        | Elpi_lexer_config.Tokens.FRESHUV ->
            let _menhir_stack = MenhirCell1_separated_nonempty_list_CONJ_constant_ (_menhir_stack, _menhir_s, _v, _endpos) in
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_17 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_17, _startpos) in
            let _v = _menhir_action_086 () in
            _menhir_run_279 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState361 _tok
        | Elpi_lexer_config.Tokens.CUT ->
            let _menhir_stack = MenhirCell1_separated_nonempty_list_CONJ_constant_ (_menhir_stack, _menhir_s, _v, _endpos) in
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_19 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_19, _startpos) in
            let _v = _menhir_action_083 () in
            _menhir_run_279 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState361 _tok
        | Elpi_lexer_config.Tokens.CONSTANT _v_21 ->
            let _menhir_stack = MenhirCell1_separated_nonempty_list_CONJ_constant_ (_menhir_stack, _menhir_s, _v, _endpos) in
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_22 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_22, _startpos, _v_21) in
            let _v = _menhir_action_075 c in
            _menhir_run_279 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState361 _tok
        | Elpi_lexer_config.Tokens.BEFORE ->
            let _menhir_stack = MenhirCell1_separated_nonempty_list_CONJ_constant_ (_menhir_stack, _menhir_s, _v, _endpos) in
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_24 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_24, _startpos) in
            let _v = _menhir_action_078 () in
            _menhir_run_279 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState361 _tok
        | Elpi_lexer_config.Tokens.AFTER ->
            let _menhir_stack = MenhirCell1_separated_nonempty_list_CONJ_constant_ (_menhir_stack, _menhir_s, _v, _endpos) in
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_26 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_26, _startpos) in
            let _v = _menhir_action_079 () in
            _menhir_run_279 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState361 _tok
        | Elpi_lexer_config.Tokens.FULLSTOP ->
            let MenhirCell1_EXPORTDEF (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
            let _endpos__2_ = _endpos in
            let _ = _menhir_action_118 _endpos__2_ _startpos__1_ in
            _menhir_goto_ignored _menhir_stack _menhir_lexbuf _menhir_lexer _startpos__1_ _menhir_s _tok
        | _ ->
            _eRR 361
    
    and _menhir_run_348 : type  ttv_stack. ((ttv_stack, _menhir_box_program) _menhir_cell1_KIND as 'stack) -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_separated_nonempty_list_CONJ_constant_ (_menhir_stack, _menhir_s, _v, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.TYPE ->
            _menhir_run_349 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState348
        | _ ->
            _eRR 348
    
    and _menhir_run_349 : type  ttv_stack. ttv_stack -> _ -> _ -> (ttv_stack, _menhir_box_program) _menhir_state -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.ARROW ->
            let _menhir_stack = MenhirCell1_TYPE (_menhir_stack, _menhir_s, _startpos, _endpos) in
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell0_ARROW (_menhir_stack, _startpos, _endpos) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Elpi_lexer_config.Tokens.TYPE ->
                _menhir_run_349 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState350
            | _ ->
                _eRR 350)
        | Elpi_lexer_config.Tokens.FULLSTOP ->
            let _endpos__1_ = _endpos in
            let _v = _menhir_action_157 () in
            _menhir_goto_kind_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _v _menhir_s
        | _ ->
            _eRR 349
    
    and _menhir_goto_kind_term : type  ttv_stack. ttv_stack -> _ -> _ -> _ -> _ -> (ttv_stack, _menhir_box_program) _menhir_state -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s ->
        match _menhir_s with
        | MenhirState348 ->
            _menhir_run_352 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v
        | MenhirState350 ->
            _menhir_run_351 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_352 : type  ttv_stack. ((ttv_stack, _menhir_box_program) _menhir_cell1_KIND, _menhir_box_program) _menhir_cell1_separated_nonempty_list_CONJ_constant_ -> _ -> _ -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v ->
        let MenhirCell1_separated_nonempty_list_CONJ_constant_ (_menhir_stack, _, names, _) = _menhir_stack in
        let MenhirCell1_KIND (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
        let (_endpos_k_, k) = (_endpos, _v) in
        let _v = _menhir_action_156 _endpos_k_ _startpos__1_ k names in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        let t = _v in
        let _v = _menhir_action_094 t in
        _menhir_goto_decl _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
    
    and _menhir_run_351 : type  ttv_stack. (ttv_stack, _menhir_box_program) _menhir_cell1_TYPE _menhir_cell0_ARROW -> _ -> _ -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v ->
        let MenhirCell0_ARROW (_menhir_stack, _, _) = _menhir_stack in
        let MenhirCell1_TYPE (_menhir_stack, _menhir_s, _startpos_hd_, _endpos_hd_) = _menhir_stack in
        let (_endpos_t_, t, hd) = (_endpos, _v, ()) in
        let _v = _menhir_action_158 _endpos_hd_ _startpos_hd_ hd t in
        _menhir_goto_kind_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _v _menhir_s
    
    and _menhir_run_342 : type  ttv_stack. ((ttv_stack, _menhir_box_program) _menhir_cell1_LOCAL as 'stack) -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_separated_nonempty_list_CONJ_constant_ (_menhir_stack, _menhir_s, _v, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.SIGMA ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_0, _startpos) in
            let _v = _menhir_action_085 () in
            _menhir_run_279 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState342 _tok
        | Elpi_lexer_config.Tokens.REPLACE ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_2 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_2, _startpos) in
            let _v = _menhir_action_080 () in
            _menhir_run_279 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState342 _tok
        | Elpi_lexer_config.Tokens.PI ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_4 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_4, _startpos) in
            let _v = _menhir_action_084 () in
            _menhir_run_279 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState342 _tok
        | Elpi_lexer_config.Tokens.NIL ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_6 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_6, _startpos) in
            let _v = _menhir_action_089 () in
            _menhir_run_279 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState342 _tok
        | Elpi_lexer_config.Tokens.NAME ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_8 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_8, _startpos) in
            let _v = _menhir_action_077 () in
            _menhir_run_279 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState342 _tok
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_274 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState342
        | Elpi_lexer_config.Tokens.IO _v_10 ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_11 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_11, _startpos, _v_10) in
            let _v = _menhir_action_082 c in
            _menhir_run_279 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState342 _tok
        | Elpi_lexer_config.Tokens.INDEX ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_13 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_13, _startpos) in
            let _v = _menhir_action_081 () in
            _menhir_run_279 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState342 _tok
        | Elpi_lexer_config.Tokens.IF ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_15 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_15, _startpos) in
            let _v = _menhir_action_076 () in
            _menhir_run_279 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState342 _tok
        | Elpi_lexer_config.Tokens.FRESHUV ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_17 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_17, _startpos) in
            let _v = _menhir_action_086 () in
            _menhir_run_279 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState342 _tok
        | Elpi_lexer_config.Tokens.CUT ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_19 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_19, _startpos) in
            let _v = _menhir_action_083 () in
            _menhir_run_279 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState342 _tok
        | Elpi_lexer_config.Tokens.CONSTANT _v_21 ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_22 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_22, _startpos, _v_21) in
            let _v = _menhir_action_075 c in
            _menhir_run_279 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState342 _tok
        | Elpi_lexer_config.Tokens.BEFORE ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_24 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_24, _startpos) in
            let _v = _menhir_action_078 () in
            _menhir_run_279 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState342 _tok
        | Elpi_lexer_config.Tokens.AFTER ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_26 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_26, _startpos) in
            let _v = _menhir_action_079 () in
            _menhir_run_279 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState342 _tok
        | Elpi_lexer_config.Tokens.FULLSTOP ->
            let _ = _menhir_action_292 () in
            _menhir_run_344 _menhir_stack _menhir_lexbuf _menhir_lexer
        | _ ->
            _eRR 342
    
    and _menhir_run_340 : type  ttv_stack. (ttv_stack, _menhir_box_program) _menhir_cell1_LOCALKIND -> _ -> _ -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _tok ->
        let MenhirCell1_LOCALKIND (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
        let _endpos__2_ = _endpos in
        let _ = _menhir_action_120 _endpos__2_ _startpos__1_ in
        _menhir_goto_ignored _menhir_stack _menhir_lexbuf _menhir_lexer _startpos__1_ _menhir_s _tok
    
    and _menhir_run_291 : type  ttv_stack. (ttv_stack, _menhir_box_program) _menhir_cell1_constant _menhir_cell0_CONJ -> _ -> _ -> _ -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let MenhirCell0_CONJ (_menhir_stack, _, _) = _menhir_stack in
        let MenhirCell1_constant (_menhir_stack, _menhir_s, x, _, _) = _menhir_stack in
        let (_endpos_xs_, xs) = (_endpos, _v) in
        let _v = _menhir_action_303 x xs in
        _menhir_goto_separated_nonempty_list_CONJ_constant_ _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_xs_ _v _menhir_s _tok
    
    and _menhir_run_273 : type  ttv_stack. ((ttv_stack, _menhir_box_program) _menhir_cell1_USEONLY as 'stack) -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.SIGMA ->
            let _menhir_stack = MenhirCell1_separated_nonempty_list_CONJ_constant_ (_menhir_stack, _menhir_s, _v, _endpos) in
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_0, _startpos) in
            let _v = _menhir_action_085 () in
            _menhir_run_279 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState273 _tok
        | Elpi_lexer_config.Tokens.REPLACE ->
            let _menhir_stack = MenhirCell1_separated_nonempty_list_CONJ_constant_ (_menhir_stack, _menhir_s, _v, _endpos) in
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_2 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_2, _startpos) in
            let _v = _menhir_action_080 () in
            _menhir_run_279 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState273 _tok
        | Elpi_lexer_config.Tokens.PI ->
            let _menhir_stack = MenhirCell1_separated_nonempty_list_CONJ_constant_ (_menhir_stack, _menhir_s, _v, _endpos) in
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_4 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_4, _startpos) in
            let _v = _menhir_action_084 () in
            _menhir_run_279 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState273 _tok
        | Elpi_lexer_config.Tokens.NIL ->
            let _menhir_stack = MenhirCell1_separated_nonempty_list_CONJ_constant_ (_menhir_stack, _menhir_s, _v, _endpos) in
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_6 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_6, _startpos) in
            let _v = _menhir_action_089 () in
            _menhir_run_279 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState273 _tok
        | Elpi_lexer_config.Tokens.NAME ->
            let _menhir_stack = MenhirCell1_separated_nonempty_list_CONJ_constant_ (_menhir_stack, _menhir_s, _v, _endpos) in
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_8 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_8, _startpos) in
            let _v = _menhir_action_077 () in
            _menhir_run_279 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState273 _tok
        | Elpi_lexer_config.Tokens.LPAREN ->
            let _menhir_stack = MenhirCell1_separated_nonempty_list_CONJ_constant_ (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_274 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState273
        | Elpi_lexer_config.Tokens.IO _v_10 ->
            let _menhir_stack = MenhirCell1_separated_nonempty_list_CONJ_constant_ (_menhir_stack, _menhir_s, _v, _endpos) in
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_11 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_11, _startpos, _v_10) in
            let _v = _menhir_action_082 c in
            _menhir_run_279 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState273 _tok
        | Elpi_lexer_config.Tokens.INDEX ->
            let _menhir_stack = MenhirCell1_separated_nonempty_list_CONJ_constant_ (_menhir_stack, _menhir_s, _v, _endpos) in
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_13 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_13, _startpos) in
            let _v = _menhir_action_081 () in
            _menhir_run_279 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState273 _tok
        | Elpi_lexer_config.Tokens.IF ->
            let _menhir_stack = MenhirCell1_separated_nonempty_list_CONJ_constant_ (_menhir_stack, _menhir_s, _v, _endpos) in
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_15 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_15, _startpos) in
            let _v = _menhir_action_076 () in
            _menhir_run_279 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState273 _tok
        | Elpi_lexer_config.Tokens.FRESHUV ->
            let _menhir_stack = MenhirCell1_separated_nonempty_list_CONJ_constant_ (_menhir_stack, _menhir_s, _v, _endpos) in
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_17 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_17, _startpos) in
            let _v = _menhir_action_086 () in
            _menhir_run_279 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState273 _tok
        | Elpi_lexer_config.Tokens.CUT ->
            let _menhir_stack = MenhirCell1_separated_nonempty_list_CONJ_constant_ (_menhir_stack, _menhir_s, _v, _endpos) in
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_19 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_19, _startpos) in
            let _v = _menhir_action_083 () in
            _menhir_run_279 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState273 _tok
        | Elpi_lexer_config.Tokens.CONSTANT _v_21 ->
            let _menhir_stack = MenhirCell1_separated_nonempty_list_CONJ_constant_ (_menhir_stack, _menhir_s, _v, _endpos) in
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_22 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_22, _startpos, _v_21) in
            let _v = _menhir_action_075 c in
            _menhir_run_279 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState273 _tok
        | Elpi_lexer_config.Tokens.BEFORE ->
            let _menhir_stack = MenhirCell1_separated_nonempty_list_CONJ_constant_ (_menhir_stack, _menhir_s, _v, _endpos) in
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_24 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_24, _startpos) in
            let _v = _menhir_action_078 () in
            _menhir_run_279 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState273 _tok
        | Elpi_lexer_config.Tokens.AFTER ->
            let _menhir_stack = MenhirCell1_separated_nonempty_list_CONJ_constant_ (_menhir_stack, _menhir_s, _v, _endpos) in
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_26 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_26, _startpos) in
            let _v = _menhir_action_079 () in
            _menhir_run_279 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState273 _tok
        | Elpi_lexer_config.Tokens.FULLSTOP ->
            let MenhirCell1_USEONLY (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
            let _endpos__2_ = _endpos in
            let _ = _menhir_action_121 _endpos__2_ _startpos__1_ in
            _menhir_goto_ignored _menhir_stack _menhir_lexbuf _menhir_lexer _startpos__1_ _menhir_s _tok
        | _ ->
            _eRR 273
    
    and _menhir_run_292 : type  ttv_stack. ttv_stack -> _ -> _ -> (ttv_stack, _menhir_box_program) _menhir_state -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_TYPEABBREV (_menhir_stack, _menhir_s, _startpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.SIGMA ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_085 () in
            _menhir_run_299_spec_292 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.REPLACE ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_080 () in
            _menhir_run_299_spec_292 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.PI ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_084 () in
            _menhir_run_299_spec_292 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.NIL ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_089 () in
            _menhir_run_299_spec_292 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.NAME ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_077 () in
            _menhir_run_299_spec_292 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.LPAREN ->
            let _startpos_5 = _menhir_lexbuf.Lexing.lex_start_p in
            let _menhir_stack = MenhirCell1_LPAREN (_menhir_stack, MenhirState292, _startpos_5) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Elpi_lexer_config.Tokens.VDASH ->
                let _tok = _menhir_lexer _menhir_lexbuf in
                let _v = _menhir_action_201 () in
                _menhir_run_224 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
            | Elpi_lexer_config.Tokens.SLASH ->
                let _tok = _menhir_lexer _menhir_lexbuf in
                let _v = _menhir_action_198 () in
                _menhir_run_224 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
            | Elpi_lexer_config.Tokens.SIGMA ->
                let _startpos_8 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_8) in
                let _v = _menhir_action_085 () in
                _menhir_run_294 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState293 _tok
            | Elpi_lexer_config.Tokens.REPLACE ->
                let _startpos_9 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_9) in
                let _v = _menhir_action_080 () in
                _menhir_run_294 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState293 _tok
            | Elpi_lexer_config.Tokens.QDASH ->
                let _tok = _menhir_lexer _menhir_lexbuf in
                let _v = _menhir_action_197 () in
                _menhir_run_224 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
            | Elpi_lexer_config.Tokens.PI ->
                let _startpos_11 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_11) in
                let _v = _menhir_action_084 () in
                _menhir_run_294 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState293 _tok
            | Elpi_lexer_config.Tokens.OR ->
                let _tok = _menhir_lexer _menhir_lexbuf in
                let _v = _menhir_action_191 () in
                _menhir_run_224 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
            | Elpi_lexer_config.Tokens.NIL ->
                let _startpos_13 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_13) in
                let _v = _menhir_action_089 () in
                _menhir_run_294 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState293 _tok
            | Elpi_lexer_config.Tokens.NAME ->
                let _startpos_14 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_14) in
                let _v = _menhir_action_077 () in
                _menhir_run_294 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState293 _tok
            | Elpi_lexer_config.Tokens.MOD ->
                let _tok = _menhir_lexer _menhir_lexbuf in
                let _v = _menhir_action_193 () in
                _menhir_run_224 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
            | Elpi_lexer_config.Tokens.MINUSs ->
                let _tok = _menhir_lexer _menhir_lexbuf in
                let _v = _menhir_action_189 () in
                _menhir_run_224 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
            | Elpi_lexer_config.Tokens.MINUSr ->
                let _tok = _menhir_lexer _menhir_lexbuf in
                let _v = _menhir_action_187 () in
                _menhir_run_224 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
            | Elpi_lexer_config.Tokens.MINUSi ->
                let _tok = _menhir_lexer _menhir_lexbuf in
                let _v = _menhir_action_188 () in
                _menhir_run_224 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
            | Elpi_lexer_config.Tokens.MINUS ->
                let _tok = _menhir_lexer _menhir_lexbuf in
                let _v = _menhir_action_186 () in
                _menhir_run_224 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
            | Elpi_lexer_config.Tokens.LPAREN ->
                _menhir_run_271 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState293
            | Elpi_lexer_config.Tokens.IS ->
                let _tok = _menhir_lexer _menhir_lexbuf in
                let _v = _menhir_action_192 () in
                _menhir_run_224 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
            | Elpi_lexer_config.Tokens.IO _v ->
                let _startpos_21 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_c_, _startpos_c_, c) = (_endpos, _startpos_21, _v) in
                let _v = _menhir_action_082 c in
                _menhir_run_294 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState293 _tok
            | Elpi_lexer_config.Tokens.INDEX ->
                let _startpos_22 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_22) in
                let _v = _menhir_action_081 () in
                _menhir_run_294 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState293 _tok
            | Elpi_lexer_config.Tokens.IF ->
                let _startpos_23 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_23) in
                let _v = _menhir_action_076 () in
                _menhir_run_294 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState293 _tok
            | Elpi_lexer_config.Tokens.FRESHUV ->
                let _startpos_24 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_24) in
                let _v = _menhir_action_086 () in
                _menhir_run_294 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState293 _tok
            | Elpi_lexer_config.Tokens.FAMILY_TIMES _v ->
                let _tok = _menhir_lexer _menhir_lexbuf in
                let s = _v in
                let _v = _menhir_action_173 s in
                _menhir_run_224 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
            | Elpi_lexer_config.Tokens.FAMILY_TILDE _v ->
                let _tok = _menhir_lexer _menhir_lexbuf in
                let s = _v in
                let _v = _menhir_action_202 s in
                _menhir_run_224 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
            | Elpi_lexer_config.Tokens.FAMILY_TICK _v ->
                let _tok = _menhir_lexer _menhir_lexbuf in
                let s = _v in
                let _v = _menhir_action_183 s in
                _menhir_run_224 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
            | Elpi_lexer_config.Tokens.FAMILY_SHARP _v ->
                let _tok = _menhir_lexer _menhir_lexbuf in
                let s = _v in
                let _v = _menhir_action_181 s in
                _menhir_run_224 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
            | Elpi_lexer_config.Tokens.FAMILY_QMARK _v ->
                let _tok = _menhir_lexer _menhir_lexbuf in
                let s = _v in
                let _v = _menhir_action_203 s in
                _menhir_run_224 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
            | Elpi_lexer_config.Tokens.FAMILY_PLUS _v ->
                let _tok = _menhir_lexer _menhir_lexbuf in
                let s = _v in
                let _v = _menhir_action_172 s in
                _menhir_run_224 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
            | Elpi_lexer_config.Tokens.FAMILY_OR _v ->
                let _tok = _menhir_lexer _menhir_lexbuf in
                let s = _v in
                let _v = _menhir_action_180 s in
                _menhir_run_224 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
            | Elpi_lexer_config.Tokens.FAMILY_MINUS _v ->
                let _tok = _menhir_lexer _menhir_lexbuf in
                let s = _v in
                let _v = _menhir_action_174 s in
                _menhir_run_224 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
            | Elpi_lexer_config.Tokens.FAMILY_LT _v ->
                let _tok = _menhir_lexer _menhir_lexbuf in
                let s = _v in
                let _v = _menhir_action_176 s in
                _menhir_run_224 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
            | Elpi_lexer_config.Tokens.FAMILY_GT _v ->
                let _tok = _menhir_lexer _menhir_lexbuf in
                let s = _v in
                let _v = _menhir_action_177 s in
                _menhir_run_224 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
            | Elpi_lexer_config.Tokens.FAMILY_EXP _v ->
                let _tok = _menhir_lexer _menhir_lexbuf in
                let s = _v in
                let _v = _menhir_action_175 s in
                _menhir_run_224 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
            | Elpi_lexer_config.Tokens.FAMILY_EQ _v ->
                let _tok = _menhir_lexer _menhir_lexbuf in
                let s = _v in
                let _v = _menhir_action_178 s in
                _menhir_run_224 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
            | Elpi_lexer_config.Tokens.FAMILY_BTICK _v ->
                let _tok = _menhir_lexer _menhir_lexbuf in
                let s = _v in
                let _v = _menhir_action_182 s in
                _menhir_run_224 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
            | Elpi_lexer_config.Tokens.FAMILY_AND _v ->
                let _tok = _menhir_lexer _menhir_lexbuf in
                let s = _v in
                let _v = _menhir_action_179 s in
                _menhir_run_224 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
            | Elpi_lexer_config.Tokens.EQ2 ->
                let _tok = _menhir_lexer _menhir_lexbuf in
                let _v = _menhir_action_190 () in
                _menhir_run_224 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
            | Elpi_lexer_config.Tokens.EQ ->
                let _tok = _menhir_lexer _menhir_lexbuf in
                let _v = _menhir_action_185 () in
                _menhir_run_224 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
            | Elpi_lexer_config.Tokens.DIV ->
                let _tok = _menhir_lexer _menhir_lexbuf in
                let _v = _menhir_action_194 () in
                _menhir_run_224 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
            | Elpi_lexer_config.Tokens.DARROW ->
                let _tok = _menhir_lexer _menhir_lexbuf in
                let _v = _menhir_action_196 () in
                _menhir_run_224 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
            | Elpi_lexer_config.Tokens.CUT ->
                let _startpos_43 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_43) in
                let _v = _menhir_action_083 () in
                _menhir_run_294 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState293 _tok
            | Elpi_lexer_config.Tokens.CONSTANT _v ->
                let _startpos_44 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_c_, _startpos_c_, c) = (_endpos, _startpos_44, _v) in
                let _v = _menhir_action_075 c in
                _menhir_run_294 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState293 _tok
            | Elpi_lexer_config.Tokens.CONS ->
                let _tok = _menhir_lexer _menhir_lexbuf in
                let _v = _menhir_action_184 () in
                _menhir_run_224 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
            | Elpi_lexer_config.Tokens.CONJ2 ->
                let _tok = _menhir_lexer _menhir_lexbuf in
                let _v = _menhir_action_199 () in
                _menhir_run_224 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
            | Elpi_lexer_config.Tokens.CONJ ->
                let _tok = _menhir_lexer _menhir_lexbuf in
                let _v = _menhir_action_200 () in
                _menhir_run_224 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
            | Elpi_lexer_config.Tokens.BEFORE ->
                let _startpos_48 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_48) in
                let _v = _menhir_action_078 () in
                _menhir_run_294 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState293 _tok
            | Elpi_lexer_config.Tokens.AS ->
                _menhir_run_216 _menhir_stack _menhir_lexbuf _menhir_lexer
            | Elpi_lexer_config.Tokens.ARROW ->
                let _tok = _menhir_lexer _menhir_lexbuf in
                let _v = _menhir_action_195 () in
                _menhir_run_224 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
            | Elpi_lexer_config.Tokens.AFTER ->
                let _startpos_50 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_50) in
                let _v = _menhir_action_079 () in
                _menhir_run_294 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState293 _tok
            | _ ->
                _eRR 293)
        | Elpi_lexer_config.Tokens.IO _v ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let c = _v in
            let _v = _menhir_action_082 c in
            _menhir_run_299_spec_292 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.INDEX ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_081 () in
            _menhir_run_299_spec_292 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.IF ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_076 () in
            _menhir_run_299_spec_292 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.FRESHUV ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_086 () in
            _menhir_run_299_spec_292 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.CUT ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_083 () in
            _menhir_run_299_spec_292 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.CONSTANT _v ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let c = _v in
            let _v = _menhir_action_075 c in
            _menhir_run_299_spec_292 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.BEFORE ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_078 () in
            _menhir_run_299_spec_292 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.AFTER ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_079 () in
            _menhir_run_299_spec_292 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | _ ->
            _eRR 292
    
    and _menhir_run_299_spec_292 : type  ttv_stack. (ttv_stack, _menhir_box_program) _menhir_cell1_TYPEABBREV -> _ -> _ -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok ->
        let c = _v in
        let _v = _menhir_action_005 c in
        _menhir_run_300 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState292 _tok
    
    and _menhir_run_300 : type  ttv_stack. ((ttv_stack, _menhir_box_program) _menhir_cell1_TYPEABBREV as 'stack) -> _ -> _ -> _ -> ('stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_abbrevform (_menhir_stack, _menhir_s, _v) in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.SIGMA ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos) in
            let _v = _menhir_action_085 () in
            _menhir_run_279 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState300 _tok
        | Elpi_lexer_config.Tokens.REPLACE ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos) in
            let _v = _menhir_action_080 () in
            _menhir_run_279 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState300 _tok
        | Elpi_lexer_config.Tokens.PI ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos) in
            let _v = _menhir_action_084 () in
            _menhir_run_279 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState300 _tok
        | Elpi_lexer_config.Tokens.NIL ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos) in
            let _v = _menhir_action_089 () in
            _menhir_run_279 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState300 _tok
        | Elpi_lexer_config.Tokens.NAME ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos) in
            let _v = _menhir_action_077 () in
            _menhir_run_279 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState300 _tok
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_274 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState300
        | Elpi_lexer_config.Tokens.IO _v_5 ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos, _startpos, _v_5) in
            let _v = _menhir_action_082 c in
            _menhir_run_279 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState300 _tok
        | Elpi_lexer_config.Tokens.INDEX ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos) in
            let _v = _menhir_action_081 () in
            _menhir_run_279 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState300 _tok
        | Elpi_lexer_config.Tokens.IF ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos) in
            let _v = _menhir_action_076 () in
            _menhir_run_279 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState300 _tok
        | Elpi_lexer_config.Tokens.FRESHUV ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos) in
            let _v = _menhir_action_086 () in
            _menhir_run_279 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState300 _tok
        | Elpi_lexer_config.Tokens.CUT ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos) in
            let _v = _menhir_action_083 () in
            _menhir_run_279 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState300 _tok
        | Elpi_lexer_config.Tokens.CONSTANT _v_11 ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos, _startpos, _v_11) in
            let _v = _menhir_action_075 c in
            _menhir_run_279 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState300 _tok
        | Elpi_lexer_config.Tokens.BEFORE ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos) in
            let _v = _menhir_action_078 () in
            _menhir_run_279 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState300 _tok
        | Elpi_lexer_config.Tokens.AFTER ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos) in
            let _v = _menhir_action_079 () in
            _menhir_run_279 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState300 _tok
        | _ ->
            _eRR 300
    
    and _menhir_run_294 : type  ttv_stack. (((ttv_stack, _menhir_box_program) _menhir_cell1_TYPEABBREV, _menhir_box_program) _menhir_cell1_LPAREN as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_constant (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.SIGMA ->
            let _startpos_0 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_1 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_1, _startpos_0) in
            let _v = _menhir_action_085 () in
            _menhir_run_297 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState294 _tok
        | Elpi_lexer_config.Tokens.REPLACE ->
            let _startpos_3 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_4 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_4, _startpos_3) in
            let _v = _menhir_action_080 () in
            _menhir_run_297 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState294 _tok
        | Elpi_lexer_config.Tokens.PI ->
            let _startpos_6 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_7 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_7, _startpos_6) in
            let _v = _menhir_action_084 () in
            _menhir_run_297 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState294 _tok
        | Elpi_lexer_config.Tokens.NIL ->
            let _startpos_9 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_10 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_10, _startpos_9) in
            let _v = _menhir_action_089 () in
            _menhir_run_297 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState294 _tok
        | Elpi_lexer_config.Tokens.NAME ->
            let _startpos_12 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_13 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_13, _startpos_12) in
            let _v = _menhir_action_077 () in
            _menhir_run_297 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState294 _tok
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_271 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState294
        | Elpi_lexer_config.Tokens.IO _v_15 ->
            let _startpos_16 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_17 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_17, _startpos_16, _v_15) in
            let _v = _menhir_action_082 c in
            _menhir_run_297 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState294 _tok
        | Elpi_lexer_config.Tokens.INDEX ->
            let _startpos_19 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_20 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_20, _startpos_19) in
            let _v = _menhir_action_081 () in
            _menhir_run_297 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState294 _tok
        | Elpi_lexer_config.Tokens.IF ->
            let _startpos_22 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_23 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_23, _startpos_22) in
            let _v = _menhir_action_076 () in
            _menhir_run_297 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState294 _tok
        | Elpi_lexer_config.Tokens.FRESHUV ->
            let _startpos_25 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_26 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_26, _startpos_25) in
            let _v = _menhir_action_086 () in
            _menhir_run_297 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState294 _tok
        | Elpi_lexer_config.Tokens.CUT ->
            let _startpos_28 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_29 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_29, _startpos_28) in
            let _v = _menhir_action_083 () in
            _menhir_run_297 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState294 _tok
        | Elpi_lexer_config.Tokens.CONSTANT _v_31 ->
            let _startpos_32 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_33 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_33, _startpos_32, _v_31) in
            let _v = _menhir_action_075 c in
            _menhir_run_297 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState294 _tok
        | Elpi_lexer_config.Tokens.BEFORE ->
            let _startpos_35 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_36 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_36, _startpos_35) in
            let _v = _menhir_action_078 () in
            _menhir_run_297 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState294 _tok
        | Elpi_lexer_config.Tokens.AFTER ->
            let _startpos_38 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_39 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_39, _startpos_38) in
            let _v = _menhir_action_079 () in
            _menhir_run_297 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState294 _tok
        | _ ->
            _eRR 294
    
    and _menhir_run_297 : type  ttv_stack. ((ttv_stack, _menhir_box_program) _menhir_cell1_constant as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.SIGMA ->
            let _menhir_stack = MenhirCell1_constant (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos_0 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_1 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_1, _startpos_0) in
            let _v = _menhir_action_085 () in
            _menhir_run_297 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState297 _tok
        | Elpi_lexer_config.Tokens.REPLACE ->
            let _menhir_stack = MenhirCell1_constant (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos_3 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_4 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_4, _startpos_3) in
            let _v = _menhir_action_080 () in
            _menhir_run_297 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState297 _tok
        | Elpi_lexer_config.Tokens.PI ->
            let _menhir_stack = MenhirCell1_constant (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos_6 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_7 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_7, _startpos_6) in
            let _v = _menhir_action_084 () in
            _menhir_run_297 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState297 _tok
        | Elpi_lexer_config.Tokens.NIL ->
            let _menhir_stack = MenhirCell1_constant (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos_9 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_10 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_10, _startpos_9) in
            let _v = _menhir_action_089 () in
            _menhir_run_297 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState297 _tok
        | Elpi_lexer_config.Tokens.NAME ->
            let _menhir_stack = MenhirCell1_constant (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos_12 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_13 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_13, _startpos_12) in
            let _v = _menhir_action_077 () in
            _menhir_run_297 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState297 _tok
        | Elpi_lexer_config.Tokens.LPAREN ->
            let _menhir_stack = MenhirCell1_constant (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_271 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState297
        | Elpi_lexer_config.Tokens.IO _v_15 ->
            let _menhir_stack = MenhirCell1_constant (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos_16 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_17 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_17, _startpos_16, _v_15) in
            let _v = _menhir_action_082 c in
            _menhir_run_297 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState297 _tok
        | Elpi_lexer_config.Tokens.INDEX ->
            let _menhir_stack = MenhirCell1_constant (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos_19 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_20 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_20, _startpos_19) in
            let _v = _menhir_action_081 () in
            _menhir_run_297 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState297 _tok
        | Elpi_lexer_config.Tokens.IF ->
            let _menhir_stack = MenhirCell1_constant (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos_22 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_23 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_23, _startpos_22) in
            let _v = _menhir_action_076 () in
            _menhir_run_297 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState297 _tok
        | Elpi_lexer_config.Tokens.FRESHUV ->
            let _menhir_stack = MenhirCell1_constant (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos_25 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_26 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_26, _startpos_25) in
            let _v = _menhir_action_086 () in
            _menhir_run_297 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState297 _tok
        | Elpi_lexer_config.Tokens.CUT ->
            let _menhir_stack = MenhirCell1_constant (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos_28 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_29 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_29, _startpos_28) in
            let _v = _menhir_action_083 () in
            _menhir_run_297 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState297 _tok
        | Elpi_lexer_config.Tokens.CONSTANT _v_31 ->
            let _menhir_stack = MenhirCell1_constant (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos_32 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_33 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_33, _startpos_32, _v_31) in
            let _v = _menhir_action_075 c in
            _menhir_run_297 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState297 _tok
        | Elpi_lexer_config.Tokens.BEFORE ->
            let _menhir_stack = MenhirCell1_constant (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos_35 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_36 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_36, _startpos_35) in
            let _v = _menhir_action_078 () in
            _menhir_run_297 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState297 _tok
        | Elpi_lexer_config.Tokens.AFTER ->
            let _menhir_stack = MenhirCell1_constant (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos_38 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_39 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_39, _startpos_38) in
            let _v = _menhir_action_079 () in
            _menhir_run_297 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState297 _tok
        | Elpi_lexer_config.Tokens.RPAREN ->
            let x = _v in
            let _v = _menhir_action_209 x in
            _menhir_goto_nonempty_list_constant_ _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | _ ->
            _eRR 297
    
    and _menhir_goto_nonempty_list_constant_ : type  ttv_stack. ((ttv_stack, _menhir_box_program) _menhir_cell1_constant as 'stack) -> _ -> _ -> _ -> ('stack, _menhir_box_program) _menhir_state -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s ->
        match _menhir_s with
        | MenhirState297 ->
            _menhir_run_298 _menhir_stack _menhir_lexbuf _menhir_lexer _v
        | MenhirState294 ->
            _menhir_run_295 _menhir_stack _menhir_lexbuf _menhir_lexer _v
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_298 : type  ttv_stack. ((ttv_stack, _menhir_box_program) _menhir_cell1_constant, _menhir_box_program) _menhir_cell1_constant -> _ -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let MenhirCell1_constant (_menhir_stack, _menhir_s, x, _, _) = _menhir_stack in
        let xs = _v in
        let _v = _menhir_action_210 x xs in
        _menhir_goto_nonempty_list_constant_ _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
    
    and _menhir_run_295 : type  ttv_stack. (((ttv_stack, _menhir_box_program) _menhir_cell1_TYPEABBREV, _menhir_box_program) _menhir_cell1_LPAREN, _menhir_box_program) _menhir_cell1_constant -> _ -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let _tok = _menhir_lexer _menhir_lexbuf in
        let MenhirCell1_constant (_menhir_stack, _, hd, _, _) = _menhir_stack in
        let MenhirCell1_LPAREN (_menhir_stack, _menhir_s, _) = _menhir_stack in
        let args = _v in
        let _v = _menhir_action_006 args hd in
        _menhir_run_300 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
    
    and _menhir_run_302 : type  ttv_stack. ttv_stack -> _ -> _ -> (ttv_stack, _menhir_box_program) _menhir_state -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_SIG (_menhir_stack, _menhir_s, _startpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.SIGMA ->
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _endpos__1_ = _endpos in
            let _ = _menhir_action_085 () in
            _menhir_run_303 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _tok
        | Elpi_lexer_config.Tokens.REPLACE ->
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _endpos__1_ = _endpos in
            let _ = _menhir_action_080 () in
            _menhir_run_303 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _tok
        | Elpi_lexer_config.Tokens.PI ->
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _endpos__1_ = _endpos in
            let _ = _menhir_action_084 () in
            _menhir_run_303 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _tok
        | Elpi_lexer_config.Tokens.NIL ->
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _endpos__1_ = _endpos in
            let _ = _menhir_action_089 () in
            _menhir_run_303 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _tok
        | Elpi_lexer_config.Tokens.NAME ->
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _endpos__1_ = _endpos in
            let _ = _menhir_action_077 () in
            _menhir_run_303 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _tok
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_271 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState302
        | Elpi_lexer_config.Tokens.IO _v ->
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, c) = (_endpos, _v) in
            let _ = _menhir_action_082 c in
            _menhir_run_303 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _tok
        | Elpi_lexer_config.Tokens.INDEX ->
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _endpos__1_ = _endpos in
            let _ = _menhir_action_081 () in
            _menhir_run_303 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _tok
        | Elpi_lexer_config.Tokens.IF ->
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _endpos__1_ = _endpos in
            let _ = _menhir_action_076 () in
            _menhir_run_303 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _tok
        | Elpi_lexer_config.Tokens.FRESHUV ->
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _endpos__1_ = _endpos in
            let _ = _menhir_action_086 () in
            _menhir_run_303 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _tok
        | Elpi_lexer_config.Tokens.CUT ->
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _endpos__1_ = _endpos in
            let _ = _menhir_action_083 () in
            _menhir_run_303 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _tok
        | Elpi_lexer_config.Tokens.CONSTANT _v ->
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, c) = (_endpos, _v) in
            let _ = _menhir_action_075 c in
            _menhir_run_303 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _tok
        | Elpi_lexer_config.Tokens.BEFORE ->
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _endpos__1_ = _endpos in
            let _ = _menhir_action_078 () in
            _menhir_run_303 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _tok
        | Elpi_lexer_config.Tokens.AFTER ->
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _endpos__1_ = _endpos in
            let _ = _menhir_action_079 () in
            _menhir_run_303 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _tok
        | _ ->
            _eRR 302
    
    and _menhir_run_303 : type  ttv_stack. (ttv_stack, _menhir_box_program) _menhir_cell1_SIG -> _ -> _ -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _tok ->
        let MenhirCell1_SIG (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
        let _endpos__2_ = _endpos in
        let _ = _menhir_action_117 _endpos__2_ _startpos__1_ in
        _menhir_goto_ignored _menhir_stack _menhir_lexbuf _menhir_lexer _startpos__1_ _menhir_s _tok
    
    and _menhir_run_304 : type  ttv_stack. ttv_stack -> _ -> _ -> (ttv_stack, _menhir_box_program) _menhir_state -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_SHORTEN (_menhir_stack, _menhir_s, _startpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.SIGMA ->
            let _startpos_0 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_0) in
            let _v = _menhir_action_085 () in
            _menhir_run_308 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState304 _tok
        | Elpi_lexer_config.Tokens.REPLACE ->
            let _startpos_1 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_1) in
            let _v = _menhir_action_080 () in
            _menhir_run_308 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState304 _tok
        | Elpi_lexer_config.Tokens.PI ->
            let _startpos_2 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_2) in
            let _v = _menhir_action_084 () in
            _menhir_run_308 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState304 _tok
        | Elpi_lexer_config.Tokens.NIL ->
            let _startpos_3 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_3) in
            let _v = _menhir_action_089 () in
            _menhir_run_308 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState304 _tok
        | Elpi_lexer_config.Tokens.NAME ->
            let _startpos_4 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_4) in
            let _v = _menhir_action_077 () in
            _menhir_run_308 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState304 _tok
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_271 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState304
        | Elpi_lexer_config.Tokens.IO _v ->
            let _startpos_5 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos, _startpos_5, _v) in
            let _v = _menhir_action_082 c in
            _menhir_run_308 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState304 _tok
        | Elpi_lexer_config.Tokens.INDEX ->
            let _startpos_6 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_6) in
            let _v = _menhir_action_081 () in
            _menhir_run_308 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState304 _tok
        | Elpi_lexer_config.Tokens.IF ->
            let _startpos_7 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_7) in
            let _v = _menhir_action_076 () in
            _menhir_run_308 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState304 _tok
        | Elpi_lexer_config.Tokens.FRESHUV ->
            let _startpos_8 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_8) in
            let _v = _menhir_action_086 () in
            _menhir_run_308 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState304 _tok
        | Elpi_lexer_config.Tokens.CUT ->
            let _startpos_9 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_9) in
            let _v = _menhir_action_083 () in
            _menhir_run_308 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState304 _tok
        | Elpi_lexer_config.Tokens.CONSTANT _v ->
            let _startpos_10 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos, _startpos_10, _v) in
            let _v = _menhir_action_075 c in
            _menhir_run_308 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState304 _tok
        | Elpi_lexer_config.Tokens.BEFORE ->
            let _startpos_11 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_11) in
            let _v = _menhir_action_078 () in
            _menhir_run_308 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState304 _tok
        | Elpi_lexer_config.Tokens.AFTER ->
            let _startpos_12 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_12) in
            let _v = _menhir_action_079 () in
            _menhir_run_308 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState304 _tok
        | _ ->
            _eRR 304
    
    and _menhir_run_308 : type  ttv_stack. ((ttv_stack, _menhir_box_program) _menhir_cell1_SHORTEN as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_constant (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.FULLSTOP ->
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell0_FULLSTOP (_menhir_stack, _endpos_0) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Elpi_lexer_config.Tokens.LCURLY ->
                let _startpos_1 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_2 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _menhir_stack = MenhirCell0_LCURLY (_menhir_stack, _startpos_1, _endpos_2) in
                let _tok = _menhir_lexer _menhir_lexbuf in
                (match (_tok : MenhirBasics.token) with
                | Elpi_lexer_config.Tokens.SIGMA ->
                    let _startpos_3 = _menhir_lexbuf.Lexing.lex_start_p in
                    let _endpos_4 = _menhir_lexbuf.Lexing.lex_curr_p in
                    let _tok = _menhir_lexer _menhir_lexbuf in
                    let (_endpos__1_, _startpos__1_) = (_endpos_4, _startpos_3) in
                    let _v = _menhir_action_085 () in
                    _menhir_run_314 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState310 _tok
                | Elpi_lexer_config.Tokens.REPLACE ->
                    let _startpos_6 = _menhir_lexbuf.Lexing.lex_start_p in
                    let _endpos_7 = _menhir_lexbuf.Lexing.lex_curr_p in
                    let _tok = _menhir_lexer _menhir_lexbuf in
                    let (_endpos__1_, _startpos__1_) = (_endpos_7, _startpos_6) in
                    let _v = _menhir_action_080 () in
                    _menhir_run_314 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState310 _tok
                | Elpi_lexer_config.Tokens.PI ->
                    let _startpos_9 = _menhir_lexbuf.Lexing.lex_start_p in
                    let _endpos_10 = _menhir_lexbuf.Lexing.lex_curr_p in
                    let _tok = _menhir_lexer _menhir_lexbuf in
                    let (_endpos__1_, _startpos__1_) = (_endpos_10, _startpos_9) in
                    let _v = _menhir_action_084 () in
                    _menhir_run_314 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState310 _tok
                | Elpi_lexer_config.Tokens.NIL ->
                    let _startpos_12 = _menhir_lexbuf.Lexing.lex_start_p in
                    let _endpos_13 = _menhir_lexbuf.Lexing.lex_curr_p in
                    let _tok = _menhir_lexer _menhir_lexbuf in
                    let (_endpos__1_, _startpos__1_) = (_endpos_13, _startpos_12) in
                    let _v = _menhir_action_089 () in
                    _menhir_run_314 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState310 _tok
                | Elpi_lexer_config.Tokens.NAME ->
                    let _startpos_15 = _menhir_lexbuf.Lexing.lex_start_p in
                    let _endpos_16 = _menhir_lexbuf.Lexing.lex_curr_p in
                    let _tok = _menhir_lexer _menhir_lexbuf in
                    let (_endpos__1_, _startpos__1_) = (_endpos_16, _startpos_15) in
                    let _v = _menhir_action_077 () in
                    _menhir_run_314 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState310 _tok
                | Elpi_lexer_config.Tokens.LPAREN ->
                    _menhir_run_271 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState310
                | Elpi_lexer_config.Tokens.IO _v_18 ->
                    let _startpos_19 = _menhir_lexbuf.Lexing.lex_start_p in
                    let _endpos_20 = _menhir_lexbuf.Lexing.lex_curr_p in
                    let _tok = _menhir_lexer _menhir_lexbuf in
                    let (_endpos_c_, _startpos_c_, c) = (_endpos_20, _startpos_19, _v_18) in
                    let _v = _menhir_action_082 c in
                    _menhir_run_314 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState310 _tok
                | Elpi_lexer_config.Tokens.INDEX ->
                    let _startpos_22 = _menhir_lexbuf.Lexing.lex_start_p in
                    let _endpos_23 = _menhir_lexbuf.Lexing.lex_curr_p in
                    let _tok = _menhir_lexer _menhir_lexbuf in
                    let (_endpos__1_, _startpos__1_) = (_endpos_23, _startpos_22) in
                    let _v = _menhir_action_081 () in
                    _menhir_run_314 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState310 _tok
                | Elpi_lexer_config.Tokens.IF ->
                    let _startpos_25 = _menhir_lexbuf.Lexing.lex_start_p in
                    let _endpos_26 = _menhir_lexbuf.Lexing.lex_curr_p in
                    let _tok = _menhir_lexer _menhir_lexbuf in
                    let (_endpos__1_, _startpos__1_) = (_endpos_26, _startpos_25) in
                    let _v = _menhir_action_076 () in
                    _menhir_run_314 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState310 _tok
                | Elpi_lexer_config.Tokens.FRESHUV ->
                    let _startpos_28 = _menhir_lexbuf.Lexing.lex_start_p in
                    let _endpos_29 = _menhir_lexbuf.Lexing.lex_curr_p in
                    let _tok = _menhir_lexer _menhir_lexbuf in
                    let (_endpos__1_, _startpos__1_) = (_endpos_29, _startpos_28) in
                    let _v = _menhir_action_086 () in
                    _menhir_run_314 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState310 _tok
                | Elpi_lexer_config.Tokens.CUT ->
                    let _startpos_31 = _menhir_lexbuf.Lexing.lex_start_p in
                    let _endpos_32 = _menhir_lexbuf.Lexing.lex_curr_p in
                    let _tok = _menhir_lexer _menhir_lexbuf in
                    let (_endpos__1_, _startpos__1_) = (_endpos_32, _startpos_31) in
                    let _v = _menhir_action_083 () in
                    _menhir_run_314 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState310 _tok
                | Elpi_lexer_config.Tokens.CONSTANT _v_34 ->
                    let _startpos_35 = _menhir_lexbuf.Lexing.lex_start_p in
                    let _endpos_36 = _menhir_lexbuf.Lexing.lex_curr_p in
                    let _tok = _menhir_lexer _menhir_lexbuf in
                    let (_endpos_c_, _startpos_c_, c) = (_endpos_36, _startpos_35, _v_34) in
                    let _v = _menhir_action_075 c in
                    _menhir_run_314 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState310 _tok
                | Elpi_lexer_config.Tokens.BEFORE ->
                    let _startpos_38 = _menhir_lexbuf.Lexing.lex_start_p in
                    let _endpos_39 = _menhir_lexbuf.Lexing.lex_curr_p in
                    let _tok = _menhir_lexer _menhir_lexbuf in
                    let (_endpos__1_, _startpos__1_) = (_endpos_39, _startpos_38) in
                    let _v = _menhir_action_078 () in
                    _menhir_run_314 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState310 _tok
                | Elpi_lexer_config.Tokens.AFTER ->
                    let _startpos_41 = _menhir_lexbuf.Lexing.lex_start_p in
                    let _endpos_42 = _menhir_lexbuf.Lexing.lex_curr_p in
                    let _tok = _menhir_lexer _menhir_lexbuf in
                    let (_endpos__1_, _startpos__1_) = (_endpos_42, _startpos_41) in
                    let _v = _menhir_action_079 () in
                    _menhir_run_314 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState310 _tok
                | _ ->
                    _eRR 310)
            | _ ->
                _eRR 309)
        | _ ->
            _eRR 308
    
    and _menhir_run_314 : type  ttv_stack. ttv_stack -> _ -> _ -> _ -> _ -> _ -> (ttv_stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.FULLSTOP ->
            let _menhir_stack = MenhirCell1_constant (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell0_FULLSTOP (_menhir_stack, _endpos_0) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Elpi_lexer_config.Tokens.LCURLY ->
                let _startpos_1 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_2 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _menhir_stack = MenhirCell0_LCURLY (_menhir_stack, _startpos_1, _endpos_2) in
                let _tok = _menhir_lexer _menhir_lexbuf in
                (match (_tok : MenhirBasics.token) with
                | Elpi_lexer_config.Tokens.SIGMA ->
                    let _startpos_3 = _menhir_lexbuf.Lexing.lex_start_p in
                    let _endpos_4 = _menhir_lexbuf.Lexing.lex_curr_p in
                    let _tok = _menhir_lexer _menhir_lexbuf in
                    let (_endpos__1_, _startpos__1_) = (_endpos_4, _startpos_3) in
                    let _v = _menhir_action_085 () in
                    _menhir_run_314 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState316 _tok
                | Elpi_lexer_config.Tokens.REPLACE ->
                    let _startpos_6 = _menhir_lexbuf.Lexing.lex_start_p in
                    let _endpos_7 = _menhir_lexbuf.Lexing.lex_curr_p in
                    let _tok = _menhir_lexer _menhir_lexbuf in
                    let (_endpos__1_, _startpos__1_) = (_endpos_7, _startpos_6) in
                    let _v = _menhir_action_080 () in
                    _menhir_run_314 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState316 _tok
                | Elpi_lexer_config.Tokens.PI ->
                    let _startpos_9 = _menhir_lexbuf.Lexing.lex_start_p in
                    let _endpos_10 = _menhir_lexbuf.Lexing.lex_curr_p in
                    let _tok = _menhir_lexer _menhir_lexbuf in
                    let (_endpos__1_, _startpos__1_) = (_endpos_10, _startpos_9) in
                    let _v = _menhir_action_084 () in
                    _menhir_run_314 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState316 _tok
                | Elpi_lexer_config.Tokens.NIL ->
                    let _startpos_12 = _menhir_lexbuf.Lexing.lex_start_p in
                    let _endpos_13 = _menhir_lexbuf.Lexing.lex_curr_p in
                    let _tok = _menhir_lexer _menhir_lexbuf in
                    let (_endpos__1_, _startpos__1_) = (_endpos_13, _startpos_12) in
                    let _v = _menhir_action_089 () in
                    _menhir_run_314 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState316 _tok
                | Elpi_lexer_config.Tokens.NAME ->
                    let _startpos_15 = _menhir_lexbuf.Lexing.lex_start_p in
                    let _endpos_16 = _menhir_lexbuf.Lexing.lex_curr_p in
                    let _tok = _menhir_lexer _menhir_lexbuf in
                    let (_endpos__1_, _startpos__1_) = (_endpos_16, _startpos_15) in
                    let _v = _menhir_action_077 () in
                    _menhir_run_314 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState316 _tok
                | Elpi_lexer_config.Tokens.LPAREN ->
                    _menhir_run_271 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState316
                | Elpi_lexer_config.Tokens.IO _v_18 ->
                    let _startpos_19 = _menhir_lexbuf.Lexing.lex_start_p in
                    let _endpos_20 = _menhir_lexbuf.Lexing.lex_curr_p in
                    let _tok = _menhir_lexer _menhir_lexbuf in
                    let (_endpos_c_, _startpos_c_, c) = (_endpos_20, _startpos_19, _v_18) in
                    let _v = _menhir_action_082 c in
                    _menhir_run_314 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState316 _tok
                | Elpi_lexer_config.Tokens.INDEX ->
                    let _startpos_22 = _menhir_lexbuf.Lexing.lex_start_p in
                    let _endpos_23 = _menhir_lexbuf.Lexing.lex_curr_p in
                    let _tok = _menhir_lexer _menhir_lexbuf in
                    let (_endpos__1_, _startpos__1_) = (_endpos_23, _startpos_22) in
                    let _v = _menhir_action_081 () in
                    _menhir_run_314 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState316 _tok
                | Elpi_lexer_config.Tokens.IF ->
                    let _startpos_25 = _menhir_lexbuf.Lexing.lex_start_p in
                    let _endpos_26 = _menhir_lexbuf.Lexing.lex_curr_p in
                    let _tok = _menhir_lexer _menhir_lexbuf in
                    let (_endpos__1_, _startpos__1_) = (_endpos_26, _startpos_25) in
                    let _v = _menhir_action_076 () in
                    _menhir_run_314 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState316 _tok
                | Elpi_lexer_config.Tokens.FRESHUV ->
                    let _startpos_28 = _menhir_lexbuf.Lexing.lex_start_p in
                    let _endpos_29 = _menhir_lexbuf.Lexing.lex_curr_p in
                    let _tok = _menhir_lexer _menhir_lexbuf in
                    let (_endpos__1_, _startpos__1_) = (_endpos_29, _startpos_28) in
                    let _v = _menhir_action_086 () in
                    _menhir_run_314 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState316 _tok
                | Elpi_lexer_config.Tokens.CUT ->
                    let _startpos_31 = _menhir_lexbuf.Lexing.lex_start_p in
                    let _endpos_32 = _menhir_lexbuf.Lexing.lex_curr_p in
                    let _tok = _menhir_lexer _menhir_lexbuf in
                    let (_endpos__1_, _startpos__1_) = (_endpos_32, _startpos_31) in
                    let _v = _menhir_action_083 () in
                    _menhir_run_314 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState316 _tok
                | Elpi_lexer_config.Tokens.CONSTANT _v_34 ->
                    let _startpos_35 = _menhir_lexbuf.Lexing.lex_start_p in
                    let _endpos_36 = _menhir_lexbuf.Lexing.lex_curr_p in
                    let _tok = _menhir_lexer _menhir_lexbuf in
                    let (_endpos_c_, _startpos_c_, c) = (_endpos_36, _startpos_35, _v_34) in
                    let _v = _menhir_action_075 c in
                    _menhir_run_314 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState316 _tok
                | Elpi_lexer_config.Tokens.BEFORE ->
                    let _startpos_38 = _menhir_lexbuf.Lexing.lex_start_p in
                    let _endpos_39 = _menhir_lexbuf.Lexing.lex_curr_p in
                    let _tok = _menhir_lexer _menhir_lexbuf in
                    let (_endpos__1_, _startpos__1_) = (_endpos_39, _startpos_38) in
                    let _v = _menhir_action_078 () in
                    _menhir_run_314 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState316 _tok
                | Elpi_lexer_config.Tokens.AFTER ->
                    let _startpos_41 = _menhir_lexbuf.Lexing.lex_start_p in
                    let _endpos_42 = _menhir_lexbuf.Lexing.lex_curr_p in
                    let _tok = _menhir_lexer _menhir_lexbuf in
                    let (_endpos__1_, _startpos__1_) = (_endpos_42, _startpos_41) in
                    let _v = _menhir_action_079 () in
                    _menhir_run_314 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState316 _tok
                | _ ->
                    _eRR 316)
            | _ ->
                _eRR 315)
        | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.RCURLY ->
            let name = _v in
            let _v = _menhir_action_313 name in
            _menhir_goto_subtrie _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | _ ->
            _eRR 314
    
    and _menhir_goto_subtrie : type  ttv_stack. ttv_stack -> _ -> _ -> _ -> (ttv_stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.CONJ ->
            let _menhir_stack = MenhirCell1_subtrie (_menhir_stack, _menhir_s, _v) in
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell0_CONJ (_menhir_stack, _startpos, _endpos) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Elpi_lexer_config.Tokens.SIGMA ->
                let _startpos_0 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1, _startpos_0) in
                let _v = _menhir_action_085 () in
                _menhir_run_314 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState312 _tok
            | Elpi_lexer_config.Tokens.REPLACE ->
                let _startpos_3 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_4 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_4, _startpos_3) in
                let _v = _menhir_action_080 () in
                _menhir_run_314 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState312 _tok
            | Elpi_lexer_config.Tokens.PI ->
                let _startpos_6 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_7 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_7, _startpos_6) in
                let _v = _menhir_action_084 () in
                _menhir_run_314 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState312 _tok
            | Elpi_lexer_config.Tokens.NIL ->
                let _startpos_9 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_10 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_10, _startpos_9) in
                let _v = _menhir_action_089 () in
                _menhir_run_314 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState312 _tok
            | Elpi_lexer_config.Tokens.NAME ->
                let _startpos_12 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_13 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_13, _startpos_12) in
                let _v = _menhir_action_077 () in
                _menhir_run_314 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState312 _tok
            | Elpi_lexer_config.Tokens.LPAREN ->
                _menhir_run_271 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState312
            | Elpi_lexer_config.Tokens.IO _v_15 ->
                let _startpos_16 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_17 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_c_, _startpos_c_, c) = (_endpos_17, _startpos_16, _v_15) in
                let _v = _menhir_action_082 c in
                _menhir_run_314 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState312 _tok
            | Elpi_lexer_config.Tokens.INDEX ->
                let _startpos_19 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_20 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_20, _startpos_19) in
                let _v = _menhir_action_081 () in
                _menhir_run_314 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState312 _tok
            | Elpi_lexer_config.Tokens.IF ->
                let _startpos_22 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_23 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_23, _startpos_22) in
                let _v = _menhir_action_076 () in
                _menhir_run_314 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState312 _tok
            | Elpi_lexer_config.Tokens.FRESHUV ->
                let _startpos_25 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_26 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_26, _startpos_25) in
                let _v = _menhir_action_086 () in
                _menhir_run_314 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState312 _tok
            | Elpi_lexer_config.Tokens.CUT ->
                let _startpos_28 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_29 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_29, _startpos_28) in
                let _v = _menhir_action_083 () in
                _menhir_run_314 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState312 _tok
            | Elpi_lexer_config.Tokens.CONSTANT _v_31 ->
                let _startpos_32 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_33 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_c_, _startpos_c_, c) = (_endpos_33, _startpos_32, _v_31) in
                let _v = _menhir_action_075 c in
                _menhir_run_314 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState312 _tok
            | Elpi_lexer_config.Tokens.BEFORE ->
                let _startpos_35 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_36 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_36, _startpos_35) in
                let _v = _menhir_action_078 () in
                _menhir_run_314 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState312 _tok
            | Elpi_lexer_config.Tokens.AFTER ->
                let _startpos_38 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_39 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_39, _startpos_38) in
                let _v = _menhir_action_079 () in
                _menhir_run_314 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState312 _tok
            | _ ->
                _eRR 312)
        | Elpi_lexer_config.Tokens.RCURLY ->
            let x = _v in
            let _v = _menhir_action_306 x in
            _menhir_goto_separated_nonempty_list_CONJ_subtrie_ _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | _ ->
            _eRR 311
    
    and _menhir_goto_separated_nonempty_list_CONJ_subtrie_ : type  ttv_stack. ttv_stack -> _ -> _ -> _ -> (ttv_stack, _menhir_box_program) _menhir_state -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s ->
        match _menhir_s with
        | MenhirState310 ->
            _menhir_run_319 _menhir_stack _menhir_lexbuf _menhir_lexer _v
        | MenhirState316 ->
            _menhir_run_317 _menhir_stack _menhir_lexbuf _menhir_lexer _v
        | MenhirState312 ->
            _menhir_run_313 _menhir_stack _menhir_lexbuf _menhir_lexer _v
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_319 : type  ttv_stack. ((ttv_stack, _menhir_box_program) _menhir_cell1_SHORTEN, _menhir_box_program) _menhir_cell1_constant _menhir_cell0_FULLSTOP _menhir_cell0_LCURLY -> _ -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let _tok = _menhir_lexer _menhir_lexbuf in
        let MenhirCell0_LCURLY (_menhir_stack, _, _) = _menhir_stack in
        let MenhirCell0_FULLSTOP (_menhir_stack, _) = _menhir_stack in
        let MenhirCell1_constant (_menhir_stack, _, c, _, _) = _menhir_stack in
        let l = _v in
        let _v = _menhir_action_321 c l in
        let l = _v in
        let _v = _menhir_action_312 l in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.FULLSTOP ->
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let MenhirCell1_SHORTEN (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
            let (s, _endpos__3_) = (_v, _endpos) in
            let _v = _menhir_action_099 _endpos__3_ _startpos__1_ s in
            _menhir_goto_decl _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | _ ->
            _eRR 306
    
    and _menhir_run_317 : type  ttv_stack. (ttv_stack, _menhir_box_program) _menhir_cell1_constant _menhir_cell0_FULLSTOP _menhir_cell0_LCURLY -> _ -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let _tok = _menhir_lexer _menhir_lexbuf in
        let MenhirCell0_LCURLY (_menhir_stack, _, _) = _menhir_stack in
        let MenhirCell0_FULLSTOP (_menhir_stack, _) = _menhir_stack in
        let MenhirCell1_constant (_menhir_stack, _menhir_s, prefix, _, _) = _menhir_stack in
        let l = _v in
        let _v = _menhir_action_314 l prefix in
        _menhir_goto_subtrie _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
    
    and _menhir_run_313 : type  ttv_stack. (ttv_stack, _menhir_box_program) _menhir_cell1_subtrie _menhir_cell0_CONJ -> _ -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let MenhirCell0_CONJ (_menhir_stack, _, _) = _menhir_stack in
        let MenhirCell1_subtrie (_menhir_stack, _menhir_s, x) = _menhir_stack in
        let xs = _v in
        let _v = _menhir_action_307 x xs in
        _menhir_goto_separated_nonempty_list_CONJ_subtrie_ _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
    
    and _menhir_run_322 : type  ttv_stack. ttv_stack -> _ -> _ -> (ttv_stack, _menhir_box_program) _menhir_state -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_NAMESPACE (_menhir_stack, _menhir_s, _startpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.SIGMA ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_085 () in
            _menhir_run_323 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.REPLACE ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_080 () in
            _menhir_run_323 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.PI ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_084 () in
            _menhir_run_323 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.NIL ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_089 () in
            _menhir_run_323 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.NAME ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_077 () in
            _menhir_run_323 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_271 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState322
        | Elpi_lexer_config.Tokens.IO _v ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let c = _v in
            let _v = _menhir_action_082 c in
            _menhir_run_323 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.INDEX ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_081 () in
            _menhir_run_323 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.IF ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_076 () in
            _menhir_run_323 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.FRESHUV ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_086 () in
            _menhir_run_323 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.CUT ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_083 () in
            _menhir_run_323 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.CONSTANT _v ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let c = _v in
            let _v = _menhir_action_075 c in
            _menhir_run_323 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.BEFORE ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_078 () in
            _menhir_run_323 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.AFTER ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_079 () in
            _menhir_run_323 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | _ ->
            _eRR 322
    
    and _menhir_run_323 : type  ttv_stack. (ttv_stack, _menhir_box_program) _menhir_cell1_NAMESPACE -> _ -> _ -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.LCURLY ->
            let _endpos_1 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let MenhirCell1_NAMESPACE (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
            let (_endpos, c, _endpos__3_) = (_endpos_1, _v, _endpos_1) in
            let _v = _menhir_action_098 _endpos__3_ _startpos__1_ c in
            _menhir_goto_decl _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | _ ->
            _eRR 323
    
    and _menhir_run_325 : type  ttv_stack. ttv_stack -> _ -> _ -> (ttv_stack, _menhir_box_program) _menhir_state -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_MODULE (_menhir_stack, _menhir_s, _startpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.SIGMA ->
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _endpos__1_ = _endpos in
            let _ = _menhir_action_085 () in
            _menhir_run_326 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _tok
        | Elpi_lexer_config.Tokens.REPLACE ->
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _endpos__1_ = _endpos in
            let _ = _menhir_action_080 () in
            _menhir_run_326 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _tok
        | Elpi_lexer_config.Tokens.PI ->
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _endpos__1_ = _endpos in
            let _ = _menhir_action_084 () in
            _menhir_run_326 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _tok
        | Elpi_lexer_config.Tokens.NIL ->
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _endpos__1_ = _endpos in
            let _ = _menhir_action_089 () in
            _menhir_run_326 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _tok
        | Elpi_lexer_config.Tokens.NAME ->
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _endpos__1_ = _endpos in
            let _ = _menhir_action_077 () in
            _menhir_run_326 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _tok
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_271 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState325
        | Elpi_lexer_config.Tokens.IO _v ->
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, c) = (_endpos, _v) in
            let _ = _menhir_action_082 c in
            _menhir_run_326 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _tok
        | Elpi_lexer_config.Tokens.INDEX ->
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _endpos__1_ = _endpos in
            let _ = _menhir_action_081 () in
            _menhir_run_326 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _tok
        | Elpi_lexer_config.Tokens.IF ->
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _endpos__1_ = _endpos in
            let _ = _menhir_action_076 () in
            _menhir_run_326 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _tok
        | Elpi_lexer_config.Tokens.FRESHUV ->
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _endpos__1_ = _endpos in
            let _ = _menhir_action_086 () in
            _menhir_run_326 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _tok
        | Elpi_lexer_config.Tokens.CUT ->
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _endpos__1_ = _endpos in
            let _ = _menhir_action_083 () in
            _menhir_run_326 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _tok
        | Elpi_lexer_config.Tokens.CONSTANT _v ->
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, c) = (_endpos, _v) in
            let _ = _menhir_action_075 c in
            _menhir_run_326 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _tok
        | Elpi_lexer_config.Tokens.BEFORE ->
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _endpos__1_ = _endpos in
            let _ = _menhir_action_078 () in
            _menhir_run_326 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _tok
        | Elpi_lexer_config.Tokens.AFTER ->
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _endpos__1_ = _endpos in
            let _ = _menhir_action_079 () in
            _menhir_run_326 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _tok
        | _ ->
            _eRR 325
    
    and _menhir_run_326 : type  ttv_stack. (ttv_stack, _menhir_box_program) _menhir_cell1_MODULE -> _ -> _ -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _tok ->
        let MenhirCell1_MODULE (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
        let _endpos__2_ = _endpos in
        let _ = _menhir_action_116 _endpos__2_ _startpos__1_ in
        _menhir_goto_ignored _menhir_stack _menhir_lexbuf _menhir_lexer _startpos__1_ _menhir_s _tok
    
    and _menhir_run_327 : type  ttv_stack. ttv_stack -> _ -> _ -> (ttv_stack, _menhir_box_program) _menhir_state -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_MODE (_menhir_stack, _menhir_s, _startpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.LPAREN ->
            let _startpos_0 = _menhir_lexbuf.Lexing.lex_start_p in
            let _menhir_stack = MenhirCell0_LPAREN (_menhir_stack, _startpos_0) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Elpi_lexer_config.Tokens.SIGMA ->
                let _startpos_1 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_1) in
                let _v = _menhir_action_085 () in
                _menhir_run_329 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState328 _tok
            | Elpi_lexer_config.Tokens.REPLACE ->
                let _startpos_2 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_2) in
                let _v = _menhir_action_080 () in
                _menhir_run_329 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState328 _tok
            | Elpi_lexer_config.Tokens.PI ->
                let _startpos_3 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_3) in
                let _v = _menhir_action_084 () in
                _menhir_run_329 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState328 _tok
            | Elpi_lexer_config.Tokens.NIL ->
                let _startpos_4 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_4) in
                let _v = _menhir_action_089 () in
                _menhir_run_329 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState328 _tok
            | Elpi_lexer_config.Tokens.NAME ->
                let _startpos_5 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_5) in
                let _v = _menhir_action_077 () in
                _menhir_run_329 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState328 _tok
            | Elpi_lexer_config.Tokens.LPAREN ->
                _menhir_run_271 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState328
            | Elpi_lexer_config.Tokens.IO _v ->
                let _startpos_6 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_c_, _startpos_c_, c) = (_endpos, _startpos_6, _v) in
                let _v = _menhir_action_082 c in
                _menhir_run_329 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState328 _tok
            | Elpi_lexer_config.Tokens.INDEX ->
                let _startpos_7 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_7) in
                let _v = _menhir_action_081 () in
                _menhir_run_329 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState328 _tok
            | Elpi_lexer_config.Tokens.IF ->
                let _startpos_8 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_8) in
                let _v = _menhir_action_076 () in
                _menhir_run_329 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState328 _tok
            | Elpi_lexer_config.Tokens.FRESHUV ->
                let _startpos_9 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_9) in
                let _v = _menhir_action_086 () in
                _menhir_run_329 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState328 _tok
            | Elpi_lexer_config.Tokens.CUT ->
                let _startpos_10 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_10) in
                let _v = _menhir_action_083 () in
                _menhir_run_329 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState328 _tok
            | Elpi_lexer_config.Tokens.CONSTANT _v ->
                let _startpos_11 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_c_, _startpos_c_, c) = (_endpos, _startpos_11, _v) in
                let _v = _menhir_action_075 c in
                _menhir_run_329 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState328 _tok
            | Elpi_lexer_config.Tokens.BEFORE ->
                let _startpos_12 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_12) in
                let _v = _menhir_action_078 () in
                _menhir_run_329 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState328 _tok
            | Elpi_lexer_config.Tokens.AFTER ->
                let _startpos_13 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_13) in
                let _v = _menhir_action_079 () in
                _menhir_run_329 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState328 _tok
            | _ ->
                _eRR 328)
        | _ ->
            _eRR 327
    
    and _menhir_run_329 : type  ttv_stack. ((ttv_stack, _menhir_box_program) _menhir_cell1_MODE _menhir_cell0_LPAREN as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_constant (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.IO _v_0 ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let io = _v_0 in
            let _v = _menhir_action_115 io in
            _menhir_run_333 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState329 _tok
        | _ ->
            _eRR 329
    
    and _menhir_run_333 : type  ttv_stack. ttv_stack -> _ -> _ -> _ -> (ttv_stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.IO _v_0 ->
            let _menhir_stack = MenhirCell1_i_o (_menhir_stack, _menhir_s, _v) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let io = _v_0 in
            let _v = _menhir_action_115 io in
            _menhir_run_333 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState333 _tok
        | Elpi_lexer_config.Tokens.RPAREN ->
            let x = _v in
            let _v = _menhir_action_211 x in
            _menhir_goto_nonempty_list_i_o_ _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | _ ->
            _eRR 333
    
    and _menhir_goto_nonempty_list_i_o_ : type  ttv_stack. ttv_stack -> _ -> _ -> _ -> (ttv_stack, _menhir_box_program) _menhir_state -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s ->
        match _menhir_s with
        | MenhirState333 ->
            _menhir_run_334 _menhir_stack _menhir_lexbuf _menhir_lexer _v
        | MenhirState329 ->
            _menhir_run_331 _menhir_stack _menhir_lexbuf _menhir_lexer _v
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_334 : type  ttv_stack. (ttv_stack, _menhir_box_program) _menhir_cell1_i_o -> _ -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let MenhirCell1_i_o (_menhir_stack, _menhir_s, x) = _menhir_stack in
        let xs = _v in
        let _v = _menhir_action_212 x xs in
        _menhir_goto_nonempty_list_i_o_ _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
    
    and _menhir_run_331 : type  ttv_stack. ((ttv_stack, _menhir_box_program) _menhir_cell1_MODE _menhir_cell0_LPAREN, _menhir_box_program) _menhir_cell1_constant -> _ -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        let MenhirCell1_constant (_menhir_stack, _, c, _, _) = _menhir_stack in
        let MenhirCell0_LPAREN (_menhir_stack, _) = _menhir_stack in
        let MenhirCell1_MODE (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
        let (l, _endpos__5_) = (_v, _endpos) in
        let _v = _menhir_action_204 _endpos__5_ _startpos__1_ c l in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.FULLSTOP ->
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let m = _v in
            let _v = _menhir_action_095 m in
            _menhir_goto_decl _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | _ ->
            _eRR 404
    
    and _menhir_run_335 : type  ttv_stack. ttv_stack -> _ -> _ -> (ttv_stack, _menhir_box_program) _menhir_state -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_MACRO (_menhir_stack, _menhir_s, _startpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v ->
            let _startpos_0 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos, _startpos_0, _v) in
            let _v = _menhir_action_068 x in
            _menhir_run_053_spec_335 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.SIGMA ->
            let _startpos_1 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_1) in
            let _v = _menhir_action_085 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState335 _tok
        | Elpi_lexer_config.Tokens.REPLACE ->
            let _startpos_2 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_2) in
            let _v = _menhir_action_080 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState335 _tok
        | Elpi_lexer_config.Tokens.QUOTED _v ->
            let _startpos_3 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos, _startpos_3, _v) in
            let _v = _menhir_action_069 _endpos_x_ _startpos_x_ x in
            _menhir_run_053_spec_335 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.PI ->
            let _startpos_4 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_4) in
            let _v = _menhir_action_084 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState335 _tok
        | Elpi_lexer_config.Tokens.NIL ->
            let _startpos_5 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_5) in
            let _v = _menhir_action_089 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState335 _tok
        | Elpi_lexer_config.Tokens.NAME ->
            let _startpos_6 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_6) in
            let _v = _menhir_action_077 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState335 _tok
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState335
        | Elpi_lexer_config.Tokens.LCURLY ->
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState335
        | Elpi_lexer_config.Tokens.LBRACKET ->
            _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState335
        | Elpi_lexer_config.Tokens.IO _v ->
            let _startpos_7 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos, _startpos_7, _v) in
            let _v = _menhir_action_082 c in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState335 _tok
        | Elpi_lexer_config.Tokens.INTEGER _v ->
            let _startpos_8 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos, _startpos_8, _v) in
            let _v = _menhir_action_066 x in
            _menhir_run_053_spec_335 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.INDEX ->
            let _startpos_9 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_9) in
            let _v = _menhir_action_081 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState335 _tok
        | Elpi_lexer_config.Tokens.IF ->
            let _startpos_10 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_10) in
            let _v = _menhir_action_076 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState335 _tok
        | Elpi_lexer_config.Tokens.FRESHUV ->
            let _startpos_11 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_11) in
            let _v = _menhir_action_086 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState335 _tok
        | Elpi_lexer_config.Tokens.FLOAT _v ->
            let _startpos_12 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos, _startpos_12, _v) in
            let _v = _menhir_action_067 x in
            _menhir_run_053_spec_335 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_TILDE _v ->
            _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState335
        | Elpi_lexer_config.Tokens.CUT ->
            let _startpos_13 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_13) in
            let _v = _menhir_action_083 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState335 _tok
        | Elpi_lexer_config.Tokens.CONSTANT _v ->
            let _startpos_14 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos, _startpos_14, _v) in
            let _v = _menhir_action_075 c in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState335 _tok
        | Elpi_lexer_config.Tokens.BEFORE ->
            let _startpos_15 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_15) in
            let _v = _menhir_action_078 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState335 _tok
        | Elpi_lexer_config.Tokens.AFTER ->
            let _startpos_16 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_16) in
            let _v = _menhir_action_079 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState335 _tok
        | _ ->
            _eRR 335
    
    and _menhir_run_053_spec_335 : type  ttv_stack. (ttv_stack, _menhir_box_program) _menhir_cell1_MACRO -> _ -> _ -> _ -> _ -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_317 t in
        _menhir_run_336 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v MenhirState335 _tok
    
    and _menhir_run_336 : type  ttv_stack. ((ttv_stack, _menhir_box_program) _menhir_cell1_MACRO as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.VDASH ->
            let _startpos_0 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_1 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell0_VDASH (_menhir_stack, _startpos_0, _endpos_1) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Elpi_lexer_config.Tokens.STRING _v_2 ->
                let _startpos_3 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_4 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_4, _startpos_3, _v_2) in
                let _v = _menhir_action_068 x in
                _menhir_run_053_spec_337 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.SIGMA ->
                let _startpos_6 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_7 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_7, _startpos_6) in
                let _v = _menhir_action_085 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState337 _tok
            | Elpi_lexer_config.Tokens.REPLACE ->
                let _startpos_9 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_10 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_10, _startpos_9) in
                let _v = _menhir_action_080 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState337 _tok
            | Elpi_lexer_config.Tokens.QUOTED _v_12 ->
                let _startpos_13 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_14 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_14, _startpos_13, _v_12) in
                let _v = _menhir_action_069 _endpos_x_ _startpos_x_ x in
                _menhir_run_053_spec_337 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.PI ->
                let _startpos_16 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_17 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_17, _startpos_16) in
                let _v = _menhir_action_084 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState337 _tok
            | Elpi_lexer_config.Tokens.NIL ->
                let _startpos_19 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_20 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_20, _startpos_19) in
                let _v = _menhir_action_089 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState337 _tok
            | Elpi_lexer_config.Tokens.NAME ->
                let _startpos_22 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_23 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_23, _startpos_22) in
                let _v = _menhir_action_077 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState337 _tok
            | Elpi_lexer_config.Tokens.LPAREN ->
                _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState337
            | Elpi_lexer_config.Tokens.LCURLY ->
                _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState337
            | Elpi_lexer_config.Tokens.LBRACKET ->
                _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState337
            | Elpi_lexer_config.Tokens.IO _v_25 ->
                let _startpos_26 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_27 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_c_, _startpos_c_, c) = (_endpos_27, _startpos_26, _v_25) in
                let _v = _menhir_action_082 c in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState337 _tok
            | Elpi_lexer_config.Tokens.INTEGER _v_29 ->
                let _startpos_30 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_31 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_31, _startpos_30, _v_29) in
                let _v = _menhir_action_066 x in
                _menhir_run_053_spec_337 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.INDEX ->
                let _startpos_33 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_34 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_34, _startpos_33) in
                let _v = _menhir_action_081 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState337 _tok
            | Elpi_lexer_config.Tokens.IF ->
                let _startpos_36 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_37 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_37, _startpos_36) in
                let _v = _menhir_action_076 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState337 _tok
            | Elpi_lexer_config.Tokens.FRESHUV ->
                let _startpos_39 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_40 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_40, _startpos_39) in
                let _v = _menhir_action_086 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState337 _tok
            | Elpi_lexer_config.Tokens.FLOAT _v_42 ->
                let _startpos_43 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_44 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_44, _startpos_43, _v_42) in
                let _v = _menhir_action_067 x in
                _menhir_run_053_spec_337 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.FAMILY_TILDE _v_46 ->
                _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer _v_46 MenhirState337
            | Elpi_lexer_config.Tokens.CUT ->
                let _startpos_47 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_48 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_48, _startpos_47) in
                let _v = _menhir_action_083 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState337 _tok
            | Elpi_lexer_config.Tokens.CONSTANT _v_50 ->
                let _startpos_51 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_52 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_c_, _startpos_c_, c) = (_endpos_52, _startpos_51, _v_50) in
                let _v = _menhir_action_075 c in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState337 _tok
            | Elpi_lexer_config.Tokens.BEFORE ->
                let _startpos_54 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_55 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_55, _startpos_54) in
                let _v = _menhir_action_078 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState337 _tok
            | Elpi_lexer_config.Tokens.AFTER ->
                let _startpos_57 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_58 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_58, _startpos_57) in
                let _v = _menhir_action_079 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState337 _tok
            | _ ->
                _eRR 337)
        | Elpi_lexer_config.Tokens.SLASH ->
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.QDASH ->
            _menhir_run_114 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.OR ->
            _menhir_run_072 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MOD ->
            _menhir_run_074 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSs ->
            _menhir_run_076 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSr ->
            _menhir_run_082 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSi ->
            _menhir_run_084 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUS ->
            _menhir_run_086 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.IS ->
            _menhir_run_088 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FAMILY_TIMES _v_60 ->
            _menhir_run_078 _menhir_stack _menhir_lexbuf _menhir_lexer _v_60
        | Elpi_lexer_config.Tokens.FAMILY_TICK _v_61 ->
            _menhir_run_090 _menhir_stack _menhir_lexbuf _menhir_lexer _v_61
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_62 ->
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer _v_62
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_63 ->
            _menhir_run_041 _menhir_stack _menhir_lexbuf _menhir_lexer _v_63
        | Elpi_lexer_config.Tokens.FAMILY_PLUS _v_64 ->
            _menhir_run_092 _menhir_stack _menhir_lexbuf _menhir_lexer _v_64
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_65 ->
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer _v_65
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_66 ->
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer _v_66
        | Elpi_lexer_config.Tokens.FAMILY_LT _v_67 ->
            _menhir_run_098 _menhir_stack _menhir_lexbuf _menhir_lexer _v_67
        | Elpi_lexer_config.Tokens.FAMILY_GT _v_68 ->
            _menhir_run_100 _menhir_stack _menhir_lexbuf _menhir_lexer _v_68
        | Elpi_lexer_config.Tokens.FAMILY_EXP _v_69 ->
            _menhir_run_094 _menhir_stack _menhir_lexbuf _menhir_lexer _v_69
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_70 ->
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer _v_70
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_71 ->
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer _v_71
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_72 ->
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer _v_72
        | Elpi_lexer_config.Tokens.EQ2 ->
            _menhir_run_102 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.EQ ->
            _menhir_run_104 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.DIV ->
            _menhir_run_080 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.DARROW ->
            _menhir_run_106 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONS ->
            _menhir_run_096 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONJ2 ->
            _menhir_run_108 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONJ ->
            _menhir_run_110 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.ARROW ->
            _menhir_run_112 _menhir_stack _menhir_lexbuf _menhir_lexer
        | _ ->
            _eRR 336
    
    and _menhir_run_053_spec_337 : type  ttv_stack. ((ttv_stack, _menhir_box_program) _menhir_cell1_MACRO, _menhir_box_program) _menhir_cell1_term _menhir_cell0_VDASH -> _ -> _ -> _ -> _ -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_317 t in
        _menhir_run_338 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v MenhirState337 _tok
    
    and _menhir_run_338 : type  ttv_stack. (((ttv_stack, _menhir_box_program) _menhir_cell1_MACRO, _menhir_box_program) _menhir_cell1_term _menhir_cell0_VDASH as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.SLASH ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.OR ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_072 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MOD ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_074 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSs ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_076 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSr ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_082 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSi ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_084 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_086 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.IS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_088 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FAMILY_TIMES _v_0 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_078 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_TICK _v_1 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_090 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_3 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_041 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_PLUS _v_4 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_092 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_5 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_6 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.FAMILY_LT _v_7 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_098 _menhir_stack _menhir_lexbuf _menhir_lexer _v_7
        | Elpi_lexer_config.Tokens.FAMILY_GT _v_8 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_100 _menhir_stack _menhir_lexbuf _menhir_lexer _v_8
        | Elpi_lexer_config.Tokens.FAMILY_EXP _v_9 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_094 _menhir_stack _menhir_lexbuf _menhir_lexer _v_9
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_10 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer _v_10
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_11 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer _v_11
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_12 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer _v_12
        | Elpi_lexer_config.Tokens.EQ2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_102 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.EQ ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_104 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.DIV ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_080 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.DARROW ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_106 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_096 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONJ2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_108 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONJ ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_110 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.ARROW ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_112 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FULLSTOP ->
            let MenhirCell0_VDASH (_menhir_stack, _, _) = _menhir_stack in
            let MenhirCell1_term (_menhir_stack, _, m, _, _) = _menhir_stack in
            let MenhirCell1_MACRO (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
            let (_endpos_b_, b) = (_endpos, _v) in
            let _v = _menhir_action_171 _endpos_b_ _startpos__1_ b m in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let m = _v in
            let _v = _menhir_action_096 m in
            _menhir_goto_decl _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | _ ->
            _eRR 338
    
    and _menhir_run_082 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell0_MINUSr (_menhir_stack, _startpos, _endpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v ->
            let _startpos_0 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_1 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_1, _startpos_0, _v) in
            let _v = _menhir_action_068 x in
            _menhir_run_053_spec_082 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.SIGMA ->
            let _startpos_2 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_3 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_3, _startpos_2) in
            let _v = _menhir_action_085 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState082 _tok
        | Elpi_lexer_config.Tokens.REPLACE ->
            let _startpos_4 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_5 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_5, _startpos_4) in
            let _v = _menhir_action_080 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState082 _tok
        | Elpi_lexer_config.Tokens.QUOTED _v ->
            let _startpos_6 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_7 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_7, _startpos_6, _v) in
            let _v = _menhir_action_069 _endpos_x_ _startpos_x_ x in
            _menhir_run_053_spec_082 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.PI ->
            let _startpos_8 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_9 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_9, _startpos_8) in
            let _v = _menhir_action_084 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState082 _tok
        | Elpi_lexer_config.Tokens.NIL ->
            let _startpos_10 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_11 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_11, _startpos_10) in
            let _v = _menhir_action_089 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState082 _tok
        | Elpi_lexer_config.Tokens.NAME ->
            let _startpos_12 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_13 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_13, _startpos_12) in
            let _v = _menhir_action_077 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState082 _tok
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState082
        | Elpi_lexer_config.Tokens.LCURLY ->
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState082
        | Elpi_lexer_config.Tokens.LBRACKET ->
            _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState082
        | Elpi_lexer_config.Tokens.IO _v ->
            let _startpos_14 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_15 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_15, _startpos_14, _v) in
            let _v = _menhir_action_082 c in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState082 _tok
        | Elpi_lexer_config.Tokens.INTEGER _v ->
            let _startpos_16 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_17 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_17, _startpos_16, _v) in
            let _v = _menhir_action_066 x in
            _menhir_run_053_spec_082 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.INDEX ->
            let _startpos_18 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_19 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_19, _startpos_18) in
            let _v = _menhir_action_081 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState082 _tok
        | Elpi_lexer_config.Tokens.IF ->
            let _startpos_20 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_21 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_21, _startpos_20) in
            let _v = _menhir_action_076 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState082 _tok
        | Elpi_lexer_config.Tokens.FRESHUV ->
            let _startpos_22 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_23 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_23, _startpos_22) in
            let _v = _menhir_action_086 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState082 _tok
        | Elpi_lexer_config.Tokens.FLOAT _v ->
            let _startpos_24 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_25 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_25, _startpos_24, _v) in
            let _v = _menhir_action_067 x in
            _menhir_run_053_spec_082 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_TILDE _v ->
            _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState082
        | Elpi_lexer_config.Tokens.CUT ->
            let _startpos_26 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_27 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_27, _startpos_26) in
            let _v = _menhir_action_083 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState082 _tok
        | Elpi_lexer_config.Tokens.CONSTANT _v ->
            let _startpos_28 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_29 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_29, _startpos_28, _v) in
            let _v = _menhir_action_075 c in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState082 _tok
        | Elpi_lexer_config.Tokens.BEFORE ->
            let _startpos_30 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_31 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_31, _startpos_30) in
            let _v = _menhir_action_078 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState082 _tok
        | Elpi_lexer_config.Tokens.AFTER ->
            let _startpos_32 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_33 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_33, _startpos_32) in
            let _v = _menhir_action_079 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState082 _tok
        | _ ->
            _eRR 82
    
    and _menhir_run_053_spec_082 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term _menhir_cell0_MINUSr -> _ -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_317 t in
        _menhir_run_083 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v MenhirState082 _tok
    
    and _menhir_run_083 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_term _menhir_cell0_MINUSr as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.SLASH ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MOD ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_074 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FAMILY_TIMES _v_0 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_078 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_1 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_041 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_3 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_4 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_5 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_6 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_7 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer _v_7
        | Elpi_lexer_config.Tokens.DIV ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_080 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.AS | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.CONS | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.EOF | Elpi_lexer_config.Tokens.EQ | Elpi_lexer_config.Tokens.EQ2 | Elpi_lexer_config.Tokens.FAMILY_EXP _ | Elpi_lexer_config.Tokens.FAMILY_GT _ | Elpi_lexer_config.Tokens.FAMILY_LT _ | Elpi_lexer_config.Tokens.FAMILY_PLUS _ | Elpi_lexer_config.Tokens.FAMILY_TICK _ | Elpi_lexer_config.Tokens.FULLSTOP | Elpi_lexer_config.Tokens.IFF | Elpi_lexer_config.Tokens.IS | Elpi_lexer_config.Tokens.MINUS | Elpi_lexer_config.Tokens.MINUSi | Elpi_lexer_config.Tokens.MINUSr | Elpi_lexer_config.Tokens.MINUSs | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.PIPE | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.RBRACKET | Elpi_lexer_config.Tokens.RCURLY | Elpi_lexer_config.Tokens.RPAREN | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_MINUSr (_menhir_stack, _, _) = _menhir_stack in
            let MenhirCell1_term (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_233 _endpos_r_ _startpos_l_ l r in
            _menhir_goto_open_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 83
    
    and _menhir_run_070 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell0_FAMILY_BTICK (_menhir_stack, _v, _startpos, _endpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v_0 ->
            let _startpos_1 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_2 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_2, _startpos_1, _v_0) in
            let _v = _menhir_action_068 x in
            _menhir_run_053_spec_070 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.SIGMA ->
            let _startpos_4 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_5 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_5, _startpos_4) in
            let _v = _menhir_action_085 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState070 _tok
        | Elpi_lexer_config.Tokens.REPLACE ->
            let _startpos_7 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_8 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_8, _startpos_7) in
            let _v = _menhir_action_080 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState070 _tok
        | Elpi_lexer_config.Tokens.QUOTED _v_10 ->
            let _startpos_11 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_12 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_12, _startpos_11, _v_10) in
            let _v = _menhir_action_069 _endpos_x_ _startpos_x_ x in
            _menhir_run_053_spec_070 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.PI ->
            let _startpos_14 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_15 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_15, _startpos_14) in
            let _v = _menhir_action_084 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState070 _tok
        | Elpi_lexer_config.Tokens.NIL ->
            let _startpos_17 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_18 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_18, _startpos_17) in
            let _v = _menhir_action_089 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState070 _tok
        | Elpi_lexer_config.Tokens.NAME ->
            let _startpos_20 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_21 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_21, _startpos_20) in
            let _v = _menhir_action_077 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState070 _tok
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState070
        | Elpi_lexer_config.Tokens.LCURLY ->
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState070
        | Elpi_lexer_config.Tokens.LBRACKET ->
            _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState070
        | Elpi_lexer_config.Tokens.IO _v_23 ->
            let _startpos_24 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_25 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_25, _startpos_24, _v_23) in
            let _v = _menhir_action_082 c in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState070 _tok
        | Elpi_lexer_config.Tokens.INTEGER _v_27 ->
            let _startpos_28 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_29 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_29, _startpos_28, _v_27) in
            let _v = _menhir_action_066 x in
            _menhir_run_053_spec_070 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.INDEX ->
            let _startpos_31 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_32 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_32, _startpos_31) in
            let _v = _menhir_action_081 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState070 _tok
        | Elpi_lexer_config.Tokens.IF ->
            let _startpos_34 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_35 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_35, _startpos_34) in
            let _v = _menhir_action_076 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState070 _tok
        | Elpi_lexer_config.Tokens.FRESHUV ->
            let _startpos_37 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_38 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_38, _startpos_37) in
            let _v = _menhir_action_086 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState070 _tok
        | Elpi_lexer_config.Tokens.FLOAT _v_40 ->
            let _startpos_41 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_42 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_42, _startpos_41, _v_40) in
            let _v = _menhir_action_067 x in
            _menhir_run_053_spec_070 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_TILDE _v_44 ->
            _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer _v_44 MenhirState070
        | Elpi_lexer_config.Tokens.CUT ->
            let _startpos_45 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_46 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_46, _startpos_45) in
            let _v = _menhir_action_083 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState070 _tok
        | Elpi_lexer_config.Tokens.CONSTANT _v_48 ->
            let _startpos_49 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_50 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_50, _startpos_49, _v_48) in
            let _v = _menhir_action_075 c in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState070 _tok
        | Elpi_lexer_config.Tokens.BEFORE ->
            let _startpos_52 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_53 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_53, _startpos_52) in
            let _v = _menhir_action_078 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState070 _tok
        | Elpi_lexer_config.Tokens.AFTER ->
            let _startpos_55 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_56 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_56, _startpos_55) in
            let _v = _menhir_action_079 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState070 _tok
        | _ ->
            _eRR 70
    
    and _menhir_run_053_spec_070 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term _menhir_cell0_FAMILY_BTICK -> _ -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_317 t in
        _menhir_run_071 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v MenhirState070 _tok
    
    and _menhir_run_071 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_term _menhir_cell0_FAMILY_BTICK as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_0 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_1 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_041 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_3 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_4 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.AS | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.CONS | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.DIV | Elpi_lexer_config.Tokens.EOF | Elpi_lexer_config.Tokens.EQ | Elpi_lexer_config.Tokens.EQ2 | Elpi_lexer_config.Tokens.FAMILY_EXP _ | Elpi_lexer_config.Tokens.FAMILY_GT _ | Elpi_lexer_config.Tokens.FAMILY_LT _ | Elpi_lexer_config.Tokens.FAMILY_MINUS _ | Elpi_lexer_config.Tokens.FAMILY_PLUS _ | Elpi_lexer_config.Tokens.FAMILY_TICK _ | Elpi_lexer_config.Tokens.FAMILY_TIMES _ | Elpi_lexer_config.Tokens.FULLSTOP | Elpi_lexer_config.Tokens.IFF | Elpi_lexer_config.Tokens.IS | Elpi_lexer_config.Tokens.MINUS | Elpi_lexer_config.Tokens.MINUSi | Elpi_lexer_config.Tokens.MINUSr | Elpi_lexer_config.Tokens.MINUSs | Elpi_lexer_config.Tokens.MOD | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.PIPE | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.RBRACKET | Elpi_lexer_config.Tokens.RCURLY | Elpi_lexer_config.Tokens.RPAREN | Elpi_lexer_config.Tokens.SLASH | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_FAMILY_BTICK (_menhir_stack, s, _, _) = _menhir_stack in
            let MenhirCell1_term (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_228 _endpos_r_ _startpos_l_ l r s in
            _menhir_goto_open_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 71
    
    and _menhir_run_018 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell1_LCURLY (_menhir_stack, _menhir_s, _startpos, _endpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v ->
            let _startpos_0 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_1 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_1, _startpos_0, _v) in
            let _v = _menhir_action_068 x in
            _menhir_run_053_spec_018 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.SIGMA ->
            let _startpos_2 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_3 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_3, _startpos_2) in
            let _v = _menhir_action_085 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState018 _tok
        | Elpi_lexer_config.Tokens.REPLACE ->
            let _startpos_4 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_5 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_5, _startpos_4) in
            let _v = _menhir_action_080 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState018 _tok
        | Elpi_lexer_config.Tokens.QUOTED _v ->
            let _startpos_6 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_7 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_7, _startpos_6, _v) in
            let _v = _menhir_action_069 _endpos_x_ _startpos_x_ x in
            _menhir_run_053_spec_018 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.PI ->
            let _startpos_8 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_9 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_9, _startpos_8) in
            let _v = _menhir_action_084 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState018 _tok
        | Elpi_lexer_config.Tokens.NIL ->
            let _startpos_10 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_11 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_11, _startpos_10) in
            let _v = _menhir_action_089 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState018 _tok
        | Elpi_lexer_config.Tokens.NAME ->
            let _startpos_12 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_13 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_13, _startpos_12) in
            let _v = _menhir_action_077 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState018 _tok
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState018
        | Elpi_lexer_config.Tokens.LCURLY ->
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState018
        | Elpi_lexer_config.Tokens.LBRACKET ->
            _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState018
        | Elpi_lexer_config.Tokens.IO _v ->
            let _startpos_14 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_15 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_15, _startpos_14, _v) in
            let _v = _menhir_action_082 c in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState018 _tok
        | Elpi_lexer_config.Tokens.INTEGER _v ->
            let _startpos_16 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_17 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_17, _startpos_16, _v) in
            let _v = _menhir_action_066 x in
            _menhir_run_053_spec_018 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.INDEX ->
            let _startpos_18 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_19 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_19, _startpos_18) in
            let _v = _menhir_action_081 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState018 _tok
        | Elpi_lexer_config.Tokens.IF ->
            let _startpos_20 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_21 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_21, _startpos_20) in
            let _v = _menhir_action_076 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState018 _tok
        | Elpi_lexer_config.Tokens.FRESHUV ->
            let _startpos_22 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_23 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_23, _startpos_22) in
            let _v = _menhir_action_086 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState018 _tok
        | Elpi_lexer_config.Tokens.FLOAT _v ->
            let _startpos_24 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_25 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_25, _startpos_24, _v) in
            let _v = _menhir_action_067 x in
            _menhir_run_053_spec_018 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_TILDE _v ->
            _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState018
        | Elpi_lexer_config.Tokens.CUT ->
            let _startpos_26 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_27 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_27, _startpos_26) in
            let _v = _menhir_action_083 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState018 _tok
        | Elpi_lexer_config.Tokens.CONSTANT _v ->
            let _startpos_28 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_29 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_29, _startpos_28, _v) in
            let _v = _menhir_action_075 c in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState018 _tok
        | Elpi_lexer_config.Tokens.BEFORE ->
            let _startpos_30 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_31 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_31, _startpos_30) in
            let _v = _menhir_action_078 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState018 _tok
        | Elpi_lexer_config.Tokens.AFTER ->
            let _startpos_32 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_33 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_33, _startpos_32) in
            let _v = _menhir_action_079 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState018 _tok
        | _ ->
            _eRR 18
    
    and _menhir_run_053_spec_018 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_LCURLY -> _ -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_317 t in
        _menhir_run_192 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v MenhirState018 _tok
    
    and _menhir_run_192 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_LCURLY as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.VDASH ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_056 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.SLASH ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.RCURLY ->
            let _endpos_1 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let MenhirCell1_LCURLY (_menhir_stack, _menhir_s, _startpos__1_, _) = _menhir_stack in
            let (_endpos__3_, t) = (_endpos_1, _v) in
            let _v = _menhir_action_073 t in
            _menhir_goto_closed_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__3_ _startpos__1_ _v _menhir_s _tok
        | Elpi_lexer_config.Tokens.QDASH ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_114 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.OR ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_072 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MOD ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_074 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSs ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_076 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSr ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_082 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSi ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_084 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_086 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.IS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_088 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FAMILY_TIMES _v_2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_078 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_TICK _v_3 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_090 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_4 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_5 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_041 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_PLUS _v_6 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_092 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_7 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer _v_7
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_8 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer _v_8
        | Elpi_lexer_config.Tokens.FAMILY_LT _v_9 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_098 _menhir_stack _menhir_lexbuf _menhir_lexer _v_9
        | Elpi_lexer_config.Tokens.FAMILY_GT _v_10 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_100 _menhir_stack _menhir_lexbuf _menhir_lexer _v_10
        | Elpi_lexer_config.Tokens.FAMILY_EXP _v_11 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_094 _menhir_stack _menhir_lexbuf _menhir_lexer _v_11
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_12 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer _v_12
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_13 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer _v_13
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_14 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer _v_14
        | Elpi_lexer_config.Tokens.EQ2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_102 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.EQ ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_104 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.DIV ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_080 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.DARROW ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_106 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_096 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONJ2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_108 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONJ ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_110 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.ARROW ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_112 _menhir_stack _menhir_lexbuf _menhir_lexer
        | _ ->
            _eRR 192
    
    and _menhir_goto_closed_term : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match _menhir_s with
        | MenhirState424 ->
            _menhir_run_432_spec_424 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState442 ->
            _menhir_run_432_spec_442 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState434 ->
            _menhir_run_432_spec_434 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState435 ->
            _menhir_run_432_spec_435 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState430 ->
            _menhir_run_432_spec_430 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState019 ->
            _menhir_run_120_spec_019 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState187 ->
            _menhir_run_120_spec_187 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState184 ->
            _menhir_run_120_spec_184 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState021 ->
            _menhir_run_120_spec_021 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState180 ->
            _menhir_run_120_spec_180 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState123 ->
            _menhir_run_120_spec_123 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState139 ->
            _menhir_run_120_spec_139 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState175 ->
            _menhir_run_120_spec_175 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState177 ->
            _menhir_run_120_spec_177 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState173 ->
            _menhir_run_120_spec_173 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState171 ->
            _menhir_run_120_spec_171 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState169 ->
            _menhir_run_120_spec_169 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState167 ->
            _menhir_run_120_spec_167 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState165 ->
            _menhir_run_120_spec_165 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState155 ->
            _menhir_run_120_spec_155 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState163 ->
            _menhir_run_120_spec_163 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState157 ->
            _menhir_run_120_spec_157 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState161 ->
            _menhir_run_120_spec_161 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState159 ->
            _menhir_run_120_spec_159 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState153 ->
            _menhir_run_120_spec_153 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState151 ->
            _menhir_run_120_spec_151 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState149 ->
            _menhir_run_120_spec_149 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState143 ->
            _menhir_run_120_spec_143 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState147 ->
            _menhir_run_120_spec_147 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState145 ->
            _menhir_run_120_spec_145 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState141 ->
            _menhir_run_120_spec_141 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState125 ->
            _menhir_run_120_spec_125 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState133 ->
            _menhir_run_120_spec_133 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState137 ->
            _menhir_run_120_spec_137 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState135 ->
            _menhir_run_120_spec_135 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState129 ->
            _menhir_run_120_spec_129 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState131 ->
            _menhir_run_120_spec_131 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState127 ->
            _menhir_run_120_spec_127 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState028 ->
            _menhir_run_120_spec_028 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState524 ->
            _menhir_run_053_spec_524 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState522 ->
            _menhir_run_053_spec_522 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState520 ->
            _menhir_run_053_spec_520 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState518 ->
            _menhir_run_053_spec_518 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState516 ->
            _menhir_run_053_spec_516 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState514 ->
            _menhir_run_053_spec_514 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState512 ->
            _menhir_run_053_spec_512 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState510 ->
            _menhir_run_053_spec_510 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState508 ->
            _menhir_run_053_spec_508 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState506 ->
            _menhir_run_053_spec_506 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState504 ->
            _menhir_run_053_spec_504 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState502 ->
            _menhir_run_053_spec_502 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState500 ->
            _menhir_run_053_spec_500 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState498 ->
            _menhir_run_053_spec_498 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState496 ->
            _menhir_run_053_spec_496 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState494 ->
            _menhir_run_053_spec_494 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState492 ->
            _menhir_run_053_spec_492 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState489 ->
            _menhir_run_053_spec_489 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState487 ->
            _menhir_run_053_spec_487 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState485 ->
            _menhir_run_053_spec_485 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState483 ->
            _menhir_run_053_spec_483 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState481 ->
            _menhir_run_053_spec_481 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState479 ->
            _menhir_run_053_spec_479 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState477 ->
            _menhir_run_053_spec_477 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState475 ->
            _menhir_run_053_spec_475 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState473 ->
            _menhir_run_053_spec_473 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState471 ->
            _menhir_run_053_spec_471 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState469 ->
            _menhir_run_053_spec_469 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState467 ->
            _menhir_run_053_spec_467 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState465 ->
            _menhir_run_053_spec_465 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState458 ->
            _menhir_run_053_spec_458 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState455 ->
            _menhir_run_053_spec_455 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState439 ->
            _menhir_run_053_spec_439 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState425 ->
            _menhir_run_053_spec_425 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState427 ->
            _menhir_run_053_spec_427 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState335 ->
            _menhir_run_053_spec_335 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState337 ->
            _menhir_run_053_spec_337 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState000 ->
            _menhir_run_053_spec_000 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState008 ->
            _menhir_run_053_spec_008 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState221 ->
            _menhir_run_053_spec_221 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState196 ->
            _menhir_run_053_spec_196 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState018 ->
            _menhir_run_053_spec_018 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState118 ->
            _menhir_run_053_spec_118 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState038 ->
            _menhir_run_053_spec_038 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState114 ->
            _menhir_run_053_spec_114 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState056 ->
            _menhir_run_053_spec_056 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState072 ->
            _menhir_run_053_spec_072 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState108 ->
            _menhir_run_053_spec_108 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState110 ->
            _menhir_run_053_spec_110 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState112 ->
            _menhir_run_053_spec_112 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState106 ->
            _menhir_run_053_spec_106 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState104 ->
            _menhir_run_053_spec_104 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState102 ->
            _menhir_run_053_spec_102 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState100 ->
            _menhir_run_053_spec_100 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState098 ->
            _menhir_run_053_spec_098 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState088 ->
            _menhir_run_053_spec_088 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState096 ->
            _menhir_run_053_spec_096 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState090 ->
            _menhir_run_053_spec_090 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState094 ->
            _menhir_run_053_spec_094 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState092 ->
            _menhir_run_053_spec_092 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState086 ->
            _menhir_run_053_spec_086 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState084 ->
            _menhir_run_053_spec_084 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState082 ->
            _menhir_run_053_spec_082 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState076 ->
            _menhir_run_053_spec_076 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState080 ->
            _menhir_run_053_spec_080 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState078 ->
            _menhir_run_053_spec_078 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState074 ->
            _menhir_run_053_spec_074 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState058 ->
            _menhir_run_053_spec_058 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState066 ->
            _menhir_run_053_spec_066 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState070 ->
            _menhir_run_053_spec_070 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState068 ->
            _menhir_run_053_spec_068 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState062 ->
            _menhir_run_053_spec_062 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState064 ->
            _menhir_run_053_spec_064 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState060 ->
            _menhir_run_053_spec_060 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState039 ->
            _menhir_run_053_spec_039 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState460 ->
            _menhir_run_049 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState036 ->
            _menhir_run_049 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState049 ->
            _menhir_run_049 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState043 ->
            _menhir_run_049 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_432_spec_424 : type  ttv_stack. ((ttv_stack, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_RULE -> _ -> _ -> _ -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let (_endpos_t_, t) = (_endpos, _v) in
        let _v = _menhir_action_310 t in
        _menhir_run_430 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _v MenhirState424 _tok
    
    and _menhir_run_430 : type  ttv_stack. ttv_stack -> _ -> _ -> _ -> _ -> (ttv_stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_sequent (_menhir_stack, _menhir_s, _v, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v_0 ->
            let _endpos_1 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, x) = (_endpos_1, _v_0) in
            let _v = _menhir_action_068 x in
            _menhir_run_432_spec_430 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.SIGMA ->
            let _endpos_3 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _endpos__1_ = _endpos_3 in
            let _v = _menhir_action_085 () in
            _menhir_run_048_spec_430 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _v _tok
        | Elpi_lexer_config.Tokens.REPLACE ->
            let _endpos_5 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _endpos__1_ = _endpos_5 in
            let _v = _menhir_action_080 () in
            _menhir_run_048_spec_430 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _v _tok
        | Elpi_lexer_config.Tokens.QUOTED _v_7 ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_8 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_8, _startpos, _v_7) in
            let _v = _menhir_action_069 _endpos_x_ _startpos_x_ x in
            _menhir_run_432_spec_430 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.PI ->
            let _endpos_10 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _endpos__1_ = _endpos_10 in
            let _v = _menhir_action_084 () in
            _menhir_run_048_spec_430 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _v _tok
        | Elpi_lexer_config.Tokens.NIL ->
            let _endpos_12 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _endpos__1_ = _endpos_12 in
            let _v = _menhir_action_089 () in
            _menhir_run_048_spec_430 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _v _tok
        | Elpi_lexer_config.Tokens.NAME ->
            let _endpos_14 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _endpos__1_ = _endpos_14 in
            let _v = _menhir_action_077 () in
            _menhir_run_048_spec_430 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _v _tok
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_425 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState430
        | Elpi_lexer_config.Tokens.LCURLY ->
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState430
        | Elpi_lexer_config.Tokens.LBRACKET ->
            _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState430
        | Elpi_lexer_config.Tokens.IO _v_16 ->
            let _endpos_17 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, c) = (_endpos_17, _v_16) in
            let _v = _menhir_action_082 c in
            _menhir_run_048_spec_430 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _v _tok
        | Elpi_lexer_config.Tokens.INTEGER _v_19 ->
            let _endpos_20 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, x) = (_endpos_20, _v_19) in
            let _v = _menhir_action_066 x in
            _menhir_run_432_spec_430 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.INDEX ->
            let _endpos_22 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _endpos__1_ = _endpos_22 in
            let _v = _menhir_action_081 () in
            _menhir_run_048_spec_430 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _v _tok
        | Elpi_lexer_config.Tokens.IF ->
            let _endpos_24 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _endpos__1_ = _endpos_24 in
            let _v = _menhir_action_076 () in
            _menhir_run_048_spec_430 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _v _tok
        | Elpi_lexer_config.Tokens.FRESHUV ->
            let _endpos_26 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _endpos__1_ = _endpos_26 in
            let _v = _menhir_action_086 () in
            _menhir_run_048_spec_430 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _v _tok
        | Elpi_lexer_config.Tokens.FLOAT _v_28 ->
            let _endpos_29 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, x) = (_endpos_29, _v_28) in
            let _v = _menhir_action_067 x in
            _menhir_run_432_spec_430 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.CUT ->
            let _endpos_31 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _endpos__1_ = _endpos_31 in
            let _v = _menhir_action_083 () in
            _menhir_run_048_spec_430 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _v _tok
        | Elpi_lexer_config.Tokens.CONSTANT _v_33 ->
            let _endpos_34 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, c) = (_endpos_34, _v_33) in
            let _v = _menhir_action_075 c in
            _menhir_run_048_spec_430 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _v _tok
        | Elpi_lexer_config.Tokens.BEFORE ->
            let _endpos_36 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _endpos__1_ = _endpos_36 in
            let _v = _menhir_action_078 () in
            _menhir_run_048_spec_430 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _v _tok
        | Elpi_lexer_config.Tokens.AFTER ->
            let _endpos_38 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _endpos__1_ = _endpos_38 in
            let _v = _menhir_action_079 () in
            _menhir_run_048_spec_430 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _v _tok
        | Elpi_lexer_config.Tokens.BIND | Elpi_lexer_config.Tokens.FULLSTOP | Elpi_lexer_config.Tokens.IFF | Elpi_lexer_config.Tokens.PIPE ->
            let _v = _menhir_action_161 () in
            _menhir_run_431 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | _ ->
            _eRR 430
    
    and _menhir_run_432_spec_430 : type  ttv_stack. (ttv_stack, _menhir_box_program) _menhir_cell1_sequent -> _ -> _ -> _ -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let (_endpos_t_, t) = (_endpos, _v) in
        let _v = _menhir_action_310 t in
        _menhir_run_430 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _v MenhirState430 _tok
    
    and _menhir_run_048_spec_430 : type  ttv_stack. (ttv_stack, _menhir_box_program) _menhir_cell1_sequent -> _ -> _ -> _ -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let (_endpos_t_, t) = (_endpos, _v) in
        let _v = _menhir_action_113 t in
        _menhir_run_047_spec_430 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _v _tok
    
    and _menhir_run_047_spec_430 : type  ttv_stack. (ttv_stack, _menhir_box_program) _menhir_cell1_sequent -> _ -> _ -> _ -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let (_endpos_t_, t) = (_endpos, _v) in
        let _v = _menhir_action_074 t in
        _menhir_run_432_spec_430 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _v _tok
    
    and _menhir_run_425 : type  ttv_stack. ttv_stack -> _ -> _ -> (ttv_stack, _menhir_box_program) _menhir_state -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_LPAREN (_menhir_stack, _menhir_s, _startpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.VDASH ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_201 () in
            _menhir_run_224 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.STRING _v ->
            let _startpos_1 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos, _startpos_1, _v) in
            let _v = _menhir_action_068 x in
            _menhir_run_053_spec_425 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.SLASH ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_198 () in
            _menhir_run_224 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.SIGMA ->
            let _startpos_3 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_3) in
            let _v = _menhir_action_085 () in
            _menhir_run_426 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState425 _tok
        | Elpi_lexer_config.Tokens.REPLACE ->
            let _startpos_4 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_4) in
            let _v = _menhir_action_080 () in
            _menhir_run_426 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState425 _tok
        | Elpi_lexer_config.Tokens.QUOTED _v ->
            let _startpos_5 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos, _startpos_5, _v) in
            let _v = _menhir_action_069 _endpos_x_ _startpos_x_ x in
            _menhir_run_053_spec_425 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.QDASH ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_197 () in
            _menhir_run_224 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.PI ->
            let _startpos_7 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_7) in
            let _v = _menhir_action_084 () in
            _menhir_run_426 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState425 _tok
        | Elpi_lexer_config.Tokens.OR ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_191 () in
            _menhir_run_224 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.NIL ->
            let _startpos_9 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_9) in
            let _v = _menhir_action_089 () in
            _menhir_run_426 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState425 _tok
        | Elpi_lexer_config.Tokens.NAME ->
            let _startpos_10 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_10) in
            let _v = _menhir_action_077 () in
            _menhir_run_426 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState425 _tok
        | Elpi_lexer_config.Tokens.MOD ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_193 () in
            _menhir_run_224 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.MINUSs ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_189 () in
            _menhir_run_224 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.MINUSr ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_187 () in
            _menhir_run_224 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.MINUSi ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_188 () in
            _menhir_run_224 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.MINUS ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_186 () in
            _menhir_run_224 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState425
        | Elpi_lexer_config.Tokens.LCURLY ->
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState425
        | Elpi_lexer_config.Tokens.LBRACKET ->
            _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState425
        | Elpi_lexer_config.Tokens.IS ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_192 () in
            _menhir_run_224 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.IO _v ->
            let _startpos_17 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos, _startpos_17, _v) in
            let _v = _menhir_action_082 c in
            _menhir_run_426 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState425 _tok
        | Elpi_lexer_config.Tokens.INTEGER _v ->
            let _startpos_18 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos, _startpos_18, _v) in
            let _v = _menhir_action_066 x in
            _menhir_run_053_spec_425 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.INDEX ->
            let _startpos_19 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_19) in
            let _v = _menhir_action_081 () in
            _menhir_run_426 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState425 _tok
        | Elpi_lexer_config.Tokens.IF ->
            let _startpos_20 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_20) in
            let _v = _menhir_action_076 () in
            _menhir_run_426 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState425 _tok
        | Elpi_lexer_config.Tokens.FRESHUV ->
            let _startpos_21 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_21) in
            let _v = _menhir_action_086 () in
            _menhir_run_426 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState425 _tok
        | Elpi_lexer_config.Tokens.FLOAT _v ->
            let _startpos_22 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos, _startpos_22, _v) in
            let _v = _menhir_action_067 x in
            _menhir_run_053_spec_425 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_TIMES _v ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let s = _v in
            let _v = _menhir_action_173 s in
            _menhir_run_224 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_TILDE _v ->
            _menhir_run_196 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState425
        | Elpi_lexer_config.Tokens.FAMILY_TICK _v ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let s = _v in
            let _v = _menhir_action_183 s in
            _menhir_run_224 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let s = _v in
            let _v = _menhir_action_181 s in
            _menhir_run_224 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let s = _v in
            let _v = _menhir_action_203 s in
            _menhir_run_224 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_PLUS _v ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let s = _v in
            let _v = _menhir_action_172 s in
            _menhir_run_224 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_OR _v ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let s = _v in
            let _v = _menhir_action_180 s in
            _menhir_run_224 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let s = _v in
            let _v = _menhir_action_174 s in
            _menhir_run_224 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_LT _v ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let s = _v in
            let _v = _menhir_action_176 s in
            _menhir_run_224 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_GT _v ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let s = _v in
            let _v = _menhir_action_177 s in
            _menhir_run_224 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_EXP _v ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let s = _v in
            let _v = _menhir_action_175 s in
            _menhir_run_224 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let s = _v in
            let _v = _menhir_action_178 s in
            _menhir_run_224 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let s = _v in
            let _v = _menhir_action_182 s in
            _menhir_run_224 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_AND _v ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let s = _v in
            let _v = _menhir_action_179 s in
            _menhir_run_224 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.EQ2 ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_190 () in
            _menhir_run_224 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.EQ ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_185 () in
            _menhir_run_224 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.DIV ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_194 () in
            _menhir_run_224 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.DARROW ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_196 () in
            _menhir_run_224 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.CUT ->
            let _startpos_40 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_40) in
            let _v = _menhir_action_083 () in
            _menhir_run_426 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState425 _tok
        | Elpi_lexer_config.Tokens.CONSTANT _v ->
            let _startpos_41 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos, _startpos_41, _v) in
            let _v = _menhir_action_075 c in
            _menhir_run_426 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState425 _tok
        | Elpi_lexer_config.Tokens.CONS ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_184 () in
            _menhir_run_224 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.CONJ2 ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_199 () in
            _menhir_run_224 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.CONJ ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_200 () in
            _menhir_run_224 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.BEFORE ->
            let _startpos_45 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_45) in
            let _v = _menhir_action_078 () in
            _menhir_run_426 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState425 _tok
        | Elpi_lexer_config.Tokens.AS ->
            _menhir_run_216 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.ARROW ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_195 () in
            _menhir_run_224 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | Elpi_lexer_config.Tokens.AFTER ->
            let _startpos_47 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_47) in
            let _v = _menhir_action_079 () in
            _menhir_run_426 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState425 _tok
        | _ ->
            _eRR 425
    
    and _menhir_run_053_spec_425 : type  ttv_stack. (ttv_stack, _menhir_box_program) _menhir_cell1_LPAREN -> _ -> _ -> _ -> _ -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_317 t in
        _menhir_run_219 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v MenhirState425 _tok
    
    and _menhir_run_219 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_LPAREN as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.VDASH ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_056 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.SLASH ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.RPAREN ->
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let MenhirCell1_LPAREN (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
            let (_endpos__3_, t) = (_endpos_0, _v) in
            let _v = _menhir_action_114 t in
            _menhir_goto_head_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__3_ _startpos__1_ _v _menhir_s _tok
        | Elpi_lexer_config.Tokens.QDASH ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_114 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.OR ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_072 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MOD ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_074 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSs ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_076 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSr ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_082 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSi ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_084 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_086 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.IS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_088 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FAMILY_TIMES _v_1 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_078 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_TICK _v_2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_090 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_3 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_4 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_041 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_PLUS _v_5 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_092 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_6 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_7 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer _v_7
        | Elpi_lexer_config.Tokens.FAMILY_LT _v_8 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_098 _menhir_stack _menhir_lexbuf _menhir_lexer _v_8
        | Elpi_lexer_config.Tokens.FAMILY_GT _v_9 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_100 _menhir_stack _menhir_lexbuf _menhir_lexer _v_9
        | Elpi_lexer_config.Tokens.FAMILY_EXP _v_10 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_094 _menhir_stack _menhir_lexbuf _menhir_lexer _v_10
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_11 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer _v_11
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_12 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer _v_12
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_13 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer _v_13
        | Elpi_lexer_config.Tokens.EQ2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_102 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.EQ ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_104 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.DIV ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_080 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.DARROW ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_106 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_096 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONJ2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_108 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONJ ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_110 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.AS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Elpi_lexer_config.Tokens.STRING _v_14 ->
                let _startpos_15 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_16 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_16, _startpos_15, _v_14) in
                let _v = _menhir_action_068 x in
                _menhir_run_053_spec_221 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.SIGMA ->
                let _startpos_18 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_19 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_19, _startpos_18) in
                let _v = _menhir_action_085 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState221 _tok
            | Elpi_lexer_config.Tokens.REPLACE ->
                let _startpos_21 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_22 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_22, _startpos_21) in
                let _v = _menhir_action_080 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState221 _tok
            | Elpi_lexer_config.Tokens.QUOTED _v_24 ->
                let _startpos_25 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_26 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_26, _startpos_25, _v_24) in
                let _v = _menhir_action_069 _endpos_x_ _startpos_x_ x in
                _menhir_run_053_spec_221 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.PI ->
                let _startpos_28 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_29 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_29, _startpos_28) in
                let _v = _menhir_action_084 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState221 _tok
            | Elpi_lexer_config.Tokens.NIL ->
                let _startpos_31 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_32 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_32, _startpos_31) in
                let _v = _menhir_action_089 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState221 _tok
            | Elpi_lexer_config.Tokens.NAME ->
                let _startpos_34 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_35 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_35, _startpos_34) in
                let _v = _menhir_action_077 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState221 _tok
            | Elpi_lexer_config.Tokens.LPAREN ->
                _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState221
            | Elpi_lexer_config.Tokens.LCURLY ->
                _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState221
            | Elpi_lexer_config.Tokens.LBRACKET ->
                _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState221
            | Elpi_lexer_config.Tokens.IO _v_37 ->
                let _startpos_38 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_39 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_c_, _startpos_c_, c) = (_endpos_39, _startpos_38, _v_37) in
                let _v = _menhir_action_082 c in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState221 _tok
            | Elpi_lexer_config.Tokens.INTEGER _v_41 ->
                let _startpos_42 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_43 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_43, _startpos_42, _v_41) in
                let _v = _menhir_action_066 x in
                _menhir_run_053_spec_221 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.INDEX ->
                let _startpos_45 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_46 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_46, _startpos_45) in
                let _v = _menhir_action_081 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState221 _tok
            | Elpi_lexer_config.Tokens.IF ->
                let _startpos_48 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_49 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_49, _startpos_48) in
                let _v = _menhir_action_076 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState221 _tok
            | Elpi_lexer_config.Tokens.FRESHUV ->
                let _startpos_51 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_52 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_52, _startpos_51) in
                let _v = _menhir_action_086 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState221 _tok
            | Elpi_lexer_config.Tokens.FLOAT _v_54 ->
                let _startpos_55 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_56 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_56, _startpos_55, _v_54) in
                let _v = _menhir_action_067 x in
                _menhir_run_053_spec_221 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.FAMILY_TILDE _v_58 ->
                _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer _v_58 MenhirState221
            | Elpi_lexer_config.Tokens.CUT ->
                let _startpos_59 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_60 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_60, _startpos_59) in
                let _v = _menhir_action_083 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState221 _tok
            | Elpi_lexer_config.Tokens.CONSTANT _v_62 ->
                let _startpos_63 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_64 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_c_, _startpos_c_, c) = (_endpos_64, _startpos_63, _v_62) in
                let _v = _menhir_action_075 c in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState221 _tok
            | Elpi_lexer_config.Tokens.BEFORE ->
                let _startpos_66 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_67 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_67, _startpos_66) in
                let _v = _menhir_action_078 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState221 _tok
            | Elpi_lexer_config.Tokens.AFTER ->
                let _startpos_69 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_70 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_70, _startpos_69) in
                let _v = _menhir_action_079 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState221 _tok
            | _ ->
                _eRR 221)
        | Elpi_lexer_config.Tokens.ARROW ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_112 _menhir_stack _menhir_lexbuf _menhir_lexer
        | _ ->
            _eRR 219
    
    and _menhir_goto_head_term : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match _menhir_s with
        | MenhirState420 ->
            _menhir_run_460 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState460 ->
            _menhir_run_047_spec_460 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState424 ->
            _menhir_run_047_spec_424 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState442 ->
            _menhir_run_047_spec_442 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState434 ->
            _menhir_run_047_spec_434 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState435 ->
            _menhir_run_047_spec_435 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState430 ->
            _menhir_run_047_spec_430 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState036 ->
            _menhir_run_047_spec_036 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState049 ->
            _menhir_run_047_spec_049 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState043 ->
            _menhir_run_047_spec_043 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState524 ->
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState522 ->
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState520 ->
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState518 ->
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState516 ->
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState514 ->
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState512 ->
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState510 ->
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState508 ->
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState506 ->
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState504 ->
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState502 ->
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState500 ->
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState498 ->
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState496 ->
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState494 ->
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState492 ->
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState489 ->
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState487 ->
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState485 ->
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState483 ->
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState481 ->
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState479 ->
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState477 ->
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState475 ->
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState473 ->
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState471 ->
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState469 ->
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState467 ->
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState465 ->
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState458 ->
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState455 ->
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState439 ->
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState427 ->
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState425 ->
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState335 ->
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState337 ->
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState000 ->
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState008 ->
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState221 ->
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState196 ->
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState018 ->
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState118 ->
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState038 ->
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState114 ->
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState056 ->
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState072 ->
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState108 ->
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState110 ->
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState112 ->
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState106 ->
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState104 ->
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState102 ->
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState100 ->
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState098 ->
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState088 ->
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState096 ->
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState090 ->
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState094 ->
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState092 ->
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState086 ->
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState084 ->
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState082 ->
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState076 ->
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState080 ->
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState078 ->
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState074 ->
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState058 ->
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState066 ->
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState070 ->
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState068 ->
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState062 ->
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState064 ->
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState060 ->
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState039 ->
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState019 ->
            _menhir_run_036 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState187 ->
            _menhir_run_036 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState184 ->
            _menhir_run_036 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState021 ->
            _menhir_run_036 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState180 ->
            _menhir_run_036 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState123 ->
            _menhir_run_036 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState139 ->
            _menhir_run_036 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState175 ->
            _menhir_run_036 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState177 ->
            _menhir_run_036 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState173 ->
            _menhir_run_036 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState171 ->
            _menhir_run_036 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState169 ->
            _menhir_run_036 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState167 ->
            _menhir_run_036 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState165 ->
            _menhir_run_036 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState155 ->
            _menhir_run_036 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState163 ->
            _menhir_run_036 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState157 ->
            _menhir_run_036 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState161 ->
            _menhir_run_036 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState159 ->
            _menhir_run_036 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState153 ->
            _menhir_run_036 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState151 ->
            _menhir_run_036 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState149 ->
            _menhir_run_036 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState143 ->
            _menhir_run_036 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState147 ->
            _menhir_run_036 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState145 ->
            _menhir_run_036 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState141 ->
            _menhir_run_036 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState125 ->
            _menhir_run_036 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState133 ->
            _menhir_run_036 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState137 ->
            _menhir_run_036 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState135 ->
            _menhir_run_036 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState129 ->
            _menhir_run_036 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState131 ->
            _menhir_run_036 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState127 ->
            _menhir_run_036 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState028 ->
            _menhir_run_036 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_460 : type  ttv_stack. ((ttv_stack, _menhir_box_program) _menhir_cell1_attributes as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_head_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v_0 ->
            let _startpos_1 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_2 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_2, _startpos_1, _v_0) in
            let _v = _menhir_action_068 x in
            _menhir_run_049 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v MenhirState460 _tok
        | Elpi_lexer_config.Tokens.SIGMA ->
            let _startpos_4 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_5 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_5, _startpos_4) in
            let _v = _menhir_action_085 () in
            _menhir_run_048_spec_460 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v _tok
        | Elpi_lexer_config.Tokens.REPLACE ->
            let _startpos_7 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_8 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_8, _startpos_7) in
            let _v = _menhir_action_080 () in
            _menhir_run_048_spec_460 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v _tok
        | Elpi_lexer_config.Tokens.QUOTED _v_10 ->
            let _startpos_11 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_12 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_12, _startpos_11, _v_10) in
            let _v = _menhir_action_069 _endpos_x_ _startpos_x_ x in
            _menhir_run_049 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v MenhirState460 _tok
        | Elpi_lexer_config.Tokens.PI ->
            let _startpos_14 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_15 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_15, _startpos_14) in
            let _v = _menhir_action_084 () in
            _menhir_run_048_spec_460 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v _tok
        | Elpi_lexer_config.Tokens.NIL ->
            let _startpos_17 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_18 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_18, _startpos_17) in
            let _v = _menhir_action_089 () in
            _menhir_run_048_spec_460 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v _tok
        | Elpi_lexer_config.Tokens.NAME ->
            let _startpos_20 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_21 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_21, _startpos_20) in
            let _v = _menhir_action_077 () in
            _menhir_run_048_spec_460 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v _tok
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState460
        | Elpi_lexer_config.Tokens.LCURLY ->
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState460
        | Elpi_lexer_config.Tokens.LBRACKET ->
            _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState460
        | Elpi_lexer_config.Tokens.IO _v_23 ->
            let _startpos_24 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_25 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_25, _startpos_24, _v_23) in
            let _v = _menhir_action_082 c in
            _menhir_run_048_spec_460 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v _tok
        | Elpi_lexer_config.Tokens.INTEGER _v_27 ->
            let _startpos_28 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_29 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_29, _startpos_28, _v_27) in
            let _v = _menhir_action_066 x in
            _menhir_run_049 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v MenhirState460 _tok
        | Elpi_lexer_config.Tokens.INDEX ->
            let _startpos_31 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_32 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_32, _startpos_31) in
            let _v = _menhir_action_081 () in
            _menhir_run_048_spec_460 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v _tok
        | Elpi_lexer_config.Tokens.IF ->
            let _startpos_34 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_35 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_35, _startpos_34) in
            let _v = _menhir_action_076 () in
            _menhir_run_048_spec_460 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v _tok
        | Elpi_lexer_config.Tokens.FRESHUV ->
            let _startpos_37 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_38 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_38, _startpos_37) in
            let _v = _menhir_action_086 () in
            _menhir_run_048_spec_460 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v _tok
        | Elpi_lexer_config.Tokens.FLOAT _v_40 ->
            let _startpos_41 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_42 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_42, _startpos_41, _v_40) in
            let _v = _menhir_action_067 x in
            _menhir_run_049 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v MenhirState460 _tok
        | Elpi_lexer_config.Tokens.CUT ->
            let _startpos_44 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_45 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_45, _startpos_44) in
            let _v = _menhir_action_083 () in
            _menhir_run_048_spec_460 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v _tok
        | Elpi_lexer_config.Tokens.CONSTANT _v_47 ->
            let _startpos_48 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_49 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_49, _startpos_48, _v_47) in
            let _v = _menhir_action_075 c in
            _menhir_run_048_spec_460 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v _tok
        | Elpi_lexer_config.Tokens.BEFORE ->
            let _startpos_51 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_52 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_52, _startpos_51) in
            let _v = _menhir_action_078 () in
            _menhir_run_048_spec_460 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v _tok
        | Elpi_lexer_config.Tokens.AFTER ->
            let _startpos_54 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_55 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_55, _startpos_54) in
            let _v = _menhir_action_079 () in
            _menhir_run_048_spec_460 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v _tok
        | _ ->
            _eRR 460
    
    and _menhir_run_049 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v_0 ->
            let _menhir_stack = MenhirCell1_closed_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos_1 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_2 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_2, _startpos_1, _v_0) in
            let _v = _menhir_action_068 x in
            _menhir_run_049 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v MenhirState049 _tok
        | Elpi_lexer_config.Tokens.SIGMA ->
            let _menhir_stack = MenhirCell1_closed_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos_4 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_5 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_5, _startpos_4) in
            let _v = _menhir_action_085 () in
            _menhir_run_048_spec_049 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v _tok
        | Elpi_lexer_config.Tokens.REPLACE ->
            let _menhir_stack = MenhirCell1_closed_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos_7 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_8 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_8, _startpos_7) in
            let _v = _menhir_action_080 () in
            _menhir_run_048_spec_049 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v _tok
        | Elpi_lexer_config.Tokens.QUOTED _v_10 ->
            let _menhir_stack = MenhirCell1_closed_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos_11 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_12 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_12, _startpos_11, _v_10) in
            let _v = _menhir_action_069 _endpos_x_ _startpos_x_ x in
            _menhir_run_049 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v MenhirState049 _tok
        | Elpi_lexer_config.Tokens.PI ->
            let _menhir_stack = MenhirCell1_closed_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos_14 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_15 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_15, _startpos_14) in
            let _v = _menhir_action_084 () in
            _menhir_run_048_spec_049 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v _tok
        | Elpi_lexer_config.Tokens.NIL ->
            let _menhir_stack = MenhirCell1_closed_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos_17 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_18 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_18, _startpos_17) in
            let _v = _menhir_action_089 () in
            _menhir_run_048_spec_049 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v _tok
        | Elpi_lexer_config.Tokens.NAME ->
            let _menhir_stack = MenhirCell1_closed_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos_20 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_21 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_21, _startpos_20) in
            let _v = _menhir_action_077 () in
            _menhir_run_048_spec_049 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v _tok
        | Elpi_lexer_config.Tokens.LPAREN ->
            let _menhir_stack = MenhirCell1_closed_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState049
        | Elpi_lexer_config.Tokens.LCURLY ->
            let _menhir_stack = MenhirCell1_closed_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState049
        | Elpi_lexer_config.Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_closed_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState049
        | Elpi_lexer_config.Tokens.IO _v_23 ->
            let _menhir_stack = MenhirCell1_closed_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos_24 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_25 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_25, _startpos_24, _v_23) in
            let _v = _menhir_action_082 c in
            _menhir_run_048_spec_049 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v _tok
        | Elpi_lexer_config.Tokens.INTEGER _v_27 ->
            let _menhir_stack = MenhirCell1_closed_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos_28 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_29 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_29, _startpos_28, _v_27) in
            let _v = _menhir_action_066 x in
            _menhir_run_049 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v MenhirState049 _tok
        | Elpi_lexer_config.Tokens.INDEX ->
            let _menhir_stack = MenhirCell1_closed_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos_31 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_32 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_32, _startpos_31) in
            let _v = _menhir_action_081 () in
            _menhir_run_048_spec_049 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v _tok
        | Elpi_lexer_config.Tokens.IF ->
            let _menhir_stack = MenhirCell1_closed_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos_34 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_35 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_35, _startpos_34) in
            let _v = _menhir_action_076 () in
            _menhir_run_048_spec_049 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v _tok
        | Elpi_lexer_config.Tokens.FRESHUV ->
            let _menhir_stack = MenhirCell1_closed_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos_37 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_38 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_38, _startpos_37) in
            let _v = _menhir_action_086 () in
            _menhir_run_048_spec_049 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v _tok
        | Elpi_lexer_config.Tokens.FLOAT _v_40 ->
            let _menhir_stack = MenhirCell1_closed_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos_41 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_42 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_42, _startpos_41, _v_40) in
            let _v = _menhir_action_067 x in
            _menhir_run_049 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v MenhirState049 _tok
        | Elpi_lexer_config.Tokens.CUT ->
            let _menhir_stack = MenhirCell1_closed_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos_44 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_45 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_45, _startpos_44) in
            let _v = _menhir_action_083 () in
            _menhir_run_048_spec_049 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v _tok
        | Elpi_lexer_config.Tokens.CONSTANT _v_47 ->
            let _menhir_stack = MenhirCell1_closed_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos_48 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_49 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_49, _startpos_48, _v_47) in
            let _v = _menhir_action_075 c in
            _menhir_run_048_spec_049 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v _tok
        | Elpi_lexer_config.Tokens.BEFORE ->
            let _menhir_stack = MenhirCell1_closed_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos_51 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_52 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_52, _startpos_51) in
            let _v = _menhir_action_078 () in
            _menhir_run_048_spec_049 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v _tok
        | Elpi_lexer_config.Tokens.AFTER ->
            let _menhir_stack = MenhirCell1_closed_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos_54 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_55 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_55, _startpos_54) in
            let _v = _menhir_action_079 () in
            _menhir_run_048_spec_049 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v _tok
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.AS | Elpi_lexer_config.Tokens.BIND | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.CONS | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.DIV | Elpi_lexer_config.Tokens.EOF | Elpi_lexer_config.Tokens.EQ | Elpi_lexer_config.Tokens.EQ2 | Elpi_lexer_config.Tokens.FAMILY_AND _ | Elpi_lexer_config.Tokens.FAMILY_BTICK _ | Elpi_lexer_config.Tokens.FAMILY_EQ _ | Elpi_lexer_config.Tokens.FAMILY_EXP _ | Elpi_lexer_config.Tokens.FAMILY_GT _ | Elpi_lexer_config.Tokens.FAMILY_LT _ | Elpi_lexer_config.Tokens.FAMILY_MINUS _ | Elpi_lexer_config.Tokens.FAMILY_OR _ | Elpi_lexer_config.Tokens.FAMILY_PLUS _ | Elpi_lexer_config.Tokens.FAMILY_QMARK _ | Elpi_lexer_config.Tokens.FAMILY_SHARP _ | Elpi_lexer_config.Tokens.FAMILY_TICK _ | Elpi_lexer_config.Tokens.FAMILY_TIMES _ | Elpi_lexer_config.Tokens.FULLSTOP | Elpi_lexer_config.Tokens.IFF | Elpi_lexer_config.Tokens.IS | Elpi_lexer_config.Tokens.MINUS | Elpi_lexer_config.Tokens.MINUSi | Elpi_lexer_config.Tokens.MINUSr | Elpi_lexer_config.Tokens.MINUSs | Elpi_lexer_config.Tokens.MOD | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.PIPE | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.RBRACKET | Elpi_lexer_config.Tokens.RCURLY | Elpi_lexer_config.Tokens.RPAREN | Elpi_lexer_config.Tokens.SLASH | Elpi_lexer_config.Tokens.VDASH ->
            let x = _v in
            let _v = _menhir_action_207 x in
            _menhir_goto_nonempty_list_closed_term_ _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | _ ->
            _eRR 49
    
    and _menhir_run_048_spec_049 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_closed_term -> _ -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_113 t in
        _menhir_run_047_spec_049 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v _tok
    
    and _menhir_run_047_spec_049 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_closed_term -> _ -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_074 t in
        _menhir_run_049 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v MenhirState049 _tok
    
    and _menhir_run_019 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_LBRACKET (_menhir_stack, _menhir_s, _startpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v ->
            let _startpos_0 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos, _startpos_0, _v) in
            let _v = _menhir_action_068 x in
            _menhir_run_120_spec_019 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.SIGMA ->
            let _startpos_1 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_1) in
            let _v = _menhir_action_085 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState019 _tok
        | Elpi_lexer_config.Tokens.REPLACE ->
            let _startpos_2 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_2) in
            let _v = _menhir_action_080 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState019 _tok
        | Elpi_lexer_config.Tokens.RBRACKET ->
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _endpos__1_ = _endpos in
            let _v = _menhir_action_163 () in
            _menhir_run_191 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _v _tok
        | Elpi_lexer_config.Tokens.QUOTED _v ->
            let _startpos_3 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos, _startpos_3, _v) in
            let _v = _menhir_action_069 _endpos_x_ _startpos_x_ x in
            _menhir_run_120_spec_019 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.PIPE ->
            _menhir_run_021 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState019
        | Elpi_lexer_config.Tokens.PI ->
            let _startpos_4 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_4) in
            let _v = _menhir_action_084 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState019 _tok
        | Elpi_lexer_config.Tokens.NIL ->
            let _startpos_5 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_5) in
            let _v = _menhir_action_089 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState019 _tok
        | Elpi_lexer_config.Tokens.NAME ->
            let _startpos_6 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_6) in
            let _v = _menhir_action_077 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState019 _tok
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState019
        | Elpi_lexer_config.Tokens.LCURLY ->
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState019
        | Elpi_lexer_config.Tokens.LBRACKET ->
            _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState019
        | Elpi_lexer_config.Tokens.IO _v ->
            let _startpos_7 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos, _startpos_7, _v) in
            let _v = _menhir_action_082 c in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState019 _tok
        | Elpi_lexer_config.Tokens.INTEGER _v ->
            let _startpos_8 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos, _startpos_8, _v) in
            let _v = _menhir_action_066 x in
            _menhir_run_120_spec_019 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.INDEX ->
            let _startpos_9 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_9) in
            let _v = _menhir_action_081 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState019 _tok
        | Elpi_lexer_config.Tokens.IF ->
            let _startpos_10 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_10) in
            let _v = _menhir_action_076 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState019 _tok
        | Elpi_lexer_config.Tokens.FRESHUV ->
            let _startpos_11 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_11) in
            let _v = _menhir_action_086 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState019 _tok
        | Elpi_lexer_config.Tokens.FLOAT _v ->
            let _startpos_12 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos, _startpos_12, _v) in
            let _v = _menhir_action_067 x in
            _menhir_run_120_spec_019 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_TILDE _v ->
            _menhir_run_028 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState019
        | Elpi_lexer_config.Tokens.CUT ->
            let _startpos_13 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_13) in
            let _v = _menhir_action_083 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState019 _tok
        | Elpi_lexer_config.Tokens.CONSTANT _v ->
            let _startpos_14 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos, _startpos_14, _v) in
            let _v = _menhir_action_075 c in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState019 _tok
        | Elpi_lexer_config.Tokens.BEFORE ->
            let _startpos_15 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_15) in
            let _v = _menhir_action_078 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState019 _tok
        | Elpi_lexer_config.Tokens.AFTER ->
            let _startpos_16 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_16) in
            let _v = _menhir_action_079 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState019 _tok
        | _ ->
            _eRR 19
    
    and _menhir_run_120_spec_019 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_LBRACKET -> _ -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_320 t in
        _menhir_run_182 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v MenhirState019 _tok
    
    and _menhir_run_182 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.VDASH ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_123 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.SLASH ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_125 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.RBRACKET ->
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (x, _endpos__2_) = (_v, _endpos_0) in
            let _v = _menhir_action_164 x in
            _menhir_goto_list_items _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__2_ _v _menhir_s _tok
        | Elpi_lexer_config.Tokens.QDASH ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_180 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.PIPE ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Elpi_lexer_config.Tokens.STRING _v_1 ->
                let _startpos_2 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_3 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_3, _startpos_2, _v_1) in
                let _v = _menhir_action_068 x in
                _menhir_run_120_spec_184 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.SIGMA ->
                let _startpos_5 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_6 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_6, _startpos_5) in
                let _v = _menhir_action_085 () in
                _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState184 _tok
            | Elpi_lexer_config.Tokens.REPLACE ->
                let _startpos_8 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_9 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_9, _startpos_8) in
                let _v = _menhir_action_080 () in
                _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState184 _tok
            | Elpi_lexer_config.Tokens.QUOTED _v_11 ->
                let _startpos_12 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_13 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_13, _startpos_12, _v_11) in
                let _v = _menhir_action_069 _endpos_x_ _startpos_x_ x in
                _menhir_run_120_spec_184 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.PI ->
                let _startpos_15 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_16 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_16, _startpos_15) in
                let _v = _menhir_action_084 () in
                _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState184 _tok
            | Elpi_lexer_config.Tokens.NIL ->
                let _startpos_18 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_19 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_19, _startpos_18) in
                let _v = _menhir_action_089 () in
                _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState184 _tok
            | Elpi_lexer_config.Tokens.NAME ->
                let _startpos_21 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_22 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_22, _startpos_21) in
                let _v = _menhir_action_077 () in
                _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState184 _tok
            | Elpi_lexer_config.Tokens.LPAREN ->
                _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState184
            | Elpi_lexer_config.Tokens.LCURLY ->
                _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState184
            | Elpi_lexer_config.Tokens.LBRACKET ->
                _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState184
            | Elpi_lexer_config.Tokens.IO _v_24 ->
                let _startpos_25 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_26 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_c_, _startpos_c_, c) = (_endpos_26, _startpos_25, _v_24) in
                let _v = _menhir_action_082 c in
                _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState184 _tok
            | Elpi_lexer_config.Tokens.INTEGER _v_28 ->
                let _startpos_29 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_30 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_30, _startpos_29, _v_28) in
                let _v = _menhir_action_066 x in
                _menhir_run_120_spec_184 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.INDEX ->
                let _startpos_32 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_33 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_33, _startpos_32) in
                let _v = _menhir_action_081 () in
                _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState184 _tok
            | Elpi_lexer_config.Tokens.IF ->
                let _startpos_35 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_36 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_36, _startpos_35) in
                let _v = _menhir_action_076 () in
                _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState184 _tok
            | Elpi_lexer_config.Tokens.FRESHUV ->
                let _startpos_38 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_39 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_39, _startpos_38) in
                let _v = _menhir_action_086 () in
                _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState184 _tok
            | Elpi_lexer_config.Tokens.FLOAT _v_41 ->
                let _startpos_42 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_43 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_43, _startpos_42, _v_41) in
                let _v = _menhir_action_067 x in
                _menhir_run_120_spec_184 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.FAMILY_TILDE _v_45 ->
                _menhir_run_028 _menhir_stack _menhir_lexbuf _menhir_lexer _v_45 MenhirState184
            | Elpi_lexer_config.Tokens.CUT ->
                let _startpos_46 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_47 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_47, _startpos_46) in
                let _v = _menhir_action_083 () in
                _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState184 _tok
            | Elpi_lexer_config.Tokens.CONSTANT _v_49 ->
                let _startpos_50 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_51 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_c_, _startpos_c_, c) = (_endpos_51, _startpos_50, _v_49) in
                let _v = _menhir_action_075 c in
                _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState184 _tok
            | Elpi_lexer_config.Tokens.BEFORE ->
                let _startpos_53 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_54 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_54, _startpos_53) in
                let _v = _menhir_action_078 () in
                _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState184 _tok
            | Elpi_lexer_config.Tokens.AFTER ->
                let _startpos_56 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_57 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_57, _startpos_56) in
                let _v = _menhir_action_079 () in
                _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState184 _tok
            | _ ->
                _eRR 184)
        | Elpi_lexer_config.Tokens.OR ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_139 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MOD ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_141 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSs ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_143 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSr ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_149 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSi ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_151 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_153 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.IS ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_155 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FAMILY_TIMES _v_59 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_145 _menhir_stack _menhir_lexbuf _menhir_lexer _v_59
        | Elpi_lexer_config.Tokens.FAMILY_TICK _v_60 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_157 _menhir_stack _menhir_lexbuf _menhir_lexer _v_60
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_61 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_127 _menhir_stack _menhir_lexbuf _menhir_lexer _v_61
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_62 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_034 _menhir_stack _menhir_lexbuf _menhir_lexer _v_62
        | Elpi_lexer_config.Tokens.FAMILY_PLUS _v_63 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_159 _menhir_stack _menhir_lexbuf _menhir_lexer _v_63
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_64 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_129 _menhir_stack _menhir_lexbuf _menhir_lexer _v_64
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_65 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_133 _menhir_stack _menhir_lexbuf _menhir_lexer _v_65
        | Elpi_lexer_config.Tokens.FAMILY_LT _v_66 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_165 _menhir_stack _menhir_lexbuf _menhir_lexer _v_66
        | Elpi_lexer_config.Tokens.FAMILY_GT _v_67 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_167 _menhir_stack _menhir_lexbuf _menhir_lexer _v_67
        | Elpi_lexer_config.Tokens.FAMILY_EXP _v_68 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_161 _menhir_stack _menhir_lexbuf _menhir_lexer _v_68
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_69 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_135 _menhir_stack _menhir_lexbuf _menhir_lexer _v_69
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_70 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_137 _menhir_stack _menhir_lexbuf _menhir_lexer _v_70
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_71 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_131 _menhir_stack _menhir_lexbuf _menhir_lexer _v_71
        | Elpi_lexer_config.Tokens.EQ2 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_169 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.EQ ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_171 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.DIV ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_147 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.DARROW ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_173 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONS ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_163 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONJ2 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_175 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONJ ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos_72 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_73 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell0_CONJ (_menhir_stack, _startpos_72, _endpos_73) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Elpi_lexer_config.Tokens.STRING _v_74 ->
                let _startpos_75 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_76 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_76, _startpos_75, _v_74) in
                let _v = _menhir_action_068 x in
                _menhir_run_120_spec_187 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.SIGMA ->
                let _startpos_78 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_79 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_79, _startpos_78) in
                let _v = _menhir_action_085 () in
                _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState187 _tok
            | Elpi_lexer_config.Tokens.REPLACE ->
                let _startpos_81 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_82 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_82, _startpos_81) in
                let _v = _menhir_action_080 () in
                _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState187 _tok
            | Elpi_lexer_config.Tokens.RBRACKET ->
                let _endpos_84 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let _endpos__1_ = _endpos_84 in
                let _v = _menhir_action_163 () in
                _menhir_run_189 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _v _tok
            | Elpi_lexer_config.Tokens.QUOTED _v_86 ->
                let _startpos_87 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_88 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_88, _startpos_87, _v_86) in
                let _v = _menhir_action_069 _endpos_x_ _startpos_x_ x in
                _menhir_run_120_spec_187 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.PIPE ->
                _menhir_run_021 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState187
            | Elpi_lexer_config.Tokens.PI ->
                let _startpos_90 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_91 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_91, _startpos_90) in
                let _v = _menhir_action_084 () in
                _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState187 _tok
            | Elpi_lexer_config.Tokens.NIL ->
                let _startpos_93 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_94 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_94, _startpos_93) in
                let _v = _menhir_action_089 () in
                _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState187 _tok
            | Elpi_lexer_config.Tokens.NAME ->
                let _startpos_96 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_97 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_97, _startpos_96) in
                let _v = _menhir_action_077 () in
                _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState187 _tok
            | Elpi_lexer_config.Tokens.LPAREN ->
                _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState187
            | Elpi_lexer_config.Tokens.LCURLY ->
                _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState187
            | Elpi_lexer_config.Tokens.LBRACKET ->
                _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState187
            | Elpi_lexer_config.Tokens.IO _v_99 ->
                let _startpos_100 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_101 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_c_, _startpos_c_, c) = (_endpos_101, _startpos_100, _v_99) in
                let _v = _menhir_action_082 c in
                _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState187 _tok
            | Elpi_lexer_config.Tokens.INTEGER _v_103 ->
                let _startpos_104 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_105 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_105, _startpos_104, _v_103) in
                let _v = _menhir_action_066 x in
                _menhir_run_120_spec_187 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.INDEX ->
                let _startpos_107 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_108 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_108, _startpos_107) in
                let _v = _menhir_action_081 () in
                _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState187 _tok
            | Elpi_lexer_config.Tokens.IF ->
                let _startpos_110 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_111 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_111, _startpos_110) in
                let _v = _menhir_action_076 () in
                _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState187 _tok
            | Elpi_lexer_config.Tokens.FRESHUV ->
                let _startpos_113 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_114 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_114, _startpos_113) in
                let _v = _menhir_action_086 () in
                _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState187 _tok
            | Elpi_lexer_config.Tokens.FLOAT _v_116 ->
                let _startpos_117 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_118 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_118, _startpos_117, _v_116) in
                let _v = _menhir_action_067 x in
                _menhir_run_120_spec_187 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.FAMILY_TILDE _v_120 ->
                _menhir_run_028 _menhir_stack _menhir_lexbuf _menhir_lexer _v_120 MenhirState187
            | Elpi_lexer_config.Tokens.CUT ->
                let _startpos_121 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_122 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_122, _startpos_121) in
                let _v = _menhir_action_083 () in
                _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState187 _tok
            | Elpi_lexer_config.Tokens.CONSTANT _v_124 ->
                let _startpos_125 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_126 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_c_, _startpos_c_, c) = (_endpos_126, _startpos_125, _v_124) in
                let _v = _menhir_action_075 c in
                _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState187 _tok
            | Elpi_lexer_config.Tokens.BEFORE ->
                let _startpos_128 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_129 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_129, _startpos_128) in
                let _v = _menhir_action_078 () in
                _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState187 _tok
            | Elpi_lexer_config.Tokens.AFTER ->
                let _startpos_131 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_132 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_132, _startpos_131) in
                let _v = _menhir_action_079 () in
                _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState187 _tok
            | _ ->
                _eRR 187)
        | Elpi_lexer_config.Tokens.ARROW ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_177 _menhir_stack _menhir_lexbuf _menhir_lexer
        | _ ->
            _eRR 182
    
    and _menhir_run_123 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term_noconj -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell0_VDASH (_menhir_stack, _startpos, _endpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v ->
            let _startpos_0 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_1 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_1, _startpos_0, _v) in
            let _v = _menhir_action_068 x in
            _menhir_run_120_spec_123 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.SIGMA ->
            let _startpos_2 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_3 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_3, _startpos_2) in
            let _v = _menhir_action_085 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState123 _tok
        | Elpi_lexer_config.Tokens.REPLACE ->
            let _startpos_4 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_5 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_5, _startpos_4) in
            let _v = _menhir_action_080 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState123 _tok
        | Elpi_lexer_config.Tokens.QUOTED _v ->
            let _startpos_6 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_7 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_7, _startpos_6, _v) in
            let _v = _menhir_action_069 _endpos_x_ _startpos_x_ x in
            _menhir_run_120_spec_123 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.PI ->
            let _startpos_8 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_9 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_9, _startpos_8) in
            let _v = _menhir_action_084 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState123 _tok
        | Elpi_lexer_config.Tokens.NIL ->
            let _startpos_10 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_11 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_11, _startpos_10) in
            let _v = _menhir_action_089 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState123 _tok
        | Elpi_lexer_config.Tokens.NAME ->
            let _startpos_12 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_13 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_13, _startpos_12) in
            let _v = _menhir_action_077 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState123 _tok
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState123
        | Elpi_lexer_config.Tokens.LCURLY ->
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState123
        | Elpi_lexer_config.Tokens.LBRACKET ->
            _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState123
        | Elpi_lexer_config.Tokens.IO _v ->
            let _startpos_14 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_15 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_15, _startpos_14, _v) in
            let _v = _menhir_action_082 c in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState123 _tok
        | Elpi_lexer_config.Tokens.INTEGER _v ->
            let _startpos_16 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_17 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_17, _startpos_16, _v) in
            let _v = _menhir_action_066 x in
            _menhir_run_120_spec_123 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.INDEX ->
            let _startpos_18 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_19 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_19, _startpos_18) in
            let _v = _menhir_action_081 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState123 _tok
        | Elpi_lexer_config.Tokens.IF ->
            let _startpos_20 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_21 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_21, _startpos_20) in
            let _v = _menhir_action_076 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState123 _tok
        | Elpi_lexer_config.Tokens.FRESHUV ->
            let _startpos_22 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_23 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_23, _startpos_22) in
            let _v = _menhir_action_086 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState123 _tok
        | Elpi_lexer_config.Tokens.FLOAT _v ->
            let _startpos_24 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_25 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_25, _startpos_24, _v) in
            let _v = _menhir_action_067 x in
            _menhir_run_120_spec_123 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_TILDE _v ->
            _menhir_run_028 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState123
        | Elpi_lexer_config.Tokens.CUT ->
            let _startpos_26 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_27 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_27, _startpos_26) in
            let _v = _menhir_action_083 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState123 _tok
        | Elpi_lexer_config.Tokens.CONSTANT _v ->
            let _startpos_28 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_29 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_29, _startpos_28, _v) in
            let _v = _menhir_action_075 c in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState123 _tok
        | Elpi_lexer_config.Tokens.BEFORE ->
            let _startpos_30 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_31 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_31, _startpos_30) in
            let _v = _menhir_action_078 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState123 _tok
        | Elpi_lexer_config.Tokens.AFTER ->
            let _startpos_32 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_33 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_33, _startpos_32) in
            let _v = _menhir_action_079 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState123 _tok
        | _ ->
            _eRR 123
    
    and _menhir_run_120_spec_123 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term_noconj _menhir_cell0_VDASH -> _ -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_320 t in
        _menhir_run_124 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v MenhirState123 _tok
    
    and _menhir_run_124 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_term_noconj _menhir_cell0_VDASH as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.SLASH ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_125 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.OR ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_139 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MOD ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_141 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSs ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_143 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSr ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_149 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSi ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_151 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_153 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.IS ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_155 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FAMILY_TIMES _v_0 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_145 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_TICK _v_1 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_157 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_2 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_127 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_3 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_034 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_PLUS _v_4 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_159 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_5 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_129 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_6 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_133 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.FAMILY_LT _v_7 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_165 _menhir_stack _menhir_lexbuf _menhir_lexer _v_7
        | Elpi_lexer_config.Tokens.FAMILY_GT _v_8 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_167 _menhir_stack _menhir_lexbuf _menhir_lexer _v_8
        | Elpi_lexer_config.Tokens.FAMILY_EXP _v_9 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_161 _menhir_stack _menhir_lexbuf _menhir_lexer _v_9
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_10 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_135 _menhir_stack _menhir_lexbuf _menhir_lexer _v_10
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_11 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_137 _menhir_stack _menhir_lexbuf _menhir_lexer _v_11
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_12 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_131 _menhir_stack _menhir_lexbuf _menhir_lexer _v_12
        | Elpi_lexer_config.Tokens.EQ2 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_169 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.EQ ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_171 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.DIV ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_147 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.DARROW ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_173 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONS ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_163 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONJ2 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_175 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.ARROW ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_177 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.PIPE | Elpi_lexer_config.Tokens.RBRACKET ->
            let MenhirCell0_VDASH (_menhir_stack, _, _) = _menhir_stack in
            let MenhirCell1_term_noconj (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_279 _endpos_r_ _startpos_l_ l r in
            _menhir_goto_open_term_noconj _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 124
    
    and _menhir_run_125 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term_noconj -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell0_SLASH (_menhir_stack, _startpos, _endpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v ->
            let _startpos_0 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_1 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_1, _startpos_0, _v) in
            let _v = _menhir_action_068 x in
            _menhir_run_120_spec_125 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.SIGMA ->
            let _startpos_2 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_3 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_3, _startpos_2) in
            let _v = _menhir_action_085 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState125 _tok
        | Elpi_lexer_config.Tokens.REPLACE ->
            let _startpos_4 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_5 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_5, _startpos_4) in
            let _v = _menhir_action_080 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState125 _tok
        | Elpi_lexer_config.Tokens.QUOTED _v ->
            let _startpos_6 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_7 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_7, _startpos_6, _v) in
            let _v = _menhir_action_069 _endpos_x_ _startpos_x_ x in
            _menhir_run_120_spec_125 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.PI ->
            let _startpos_8 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_9 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_9, _startpos_8) in
            let _v = _menhir_action_084 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState125 _tok
        | Elpi_lexer_config.Tokens.NIL ->
            let _startpos_10 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_11 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_11, _startpos_10) in
            let _v = _menhir_action_089 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState125 _tok
        | Elpi_lexer_config.Tokens.NAME ->
            let _startpos_12 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_13 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_13, _startpos_12) in
            let _v = _menhir_action_077 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState125 _tok
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState125
        | Elpi_lexer_config.Tokens.LCURLY ->
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState125
        | Elpi_lexer_config.Tokens.LBRACKET ->
            _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState125
        | Elpi_lexer_config.Tokens.IO _v ->
            let _startpos_14 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_15 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_15, _startpos_14, _v) in
            let _v = _menhir_action_082 c in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState125 _tok
        | Elpi_lexer_config.Tokens.INTEGER _v ->
            let _startpos_16 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_17 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_17, _startpos_16, _v) in
            let _v = _menhir_action_066 x in
            _menhir_run_120_spec_125 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.INDEX ->
            let _startpos_18 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_19 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_19, _startpos_18) in
            let _v = _menhir_action_081 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState125 _tok
        | Elpi_lexer_config.Tokens.IF ->
            let _startpos_20 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_21 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_21, _startpos_20) in
            let _v = _menhir_action_076 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState125 _tok
        | Elpi_lexer_config.Tokens.FRESHUV ->
            let _startpos_22 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_23 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_23, _startpos_22) in
            let _v = _menhir_action_086 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState125 _tok
        | Elpi_lexer_config.Tokens.FLOAT _v ->
            let _startpos_24 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_25 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_25, _startpos_24, _v) in
            let _v = _menhir_action_067 x in
            _menhir_run_120_spec_125 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_TILDE _v ->
            _menhir_run_028 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState125
        | Elpi_lexer_config.Tokens.CUT ->
            let _startpos_26 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_27 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_27, _startpos_26) in
            let _v = _menhir_action_083 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState125 _tok
        | Elpi_lexer_config.Tokens.CONSTANT _v ->
            let _startpos_28 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_29 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_29, _startpos_28, _v) in
            let _v = _menhir_action_075 c in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState125 _tok
        | Elpi_lexer_config.Tokens.BEFORE ->
            let _startpos_30 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_31 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_31, _startpos_30) in
            let _v = _menhir_action_078 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState125 _tok
        | Elpi_lexer_config.Tokens.AFTER ->
            let _startpos_32 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_33 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_33, _startpos_32) in
            let _v = _menhir_action_079 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState125 _tok
        | _ ->
            _eRR 125
    
    and _menhir_run_120_spec_125 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term_noconj _menhir_cell0_SLASH -> _ -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_320 t in
        _menhir_run_126 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v MenhirState125 _tok
    
    and _menhir_run_126 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_term_noconj _menhir_cell0_SLASH as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_0 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_127 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_1 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_034 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_2 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_129 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_3 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_133 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_4 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_135 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_5 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_137 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_6 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_131 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.CONS | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.DIV | Elpi_lexer_config.Tokens.EQ | Elpi_lexer_config.Tokens.EQ2 | Elpi_lexer_config.Tokens.FAMILY_EXP _ | Elpi_lexer_config.Tokens.FAMILY_GT _ | Elpi_lexer_config.Tokens.FAMILY_LT _ | Elpi_lexer_config.Tokens.FAMILY_PLUS _ | Elpi_lexer_config.Tokens.FAMILY_TICK _ | Elpi_lexer_config.Tokens.FAMILY_TIMES _ | Elpi_lexer_config.Tokens.IS | Elpi_lexer_config.Tokens.MINUS | Elpi_lexer_config.Tokens.MINUSi | Elpi_lexer_config.Tokens.MINUSr | Elpi_lexer_config.Tokens.MINUSs | Elpi_lexer_config.Tokens.MOD | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.PIPE | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.RBRACKET | Elpi_lexer_config.Tokens.SLASH | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_SLASH (_menhir_stack, _, _) = _menhir_stack in
            let MenhirCell1_term_noconj (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_277 _endpos_r_ _startpos_l_ l r in
            _menhir_goto_open_term_noconj _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 126
    
    and _menhir_run_127 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term_noconj -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell0_FAMILY_SHARP (_menhir_stack, _v, _startpos, _endpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v_0 ->
            let _startpos_1 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_2 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_2, _startpos_1, _v_0) in
            let _v = _menhir_action_068 x in
            _menhir_run_120_spec_127 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.SIGMA ->
            let _startpos_4 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_5 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_5, _startpos_4) in
            let _v = _menhir_action_085 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState127 _tok
        | Elpi_lexer_config.Tokens.REPLACE ->
            let _startpos_7 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_8 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_8, _startpos_7) in
            let _v = _menhir_action_080 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState127 _tok
        | Elpi_lexer_config.Tokens.QUOTED _v_10 ->
            let _startpos_11 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_12 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_12, _startpos_11, _v_10) in
            let _v = _menhir_action_069 _endpos_x_ _startpos_x_ x in
            _menhir_run_120_spec_127 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.PI ->
            let _startpos_14 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_15 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_15, _startpos_14) in
            let _v = _menhir_action_084 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState127 _tok
        | Elpi_lexer_config.Tokens.NIL ->
            let _startpos_17 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_18 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_18, _startpos_17) in
            let _v = _menhir_action_089 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState127 _tok
        | Elpi_lexer_config.Tokens.NAME ->
            let _startpos_20 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_21 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_21, _startpos_20) in
            let _v = _menhir_action_077 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState127 _tok
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState127
        | Elpi_lexer_config.Tokens.LCURLY ->
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState127
        | Elpi_lexer_config.Tokens.LBRACKET ->
            _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState127
        | Elpi_lexer_config.Tokens.IO _v_23 ->
            let _startpos_24 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_25 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_25, _startpos_24, _v_23) in
            let _v = _menhir_action_082 c in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState127 _tok
        | Elpi_lexer_config.Tokens.INTEGER _v_27 ->
            let _startpos_28 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_29 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_29, _startpos_28, _v_27) in
            let _v = _menhir_action_066 x in
            _menhir_run_120_spec_127 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.INDEX ->
            let _startpos_31 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_32 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_32, _startpos_31) in
            let _v = _menhir_action_081 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState127 _tok
        | Elpi_lexer_config.Tokens.IF ->
            let _startpos_34 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_35 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_35, _startpos_34) in
            let _v = _menhir_action_076 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState127 _tok
        | Elpi_lexer_config.Tokens.FRESHUV ->
            let _startpos_37 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_38 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_38, _startpos_37) in
            let _v = _menhir_action_086 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState127 _tok
        | Elpi_lexer_config.Tokens.FLOAT _v_40 ->
            let _startpos_41 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_42 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_42, _startpos_41, _v_40) in
            let _v = _menhir_action_067 x in
            _menhir_run_120_spec_127 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_TILDE _v_44 ->
            _menhir_run_028 _menhir_stack _menhir_lexbuf _menhir_lexer _v_44 MenhirState127
        | Elpi_lexer_config.Tokens.CUT ->
            let _startpos_45 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_46 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_46, _startpos_45) in
            let _v = _menhir_action_083 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState127 _tok
        | Elpi_lexer_config.Tokens.CONSTANT _v_48 ->
            let _startpos_49 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_50 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_50, _startpos_49, _v_48) in
            let _v = _menhir_action_075 c in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState127 _tok
        | Elpi_lexer_config.Tokens.BEFORE ->
            let _startpos_52 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_53 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_53, _startpos_52) in
            let _v = _menhir_action_078 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState127 _tok
        | Elpi_lexer_config.Tokens.AFTER ->
            let _startpos_55 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_56 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_56, _startpos_55) in
            let _v = _menhir_action_079 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState127 _tok
        | _ ->
            _eRR 127
    
    and _menhir_run_120_spec_127 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term_noconj _menhir_cell0_FAMILY_SHARP -> _ -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_320 t in
        _menhir_run_128 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v MenhirState127 _tok
    
    and _menhir_run_128 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_term_noconj _menhir_cell0_FAMILY_SHARP as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_0 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_034 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.CONS | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.DIV | Elpi_lexer_config.Tokens.EQ | Elpi_lexer_config.Tokens.EQ2 | Elpi_lexer_config.Tokens.FAMILY_AND _ | Elpi_lexer_config.Tokens.FAMILY_BTICK _ | Elpi_lexer_config.Tokens.FAMILY_EQ _ | Elpi_lexer_config.Tokens.FAMILY_EXP _ | Elpi_lexer_config.Tokens.FAMILY_GT _ | Elpi_lexer_config.Tokens.FAMILY_LT _ | Elpi_lexer_config.Tokens.FAMILY_MINUS _ | Elpi_lexer_config.Tokens.FAMILY_OR _ | Elpi_lexer_config.Tokens.FAMILY_PLUS _ | Elpi_lexer_config.Tokens.FAMILY_SHARP _ | Elpi_lexer_config.Tokens.FAMILY_TICK _ | Elpi_lexer_config.Tokens.FAMILY_TIMES _ | Elpi_lexer_config.Tokens.IS | Elpi_lexer_config.Tokens.MINUS | Elpi_lexer_config.Tokens.MINUSi | Elpi_lexer_config.Tokens.MINUSr | Elpi_lexer_config.Tokens.MINUSs | Elpi_lexer_config.Tokens.MOD | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.PIPE | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.RBRACKET | Elpi_lexer_config.Tokens.SLASH | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_FAMILY_SHARP (_menhir_stack, s, _, _) = _menhir_stack in
            let MenhirCell1_term_noconj (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_260 _endpos_r_ _startpos_l_ l r s in
            _menhir_goto_open_term_noconj _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 128
    
    and _menhir_run_034 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term_noconj -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        let MenhirCell1_term_noconj (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
        let (_endpos_s_, s) = (_endpos, _v) in
        let _v = _menhir_action_281 l s in
        _menhir_goto_open_term_noconj _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_s_ _startpos_l_ _v _menhir_s _tok
    
    and _menhir_goto_open_term_noconj : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_318 t in
        _menhir_goto_term_noconj _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v _menhir_s _tok
    
    and _menhir_goto_term_noconj : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match _menhir_s with
        | MenhirState184 ->
            _menhir_run_185 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState187 ->
            _menhir_run_182 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState019 ->
            _menhir_run_182 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState180 ->
            _menhir_run_181 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState177 ->
            _menhir_run_178 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState175 ->
            _menhir_run_176 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState173 ->
            _menhir_run_174 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState171 ->
            _menhir_run_172 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState169 ->
            _menhir_run_170 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState167 ->
            _menhir_run_168 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState165 ->
            _menhir_run_166 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState163 ->
            _menhir_run_164 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState161 ->
            _menhir_run_162 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState159 ->
            _menhir_run_160 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState157 ->
            _menhir_run_158 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState155 ->
            _menhir_run_156 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState153 ->
            _menhir_run_154 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState151 ->
            _menhir_run_152 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState149 ->
            _menhir_run_150 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState147 ->
            _menhir_run_148 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState145 ->
            _menhir_run_146 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState143 ->
            _menhir_run_144 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState141 ->
            _menhir_run_142 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState139 ->
            _menhir_run_140 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState137 ->
            _menhir_run_138 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState135 ->
            _menhir_run_136 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState133 ->
            _menhir_run_134 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState131 ->
            _menhir_run_132 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState129 ->
            _menhir_run_130 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState127 ->
            _menhir_run_128 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState125 ->
            _menhir_run_126 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState123 ->
            _menhir_run_124 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState021 ->
            _menhir_run_122 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState028 ->
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_185 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_term_noconj as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.VDASH ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_123 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.SLASH ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_125 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.RBRACKET ->
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let MenhirCell1_term_noconj (_menhir_stack, _menhir_s, x, _, _) = _menhir_stack in
            let (xs, _endpos__4_) = (_v, _endpos_0) in
            let _v = _menhir_action_167 x xs in
            _menhir_goto_list_items_tail _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__4_ _v _menhir_s _tok
        | Elpi_lexer_config.Tokens.QDASH ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_180 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.OR ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_139 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MOD ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_141 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSs ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_143 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSr ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_149 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSi ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_151 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_153 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.IS ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_155 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FAMILY_TIMES _v_1 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_145 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_TICK _v_2 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_157 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_3 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_127 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_4 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_034 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_PLUS _v_5 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_159 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_6 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_129 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_7 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_133 _menhir_stack _menhir_lexbuf _menhir_lexer _v_7
        | Elpi_lexer_config.Tokens.FAMILY_LT _v_8 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_165 _menhir_stack _menhir_lexbuf _menhir_lexer _v_8
        | Elpi_lexer_config.Tokens.FAMILY_GT _v_9 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_167 _menhir_stack _menhir_lexbuf _menhir_lexer _v_9
        | Elpi_lexer_config.Tokens.FAMILY_EXP _v_10 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_161 _menhir_stack _menhir_lexbuf _menhir_lexer _v_10
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_11 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_135 _menhir_stack _menhir_lexbuf _menhir_lexer _v_11
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_12 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_137 _menhir_stack _menhir_lexbuf _menhir_lexer _v_12
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_13 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_131 _menhir_stack _menhir_lexbuf _menhir_lexer _v_13
        | Elpi_lexer_config.Tokens.EQ2 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_169 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.EQ ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_171 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.DIV ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_147 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.DARROW ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_173 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONS ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_163 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONJ2 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_175 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.ARROW ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_177 _menhir_stack _menhir_lexbuf _menhir_lexer
        | _ ->
            _eRR 185
    
    and _menhir_goto_list_items_tail : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        match _menhir_s with
        | MenhirState019 ->
            _menhir_run_190 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState187 ->
            _menhir_run_188 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_190 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_LBRACKET -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let MenhirCell1_LBRACKET (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
        let (_endpos_l_, l) = (_endpos, _v) in
        let _v = _menhir_action_072 l in
        _menhir_goto_closed_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_l_ _startpos__1_ _v _menhir_s _tok
    
    and _menhir_run_188 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term_noconj _menhir_cell0_CONJ -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let MenhirCell0_CONJ (_menhir_stack, _, _) = _menhir_stack in
        let MenhirCell1_term_noconj (_menhir_stack, _menhir_s, x, _, _) = _menhir_stack in
        let (_endpos_xs_, xs) = (_endpos, _v) in
        let _v = _menhir_action_168 x xs in
        _menhir_goto_list_items_tail _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_xs_ _v _menhir_s _tok
    
    and _menhir_run_180 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term_noconj -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell0_QDASH (_menhir_stack, _startpos, _endpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v ->
            let _startpos_0 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_1 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_1, _startpos_0, _v) in
            let _v = _menhir_action_068 x in
            _menhir_run_120_spec_180 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.SIGMA ->
            let _startpos_2 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_3 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_3, _startpos_2) in
            let _v = _menhir_action_085 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState180 _tok
        | Elpi_lexer_config.Tokens.REPLACE ->
            let _startpos_4 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_5 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_5, _startpos_4) in
            let _v = _menhir_action_080 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState180 _tok
        | Elpi_lexer_config.Tokens.QUOTED _v ->
            let _startpos_6 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_7 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_7, _startpos_6, _v) in
            let _v = _menhir_action_069 _endpos_x_ _startpos_x_ x in
            _menhir_run_120_spec_180 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.PI ->
            let _startpos_8 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_9 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_9, _startpos_8) in
            let _v = _menhir_action_084 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState180 _tok
        | Elpi_lexer_config.Tokens.NIL ->
            let _startpos_10 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_11 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_11, _startpos_10) in
            let _v = _menhir_action_089 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState180 _tok
        | Elpi_lexer_config.Tokens.NAME ->
            let _startpos_12 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_13 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_13, _startpos_12) in
            let _v = _menhir_action_077 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState180 _tok
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState180
        | Elpi_lexer_config.Tokens.LCURLY ->
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState180
        | Elpi_lexer_config.Tokens.LBRACKET ->
            _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState180
        | Elpi_lexer_config.Tokens.IO _v ->
            let _startpos_14 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_15 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_15, _startpos_14, _v) in
            let _v = _menhir_action_082 c in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState180 _tok
        | Elpi_lexer_config.Tokens.INTEGER _v ->
            let _startpos_16 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_17 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_17, _startpos_16, _v) in
            let _v = _menhir_action_066 x in
            _menhir_run_120_spec_180 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.INDEX ->
            let _startpos_18 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_19 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_19, _startpos_18) in
            let _v = _menhir_action_081 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState180 _tok
        | Elpi_lexer_config.Tokens.IF ->
            let _startpos_20 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_21 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_21, _startpos_20) in
            let _v = _menhir_action_076 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState180 _tok
        | Elpi_lexer_config.Tokens.FRESHUV ->
            let _startpos_22 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_23 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_23, _startpos_22) in
            let _v = _menhir_action_086 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState180 _tok
        | Elpi_lexer_config.Tokens.FLOAT _v ->
            let _startpos_24 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_25 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_25, _startpos_24, _v) in
            let _v = _menhir_action_067 x in
            _menhir_run_120_spec_180 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_TILDE _v ->
            _menhir_run_028 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState180
        | Elpi_lexer_config.Tokens.CUT ->
            let _startpos_26 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_27 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_27, _startpos_26) in
            let _v = _menhir_action_083 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState180 _tok
        | Elpi_lexer_config.Tokens.CONSTANT _v ->
            let _startpos_28 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_29 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_29, _startpos_28, _v) in
            let _v = _menhir_action_075 c in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState180 _tok
        | Elpi_lexer_config.Tokens.BEFORE ->
            let _startpos_30 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_31 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_31, _startpos_30) in
            let _v = _menhir_action_078 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState180 _tok
        | Elpi_lexer_config.Tokens.AFTER ->
            let _startpos_32 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_33 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_33, _startpos_32) in
            let _v = _menhir_action_079 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState180 _tok
        | _ ->
            _eRR 180
    
    and _menhir_run_120_spec_180 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term_noconj _menhir_cell0_QDASH -> _ -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_320 t in
        _menhir_run_181 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v MenhirState180 _tok
    
    and _menhir_run_181 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_term_noconj _menhir_cell0_QDASH as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.SLASH ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_125 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.OR ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_139 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MOD ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_141 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSs ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_143 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSr ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_149 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSi ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_151 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_153 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.IS ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_155 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FAMILY_TIMES _v_0 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_145 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_TICK _v_1 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_157 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_2 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_127 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_3 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_034 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_PLUS _v_4 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_159 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_5 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_129 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_6 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_133 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.FAMILY_LT _v_7 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_165 _menhir_stack _menhir_lexbuf _menhir_lexer _v_7
        | Elpi_lexer_config.Tokens.FAMILY_GT _v_8 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_167 _menhir_stack _menhir_lexbuf _menhir_lexer _v_8
        | Elpi_lexer_config.Tokens.FAMILY_EXP _v_9 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_161 _menhir_stack _menhir_lexbuf _menhir_lexer _v_9
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_10 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_135 _menhir_stack _menhir_lexbuf _menhir_lexer _v_10
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_11 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_137 _menhir_stack _menhir_lexbuf _menhir_lexer _v_11
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_12 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_131 _menhir_stack _menhir_lexbuf _menhir_lexer _v_12
        | Elpi_lexer_config.Tokens.EQ2 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_169 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.EQ ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_171 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.DIV ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_147 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.DARROW ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_173 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONS ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_163 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONJ2 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_175 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.ARROW ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_177 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.PIPE | Elpi_lexer_config.Tokens.RBRACKET ->
            let MenhirCell0_QDASH (_menhir_stack, _, _) = _menhir_stack in
            let MenhirCell1_term_noconj (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_276 _endpos_r_ _startpos_l_ l r in
            _menhir_goto_open_term_noconj _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 181
    
    and _menhir_run_139 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term_noconj -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell0_OR (_menhir_stack, _startpos, _endpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v ->
            let _startpos_0 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_1 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_1, _startpos_0, _v) in
            let _v = _menhir_action_068 x in
            _menhir_run_120_spec_139 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.SIGMA ->
            let _startpos_2 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_3 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_3, _startpos_2) in
            let _v = _menhir_action_085 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState139 _tok
        | Elpi_lexer_config.Tokens.REPLACE ->
            let _startpos_4 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_5 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_5, _startpos_4) in
            let _v = _menhir_action_080 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState139 _tok
        | Elpi_lexer_config.Tokens.QUOTED _v ->
            let _startpos_6 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_7 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_7, _startpos_6, _v) in
            let _v = _menhir_action_069 _endpos_x_ _startpos_x_ x in
            _menhir_run_120_spec_139 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.PI ->
            let _startpos_8 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_9 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_9, _startpos_8) in
            let _v = _menhir_action_084 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState139 _tok
        | Elpi_lexer_config.Tokens.NIL ->
            let _startpos_10 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_11 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_11, _startpos_10) in
            let _v = _menhir_action_089 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState139 _tok
        | Elpi_lexer_config.Tokens.NAME ->
            let _startpos_12 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_13 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_13, _startpos_12) in
            let _v = _menhir_action_077 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState139 _tok
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState139
        | Elpi_lexer_config.Tokens.LCURLY ->
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState139
        | Elpi_lexer_config.Tokens.LBRACKET ->
            _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState139
        | Elpi_lexer_config.Tokens.IO _v ->
            let _startpos_14 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_15 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_15, _startpos_14, _v) in
            let _v = _menhir_action_082 c in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState139 _tok
        | Elpi_lexer_config.Tokens.INTEGER _v ->
            let _startpos_16 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_17 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_17, _startpos_16, _v) in
            let _v = _menhir_action_066 x in
            _menhir_run_120_spec_139 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.INDEX ->
            let _startpos_18 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_19 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_19, _startpos_18) in
            let _v = _menhir_action_081 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState139 _tok
        | Elpi_lexer_config.Tokens.IF ->
            let _startpos_20 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_21 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_21, _startpos_20) in
            let _v = _menhir_action_076 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState139 _tok
        | Elpi_lexer_config.Tokens.FRESHUV ->
            let _startpos_22 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_23 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_23, _startpos_22) in
            let _v = _menhir_action_086 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState139 _tok
        | Elpi_lexer_config.Tokens.FLOAT _v ->
            let _startpos_24 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_25 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_25, _startpos_24, _v) in
            let _v = _menhir_action_067 x in
            _menhir_run_120_spec_139 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_TILDE _v ->
            _menhir_run_028 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState139
        | Elpi_lexer_config.Tokens.CUT ->
            let _startpos_26 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_27 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_27, _startpos_26) in
            let _v = _menhir_action_083 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState139 _tok
        | Elpi_lexer_config.Tokens.CONSTANT _v ->
            let _startpos_28 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_29 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_29, _startpos_28, _v) in
            let _v = _menhir_action_075 c in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState139 _tok
        | Elpi_lexer_config.Tokens.BEFORE ->
            let _startpos_30 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_31 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_31, _startpos_30) in
            let _v = _menhir_action_078 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState139 _tok
        | Elpi_lexer_config.Tokens.AFTER ->
            let _startpos_32 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_33 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_33, _startpos_32) in
            let _v = _menhir_action_079 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState139 _tok
        | _ ->
            _eRR 139
    
    and _menhir_run_120_spec_139 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term_noconj _menhir_cell0_OR -> _ -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_320 t in
        _menhir_run_140 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v MenhirState139 _tok
    
    and _menhir_run_140 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_term_noconj _menhir_cell0_OR as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.SLASH ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_125 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.OR ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_139 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MOD ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_141 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSs ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_143 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSr ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_149 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSi ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_151 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_153 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.IS ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_155 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FAMILY_TIMES _v_0 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_145 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_TICK _v_1 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_157 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_2 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_127 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_3 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_034 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_PLUS _v_4 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_159 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_5 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_129 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_6 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_133 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.FAMILY_LT _v_7 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_165 _menhir_stack _menhir_lexbuf _menhir_lexer _v_7
        | Elpi_lexer_config.Tokens.FAMILY_GT _v_8 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_167 _menhir_stack _menhir_lexbuf _menhir_lexer _v_8
        | Elpi_lexer_config.Tokens.FAMILY_EXP _v_9 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_161 _menhir_stack _menhir_lexbuf _menhir_lexer _v_9
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_10 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_135 _menhir_stack _menhir_lexbuf _menhir_lexer _v_10
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_11 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_137 _menhir_stack _menhir_lexbuf _menhir_lexer _v_11
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_12 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_131 _menhir_stack _menhir_lexbuf _menhir_lexer _v_12
        | Elpi_lexer_config.Tokens.EQ2 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_169 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.EQ ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_171 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.DIV ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_147 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.DARROW ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_173 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONS ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_163 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONJ2 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_175 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.ARROW ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_177 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.PIPE | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.RBRACKET | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_OR (_menhir_stack, _, _) = _menhir_stack in
            let MenhirCell1_term_noconj (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_270 _endpos_r_ _startpos_l_ l r in
            _menhir_goto_open_term_noconj _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 140
    
    and _menhir_run_141 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term_noconj -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell0_MOD (_menhir_stack, _startpos, _endpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v ->
            let _startpos_0 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_1 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_1, _startpos_0, _v) in
            let _v = _menhir_action_068 x in
            _menhir_run_120_spec_141 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.SIGMA ->
            let _startpos_2 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_3 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_3, _startpos_2) in
            let _v = _menhir_action_085 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState141 _tok
        | Elpi_lexer_config.Tokens.REPLACE ->
            let _startpos_4 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_5 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_5, _startpos_4) in
            let _v = _menhir_action_080 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState141 _tok
        | Elpi_lexer_config.Tokens.QUOTED _v ->
            let _startpos_6 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_7 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_7, _startpos_6, _v) in
            let _v = _menhir_action_069 _endpos_x_ _startpos_x_ x in
            _menhir_run_120_spec_141 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.PI ->
            let _startpos_8 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_9 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_9, _startpos_8) in
            let _v = _menhir_action_084 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState141 _tok
        | Elpi_lexer_config.Tokens.NIL ->
            let _startpos_10 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_11 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_11, _startpos_10) in
            let _v = _menhir_action_089 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState141 _tok
        | Elpi_lexer_config.Tokens.NAME ->
            let _startpos_12 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_13 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_13, _startpos_12) in
            let _v = _menhir_action_077 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState141 _tok
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState141
        | Elpi_lexer_config.Tokens.LCURLY ->
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState141
        | Elpi_lexer_config.Tokens.LBRACKET ->
            _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState141
        | Elpi_lexer_config.Tokens.IO _v ->
            let _startpos_14 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_15 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_15, _startpos_14, _v) in
            let _v = _menhir_action_082 c in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState141 _tok
        | Elpi_lexer_config.Tokens.INTEGER _v ->
            let _startpos_16 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_17 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_17, _startpos_16, _v) in
            let _v = _menhir_action_066 x in
            _menhir_run_120_spec_141 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.INDEX ->
            let _startpos_18 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_19 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_19, _startpos_18) in
            let _v = _menhir_action_081 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState141 _tok
        | Elpi_lexer_config.Tokens.IF ->
            let _startpos_20 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_21 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_21, _startpos_20) in
            let _v = _menhir_action_076 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState141 _tok
        | Elpi_lexer_config.Tokens.FRESHUV ->
            let _startpos_22 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_23 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_23, _startpos_22) in
            let _v = _menhir_action_086 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState141 _tok
        | Elpi_lexer_config.Tokens.FLOAT _v ->
            let _startpos_24 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_25 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_25, _startpos_24, _v) in
            let _v = _menhir_action_067 x in
            _menhir_run_120_spec_141 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_TILDE _v ->
            _menhir_run_028 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState141
        | Elpi_lexer_config.Tokens.CUT ->
            let _startpos_26 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_27 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_27, _startpos_26) in
            let _v = _menhir_action_083 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState141 _tok
        | Elpi_lexer_config.Tokens.CONSTANT _v ->
            let _startpos_28 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_29 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_29, _startpos_28, _v) in
            let _v = _menhir_action_075 c in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState141 _tok
        | Elpi_lexer_config.Tokens.BEFORE ->
            let _startpos_30 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_31 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_31, _startpos_30) in
            let _v = _menhir_action_078 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState141 _tok
        | Elpi_lexer_config.Tokens.AFTER ->
            let _startpos_32 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_33 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_33, _startpos_32) in
            let _v = _menhir_action_079 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState141 _tok
        | _ ->
            _eRR 141
    
    and _menhir_run_120_spec_141 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term_noconj _menhir_cell0_MOD -> _ -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_320 t in
        _menhir_run_142 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v MenhirState141 _tok
    
    and _menhir_run_142 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_term_noconj _menhir_cell0_MOD as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_0 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_127 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_1 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_034 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_2 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_129 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_3 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_133 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_4 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_135 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_5 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_137 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_6 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_131 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.CONS | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.DIV | Elpi_lexer_config.Tokens.EQ | Elpi_lexer_config.Tokens.EQ2 | Elpi_lexer_config.Tokens.FAMILY_EXP _ | Elpi_lexer_config.Tokens.FAMILY_GT _ | Elpi_lexer_config.Tokens.FAMILY_LT _ | Elpi_lexer_config.Tokens.FAMILY_PLUS _ | Elpi_lexer_config.Tokens.FAMILY_TICK _ | Elpi_lexer_config.Tokens.FAMILY_TIMES _ | Elpi_lexer_config.Tokens.IS | Elpi_lexer_config.Tokens.MINUS | Elpi_lexer_config.Tokens.MINUSi | Elpi_lexer_config.Tokens.MINUSr | Elpi_lexer_config.Tokens.MINUSs | Elpi_lexer_config.Tokens.MOD | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.PIPE | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.RBRACKET | Elpi_lexer_config.Tokens.SLASH | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_MOD (_menhir_stack, _, _) = _menhir_stack in
            let MenhirCell1_term_noconj (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_272 _endpos_r_ _startpos_l_ l r in
            _menhir_goto_open_term_noconj _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 142
    
    and _menhir_run_129 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term_noconj -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell0_FAMILY_OR (_menhir_stack, _v, _startpos, _endpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v_0 ->
            let _startpos_1 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_2 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_2, _startpos_1, _v_0) in
            let _v = _menhir_action_068 x in
            _menhir_run_120_spec_129 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.SIGMA ->
            let _startpos_4 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_5 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_5, _startpos_4) in
            let _v = _menhir_action_085 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState129 _tok
        | Elpi_lexer_config.Tokens.REPLACE ->
            let _startpos_7 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_8 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_8, _startpos_7) in
            let _v = _menhir_action_080 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState129 _tok
        | Elpi_lexer_config.Tokens.QUOTED _v_10 ->
            let _startpos_11 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_12 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_12, _startpos_11, _v_10) in
            let _v = _menhir_action_069 _endpos_x_ _startpos_x_ x in
            _menhir_run_120_spec_129 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.PI ->
            let _startpos_14 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_15 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_15, _startpos_14) in
            let _v = _menhir_action_084 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState129 _tok
        | Elpi_lexer_config.Tokens.NIL ->
            let _startpos_17 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_18 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_18, _startpos_17) in
            let _v = _menhir_action_089 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState129 _tok
        | Elpi_lexer_config.Tokens.NAME ->
            let _startpos_20 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_21 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_21, _startpos_20) in
            let _v = _menhir_action_077 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState129 _tok
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState129
        | Elpi_lexer_config.Tokens.LCURLY ->
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState129
        | Elpi_lexer_config.Tokens.LBRACKET ->
            _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState129
        | Elpi_lexer_config.Tokens.IO _v_23 ->
            let _startpos_24 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_25 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_25, _startpos_24, _v_23) in
            let _v = _menhir_action_082 c in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState129 _tok
        | Elpi_lexer_config.Tokens.INTEGER _v_27 ->
            let _startpos_28 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_29 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_29, _startpos_28, _v_27) in
            let _v = _menhir_action_066 x in
            _menhir_run_120_spec_129 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.INDEX ->
            let _startpos_31 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_32 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_32, _startpos_31) in
            let _v = _menhir_action_081 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState129 _tok
        | Elpi_lexer_config.Tokens.IF ->
            let _startpos_34 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_35 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_35, _startpos_34) in
            let _v = _menhir_action_076 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState129 _tok
        | Elpi_lexer_config.Tokens.FRESHUV ->
            let _startpos_37 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_38 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_38, _startpos_37) in
            let _v = _menhir_action_086 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState129 _tok
        | Elpi_lexer_config.Tokens.FLOAT _v_40 ->
            let _startpos_41 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_42 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_42, _startpos_41, _v_40) in
            let _v = _menhir_action_067 x in
            _menhir_run_120_spec_129 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_TILDE _v_44 ->
            _menhir_run_028 _menhir_stack _menhir_lexbuf _menhir_lexer _v_44 MenhirState129
        | Elpi_lexer_config.Tokens.CUT ->
            let _startpos_45 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_46 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_46, _startpos_45) in
            let _v = _menhir_action_083 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState129 _tok
        | Elpi_lexer_config.Tokens.CONSTANT _v_48 ->
            let _startpos_49 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_50 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_50, _startpos_49, _v_48) in
            let _v = _menhir_action_075 c in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState129 _tok
        | Elpi_lexer_config.Tokens.BEFORE ->
            let _startpos_52 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_53 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_53, _startpos_52) in
            let _v = _menhir_action_078 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState129 _tok
        | Elpi_lexer_config.Tokens.AFTER ->
            let _startpos_55 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_56 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_56, _startpos_55) in
            let _v = _menhir_action_079 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState129 _tok
        | _ ->
            _eRR 129
    
    and _menhir_run_120_spec_129 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term_noconj _menhir_cell0_FAMILY_OR -> _ -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_320 t in
        _menhir_run_130 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v MenhirState129 _tok
    
    and _menhir_run_130 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_term_noconj _menhir_cell0_FAMILY_OR as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_0 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_127 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_1 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_034 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_2 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_129 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_3 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_131 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.CONS | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.DIV | Elpi_lexer_config.Tokens.EQ | Elpi_lexer_config.Tokens.EQ2 | Elpi_lexer_config.Tokens.FAMILY_BTICK _ | Elpi_lexer_config.Tokens.FAMILY_EQ _ | Elpi_lexer_config.Tokens.FAMILY_EXP _ | Elpi_lexer_config.Tokens.FAMILY_GT _ | Elpi_lexer_config.Tokens.FAMILY_LT _ | Elpi_lexer_config.Tokens.FAMILY_MINUS _ | Elpi_lexer_config.Tokens.FAMILY_PLUS _ | Elpi_lexer_config.Tokens.FAMILY_TICK _ | Elpi_lexer_config.Tokens.FAMILY_TIMES _ | Elpi_lexer_config.Tokens.IS | Elpi_lexer_config.Tokens.MINUS | Elpi_lexer_config.Tokens.MINUSi | Elpi_lexer_config.Tokens.MINUSr | Elpi_lexer_config.Tokens.MINUSs | Elpi_lexer_config.Tokens.MOD | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.PIPE | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.RBRACKET | Elpi_lexer_config.Tokens.SLASH | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_FAMILY_OR (_menhir_stack, s, _, _) = _menhir_stack in
            let MenhirCell1_term_noconj (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_259 _endpos_r_ _startpos_l_ l r s in
            _menhir_goto_open_term_noconj _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 130
    
    and _menhir_run_131 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term_noconj -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell0_FAMILY_AND (_menhir_stack, _v, _startpos, _endpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v_0 ->
            let _startpos_1 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_2 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_2, _startpos_1, _v_0) in
            let _v = _menhir_action_068 x in
            _menhir_run_120_spec_131 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.SIGMA ->
            let _startpos_4 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_5 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_5, _startpos_4) in
            let _v = _menhir_action_085 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState131 _tok
        | Elpi_lexer_config.Tokens.REPLACE ->
            let _startpos_7 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_8 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_8, _startpos_7) in
            let _v = _menhir_action_080 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState131 _tok
        | Elpi_lexer_config.Tokens.QUOTED _v_10 ->
            let _startpos_11 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_12 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_12, _startpos_11, _v_10) in
            let _v = _menhir_action_069 _endpos_x_ _startpos_x_ x in
            _menhir_run_120_spec_131 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.PI ->
            let _startpos_14 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_15 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_15, _startpos_14) in
            let _v = _menhir_action_084 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState131 _tok
        | Elpi_lexer_config.Tokens.NIL ->
            let _startpos_17 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_18 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_18, _startpos_17) in
            let _v = _menhir_action_089 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState131 _tok
        | Elpi_lexer_config.Tokens.NAME ->
            let _startpos_20 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_21 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_21, _startpos_20) in
            let _v = _menhir_action_077 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState131 _tok
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState131
        | Elpi_lexer_config.Tokens.LCURLY ->
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState131
        | Elpi_lexer_config.Tokens.LBRACKET ->
            _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState131
        | Elpi_lexer_config.Tokens.IO _v_23 ->
            let _startpos_24 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_25 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_25, _startpos_24, _v_23) in
            let _v = _menhir_action_082 c in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState131 _tok
        | Elpi_lexer_config.Tokens.INTEGER _v_27 ->
            let _startpos_28 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_29 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_29, _startpos_28, _v_27) in
            let _v = _menhir_action_066 x in
            _menhir_run_120_spec_131 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.INDEX ->
            let _startpos_31 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_32 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_32, _startpos_31) in
            let _v = _menhir_action_081 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState131 _tok
        | Elpi_lexer_config.Tokens.IF ->
            let _startpos_34 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_35 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_35, _startpos_34) in
            let _v = _menhir_action_076 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState131 _tok
        | Elpi_lexer_config.Tokens.FRESHUV ->
            let _startpos_37 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_38 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_38, _startpos_37) in
            let _v = _menhir_action_086 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState131 _tok
        | Elpi_lexer_config.Tokens.FLOAT _v_40 ->
            let _startpos_41 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_42 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_42, _startpos_41, _v_40) in
            let _v = _menhir_action_067 x in
            _menhir_run_120_spec_131 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_TILDE _v_44 ->
            _menhir_run_028 _menhir_stack _menhir_lexbuf _menhir_lexer _v_44 MenhirState131
        | Elpi_lexer_config.Tokens.CUT ->
            let _startpos_45 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_46 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_46, _startpos_45) in
            let _v = _menhir_action_083 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState131 _tok
        | Elpi_lexer_config.Tokens.CONSTANT _v_48 ->
            let _startpos_49 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_50 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_50, _startpos_49, _v_48) in
            let _v = _menhir_action_075 c in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState131 _tok
        | Elpi_lexer_config.Tokens.BEFORE ->
            let _startpos_52 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_53 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_53, _startpos_52) in
            let _v = _menhir_action_078 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState131 _tok
        | Elpi_lexer_config.Tokens.AFTER ->
            let _startpos_55 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_56 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_56, _startpos_55) in
            let _v = _menhir_action_079 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState131 _tok
        | _ ->
            _eRR 131
    
    and _menhir_run_120_spec_131 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term_noconj _menhir_cell0_FAMILY_AND -> _ -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_320 t in
        _menhir_run_132 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v MenhirState131 _tok
    
    and _menhir_run_132 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_term_noconj _menhir_cell0_FAMILY_AND as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_0 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_127 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_1 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_034 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_2 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_131 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.CONS | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.DIV | Elpi_lexer_config.Tokens.EQ | Elpi_lexer_config.Tokens.EQ2 | Elpi_lexer_config.Tokens.FAMILY_BTICK _ | Elpi_lexer_config.Tokens.FAMILY_EQ _ | Elpi_lexer_config.Tokens.FAMILY_EXP _ | Elpi_lexer_config.Tokens.FAMILY_GT _ | Elpi_lexer_config.Tokens.FAMILY_LT _ | Elpi_lexer_config.Tokens.FAMILY_MINUS _ | Elpi_lexer_config.Tokens.FAMILY_OR _ | Elpi_lexer_config.Tokens.FAMILY_PLUS _ | Elpi_lexer_config.Tokens.FAMILY_TICK _ | Elpi_lexer_config.Tokens.FAMILY_TIMES _ | Elpi_lexer_config.Tokens.IS | Elpi_lexer_config.Tokens.MINUS | Elpi_lexer_config.Tokens.MINUSi | Elpi_lexer_config.Tokens.MINUSr | Elpi_lexer_config.Tokens.MINUSs | Elpi_lexer_config.Tokens.MOD | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.PIPE | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.RBRACKET | Elpi_lexer_config.Tokens.SLASH | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_FAMILY_AND (_menhir_stack, s, _, _) = _menhir_stack in
            let MenhirCell1_term_noconj (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_258 _endpos_r_ _startpos_l_ l r s in
            _menhir_goto_open_term_noconj _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 132
    
    and _menhir_run_117 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.BIND ->
            let _menhir_stack = MenhirCell1_constant (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos_0 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_1 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell0_BIND (_menhir_stack, _startpos_0, _endpos_1) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Elpi_lexer_config.Tokens.STRING _v_2 ->
                let _startpos_3 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_4 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_4, _startpos_3, _v_2) in
                let _v = _menhir_action_068 x in
                _menhir_run_053_spec_118 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.SIGMA ->
                let _startpos_6 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_7 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_7, _startpos_6) in
                let _v = _menhir_action_085 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState118 _tok
            | Elpi_lexer_config.Tokens.REPLACE ->
                let _startpos_9 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_10 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_10, _startpos_9) in
                let _v = _menhir_action_080 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState118 _tok
            | Elpi_lexer_config.Tokens.QUOTED _v_12 ->
                let _startpos_13 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_14 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_14, _startpos_13, _v_12) in
                let _v = _menhir_action_069 _endpos_x_ _startpos_x_ x in
                _menhir_run_053_spec_118 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.PI ->
                let _startpos_16 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_17 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_17, _startpos_16) in
                let _v = _menhir_action_084 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState118 _tok
            | Elpi_lexer_config.Tokens.NIL ->
                let _startpos_19 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_20 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_20, _startpos_19) in
                let _v = _menhir_action_089 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState118 _tok
            | Elpi_lexer_config.Tokens.NAME ->
                let _startpos_22 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_23 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_23, _startpos_22) in
                let _v = _menhir_action_077 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState118 _tok
            | Elpi_lexer_config.Tokens.LPAREN ->
                _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState118
            | Elpi_lexer_config.Tokens.LCURLY ->
                _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState118
            | Elpi_lexer_config.Tokens.LBRACKET ->
                _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState118
            | Elpi_lexer_config.Tokens.IO _v_25 ->
                let _startpos_26 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_27 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_c_, _startpos_c_, c) = (_endpos_27, _startpos_26, _v_25) in
                let _v = _menhir_action_082 c in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState118 _tok
            | Elpi_lexer_config.Tokens.INTEGER _v_29 ->
                let _startpos_30 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_31 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_31, _startpos_30, _v_29) in
                let _v = _menhir_action_066 x in
                _menhir_run_053_spec_118 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.INDEX ->
                let _startpos_33 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_34 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_34, _startpos_33) in
                let _v = _menhir_action_081 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState118 _tok
            | Elpi_lexer_config.Tokens.IF ->
                let _startpos_36 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_37 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_37, _startpos_36) in
                let _v = _menhir_action_076 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState118 _tok
            | Elpi_lexer_config.Tokens.FRESHUV ->
                let _startpos_39 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_40 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_40, _startpos_39) in
                let _v = _menhir_action_086 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState118 _tok
            | Elpi_lexer_config.Tokens.FLOAT _v_42 ->
                let _startpos_43 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_44 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_44, _startpos_43, _v_42) in
                let _v = _menhir_action_067 x in
                _menhir_run_053_spec_118 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.FAMILY_TILDE _v_46 ->
                _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer _v_46 MenhirState118
            | Elpi_lexer_config.Tokens.CUT ->
                let _startpos_47 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_48 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_48, _startpos_47) in
                let _v = _menhir_action_083 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState118 _tok
            | Elpi_lexer_config.Tokens.CONSTANT _v_50 ->
                let _startpos_51 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_52 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_c_, _startpos_c_, c) = (_endpos_52, _startpos_51, _v_50) in
                let _v = _menhir_action_075 c in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState118 _tok
            | Elpi_lexer_config.Tokens.BEFORE ->
                let _startpos_54 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_55 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_55, _startpos_54) in
                let _v = _menhir_action_078 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState118 _tok
            | Elpi_lexer_config.Tokens.AFTER ->
                let _startpos_57 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_58 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_58, _startpos_57) in
                let _v = _menhir_action_079 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState118 _tok
            | _ ->
                _eRR 118)
        | Elpi_lexer_config.Tokens.AFTER | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.BEFORE | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.CONS | Elpi_lexer_config.Tokens.CONSTANT _ | Elpi_lexer_config.Tokens.CUT | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.DIV | Elpi_lexer_config.Tokens.EQ | Elpi_lexer_config.Tokens.EQ2 | Elpi_lexer_config.Tokens.FAMILY_AND _ | Elpi_lexer_config.Tokens.FAMILY_BTICK _ | Elpi_lexer_config.Tokens.FAMILY_EQ _ | Elpi_lexer_config.Tokens.FAMILY_EXP _ | Elpi_lexer_config.Tokens.FAMILY_GT _ | Elpi_lexer_config.Tokens.FAMILY_LT _ | Elpi_lexer_config.Tokens.FAMILY_MINUS _ | Elpi_lexer_config.Tokens.FAMILY_OR _ | Elpi_lexer_config.Tokens.FAMILY_PLUS _ | Elpi_lexer_config.Tokens.FAMILY_QMARK _ | Elpi_lexer_config.Tokens.FAMILY_SHARP _ | Elpi_lexer_config.Tokens.FAMILY_TICK _ | Elpi_lexer_config.Tokens.FAMILY_TIMES _ | Elpi_lexer_config.Tokens.FLOAT _ | Elpi_lexer_config.Tokens.FRESHUV | Elpi_lexer_config.Tokens.IF | Elpi_lexer_config.Tokens.INDEX | Elpi_lexer_config.Tokens.INTEGER _ | Elpi_lexer_config.Tokens.IO _ | Elpi_lexer_config.Tokens.IS | Elpi_lexer_config.Tokens.LBRACKET | Elpi_lexer_config.Tokens.LCURLY | Elpi_lexer_config.Tokens.LPAREN | Elpi_lexer_config.Tokens.MINUS | Elpi_lexer_config.Tokens.MINUSi | Elpi_lexer_config.Tokens.MINUSr | Elpi_lexer_config.Tokens.MINUSs | Elpi_lexer_config.Tokens.MOD | Elpi_lexer_config.Tokens.NAME | Elpi_lexer_config.Tokens.NIL | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.PI | Elpi_lexer_config.Tokens.PIPE | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.QUOTED _ | Elpi_lexer_config.Tokens.RBRACKET | Elpi_lexer_config.Tokens.REPLACE | Elpi_lexer_config.Tokens.SIGMA | Elpi_lexer_config.Tokens.SLASH | Elpi_lexer_config.Tokens.STRING _ | Elpi_lexer_config.Tokens.VDASH ->
            let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
            let _v = _menhir_action_113 t in
            _menhir_goto_head_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v _menhir_s _tok
        | _ ->
            _eRR 117
    
    and _menhir_run_053_spec_118 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_constant _menhir_cell0_BIND -> _ -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_317 t in
        _menhir_run_119 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v MenhirState118 _tok
    
    and _menhir_run_119 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_constant _menhir_cell0_BIND as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.VDASH ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_056 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.SLASH ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.QDASH ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_114 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.OR ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_072 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MOD ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_074 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSs ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_076 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSr ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_082 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSi ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_084 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_086 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.IS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_088 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FAMILY_TIMES _v_0 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_078 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_TICK _v_1 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_090 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_3 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_041 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_PLUS _v_4 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_092 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_5 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_6 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.FAMILY_LT _v_7 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_098 _menhir_stack _menhir_lexbuf _menhir_lexer _v_7
        | Elpi_lexer_config.Tokens.FAMILY_GT _v_8 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_100 _menhir_stack _menhir_lexbuf _menhir_lexer _v_8
        | Elpi_lexer_config.Tokens.FAMILY_EXP _v_9 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_094 _menhir_stack _menhir_lexbuf _menhir_lexer _v_9
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_10 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer _v_10
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_11 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer _v_11
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_12 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer _v_12
        | Elpi_lexer_config.Tokens.EQ2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_102 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.EQ ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_104 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.DIV ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_080 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.DARROW ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_106 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_096 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONJ2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_108 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONJ ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_110 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.ARROW ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_112 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.PIPE | Elpi_lexer_config.Tokens.RBRACKET ->
            let MenhirCell0_BIND (_menhir_stack, _, _) = _menhir_stack in
            let MenhirCell1_constant (_menhir_stack, _menhir_s, t, _startpos_t_, _) = _menhir_stack in
            let (_endpos_b_, b) = (_endpos, _v) in
            let _v = _menhir_action_026 b t in
            let (_endpos, _startpos) = (_endpos_b_, _startpos_t_) in
            let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
            let _v = _menhir_action_319 t in
            _menhir_goto_term_noconj _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v _menhir_s _tok
        | _ ->
            _eRR 119
    
    and _menhir_run_084 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell0_MINUSi (_menhir_stack, _startpos, _endpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v ->
            let _startpos_0 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_1 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_1, _startpos_0, _v) in
            let _v = _menhir_action_068 x in
            _menhir_run_053_spec_084 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.SIGMA ->
            let _startpos_2 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_3 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_3, _startpos_2) in
            let _v = _menhir_action_085 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState084 _tok
        | Elpi_lexer_config.Tokens.REPLACE ->
            let _startpos_4 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_5 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_5, _startpos_4) in
            let _v = _menhir_action_080 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState084 _tok
        | Elpi_lexer_config.Tokens.QUOTED _v ->
            let _startpos_6 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_7 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_7, _startpos_6, _v) in
            let _v = _menhir_action_069 _endpos_x_ _startpos_x_ x in
            _menhir_run_053_spec_084 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.PI ->
            let _startpos_8 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_9 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_9, _startpos_8) in
            let _v = _menhir_action_084 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState084 _tok
        | Elpi_lexer_config.Tokens.NIL ->
            let _startpos_10 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_11 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_11, _startpos_10) in
            let _v = _menhir_action_089 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState084 _tok
        | Elpi_lexer_config.Tokens.NAME ->
            let _startpos_12 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_13 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_13, _startpos_12) in
            let _v = _menhir_action_077 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState084 _tok
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState084
        | Elpi_lexer_config.Tokens.LCURLY ->
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState084
        | Elpi_lexer_config.Tokens.LBRACKET ->
            _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState084
        | Elpi_lexer_config.Tokens.IO _v ->
            let _startpos_14 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_15 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_15, _startpos_14, _v) in
            let _v = _menhir_action_082 c in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState084 _tok
        | Elpi_lexer_config.Tokens.INTEGER _v ->
            let _startpos_16 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_17 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_17, _startpos_16, _v) in
            let _v = _menhir_action_066 x in
            _menhir_run_053_spec_084 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.INDEX ->
            let _startpos_18 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_19 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_19, _startpos_18) in
            let _v = _menhir_action_081 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState084 _tok
        | Elpi_lexer_config.Tokens.IF ->
            let _startpos_20 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_21 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_21, _startpos_20) in
            let _v = _menhir_action_076 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState084 _tok
        | Elpi_lexer_config.Tokens.FRESHUV ->
            let _startpos_22 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_23 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_23, _startpos_22) in
            let _v = _menhir_action_086 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState084 _tok
        | Elpi_lexer_config.Tokens.FLOAT _v ->
            let _startpos_24 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_25 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_25, _startpos_24, _v) in
            let _v = _menhir_action_067 x in
            _menhir_run_053_spec_084 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_TILDE _v ->
            _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState084
        | Elpi_lexer_config.Tokens.CUT ->
            let _startpos_26 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_27 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_27, _startpos_26) in
            let _v = _menhir_action_083 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState084 _tok
        | Elpi_lexer_config.Tokens.CONSTANT _v ->
            let _startpos_28 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_29 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_29, _startpos_28, _v) in
            let _v = _menhir_action_075 c in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState084 _tok
        | Elpi_lexer_config.Tokens.BEFORE ->
            let _startpos_30 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_31 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_31, _startpos_30) in
            let _v = _menhir_action_078 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState084 _tok
        | Elpi_lexer_config.Tokens.AFTER ->
            let _startpos_32 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_33 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_33, _startpos_32) in
            let _v = _menhir_action_079 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState084 _tok
        | _ ->
            _eRR 84
    
    and _menhir_run_053_spec_084 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term _menhir_cell0_MINUSi -> _ -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_317 t in
        _menhir_run_085 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v MenhirState084 _tok
    
    and _menhir_run_085 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_term _menhir_cell0_MINUSi as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.SLASH ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MOD ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_074 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FAMILY_TIMES _v_0 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_078 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_1 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_041 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_3 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_4 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_5 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_6 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_7 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer _v_7
        | Elpi_lexer_config.Tokens.DIV ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_080 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.AS | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.CONS | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.EOF | Elpi_lexer_config.Tokens.EQ | Elpi_lexer_config.Tokens.EQ2 | Elpi_lexer_config.Tokens.FAMILY_EXP _ | Elpi_lexer_config.Tokens.FAMILY_GT _ | Elpi_lexer_config.Tokens.FAMILY_LT _ | Elpi_lexer_config.Tokens.FAMILY_PLUS _ | Elpi_lexer_config.Tokens.FAMILY_TICK _ | Elpi_lexer_config.Tokens.FULLSTOP | Elpi_lexer_config.Tokens.IFF | Elpi_lexer_config.Tokens.IS | Elpi_lexer_config.Tokens.MINUS | Elpi_lexer_config.Tokens.MINUSi | Elpi_lexer_config.Tokens.MINUSr | Elpi_lexer_config.Tokens.MINUSs | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.PIPE | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.RBRACKET | Elpi_lexer_config.Tokens.RCURLY | Elpi_lexer_config.Tokens.RPAREN | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_MINUSi (_menhir_stack, _, _) = _menhir_stack in
            let MenhirCell1_term (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_234 _endpos_r_ _startpos_l_ l r in
            _menhir_goto_open_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 85
    
    and _menhir_run_080 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell0_DIV (_menhir_stack, _startpos, _endpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v ->
            let _startpos_0 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_1 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_1, _startpos_0, _v) in
            let _v = _menhir_action_068 x in
            _menhir_run_053_spec_080 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.SIGMA ->
            let _startpos_2 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_3 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_3, _startpos_2) in
            let _v = _menhir_action_085 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState080 _tok
        | Elpi_lexer_config.Tokens.REPLACE ->
            let _startpos_4 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_5 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_5, _startpos_4) in
            let _v = _menhir_action_080 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState080 _tok
        | Elpi_lexer_config.Tokens.QUOTED _v ->
            let _startpos_6 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_7 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_7, _startpos_6, _v) in
            let _v = _menhir_action_069 _endpos_x_ _startpos_x_ x in
            _menhir_run_053_spec_080 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.PI ->
            let _startpos_8 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_9 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_9, _startpos_8) in
            let _v = _menhir_action_084 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState080 _tok
        | Elpi_lexer_config.Tokens.NIL ->
            let _startpos_10 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_11 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_11, _startpos_10) in
            let _v = _menhir_action_089 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState080 _tok
        | Elpi_lexer_config.Tokens.NAME ->
            let _startpos_12 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_13 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_13, _startpos_12) in
            let _v = _menhir_action_077 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState080 _tok
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState080
        | Elpi_lexer_config.Tokens.LCURLY ->
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState080
        | Elpi_lexer_config.Tokens.LBRACKET ->
            _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState080
        | Elpi_lexer_config.Tokens.IO _v ->
            let _startpos_14 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_15 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_15, _startpos_14, _v) in
            let _v = _menhir_action_082 c in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState080 _tok
        | Elpi_lexer_config.Tokens.INTEGER _v ->
            let _startpos_16 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_17 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_17, _startpos_16, _v) in
            let _v = _menhir_action_066 x in
            _menhir_run_053_spec_080 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.INDEX ->
            let _startpos_18 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_19 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_19, _startpos_18) in
            let _v = _menhir_action_081 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState080 _tok
        | Elpi_lexer_config.Tokens.IF ->
            let _startpos_20 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_21 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_21, _startpos_20) in
            let _v = _menhir_action_076 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState080 _tok
        | Elpi_lexer_config.Tokens.FRESHUV ->
            let _startpos_22 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_23 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_23, _startpos_22) in
            let _v = _menhir_action_086 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState080 _tok
        | Elpi_lexer_config.Tokens.FLOAT _v ->
            let _startpos_24 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_25 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_25, _startpos_24, _v) in
            let _v = _menhir_action_067 x in
            _menhir_run_053_spec_080 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_TILDE _v ->
            _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState080
        | Elpi_lexer_config.Tokens.CUT ->
            let _startpos_26 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_27 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_27, _startpos_26) in
            let _v = _menhir_action_083 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState080 _tok
        | Elpi_lexer_config.Tokens.CONSTANT _v ->
            let _startpos_28 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_29 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_29, _startpos_28, _v) in
            let _v = _menhir_action_075 c in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState080 _tok
        | Elpi_lexer_config.Tokens.BEFORE ->
            let _startpos_30 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_31 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_31, _startpos_30) in
            let _v = _menhir_action_078 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState080 _tok
        | Elpi_lexer_config.Tokens.AFTER ->
            let _startpos_32 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_33 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_33, _startpos_32) in
            let _v = _menhir_action_079 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState080 _tok
        | _ ->
            _eRR 80
    
    and _menhir_run_053_spec_080 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term _menhir_cell0_DIV -> _ -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_317 t in
        _menhir_run_081 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v MenhirState080 _tok
    
    and _menhir_run_081 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_term _menhir_cell0_DIV as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_0 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_1 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_041 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_3 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_4 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_5 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_6 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.AS | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.CONS | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.DIV | Elpi_lexer_config.Tokens.EOF | Elpi_lexer_config.Tokens.EQ | Elpi_lexer_config.Tokens.EQ2 | Elpi_lexer_config.Tokens.FAMILY_EXP _ | Elpi_lexer_config.Tokens.FAMILY_GT _ | Elpi_lexer_config.Tokens.FAMILY_LT _ | Elpi_lexer_config.Tokens.FAMILY_PLUS _ | Elpi_lexer_config.Tokens.FAMILY_TICK _ | Elpi_lexer_config.Tokens.FAMILY_TIMES _ | Elpi_lexer_config.Tokens.FULLSTOP | Elpi_lexer_config.Tokens.IFF | Elpi_lexer_config.Tokens.IS | Elpi_lexer_config.Tokens.MINUS | Elpi_lexer_config.Tokens.MINUSi | Elpi_lexer_config.Tokens.MINUSr | Elpi_lexer_config.Tokens.MINUSs | Elpi_lexer_config.Tokens.MOD | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.PIPE | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.RBRACKET | Elpi_lexer_config.Tokens.RCURLY | Elpi_lexer_config.Tokens.RPAREN | Elpi_lexer_config.Tokens.SLASH | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_DIV (_menhir_stack, _, _) = _menhir_stack in
            let MenhirCell1_term (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_240 _endpos_r_ _startpos_l_ l r in
            _menhir_goto_open_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 81
    
    and _menhir_run_039 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell1_FAMILY_TILDE (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v_0 ->
            let _startpos_1 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_2 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_2, _startpos_1, _v_0) in
            let _v = _menhir_action_068 x in
            _menhir_run_053_spec_039 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.SIGMA ->
            let _startpos_4 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_5 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_5, _startpos_4) in
            let _v = _menhir_action_085 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState039 _tok
        | Elpi_lexer_config.Tokens.REPLACE ->
            let _startpos_7 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_8 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_8, _startpos_7) in
            let _v = _menhir_action_080 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState039 _tok
        | Elpi_lexer_config.Tokens.QUOTED _v_10 ->
            let _startpos_11 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_12 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_12, _startpos_11, _v_10) in
            let _v = _menhir_action_069 _endpos_x_ _startpos_x_ x in
            _menhir_run_053_spec_039 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.PI ->
            let _startpos_14 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_15 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_15, _startpos_14) in
            let _v = _menhir_action_084 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState039 _tok
        | Elpi_lexer_config.Tokens.NIL ->
            let _startpos_17 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_18 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_18, _startpos_17) in
            let _v = _menhir_action_089 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState039 _tok
        | Elpi_lexer_config.Tokens.NAME ->
            let _startpos_20 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_21 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_21, _startpos_20) in
            let _v = _menhir_action_077 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState039 _tok
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState039
        | Elpi_lexer_config.Tokens.LCURLY ->
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState039
        | Elpi_lexer_config.Tokens.LBRACKET ->
            _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState039
        | Elpi_lexer_config.Tokens.IO _v_23 ->
            let _startpos_24 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_25 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_25, _startpos_24, _v_23) in
            let _v = _menhir_action_082 c in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState039 _tok
        | Elpi_lexer_config.Tokens.INTEGER _v_27 ->
            let _startpos_28 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_29 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_29, _startpos_28, _v_27) in
            let _v = _menhir_action_066 x in
            _menhir_run_053_spec_039 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.INDEX ->
            let _startpos_31 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_32 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_32, _startpos_31) in
            let _v = _menhir_action_081 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState039 _tok
        | Elpi_lexer_config.Tokens.IF ->
            let _startpos_34 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_35 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_35, _startpos_34) in
            let _v = _menhir_action_076 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState039 _tok
        | Elpi_lexer_config.Tokens.FRESHUV ->
            let _startpos_37 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_38 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_38, _startpos_37) in
            let _v = _menhir_action_086 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState039 _tok
        | Elpi_lexer_config.Tokens.FLOAT _v_40 ->
            let _startpos_41 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_42 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_42, _startpos_41, _v_40) in
            let _v = _menhir_action_067 x in
            _menhir_run_053_spec_039 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_TILDE _v_44 ->
            _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer _v_44 MenhirState039
        | Elpi_lexer_config.Tokens.CUT ->
            let _startpos_45 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_46 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_46, _startpos_45) in
            let _v = _menhir_action_083 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState039 _tok
        | Elpi_lexer_config.Tokens.CONSTANT _v_48 ->
            let _startpos_49 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_50 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_50, _startpos_49, _v_48) in
            let _v = _menhir_action_075 c in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState039 _tok
        | Elpi_lexer_config.Tokens.BEFORE ->
            let _startpos_52 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_53 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_53, _startpos_52) in
            let _v = _menhir_action_078 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState039 _tok
        | Elpi_lexer_config.Tokens.AFTER ->
            let _startpos_55 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_56 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_56, _startpos_55) in
            let _v = _menhir_action_079 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState039 _tok
        | _ ->
            _eRR 39
    
    and _menhir_run_053_spec_039 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_FAMILY_TILDE -> _ -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_317 t in
        _menhir_run_040 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v MenhirState039 _tok
    
    and _menhir_run_040 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_FAMILY_TILDE as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_0 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_041 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.AS | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.CONS | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.DIV | Elpi_lexer_config.Tokens.EOF | Elpi_lexer_config.Tokens.EQ | Elpi_lexer_config.Tokens.EQ2 | Elpi_lexer_config.Tokens.FAMILY_AND _ | Elpi_lexer_config.Tokens.FAMILY_BTICK _ | Elpi_lexer_config.Tokens.FAMILY_EQ _ | Elpi_lexer_config.Tokens.FAMILY_EXP _ | Elpi_lexer_config.Tokens.FAMILY_GT _ | Elpi_lexer_config.Tokens.FAMILY_LT _ | Elpi_lexer_config.Tokens.FAMILY_MINUS _ | Elpi_lexer_config.Tokens.FAMILY_OR _ | Elpi_lexer_config.Tokens.FAMILY_PLUS _ | Elpi_lexer_config.Tokens.FAMILY_SHARP _ | Elpi_lexer_config.Tokens.FAMILY_TICK _ | Elpi_lexer_config.Tokens.FAMILY_TIMES _ | Elpi_lexer_config.Tokens.FULLSTOP | Elpi_lexer_config.Tokens.IFF | Elpi_lexer_config.Tokens.IS | Elpi_lexer_config.Tokens.MINUS | Elpi_lexer_config.Tokens.MINUSi | Elpi_lexer_config.Tokens.MINUSr | Elpi_lexer_config.Tokens.MINUSs | Elpi_lexer_config.Tokens.MOD | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.PIPE | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.RBRACKET | Elpi_lexer_config.Tokens.RCURLY | Elpi_lexer_config.Tokens.RPAREN | Elpi_lexer_config.Tokens.SLASH | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell1_FAMILY_TILDE (_menhir_stack, _menhir_s, s, _startpos_s_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_248 r s in
            _menhir_goto_open_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_s_ _v _menhir_s _tok
        | _ ->
            _eRR 40
    
    and _menhir_run_086 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell0_MINUS (_menhir_stack, _startpos, _endpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v ->
            let _startpos_0 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_1 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_1, _startpos_0, _v) in
            let _v = _menhir_action_068 x in
            _menhir_run_053_spec_086 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.SIGMA ->
            let _startpos_2 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_3 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_3, _startpos_2) in
            let _v = _menhir_action_085 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState086 _tok
        | Elpi_lexer_config.Tokens.REPLACE ->
            let _startpos_4 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_5 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_5, _startpos_4) in
            let _v = _menhir_action_080 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState086 _tok
        | Elpi_lexer_config.Tokens.QUOTED _v ->
            let _startpos_6 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_7 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_7, _startpos_6, _v) in
            let _v = _menhir_action_069 _endpos_x_ _startpos_x_ x in
            _menhir_run_053_spec_086 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.PI ->
            let _startpos_8 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_9 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_9, _startpos_8) in
            let _v = _menhir_action_084 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState086 _tok
        | Elpi_lexer_config.Tokens.NIL ->
            let _startpos_10 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_11 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_11, _startpos_10) in
            let _v = _menhir_action_089 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState086 _tok
        | Elpi_lexer_config.Tokens.NAME ->
            let _startpos_12 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_13 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_13, _startpos_12) in
            let _v = _menhir_action_077 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState086 _tok
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState086
        | Elpi_lexer_config.Tokens.LCURLY ->
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState086
        | Elpi_lexer_config.Tokens.LBRACKET ->
            _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState086
        | Elpi_lexer_config.Tokens.IO _v ->
            let _startpos_14 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_15 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_15, _startpos_14, _v) in
            let _v = _menhir_action_082 c in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState086 _tok
        | Elpi_lexer_config.Tokens.INTEGER _v ->
            let _startpos_16 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_17 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_17, _startpos_16, _v) in
            let _v = _menhir_action_066 x in
            _menhir_run_053_spec_086 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.INDEX ->
            let _startpos_18 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_19 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_19, _startpos_18) in
            let _v = _menhir_action_081 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState086 _tok
        | Elpi_lexer_config.Tokens.IF ->
            let _startpos_20 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_21 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_21, _startpos_20) in
            let _v = _menhir_action_076 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState086 _tok
        | Elpi_lexer_config.Tokens.FRESHUV ->
            let _startpos_22 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_23 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_23, _startpos_22) in
            let _v = _menhir_action_086 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState086 _tok
        | Elpi_lexer_config.Tokens.FLOAT _v ->
            let _startpos_24 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_25 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_25, _startpos_24, _v) in
            let _v = _menhir_action_067 x in
            _menhir_run_053_spec_086 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_TILDE _v ->
            _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState086
        | Elpi_lexer_config.Tokens.CUT ->
            let _startpos_26 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_27 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_27, _startpos_26) in
            let _v = _menhir_action_083 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState086 _tok
        | Elpi_lexer_config.Tokens.CONSTANT _v ->
            let _startpos_28 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_29 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_29, _startpos_28, _v) in
            let _v = _menhir_action_075 c in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState086 _tok
        | Elpi_lexer_config.Tokens.BEFORE ->
            let _startpos_30 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_31 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_31, _startpos_30) in
            let _v = _menhir_action_078 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState086 _tok
        | Elpi_lexer_config.Tokens.AFTER ->
            let _startpos_32 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_33 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_33, _startpos_32) in
            let _v = _menhir_action_079 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState086 _tok
        | _ ->
            _eRR 86
    
    and _menhir_run_053_spec_086 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term _menhir_cell0_MINUS -> _ -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_317 t in
        _menhir_run_087 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v MenhirState086 _tok
    
    and _menhir_run_087 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_term _menhir_cell0_MINUS as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.SLASH ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MOD ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_074 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FAMILY_TIMES _v_0 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_078 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_1 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_041 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_3 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_4 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_5 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_6 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_7 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer _v_7
        | Elpi_lexer_config.Tokens.DIV ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_080 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.AS | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.CONS | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.EOF | Elpi_lexer_config.Tokens.EQ | Elpi_lexer_config.Tokens.EQ2 | Elpi_lexer_config.Tokens.FAMILY_EXP _ | Elpi_lexer_config.Tokens.FAMILY_GT _ | Elpi_lexer_config.Tokens.FAMILY_LT _ | Elpi_lexer_config.Tokens.FAMILY_PLUS _ | Elpi_lexer_config.Tokens.FAMILY_TICK _ | Elpi_lexer_config.Tokens.FULLSTOP | Elpi_lexer_config.Tokens.IFF | Elpi_lexer_config.Tokens.IS | Elpi_lexer_config.Tokens.MINUS | Elpi_lexer_config.Tokens.MINUSi | Elpi_lexer_config.Tokens.MINUSr | Elpi_lexer_config.Tokens.MINUSs | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.PIPE | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.RBRACKET | Elpi_lexer_config.Tokens.RCURLY | Elpi_lexer_config.Tokens.RPAREN | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_MINUS (_menhir_stack, _, _) = _menhir_stack in
            let MenhirCell1_term (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_232 _endpos_r_ _startpos_l_ l r in
            _menhir_goto_open_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 87
    
    and _menhir_run_088 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell0_IS (_menhir_stack, _startpos, _endpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v ->
            let _startpos_0 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_1 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_1, _startpos_0, _v) in
            let _v = _menhir_action_068 x in
            _menhir_run_053_spec_088 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.SIGMA ->
            let _startpos_2 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_3 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_3, _startpos_2) in
            let _v = _menhir_action_085 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState088 _tok
        | Elpi_lexer_config.Tokens.REPLACE ->
            let _startpos_4 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_5 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_5, _startpos_4) in
            let _v = _menhir_action_080 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState088 _tok
        | Elpi_lexer_config.Tokens.QUOTED _v ->
            let _startpos_6 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_7 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_7, _startpos_6, _v) in
            let _v = _menhir_action_069 _endpos_x_ _startpos_x_ x in
            _menhir_run_053_spec_088 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.PI ->
            let _startpos_8 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_9 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_9, _startpos_8) in
            let _v = _menhir_action_084 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState088 _tok
        | Elpi_lexer_config.Tokens.NIL ->
            let _startpos_10 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_11 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_11, _startpos_10) in
            let _v = _menhir_action_089 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState088 _tok
        | Elpi_lexer_config.Tokens.NAME ->
            let _startpos_12 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_13 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_13, _startpos_12) in
            let _v = _menhir_action_077 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState088 _tok
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState088
        | Elpi_lexer_config.Tokens.LCURLY ->
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState088
        | Elpi_lexer_config.Tokens.LBRACKET ->
            _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState088
        | Elpi_lexer_config.Tokens.IO _v ->
            let _startpos_14 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_15 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_15, _startpos_14, _v) in
            let _v = _menhir_action_082 c in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState088 _tok
        | Elpi_lexer_config.Tokens.INTEGER _v ->
            let _startpos_16 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_17 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_17, _startpos_16, _v) in
            let _v = _menhir_action_066 x in
            _menhir_run_053_spec_088 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.INDEX ->
            let _startpos_18 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_19 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_19, _startpos_18) in
            let _v = _menhir_action_081 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState088 _tok
        | Elpi_lexer_config.Tokens.IF ->
            let _startpos_20 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_21 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_21, _startpos_20) in
            let _v = _menhir_action_076 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState088 _tok
        | Elpi_lexer_config.Tokens.FRESHUV ->
            let _startpos_22 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_23 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_23, _startpos_22) in
            let _v = _menhir_action_086 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState088 _tok
        | Elpi_lexer_config.Tokens.FLOAT _v ->
            let _startpos_24 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_25 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_25, _startpos_24, _v) in
            let _v = _menhir_action_067 x in
            _menhir_run_053_spec_088 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_TILDE _v ->
            _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState088
        | Elpi_lexer_config.Tokens.CUT ->
            let _startpos_26 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_27 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_27, _startpos_26) in
            let _v = _menhir_action_083 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState088 _tok
        | Elpi_lexer_config.Tokens.CONSTANT _v ->
            let _startpos_28 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_29 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_29, _startpos_28, _v) in
            let _v = _menhir_action_075 c in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState088 _tok
        | Elpi_lexer_config.Tokens.BEFORE ->
            let _startpos_30 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_31 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_31, _startpos_30) in
            let _v = _menhir_action_078 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState088 _tok
        | Elpi_lexer_config.Tokens.AFTER ->
            let _startpos_32 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_33 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_33, _startpos_32) in
            let _v = _menhir_action_079 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState088 _tok
        | _ ->
            _eRR 88
    
    and _menhir_run_053_spec_088 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term _menhir_cell0_IS -> _ -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_317 t in
        _menhir_run_089 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v MenhirState088 _tok
    
    and _menhir_run_089 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_term _menhir_cell0_IS as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.SLASH ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MOD ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_074 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSs ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_076 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSr ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_082 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSi ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_084 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_086 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FAMILY_TIMES _v_0 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_078 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_TICK _v_1 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_090 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_3 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_041 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_PLUS _v_4 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_092 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_5 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_6 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.FAMILY_EXP _v_7 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_094 _menhir_stack _menhir_lexbuf _menhir_lexer _v_7
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_8 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer _v_8
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_9 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer _v_9
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_10 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer _v_10
        | Elpi_lexer_config.Tokens.DIV ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_080 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_096 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.AS | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.EOF | Elpi_lexer_config.Tokens.FULLSTOP | Elpi_lexer_config.Tokens.IFF | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.PIPE | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.RBRACKET | Elpi_lexer_config.Tokens.RCURLY | Elpi_lexer_config.Tokens.RPAREN | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_IS (_menhir_stack, _, _) = _menhir_stack in
            let MenhirCell1_term (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_238 _endpos_r_ _startpos_l_ l r in
            _menhir_goto_open_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 89
    
    and _menhir_run_090 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell0_FAMILY_TICK (_menhir_stack, _v, _startpos, _endpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v_0 ->
            let _startpos_1 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_2 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_2, _startpos_1, _v_0) in
            let _v = _menhir_action_068 x in
            _menhir_run_053_spec_090 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.SIGMA ->
            let _startpos_4 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_5 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_5, _startpos_4) in
            let _v = _menhir_action_085 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState090 _tok
        | Elpi_lexer_config.Tokens.REPLACE ->
            let _startpos_7 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_8 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_8, _startpos_7) in
            let _v = _menhir_action_080 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState090 _tok
        | Elpi_lexer_config.Tokens.QUOTED _v_10 ->
            let _startpos_11 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_12 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_12, _startpos_11, _v_10) in
            let _v = _menhir_action_069 _endpos_x_ _startpos_x_ x in
            _menhir_run_053_spec_090 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.PI ->
            let _startpos_14 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_15 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_15, _startpos_14) in
            let _v = _menhir_action_084 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState090 _tok
        | Elpi_lexer_config.Tokens.NIL ->
            let _startpos_17 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_18 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_18, _startpos_17) in
            let _v = _menhir_action_089 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState090 _tok
        | Elpi_lexer_config.Tokens.NAME ->
            let _startpos_20 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_21 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_21, _startpos_20) in
            let _v = _menhir_action_077 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState090 _tok
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState090
        | Elpi_lexer_config.Tokens.LCURLY ->
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState090
        | Elpi_lexer_config.Tokens.LBRACKET ->
            _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState090
        | Elpi_lexer_config.Tokens.IO _v_23 ->
            let _startpos_24 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_25 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_25, _startpos_24, _v_23) in
            let _v = _menhir_action_082 c in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState090 _tok
        | Elpi_lexer_config.Tokens.INTEGER _v_27 ->
            let _startpos_28 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_29 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_29, _startpos_28, _v_27) in
            let _v = _menhir_action_066 x in
            _menhir_run_053_spec_090 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.INDEX ->
            let _startpos_31 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_32 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_32, _startpos_31) in
            let _v = _menhir_action_081 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState090 _tok
        | Elpi_lexer_config.Tokens.IF ->
            let _startpos_34 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_35 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_35, _startpos_34) in
            let _v = _menhir_action_076 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState090 _tok
        | Elpi_lexer_config.Tokens.FRESHUV ->
            let _startpos_37 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_38 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_38, _startpos_37) in
            let _v = _menhir_action_086 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState090 _tok
        | Elpi_lexer_config.Tokens.FLOAT _v_40 ->
            let _startpos_41 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_42 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_42, _startpos_41, _v_40) in
            let _v = _menhir_action_067 x in
            _menhir_run_053_spec_090 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_TILDE _v_44 ->
            _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer _v_44 MenhirState090
        | Elpi_lexer_config.Tokens.CUT ->
            let _startpos_45 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_46 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_46, _startpos_45) in
            let _v = _menhir_action_083 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState090 _tok
        | Elpi_lexer_config.Tokens.CONSTANT _v_48 ->
            let _startpos_49 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_50 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_50, _startpos_49, _v_48) in
            let _v = _menhir_action_075 c in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState090 _tok
        | Elpi_lexer_config.Tokens.BEFORE ->
            let _startpos_52 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_53 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_53, _startpos_52) in
            let _v = _menhir_action_078 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState090 _tok
        | Elpi_lexer_config.Tokens.AFTER ->
            let _startpos_55 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_56 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_56, _startpos_55) in
            let _v = _menhir_action_079 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState090 _tok
        | _ ->
            _eRR 90
    
    and _menhir_run_053_spec_090 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term _menhir_cell0_FAMILY_TICK -> _ -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_317 t in
        _menhir_run_091 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v MenhirState090 _tok
    
    and _menhir_run_091 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_term _menhir_cell0_FAMILY_TICK as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.SLASH ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MOD ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_074 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSs ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_076 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSr ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_082 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSi ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_084 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_086 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FAMILY_TIMES _v_0 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_078 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_1 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_041 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_PLUS _v_3 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_092 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_4 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_5 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_EXP _v_6 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_094 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_7 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer _v_7
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_8 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer _v_8
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_9 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer _v_9
        | Elpi_lexer_config.Tokens.DIV ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_080 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.AS | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.CONS | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.EOF | Elpi_lexer_config.Tokens.EQ | Elpi_lexer_config.Tokens.EQ2 | Elpi_lexer_config.Tokens.FAMILY_GT _ | Elpi_lexer_config.Tokens.FAMILY_LT _ | Elpi_lexer_config.Tokens.FULLSTOP | Elpi_lexer_config.Tokens.IFF | Elpi_lexer_config.Tokens.IS | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.PIPE | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.RBRACKET | Elpi_lexer_config.Tokens.RCURLY | Elpi_lexer_config.Tokens.RPAREN | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_FAMILY_TICK (_menhir_stack, s, _, _) = _menhir_stack in
            let MenhirCell1_term (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_229 _endpos_r_ _startpos_l_ l r s in
            _menhir_goto_open_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 91
    
    and _menhir_run_092 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell0_FAMILY_PLUS (_menhir_stack, _v, _startpos, _endpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v_0 ->
            let _startpos_1 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_2 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_2, _startpos_1, _v_0) in
            let _v = _menhir_action_068 x in
            _menhir_run_053_spec_092 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.SIGMA ->
            let _startpos_4 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_5 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_5, _startpos_4) in
            let _v = _menhir_action_085 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState092 _tok
        | Elpi_lexer_config.Tokens.REPLACE ->
            let _startpos_7 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_8 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_8, _startpos_7) in
            let _v = _menhir_action_080 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState092 _tok
        | Elpi_lexer_config.Tokens.QUOTED _v_10 ->
            let _startpos_11 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_12 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_12, _startpos_11, _v_10) in
            let _v = _menhir_action_069 _endpos_x_ _startpos_x_ x in
            _menhir_run_053_spec_092 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.PI ->
            let _startpos_14 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_15 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_15, _startpos_14) in
            let _v = _menhir_action_084 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState092 _tok
        | Elpi_lexer_config.Tokens.NIL ->
            let _startpos_17 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_18 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_18, _startpos_17) in
            let _v = _menhir_action_089 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState092 _tok
        | Elpi_lexer_config.Tokens.NAME ->
            let _startpos_20 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_21 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_21, _startpos_20) in
            let _v = _menhir_action_077 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState092 _tok
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState092
        | Elpi_lexer_config.Tokens.LCURLY ->
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState092
        | Elpi_lexer_config.Tokens.LBRACKET ->
            _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState092
        | Elpi_lexer_config.Tokens.IO _v_23 ->
            let _startpos_24 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_25 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_25, _startpos_24, _v_23) in
            let _v = _menhir_action_082 c in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState092 _tok
        | Elpi_lexer_config.Tokens.INTEGER _v_27 ->
            let _startpos_28 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_29 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_29, _startpos_28, _v_27) in
            let _v = _menhir_action_066 x in
            _menhir_run_053_spec_092 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.INDEX ->
            let _startpos_31 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_32 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_32, _startpos_31) in
            let _v = _menhir_action_081 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState092 _tok
        | Elpi_lexer_config.Tokens.IF ->
            let _startpos_34 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_35 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_35, _startpos_34) in
            let _v = _menhir_action_076 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState092 _tok
        | Elpi_lexer_config.Tokens.FRESHUV ->
            let _startpos_37 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_38 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_38, _startpos_37) in
            let _v = _menhir_action_086 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState092 _tok
        | Elpi_lexer_config.Tokens.FLOAT _v_40 ->
            let _startpos_41 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_42 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_42, _startpos_41, _v_40) in
            let _v = _menhir_action_067 x in
            _menhir_run_053_spec_092 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_TILDE _v_44 ->
            _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer _v_44 MenhirState092
        | Elpi_lexer_config.Tokens.CUT ->
            let _startpos_45 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_46 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_46, _startpos_45) in
            let _v = _menhir_action_083 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState092 _tok
        | Elpi_lexer_config.Tokens.CONSTANT _v_48 ->
            let _startpos_49 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_50 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_50, _startpos_49, _v_48) in
            let _v = _menhir_action_075 c in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState092 _tok
        | Elpi_lexer_config.Tokens.BEFORE ->
            let _startpos_52 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_53 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_53, _startpos_52) in
            let _v = _menhir_action_078 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState092 _tok
        | Elpi_lexer_config.Tokens.AFTER ->
            let _startpos_55 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_56 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_56, _startpos_55) in
            let _v = _menhir_action_079 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState092 _tok
        | _ ->
            _eRR 92
    
    and _menhir_run_053_spec_092 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term _menhir_cell0_FAMILY_PLUS -> _ -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_317 t in
        _menhir_run_093 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v MenhirState092 _tok
    
    and _menhir_run_093 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_term _menhir_cell0_FAMILY_PLUS as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.SLASH ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MOD ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_074 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FAMILY_TIMES _v_0 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_078 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_1 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_041 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_3 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_4 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_5 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_6 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_7 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer _v_7
        | Elpi_lexer_config.Tokens.DIV ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_080 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.AS | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.CONS | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.EOF | Elpi_lexer_config.Tokens.EQ | Elpi_lexer_config.Tokens.EQ2 | Elpi_lexer_config.Tokens.FAMILY_EXP _ | Elpi_lexer_config.Tokens.FAMILY_GT _ | Elpi_lexer_config.Tokens.FAMILY_LT _ | Elpi_lexer_config.Tokens.FAMILY_PLUS _ | Elpi_lexer_config.Tokens.FAMILY_TICK _ | Elpi_lexer_config.Tokens.FULLSTOP | Elpi_lexer_config.Tokens.IFF | Elpi_lexer_config.Tokens.IS | Elpi_lexer_config.Tokens.MINUS | Elpi_lexer_config.Tokens.MINUSi | Elpi_lexer_config.Tokens.MINUSr | Elpi_lexer_config.Tokens.MINUSs | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.PIPE | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.RBRACKET | Elpi_lexer_config.Tokens.RCURLY | Elpi_lexer_config.Tokens.RPAREN | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_FAMILY_PLUS (_menhir_stack, s, _, _) = _menhir_stack in
            let MenhirCell1_term (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_218 _endpos_r_ _startpos_l_ l r s in
            _menhir_goto_open_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 93
    
    and _menhir_run_094 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell0_FAMILY_EXP (_menhir_stack, _v, _startpos, _endpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v_0 ->
            let _startpos_1 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_2 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_2, _startpos_1, _v_0) in
            let _v = _menhir_action_068 x in
            _menhir_run_053_spec_094 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.SIGMA ->
            let _startpos_4 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_5 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_5, _startpos_4) in
            let _v = _menhir_action_085 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState094 _tok
        | Elpi_lexer_config.Tokens.REPLACE ->
            let _startpos_7 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_8 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_8, _startpos_7) in
            let _v = _menhir_action_080 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState094 _tok
        | Elpi_lexer_config.Tokens.QUOTED _v_10 ->
            let _startpos_11 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_12 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_12, _startpos_11, _v_10) in
            let _v = _menhir_action_069 _endpos_x_ _startpos_x_ x in
            _menhir_run_053_spec_094 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.PI ->
            let _startpos_14 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_15 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_15, _startpos_14) in
            let _v = _menhir_action_084 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState094 _tok
        | Elpi_lexer_config.Tokens.NIL ->
            let _startpos_17 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_18 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_18, _startpos_17) in
            let _v = _menhir_action_089 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState094 _tok
        | Elpi_lexer_config.Tokens.NAME ->
            let _startpos_20 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_21 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_21, _startpos_20) in
            let _v = _menhir_action_077 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState094 _tok
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState094
        | Elpi_lexer_config.Tokens.LCURLY ->
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState094
        | Elpi_lexer_config.Tokens.LBRACKET ->
            _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState094
        | Elpi_lexer_config.Tokens.IO _v_23 ->
            let _startpos_24 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_25 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_25, _startpos_24, _v_23) in
            let _v = _menhir_action_082 c in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState094 _tok
        | Elpi_lexer_config.Tokens.INTEGER _v_27 ->
            let _startpos_28 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_29 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_29, _startpos_28, _v_27) in
            let _v = _menhir_action_066 x in
            _menhir_run_053_spec_094 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.INDEX ->
            let _startpos_31 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_32 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_32, _startpos_31) in
            let _v = _menhir_action_081 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState094 _tok
        | Elpi_lexer_config.Tokens.IF ->
            let _startpos_34 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_35 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_35, _startpos_34) in
            let _v = _menhir_action_076 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState094 _tok
        | Elpi_lexer_config.Tokens.FRESHUV ->
            let _startpos_37 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_38 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_38, _startpos_37) in
            let _v = _menhir_action_086 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState094 _tok
        | Elpi_lexer_config.Tokens.FLOAT _v_40 ->
            let _startpos_41 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_42 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_42, _startpos_41, _v_40) in
            let _v = _menhir_action_067 x in
            _menhir_run_053_spec_094 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_TILDE _v_44 ->
            _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer _v_44 MenhirState094
        | Elpi_lexer_config.Tokens.CUT ->
            let _startpos_45 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_46 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_46, _startpos_45) in
            let _v = _menhir_action_083 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState094 _tok
        | Elpi_lexer_config.Tokens.CONSTANT _v_48 ->
            let _startpos_49 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_50 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_50, _startpos_49, _v_48) in
            let _v = _menhir_action_075 c in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState094 _tok
        | Elpi_lexer_config.Tokens.BEFORE ->
            let _startpos_52 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_53 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_53, _startpos_52) in
            let _v = _menhir_action_078 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState094 _tok
        | Elpi_lexer_config.Tokens.AFTER ->
            let _startpos_55 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_56 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_56, _startpos_55) in
            let _v = _menhir_action_079 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState094 _tok
        | _ ->
            _eRR 94
    
    and _menhir_run_053_spec_094 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term _menhir_cell0_FAMILY_EXP -> _ -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_317 t in
        _menhir_run_095 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v MenhirState094 _tok
    
    and _menhir_run_095 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_term _menhir_cell0_FAMILY_EXP as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.SLASH ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MOD ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_074 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FAMILY_TIMES _v_0 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_078 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_1 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_041 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_3 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_4 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_5 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_6 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_7 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer _v_7
        | Elpi_lexer_config.Tokens.DIV ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_080 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.AS | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.CONS | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.EOF | Elpi_lexer_config.Tokens.EQ | Elpi_lexer_config.Tokens.EQ2 | Elpi_lexer_config.Tokens.FAMILY_EXP _ | Elpi_lexer_config.Tokens.FAMILY_GT _ | Elpi_lexer_config.Tokens.FAMILY_LT _ | Elpi_lexer_config.Tokens.FAMILY_PLUS _ | Elpi_lexer_config.Tokens.FAMILY_TICK _ | Elpi_lexer_config.Tokens.FULLSTOP | Elpi_lexer_config.Tokens.IFF | Elpi_lexer_config.Tokens.IS | Elpi_lexer_config.Tokens.MINUS | Elpi_lexer_config.Tokens.MINUSi | Elpi_lexer_config.Tokens.MINUSr | Elpi_lexer_config.Tokens.MINUSs | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.PIPE | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.RBRACKET | Elpi_lexer_config.Tokens.RCURLY | Elpi_lexer_config.Tokens.RPAREN | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_FAMILY_EXP (_menhir_stack, s, _, _) = _menhir_stack in
            let MenhirCell1_term (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_221 _endpos_r_ _startpos_l_ l r s in
            _menhir_goto_open_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 95
    
    and _menhir_run_096 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell0_CONS (_menhir_stack, _startpos, _endpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v ->
            let _startpos_0 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_1 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_1, _startpos_0, _v) in
            let _v = _menhir_action_068 x in
            _menhir_run_053_spec_096 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.SIGMA ->
            let _startpos_2 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_3 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_3, _startpos_2) in
            let _v = _menhir_action_085 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState096 _tok
        | Elpi_lexer_config.Tokens.REPLACE ->
            let _startpos_4 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_5 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_5, _startpos_4) in
            let _v = _menhir_action_080 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState096 _tok
        | Elpi_lexer_config.Tokens.QUOTED _v ->
            let _startpos_6 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_7 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_7, _startpos_6, _v) in
            let _v = _menhir_action_069 _endpos_x_ _startpos_x_ x in
            _menhir_run_053_spec_096 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.PI ->
            let _startpos_8 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_9 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_9, _startpos_8) in
            let _v = _menhir_action_084 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState096 _tok
        | Elpi_lexer_config.Tokens.NIL ->
            let _startpos_10 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_11 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_11, _startpos_10) in
            let _v = _menhir_action_089 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState096 _tok
        | Elpi_lexer_config.Tokens.NAME ->
            let _startpos_12 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_13 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_13, _startpos_12) in
            let _v = _menhir_action_077 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState096 _tok
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState096
        | Elpi_lexer_config.Tokens.LCURLY ->
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState096
        | Elpi_lexer_config.Tokens.LBRACKET ->
            _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState096
        | Elpi_lexer_config.Tokens.IO _v ->
            let _startpos_14 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_15 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_15, _startpos_14, _v) in
            let _v = _menhir_action_082 c in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState096 _tok
        | Elpi_lexer_config.Tokens.INTEGER _v ->
            let _startpos_16 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_17 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_17, _startpos_16, _v) in
            let _v = _menhir_action_066 x in
            _menhir_run_053_spec_096 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.INDEX ->
            let _startpos_18 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_19 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_19, _startpos_18) in
            let _v = _menhir_action_081 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState096 _tok
        | Elpi_lexer_config.Tokens.IF ->
            let _startpos_20 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_21 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_21, _startpos_20) in
            let _v = _menhir_action_076 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState096 _tok
        | Elpi_lexer_config.Tokens.FRESHUV ->
            let _startpos_22 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_23 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_23, _startpos_22) in
            let _v = _menhir_action_086 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState096 _tok
        | Elpi_lexer_config.Tokens.FLOAT _v ->
            let _startpos_24 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_25 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_25, _startpos_24, _v) in
            let _v = _menhir_action_067 x in
            _menhir_run_053_spec_096 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_TILDE _v ->
            _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState096
        | Elpi_lexer_config.Tokens.CUT ->
            let _startpos_26 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_27 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_27, _startpos_26) in
            let _v = _menhir_action_083 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState096 _tok
        | Elpi_lexer_config.Tokens.CONSTANT _v ->
            let _startpos_28 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_29 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_29, _startpos_28, _v) in
            let _v = _menhir_action_075 c in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState096 _tok
        | Elpi_lexer_config.Tokens.BEFORE ->
            let _startpos_30 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_31 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_31, _startpos_30) in
            let _v = _menhir_action_078 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState096 _tok
        | Elpi_lexer_config.Tokens.AFTER ->
            let _startpos_32 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_33 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_33, _startpos_32) in
            let _v = _menhir_action_079 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState096 _tok
        | _ ->
            _eRR 96
    
    and _menhir_run_053_spec_096 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term _menhir_cell0_CONS -> _ -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_317 t in
        _menhir_run_097 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v MenhirState096 _tok
    
    and _menhir_run_097 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_term _menhir_cell0_CONS as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.SLASH ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MOD ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_074 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSs ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_076 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSr ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_082 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSi ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_084 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_086 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FAMILY_TIMES _v_0 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_078 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_TICK _v_1 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_090 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_3 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_041 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_PLUS _v_4 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_092 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_5 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_6 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.FAMILY_EXP _v_7 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_094 _menhir_stack _menhir_lexbuf _menhir_lexer _v_7
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_8 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer _v_8
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_9 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer _v_9
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_10 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer _v_10
        | Elpi_lexer_config.Tokens.DIV ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_080 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_096 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.AS | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.EOF | Elpi_lexer_config.Tokens.EQ | Elpi_lexer_config.Tokens.EQ2 | Elpi_lexer_config.Tokens.FAMILY_GT _ | Elpi_lexer_config.Tokens.FAMILY_LT _ | Elpi_lexer_config.Tokens.FULLSTOP | Elpi_lexer_config.Tokens.IFF | Elpi_lexer_config.Tokens.IS | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.PIPE | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.RBRACKET | Elpi_lexer_config.Tokens.RCURLY | Elpi_lexer_config.Tokens.RPAREN | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_CONS (_menhir_stack, _, _) = _menhir_stack in
            let MenhirCell1_term (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_230 _endpos_r_ _startpos_l_ l r in
            _menhir_goto_open_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 97
    
    and _menhir_run_098 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell0_FAMILY_LT (_menhir_stack, _v, _startpos, _endpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v_0 ->
            let _startpos_1 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_2 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_2, _startpos_1, _v_0) in
            let _v = _menhir_action_068 x in
            _menhir_run_053_spec_098 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.SIGMA ->
            let _startpos_4 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_5 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_5, _startpos_4) in
            let _v = _menhir_action_085 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState098 _tok
        | Elpi_lexer_config.Tokens.REPLACE ->
            let _startpos_7 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_8 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_8, _startpos_7) in
            let _v = _menhir_action_080 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState098 _tok
        | Elpi_lexer_config.Tokens.QUOTED _v_10 ->
            let _startpos_11 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_12 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_12, _startpos_11, _v_10) in
            let _v = _menhir_action_069 _endpos_x_ _startpos_x_ x in
            _menhir_run_053_spec_098 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.PI ->
            let _startpos_14 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_15 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_15, _startpos_14) in
            let _v = _menhir_action_084 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState098 _tok
        | Elpi_lexer_config.Tokens.NIL ->
            let _startpos_17 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_18 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_18, _startpos_17) in
            let _v = _menhir_action_089 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState098 _tok
        | Elpi_lexer_config.Tokens.NAME ->
            let _startpos_20 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_21 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_21, _startpos_20) in
            let _v = _menhir_action_077 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState098 _tok
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState098
        | Elpi_lexer_config.Tokens.LCURLY ->
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState098
        | Elpi_lexer_config.Tokens.LBRACKET ->
            _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState098
        | Elpi_lexer_config.Tokens.IO _v_23 ->
            let _startpos_24 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_25 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_25, _startpos_24, _v_23) in
            let _v = _menhir_action_082 c in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState098 _tok
        | Elpi_lexer_config.Tokens.INTEGER _v_27 ->
            let _startpos_28 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_29 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_29, _startpos_28, _v_27) in
            let _v = _menhir_action_066 x in
            _menhir_run_053_spec_098 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.INDEX ->
            let _startpos_31 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_32 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_32, _startpos_31) in
            let _v = _menhir_action_081 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState098 _tok
        | Elpi_lexer_config.Tokens.IF ->
            let _startpos_34 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_35 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_35, _startpos_34) in
            let _v = _menhir_action_076 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState098 _tok
        | Elpi_lexer_config.Tokens.FRESHUV ->
            let _startpos_37 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_38 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_38, _startpos_37) in
            let _v = _menhir_action_086 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState098 _tok
        | Elpi_lexer_config.Tokens.FLOAT _v_40 ->
            let _startpos_41 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_42 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_42, _startpos_41, _v_40) in
            let _v = _menhir_action_067 x in
            _menhir_run_053_spec_098 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_TILDE _v_44 ->
            _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer _v_44 MenhirState098
        | Elpi_lexer_config.Tokens.CUT ->
            let _startpos_45 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_46 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_46, _startpos_45) in
            let _v = _menhir_action_083 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState098 _tok
        | Elpi_lexer_config.Tokens.CONSTANT _v_48 ->
            let _startpos_49 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_50 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_50, _startpos_49, _v_48) in
            let _v = _menhir_action_075 c in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState098 _tok
        | Elpi_lexer_config.Tokens.BEFORE ->
            let _startpos_52 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_53 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_53, _startpos_52) in
            let _v = _menhir_action_078 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState098 _tok
        | Elpi_lexer_config.Tokens.AFTER ->
            let _startpos_55 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_56 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_56, _startpos_55) in
            let _v = _menhir_action_079 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState098 _tok
        | _ ->
            _eRR 98
    
    and _menhir_run_053_spec_098 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term _menhir_cell0_FAMILY_LT -> _ -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_317 t in
        _menhir_run_099 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v MenhirState098 _tok
    
    and _menhir_run_099 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_term _menhir_cell0_FAMILY_LT as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.SLASH ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MOD ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_074 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSs ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_076 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSr ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_082 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSi ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_084 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_086 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FAMILY_TIMES _v_0 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_078 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_TICK _v_1 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_090 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_3 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_041 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_PLUS _v_4 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_092 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_5 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_6 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.FAMILY_EXP _v_7 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_094 _menhir_stack _menhir_lexbuf _menhir_lexer _v_7
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_8 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer _v_8
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_9 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer _v_9
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_10 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer _v_10
        | Elpi_lexer_config.Tokens.DIV ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_080 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_096 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.AS | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.EOF | Elpi_lexer_config.Tokens.FULLSTOP | Elpi_lexer_config.Tokens.IFF | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.PIPE | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.RBRACKET | Elpi_lexer_config.Tokens.RCURLY | Elpi_lexer_config.Tokens.RPAREN | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_FAMILY_LT (_menhir_stack, s, _, _) = _menhir_stack in
            let MenhirCell1_term (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_222 _endpos_r_ _startpos_l_ l r s in
            _menhir_goto_open_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 99
    
    and _menhir_run_100 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell0_FAMILY_GT (_menhir_stack, _v, _startpos, _endpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v_0 ->
            let _startpos_1 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_2 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_2, _startpos_1, _v_0) in
            let _v = _menhir_action_068 x in
            _menhir_run_053_spec_100 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.SIGMA ->
            let _startpos_4 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_5 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_5, _startpos_4) in
            let _v = _menhir_action_085 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState100 _tok
        | Elpi_lexer_config.Tokens.REPLACE ->
            let _startpos_7 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_8 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_8, _startpos_7) in
            let _v = _menhir_action_080 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState100 _tok
        | Elpi_lexer_config.Tokens.QUOTED _v_10 ->
            let _startpos_11 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_12 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_12, _startpos_11, _v_10) in
            let _v = _menhir_action_069 _endpos_x_ _startpos_x_ x in
            _menhir_run_053_spec_100 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.PI ->
            let _startpos_14 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_15 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_15, _startpos_14) in
            let _v = _menhir_action_084 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState100 _tok
        | Elpi_lexer_config.Tokens.NIL ->
            let _startpos_17 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_18 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_18, _startpos_17) in
            let _v = _menhir_action_089 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState100 _tok
        | Elpi_lexer_config.Tokens.NAME ->
            let _startpos_20 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_21 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_21, _startpos_20) in
            let _v = _menhir_action_077 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState100 _tok
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState100
        | Elpi_lexer_config.Tokens.LCURLY ->
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState100
        | Elpi_lexer_config.Tokens.LBRACKET ->
            _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState100
        | Elpi_lexer_config.Tokens.IO _v_23 ->
            let _startpos_24 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_25 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_25, _startpos_24, _v_23) in
            let _v = _menhir_action_082 c in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState100 _tok
        | Elpi_lexer_config.Tokens.INTEGER _v_27 ->
            let _startpos_28 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_29 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_29, _startpos_28, _v_27) in
            let _v = _menhir_action_066 x in
            _menhir_run_053_spec_100 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.INDEX ->
            let _startpos_31 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_32 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_32, _startpos_31) in
            let _v = _menhir_action_081 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState100 _tok
        | Elpi_lexer_config.Tokens.IF ->
            let _startpos_34 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_35 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_35, _startpos_34) in
            let _v = _menhir_action_076 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState100 _tok
        | Elpi_lexer_config.Tokens.FRESHUV ->
            let _startpos_37 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_38 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_38, _startpos_37) in
            let _v = _menhir_action_086 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState100 _tok
        | Elpi_lexer_config.Tokens.FLOAT _v_40 ->
            let _startpos_41 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_42 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_42, _startpos_41, _v_40) in
            let _v = _menhir_action_067 x in
            _menhir_run_053_spec_100 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_TILDE _v_44 ->
            _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer _v_44 MenhirState100
        | Elpi_lexer_config.Tokens.CUT ->
            let _startpos_45 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_46 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_46, _startpos_45) in
            let _v = _menhir_action_083 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState100 _tok
        | Elpi_lexer_config.Tokens.CONSTANT _v_48 ->
            let _startpos_49 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_50 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_50, _startpos_49, _v_48) in
            let _v = _menhir_action_075 c in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState100 _tok
        | Elpi_lexer_config.Tokens.BEFORE ->
            let _startpos_52 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_53 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_53, _startpos_52) in
            let _v = _menhir_action_078 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState100 _tok
        | Elpi_lexer_config.Tokens.AFTER ->
            let _startpos_55 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_56 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_56, _startpos_55) in
            let _v = _menhir_action_079 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState100 _tok
        | _ ->
            _eRR 100
    
    and _menhir_run_053_spec_100 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term _menhir_cell0_FAMILY_GT -> _ -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_317 t in
        _menhir_run_101 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v MenhirState100 _tok
    
    and _menhir_run_101 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_term _menhir_cell0_FAMILY_GT as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.SLASH ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MOD ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_074 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSs ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_076 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSr ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_082 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSi ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_084 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_086 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FAMILY_TIMES _v_0 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_078 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_TICK _v_1 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_090 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_3 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_041 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_PLUS _v_4 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_092 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_5 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_6 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.FAMILY_EXP _v_7 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_094 _menhir_stack _menhir_lexbuf _menhir_lexer _v_7
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_8 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer _v_8
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_9 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer _v_9
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_10 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer _v_10
        | Elpi_lexer_config.Tokens.DIV ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_080 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_096 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.AS | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.EOF | Elpi_lexer_config.Tokens.FULLSTOP | Elpi_lexer_config.Tokens.IFF | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.PIPE | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.RBRACKET | Elpi_lexer_config.Tokens.RCURLY | Elpi_lexer_config.Tokens.RPAREN | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_FAMILY_GT (_menhir_stack, s, _, _) = _menhir_stack in
            let MenhirCell1_term (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_223 _endpos_r_ _startpos_l_ l r s in
            _menhir_goto_open_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 101
    
    and _menhir_run_102 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell0_EQ2 (_menhir_stack, _startpos, _endpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v ->
            let _startpos_0 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_1 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_1, _startpos_0, _v) in
            let _v = _menhir_action_068 x in
            _menhir_run_053_spec_102 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.SIGMA ->
            let _startpos_2 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_3 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_3, _startpos_2) in
            let _v = _menhir_action_085 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState102 _tok
        | Elpi_lexer_config.Tokens.REPLACE ->
            let _startpos_4 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_5 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_5, _startpos_4) in
            let _v = _menhir_action_080 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState102 _tok
        | Elpi_lexer_config.Tokens.QUOTED _v ->
            let _startpos_6 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_7 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_7, _startpos_6, _v) in
            let _v = _menhir_action_069 _endpos_x_ _startpos_x_ x in
            _menhir_run_053_spec_102 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.PI ->
            let _startpos_8 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_9 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_9, _startpos_8) in
            let _v = _menhir_action_084 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState102 _tok
        | Elpi_lexer_config.Tokens.NIL ->
            let _startpos_10 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_11 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_11, _startpos_10) in
            let _v = _menhir_action_089 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState102 _tok
        | Elpi_lexer_config.Tokens.NAME ->
            let _startpos_12 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_13 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_13, _startpos_12) in
            let _v = _menhir_action_077 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState102 _tok
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState102
        | Elpi_lexer_config.Tokens.LCURLY ->
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState102
        | Elpi_lexer_config.Tokens.LBRACKET ->
            _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState102
        | Elpi_lexer_config.Tokens.IO _v ->
            let _startpos_14 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_15 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_15, _startpos_14, _v) in
            let _v = _menhir_action_082 c in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState102 _tok
        | Elpi_lexer_config.Tokens.INTEGER _v ->
            let _startpos_16 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_17 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_17, _startpos_16, _v) in
            let _v = _menhir_action_066 x in
            _menhir_run_053_spec_102 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.INDEX ->
            let _startpos_18 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_19 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_19, _startpos_18) in
            let _v = _menhir_action_081 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState102 _tok
        | Elpi_lexer_config.Tokens.IF ->
            let _startpos_20 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_21 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_21, _startpos_20) in
            let _v = _menhir_action_076 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState102 _tok
        | Elpi_lexer_config.Tokens.FRESHUV ->
            let _startpos_22 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_23 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_23, _startpos_22) in
            let _v = _menhir_action_086 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState102 _tok
        | Elpi_lexer_config.Tokens.FLOAT _v ->
            let _startpos_24 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_25 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_25, _startpos_24, _v) in
            let _v = _menhir_action_067 x in
            _menhir_run_053_spec_102 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_TILDE _v ->
            _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState102
        | Elpi_lexer_config.Tokens.CUT ->
            let _startpos_26 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_27 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_27, _startpos_26) in
            let _v = _menhir_action_083 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState102 _tok
        | Elpi_lexer_config.Tokens.CONSTANT _v ->
            let _startpos_28 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_29 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_29, _startpos_28, _v) in
            let _v = _menhir_action_075 c in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState102 _tok
        | Elpi_lexer_config.Tokens.BEFORE ->
            let _startpos_30 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_31 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_31, _startpos_30) in
            let _v = _menhir_action_078 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState102 _tok
        | Elpi_lexer_config.Tokens.AFTER ->
            let _startpos_32 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_33 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_33, _startpos_32) in
            let _v = _menhir_action_079 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState102 _tok
        | _ ->
            _eRR 102
    
    and _menhir_run_053_spec_102 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term _menhir_cell0_EQ2 -> _ -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_317 t in
        _menhir_run_103 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v MenhirState102 _tok
    
    and _menhir_run_103 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_term _menhir_cell0_EQ2 as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.SLASH ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MOD ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_074 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSs ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_076 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSr ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_082 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSi ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_084 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_086 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FAMILY_TIMES _v_0 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_078 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_TICK _v_1 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_090 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_3 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_041 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_PLUS _v_4 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_092 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_5 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_6 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.FAMILY_EXP _v_7 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_094 _menhir_stack _menhir_lexbuf _menhir_lexer _v_7
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_8 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer _v_8
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_9 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer _v_9
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_10 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer _v_10
        | Elpi_lexer_config.Tokens.DIV ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_080 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_096 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.AS | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.EOF | Elpi_lexer_config.Tokens.FULLSTOP | Elpi_lexer_config.Tokens.IFF | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.PIPE | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.RBRACKET | Elpi_lexer_config.Tokens.RCURLY | Elpi_lexer_config.Tokens.RPAREN | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_EQ2 (_menhir_stack, _, _) = _menhir_stack in
            let MenhirCell1_term (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_236 _endpos_r_ _startpos_l_ l r in
            _menhir_goto_open_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 103
    
    and _menhir_run_104 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell0_EQ (_menhir_stack, _startpos, _endpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v ->
            let _startpos_0 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_1 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_1, _startpos_0, _v) in
            let _v = _menhir_action_068 x in
            _menhir_run_053_spec_104 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.SIGMA ->
            let _startpos_2 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_3 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_3, _startpos_2) in
            let _v = _menhir_action_085 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState104 _tok
        | Elpi_lexer_config.Tokens.REPLACE ->
            let _startpos_4 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_5 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_5, _startpos_4) in
            let _v = _menhir_action_080 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState104 _tok
        | Elpi_lexer_config.Tokens.QUOTED _v ->
            let _startpos_6 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_7 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_7, _startpos_6, _v) in
            let _v = _menhir_action_069 _endpos_x_ _startpos_x_ x in
            _menhir_run_053_spec_104 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.PI ->
            let _startpos_8 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_9 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_9, _startpos_8) in
            let _v = _menhir_action_084 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState104 _tok
        | Elpi_lexer_config.Tokens.NIL ->
            let _startpos_10 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_11 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_11, _startpos_10) in
            let _v = _menhir_action_089 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState104 _tok
        | Elpi_lexer_config.Tokens.NAME ->
            let _startpos_12 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_13 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_13, _startpos_12) in
            let _v = _menhir_action_077 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState104 _tok
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState104
        | Elpi_lexer_config.Tokens.LCURLY ->
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState104
        | Elpi_lexer_config.Tokens.LBRACKET ->
            _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState104
        | Elpi_lexer_config.Tokens.IO _v ->
            let _startpos_14 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_15 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_15, _startpos_14, _v) in
            let _v = _menhir_action_082 c in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState104 _tok
        | Elpi_lexer_config.Tokens.INTEGER _v ->
            let _startpos_16 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_17 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_17, _startpos_16, _v) in
            let _v = _menhir_action_066 x in
            _menhir_run_053_spec_104 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.INDEX ->
            let _startpos_18 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_19 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_19, _startpos_18) in
            let _v = _menhir_action_081 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState104 _tok
        | Elpi_lexer_config.Tokens.IF ->
            let _startpos_20 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_21 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_21, _startpos_20) in
            let _v = _menhir_action_076 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState104 _tok
        | Elpi_lexer_config.Tokens.FRESHUV ->
            let _startpos_22 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_23 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_23, _startpos_22) in
            let _v = _menhir_action_086 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState104 _tok
        | Elpi_lexer_config.Tokens.FLOAT _v ->
            let _startpos_24 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_25 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_25, _startpos_24, _v) in
            let _v = _menhir_action_067 x in
            _menhir_run_053_spec_104 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_TILDE _v ->
            _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState104
        | Elpi_lexer_config.Tokens.CUT ->
            let _startpos_26 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_27 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_27, _startpos_26) in
            let _v = _menhir_action_083 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState104 _tok
        | Elpi_lexer_config.Tokens.CONSTANT _v ->
            let _startpos_28 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_29 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_29, _startpos_28, _v) in
            let _v = _menhir_action_075 c in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState104 _tok
        | Elpi_lexer_config.Tokens.BEFORE ->
            let _startpos_30 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_31 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_31, _startpos_30) in
            let _v = _menhir_action_078 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState104 _tok
        | Elpi_lexer_config.Tokens.AFTER ->
            let _startpos_32 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_33 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_33, _startpos_32) in
            let _v = _menhir_action_079 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState104 _tok
        | _ ->
            _eRR 104
    
    and _menhir_run_053_spec_104 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term _menhir_cell0_EQ -> _ -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_317 t in
        _menhir_run_105 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v MenhirState104 _tok
    
    and _menhir_run_105 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_term _menhir_cell0_EQ as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.SLASH ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MOD ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_074 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSs ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_076 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSr ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_082 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSi ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_084 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_086 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FAMILY_TIMES _v_0 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_078 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_TICK _v_1 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_090 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_3 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_041 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_PLUS _v_4 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_092 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_5 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_6 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.FAMILY_EXP _v_7 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_094 _menhir_stack _menhir_lexbuf _menhir_lexer _v_7
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_8 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer _v_8
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_9 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer _v_9
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_10 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer _v_10
        | Elpi_lexer_config.Tokens.DIV ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_080 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_096 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.AS | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.EOF | Elpi_lexer_config.Tokens.FULLSTOP | Elpi_lexer_config.Tokens.IFF | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.PIPE | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.RBRACKET | Elpi_lexer_config.Tokens.RCURLY | Elpi_lexer_config.Tokens.RPAREN | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_EQ (_menhir_stack, _, _) = _menhir_stack in
            let MenhirCell1_term (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_231 _endpos_r_ _startpos_l_ l r in
            _menhir_goto_open_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 105
    
    and _menhir_run_106 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell0_DARROW (_menhir_stack, _startpos, _endpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v ->
            let _startpos_0 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_1 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_1, _startpos_0, _v) in
            let _v = _menhir_action_068 x in
            _menhir_run_053_spec_106 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.SIGMA ->
            let _startpos_2 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_3 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_3, _startpos_2) in
            let _v = _menhir_action_085 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState106 _tok
        | Elpi_lexer_config.Tokens.REPLACE ->
            let _startpos_4 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_5 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_5, _startpos_4) in
            let _v = _menhir_action_080 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState106 _tok
        | Elpi_lexer_config.Tokens.QUOTED _v ->
            let _startpos_6 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_7 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_7, _startpos_6, _v) in
            let _v = _menhir_action_069 _endpos_x_ _startpos_x_ x in
            _menhir_run_053_spec_106 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.PI ->
            let _startpos_8 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_9 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_9, _startpos_8) in
            let _v = _menhir_action_084 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState106 _tok
        | Elpi_lexer_config.Tokens.NIL ->
            let _startpos_10 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_11 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_11, _startpos_10) in
            let _v = _menhir_action_089 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState106 _tok
        | Elpi_lexer_config.Tokens.NAME ->
            let _startpos_12 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_13 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_13, _startpos_12) in
            let _v = _menhir_action_077 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState106 _tok
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState106
        | Elpi_lexer_config.Tokens.LCURLY ->
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState106
        | Elpi_lexer_config.Tokens.LBRACKET ->
            _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState106
        | Elpi_lexer_config.Tokens.IO _v ->
            let _startpos_14 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_15 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_15, _startpos_14, _v) in
            let _v = _menhir_action_082 c in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState106 _tok
        | Elpi_lexer_config.Tokens.INTEGER _v ->
            let _startpos_16 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_17 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_17, _startpos_16, _v) in
            let _v = _menhir_action_066 x in
            _menhir_run_053_spec_106 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.INDEX ->
            let _startpos_18 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_19 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_19, _startpos_18) in
            let _v = _menhir_action_081 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState106 _tok
        | Elpi_lexer_config.Tokens.IF ->
            let _startpos_20 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_21 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_21, _startpos_20) in
            let _v = _menhir_action_076 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState106 _tok
        | Elpi_lexer_config.Tokens.FRESHUV ->
            let _startpos_22 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_23 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_23, _startpos_22) in
            let _v = _menhir_action_086 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState106 _tok
        | Elpi_lexer_config.Tokens.FLOAT _v ->
            let _startpos_24 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_25 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_25, _startpos_24, _v) in
            let _v = _menhir_action_067 x in
            _menhir_run_053_spec_106 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_TILDE _v ->
            _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState106
        | Elpi_lexer_config.Tokens.CUT ->
            let _startpos_26 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_27 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_27, _startpos_26) in
            let _v = _menhir_action_083 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState106 _tok
        | Elpi_lexer_config.Tokens.CONSTANT _v ->
            let _startpos_28 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_29 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_29, _startpos_28, _v) in
            let _v = _menhir_action_075 c in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState106 _tok
        | Elpi_lexer_config.Tokens.BEFORE ->
            let _startpos_30 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_31 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_31, _startpos_30) in
            let _v = _menhir_action_078 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState106 _tok
        | Elpi_lexer_config.Tokens.AFTER ->
            let _startpos_32 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_33 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_33, _startpos_32) in
            let _v = _menhir_action_079 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState106 _tok
        | _ ->
            _eRR 106
    
    and _menhir_run_053_spec_106 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term _menhir_cell0_DARROW -> _ -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_317 t in
        _menhir_run_107 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v MenhirState106 _tok
    
    and _menhir_run_107 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_term _menhir_cell0_DARROW as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.SLASH ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MOD ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_074 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSs ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_076 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSr ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_082 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSi ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_084 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_086 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.IS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_088 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FAMILY_TIMES _v_0 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_078 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_TICK _v_1 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_090 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_3 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_041 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_PLUS _v_4 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_092 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_5 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_6 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.FAMILY_LT _v_7 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_098 _menhir_stack _menhir_lexbuf _menhir_lexer _v_7
        | Elpi_lexer_config.Tokens.FAMILY_GT _v_8 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_100 _menhir_stack _menhir_lexbuf _menhir_lexer _v_8
        | Elpi_lexer_config.Tokens.FAMILY_EXP _v_9 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_094 _menhir_stack _menhir_lexbuf _menhir_lexer _v_9
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_10 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer _v_10
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_11 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer _v_11
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_12 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer _v_12
        | Elpi_lexer_config.Tokens.EQ2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_102 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.EQ ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_104 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.DIV ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_080 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.DARROW ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_106 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_096 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.AS | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.EOF | Elpi_lexer_config.Tokens.FULLSTOP | Elpi_lexer_config.Tokens.IFF | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.PIPE | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.RBRACKET | Elpi_lexer_config.Tokens.RCURLY | Elpi_lexer_config.Tokens.RPAREN | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_DARROW (_menhir_stack, _, _) = _menhir_stack in
            let MenhirCell1_term (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_242 _endpos_r_ _startpos_l_ l r in
            _menhir_goto_open_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 107
    
    and _menhir_run_108 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell0_CONJ2 (_menhir_stack, _startpos, _endpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v ->
            let _startpos_0 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_1 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_1, _startpos_0, _v) in
            let _v = _menhir_action_068 x in
            _menhir_run_053_spec_108 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.SIGMA ->
            let _startpos_2 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_3 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_3, _startpos_2) in
            let _v = _menhir_action_085 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState108 _tok
        | Elpi_lexer_config.Tokens.REPLACE ->
            let _startpos_4 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_5 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_5, _startpos_4) in
            let _v = _menhir_action_080 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState108 _tok
        | Elpi_lexer_config.Tokens.QUOTED _v ->
            let _startpos_6 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_7 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_7, _startpos_6, _v) in
            let _v = _menhir_action_069 _endpos_x_ _startpos_x_ x in
            _menhir_run_053_spec_108 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.PI ->
            let _startpos_8 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_9 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_9, _startpos_8) in
            let _v = _menhir_action_084 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState108 _tok
        | Elpi_lexer_config.Tokens.NIL ->
            let _startpos_10 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_11 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_11, _startpos_10) in
            let _v = _menhir_action_089 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState108 _tok
        | Elpi_lexer_config.Tokens.NAME ->
            let _startpos_12 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_13 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_13, _startpos_12) in
            let _v = _menhir_action_077 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState108 _tok
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState108
        | Elpi_lexer_config.Tokens.LCURLY ->
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState108
        | Elpi_lexer_config.Tokens.LBRACKET ->
            _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState108
        | Elpi_lexer_config.Tokens.IO _v ->
            let _startpos_14 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_15 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_15, _startpos_14, _v) in
            let _v = _menhir_action_082 c in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState108 _tok
        | Elpi_lexer_config.Tokens.INTEGER _v ->
            let _startpos_16 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_17 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_17, _startpos_16, _v) in
            let _v = _menhir_action_066 x in
            _menhir_run_053_spec_108 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.INDEX ->
            let _startpos_18 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_19 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_19, _startpos_18) in
            let _v = _menhir_action_081 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState108 _tok
        | Elpi_lexer_config.Tokens.IF ->
            let _startpos_20 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_21 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_21, _startpos_20) in
            let _v = _menhir_action_076 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState108 _tok
        | Elpi_lexer_config.Tokens.FRESHUV ->
            let _startpos_22 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_23 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_23, _startpos_22) in
            let _v = _menhir_action_086 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState108 _tok
        | Elpi_lexer_config.Tokens.FLOAT _v ->
            let _startpos_24 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_25 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_25, _startpos_24, _v) in
            let _v = _menhir_action_067 x in
            _menhir_run_053_spec_108 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_TILDE _v ->
            _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState108
        | Elpi_lexer_config.Tokens.CUT ->
            let _startpos_26 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_27 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_27, _startpos_26) in
            let _v = _menhir_action_083 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState108 _tok
        | Elpi_lexer_config.Tokens.CONSTANT _v ->
            let _startpos_28 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_29 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_29, _startpos_28, _v) in
            let _v = _menhir_action_075 c in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState108 _tok
        | Elpi_lexer_config.Tokens.BEFORE ->
            let _startpos_30 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_31 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_31, _startpos_30) in
            let _v = _menhir_action_078 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState108 _tok
        | Elpi_lexer_config.Tokens.AFTER ->
            let _startpos_32 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_33 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_33, _startpos_32) in
            let _v = _menhir_action_079 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState108 _tok
        | _ ->
            _eRR 108
    
    and _menhir_run_053_spec_108 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term _menhir_cell0_CONJ2 -> _ -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_317 t in
        _menhir_run_109 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v MenhirState108 _tok
    
    and _menhir_run_109 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_term _menhir_cell0_CONJ2 as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.SLASH ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MOD ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_074 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSs ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_076 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSr ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_082 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSi ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_084 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_086 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.IS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_088 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FAMILY_TIMES _v_0 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_078 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_TICK _v_1 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_090 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_3 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_041 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_PLUS _v_4 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_092 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_5 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_6 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.FAMILY_LT _v_7 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_098 _menhir_stack _menhir_lexbuf _menhir_lexer _v_7
        | Elpi_lexer_config.Tokens.FAMILY_GT _v_8 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_100 _menhir_stack _menhir_lexbuf _menhir_lexer _v_8
        | Elpi_lexer_config.Tokens.FAMILY_EXP _v_9 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_094 _menhir_stack _menhir_lexbuf _menhir_lexer _v_9
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_10 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer _v_10
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_11 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer _v_11
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_12 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer _v_12
        | Elpi_lexer_config.Tokens.EQ2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_102 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.EQ ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_104 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.DIV ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_080 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.DARROW ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_106 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_096 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONJ2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_108 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONJ ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_110 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.ARROW ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_112 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.AS | Elpi_lexer_config.Tokens.EOF | Elpi_lexer_config.Tokens.FULLSTOP | Elpi_lexer_config.Tokens.IFF | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.PIPE | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.RBRACKET | Elpi_lexer_config.Tokens.RCURLY | Elpi_lexer_config.Tokens.RPAREN | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_CONJ2 (_menhir_stack, _, _) = _menhir_stack in
            let MenhirCell1_term (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_245 _endpos_r_ _startpos_l_ l r in
            _menhir_goto_open_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 109
    
    and _menhir_run_110 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell0_CONJ (_menhir_stack, _startpos, _endpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v ->
            let _startpos_0 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_1 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_1, _startpos_0, _v) in
            let _v = _menhir_action_068 x in
            _menhir_run_053_spec_110 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.SIGMA ->
            let _startpos_2 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_3 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_3, _startpos_2) in
            let _v = _menhir_action_085 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState110 _tok
        | Elpi_lexer_config.Tokens.REPLACE ->
            let _startpos_4 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_5 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_5, _startpos_4) in
            let _v = _menhir_action_080 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState110 _tok
        | Elpi_lexer_config.Tokens.QUOTED _v ->
            let _startpos_6 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_7 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_7, _startpos_6, _v) in
            let _v = _menhir_action_069 _endpos_x_ _startpos_x_ x in
            _menhir_run_053_spec_110 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.PI ->
            let _startpos_8 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_9 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_9, _startpos_8) in
            let _v = _menhir_action_084 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState110 _tok
        | Elpi_lexer_config.Tokens.NIL ->
            let _startpos_10 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_11 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_11, _startpos_10) in
            let _v = _menhir_action_089 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState110 _tok
        | Elpi_lexer_config.Tokens.NAME ->
            let _startpos_12 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_13 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_13, _startpos_12) in
            let _v = _menhir_action_077 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState110 _tok
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState110
        | Elpi_lexer_config.Tokens.LCURLY ->
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState110
        | Elpi_lexer_config.Tokens.LBRACKET ->
            _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState110
        | Elpi_lexer_config.Tokens.IO _v ->
            let _startpos_14 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_15 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_15, _startpos_14, _v) in
            let _v = _menhir_action_082 c in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState110 _tok
        | Elpi_lexer_config.Tokens.INTEGER _v ->
            let _startpos_16 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_17 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_17, _startpos_16, _v) in
            let _v = _menhir_action_066 x in
            _menhir_run_053_spec_110 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.INDEX ->
            let _startpos_18 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_19 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_19, _startpos_18) in
            let _v = _menhir_action_081 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState110 _tok
        | Elpi_lexer_config.Tokens.IF ->
            let _startpos_20 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_21 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_21, _startpos_20) in
            let _v = _menhir_action_076 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState110 _tok
        | Elpi_lexer_config.Tokens.FRESHUV ->
            let _startpos_22 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_23 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_23, _startpos_22) in
            let _v = _menhir_action_086 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState110 _tok
        | Elpi_lexer_config.Tokens.FLOAT _v ->
            let _startpos_24 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_25 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_25, _startpos_24, _v) in
            let _v = _menhir_action_067 x in
            _menhir_run_053_spec_110 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_TILDE _v ->
            _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState110
        | Elpi_lexer_config.Tokens.CUT ->
            let _startpos_26 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_27 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_27, _startpos_26) in
            let _v = _menhir_action_083 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState110 _tok
        | Elpi_lexer_config.Tokens.CONSTANT _v ->
            let _startpos_28 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_29 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_29, _startpos_28, _v) in
            let _v = _menhir_action_075 c in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState110 _tok
        | Elpi_lexer_config.Tokens.BEFORE ->
            let _startpos_30 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_31 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_31, _startpos_30) in
            let _v = _menhir_action_078 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState110 _tok
        | Elpi_lexer_config.Tokens.AFTER ->
            let _startpos_32 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_33 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_33, _startpos_32) in
            let _v = _menhir_action_079 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState110 _tok
        | _ ->
            _eRR 110
    
    and _menhir_run_053_spec_110 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term _menhir_cell0_CONJ -> _ -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_317 t in
        _menhir_run_111 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v MenhirState110 _tok
    
    and _menhir_run_111 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_term _menhir_cell0_CONJ as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.SLASH ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MOD ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_074 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSs ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_076 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSr ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_082 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSi ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_084 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_086 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.IS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_088 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FAMILY_TIMES _v_0 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_078 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_TICK _v_1 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_090 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_3 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_041 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_PLUS _v_4 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_092 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_5 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_6 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.FAMILY_LT _v_7 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_098 _menhir_stack _menhir_lexbuf _menhir_lexer _v_7
        | Elpi_lexer_config.Tokens.FAMILY_GT _v_8 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_100 _menhir_stack _menhir_lexbuf _menhir_lexer _v_8
        | Elpi_lexer_config.Tokens.FAMILY_EXP _v_9 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_094 _menhir_stack _menhir_lexbuf _menhir_lexer _v_9
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_10 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer _v_10
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_11 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer _v_11
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_12 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer _v_12
        | Elpi_lexer_config.Tokens.EQ2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_102 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.EQ ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_104 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.DIV ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_080 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.DARROW ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_106 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_096 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONJ2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_108 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONJ ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_110 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.ARROW ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_112 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.AS | Elpi_lexer_config.Tokens.EOF | Elpi_lexer_config.Tokens.FULLSTOP | Elpi_lexer_config.Tokens.IFF | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.PIPE | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.RBRACKET | Elpi_lexer_config.Tokens.RCURLY | Elpi_lexer_config.Tokens.RPAREN | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_CONJ (_menhir_stack, _, _) = _menhir_stack in
            let MenhirCell1_term (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_246 _endpos_r_ _startpos_l_ l r in
            _menhir_goto_open_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 111
    
    and _menhir_run_112 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell0_ARROW (_menhir_stack, _startpos, _endpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v ->
            let _startpos_0 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_1 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_1, _startpos_0, _v) in
            let _v = _menhir_action_068 x in
            _menhir_run_053_spec_112 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.SIGMA ->
            let _startpos_2 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_3 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_3, _startpos_2) in
            let _v = _menhir_action_085 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState112 _tok
        | Elpi_lexer_config.Tokens.REPLACE ->
            let _startpos_4 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_5 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_5, _startpos_4) in
            let _v = _menhir_action_080 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState112 _tok
        | Elpi_lexer_config.Tokens.QUOTED _v ->
            let _startpos_6 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_7 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_7, _startpos_6, _v) in
            let _v = _menhir_action_069 _endpos_x_ _startpos_x_ x in
            _menhir_run_053_spec_112 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.PI ->
            let _startpos_8 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_9 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_9, _startpos_8) in
            let _v = _menhir_action_084 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState112 _tok
        | Elpi_lexer_config.Tokens.NIL ->
            let _startpos_10 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_11 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_11, _startpos_10) in
            let _v = _menhir_action_089 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState112 _tok
        | Elpi_lexer_config.Tokens.NAME ->
            let _startpos_12 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_13 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_13, _startpos_12) in
            let _v = _menhir_action_077 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState112 _tok
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState112
        | Elpi_lexer_config.Tokens.LCURLY ->
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState112
        | Elpi_lexer_config.Tokens.LBRACKET ->
            _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState112
        | Elpi_lexer_config.Tokens.IO _v ->
            let _startpos_14 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_15 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_15, _startpos_14, _v) in
            let _v = _menhir_action_082 c in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState112 _tok
        | Elpi_lexer_config.Tokens.INTEGER _v ->
            let _startpos_16 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_17 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_17, _startpos_16, _v) in
            let _v = _menhir_action_066 x in
            _menhir_run_053_spec_112 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.INDEX ->
            let _startpos_18 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_19 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_19, _startpos_18) in
            let _v = _menhir_action_081 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState112 _tok
        | Elpi_lexer_config.Tokens.IF ->
            let _startpos_20 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_21 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_21, _startpos_20) in
            let _v = _menhir_action_076 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState112 _tok
        | Elpi_lexer_config.Tokens.FRESHUV ->
            let _startpos_22 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_23 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_23, _startpos_22) in
            let _v = _menhir_action_086 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState112 _tok
        | Elpi_lexer_config.Tokens.FLOAT _v ->
            let _startpos_24 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_25 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_25, _startpos_24, _v) in
            let _v = _menhir_action_067 x in
            _menhir_run_053_spec_112 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_TILDE _v ->
            _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState112
        | Elpi_lexer_config.Tokens.CUT ->
            let _startpos_26 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_27 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_27, _startpos_26) in
            let _v = _menhir_action_083 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState112 _tok
        | Elpi_lexer_config.Tokens.CONSTANT _v ->
            let _startpos_28 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_29 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_29, _startpos_28, _v) in
            let _v = _menhir_action_075 c in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState112 _tok
        | Elpi_lexer_config.Tokens.BEFORE ->
            let _startpos_30 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_31 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_31, _startpos_30) in
            let _v = _menhir_action_078 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState112 _tok
        | Elpi_lexer_config.Tokens.AFTER ->
            let _startpos_32 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_33 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_33, _startpos_32) in
            let _v = _menhir_action_079 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState112 _tok
        | _ ->
            _eRR 112
    
    and _menhir_run_053_spec_112 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term _menhir_cell0_ARROW -> _ -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_317 t in
        _menhir_run_113 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v MenhirState112 _tok
    
    and _menhir_run_113 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_term _menhir_cell0_ARROW as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.SLASH ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MOD ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_074 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSs ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_076 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSr ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_082 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSi ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_084 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_086 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.IS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_088 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FAMILY_TIMES _v_0 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_078 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_TICK _v_1 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_090 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_3 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_041 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_PLUS _v_4 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_092 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_5 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_6 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.FAMILY_LT _v_7 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_098 _menhir_stack _menhir_lexbuf _menhir_lexer _v_7
        | Elpi_lexer_config.Tokens.FAMILY_GT _v_8 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_100 _menhir_stack _menhir_lexbuf _menhir_lexer _v_8
        | Elpi_lexer_config.Tokens.FAMILY_EXP _v_9 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_094 _menhir_stack _menhir_lexbuf _menhir_lexer _v_9
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_10 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer _v_10
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_11 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer _v_11
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_12 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer _v_12
        | Elpi_lexer_config.Tokens.EQ2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_102 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.EQ ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_104 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.DIV ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_080 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.DARROW ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_106 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_096 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.ARROW ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_112 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.AS | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.EOF | Elpi_lexer_config.Tokens.FULLSTOP | Elpi_lexer_config.Tokens.IFF | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.PIPE | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.RBRACKET | Elpi_lexer_config.Tokens.RCURLY | Elpi_lexer_config.Tokens.RPAREN | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_ARROW (_menhir_stack, _, _) = _menhir_stack in
            let MenhirCell1_term (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_241 _endpos_r_ _startpos_l_ l r in
            _menhir_goto_open_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 113
    
    and _menhir_run_028 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell1_FAMILY_TILDE (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v_0 ->
            let _startpos_1 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_2 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_2, _startpos_1, _v_0) in
            let _v = _menhir_action_068 x in
            _menhir_run_120_spec_028 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.SIGMA ->
            let _startpos_4 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_5 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_5, _startpos_4) in
            let _v = _menhir_action_085 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState028 _tok
        | Elpi_lexer_config.Tokens.REPLACE ->
            let _startpos_7 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_8 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_8, _startpos_7) in
            let _v = _menhir_action_080 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState028 _tok
        | Elpi_lexer_config.Tokens.QUOTED _v_10 ->
            let _startpos_11 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_12 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_12, _startpos_11, _v_10) in
            let _v = _menhir_action_069 _endpos_x_ _startpos_x_ x in
            _menhir_run_120_spec_028 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.PI ->
            let _startpos_14 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_15 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_15, _startpos_14) in
            let _v = _menhir_action_084 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState028 _tok
        | Elpi_lexer_config.Tokens.NIL ->
            let _startpos_17 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_18 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_18, _startpos_17) in
            let _v = _menhir_action_089 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState028 _tok
        | Elpi_lexer_config.Tokens.NAME ->
            let _startpos_20 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_21 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_21, _startpos_20) in
            let _v = _menhir_action_077 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState028 _tok
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState028
        | Elpi_lexer_config.Tokens.LCURLY ->
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState028
        | Elpi_lexer_config.Tokens.LBRACKET ->
            _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState028
        | Elpi_lexer_config.Tokens.IO _v_23 ->
            let _startpos_24 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_25 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_25, _startpos_24, _v_23) in
            let _v = _menhir_action_082 c in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState028 _tok
        | Elpi_lexer_config.Tokens.INTEGER _v_27 ->
            let _startpos_28 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_29 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_29, _startpos_28, _v_27) in
            let _v = _menhir_action_066 x in
            _menhir_run_120_spec_028 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.INDEX ->
            let _startpos_31 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_32 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_32, _startpos_31) in
            let _v = _menhir_action_081 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState028 _tok
        | Elpi_lexer_config.Tokens.IF ->
            let _startpos_34 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_35 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_35, _startpos_34) in
            let _v = _menhir_action_076 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState028 _tok
        | Elpi_lexer_config.Tokens.FRESHUV ->
            let _startpos_37 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_38 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_38, _startpos_37) in
            let _v = _menhir_action_086 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState028 _tok
        | Elpi_lexer_config.Tokens.FLOAT _v_40 ->
            let _startpos_41 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_42 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_42, _startpos_41, _v_40) in
            let _v = _menhir_action_067 x in
            _menhir_run_120_spec_028 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_TILDE _v_44 ->
            _menhir_run_028 _menhir_stack _menhir_lexbuf _menhir_lexer _v_44 MenhirState028
        | Elpi_lexer_config.Tokens.CUT ->
            let _startpos_45 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_46 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_46, _startpos_45) in
            let _v = _menhir_action_083 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState028 _tok
        | Elpi_lexer_config.Tokens.CONSTANT _v_48 ->
            let _startpos_49 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_50 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_50, _startpos_49, _v_48) in
            let _v = _menhir_action_075 c in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState028 _tok
        | Elpi_lexer_config.Tokens.BEFORE ->
            let _startpos_52 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_53 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_53, _startpos_52) in
            let _v = _menhir_action_078 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState028 _tok
        | Elpi_lexer_config.Tokens.AFTER ->
            let _startpos_55 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_56 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_56, _startpos_55) in
            let _v = _menhir_action_079 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState028 _tok
        | _ ->
            _eRR 28
    
    and _menhir_run_120_spec_028 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_FAMILY_TILDE -> _ -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_320 t in
        _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v MenhirState028 _tok
    
    and _menhir_run_033 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_FAMILY_TILDE as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_0 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_034 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.CONS | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.DIV | Elpi_lexer_config.Tokens.EQ | Elpi_lexer_config.Tokens.EQ2 | Elpi_lexer_config.Tokens.FAMILY_AND _ | Elpi_lexer_config.Tokens.FAMILY_BTICK _ | Elpi_lexer_config.Tokens.FAMILY_EQ _ | Elpi_lexer_config.Tokens.FAMILY_EXP _ | Elpi_lexer_config.Tokens.FAMILY_GT _ | Elpi_lexer_config.Tokens.FAMILY_LT _ | Elpi_lexer_config.Tokens.FAMILY_MINUS _ | Elpi_lexer_config.Tokens.FAMILY_OR _ | Elpi_lexer_config.Tokens.FAMILY_PLUS _ | Elpi_lexer_config.Tokens.FAMILY_SHARP _ | Elpi_lexer_config.Tokens.FAMILY_TICK _ | Elpi_lexer_config.Tokens.FAMILY_TIMES _ | Elpi_lexer_config.Tokens.IS | Elpi_lexer_config.Tokens.MINUS | Elpi_lexer_config.Tokens.MINUSi | Elpi_lexer_config.Tokens.MINUSr | Elpi_lexer_config.Tokens.MINUSs | Elpi_lexer_config.Tokens.MOD | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.PIPE | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.RBRACKET | Elpi_lexer_config.Tokens.SLASH | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell1_FAMILY_TILDE (_menhir_stack, _menhir_s, s, _startpos_s_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_280 r s in
            _menhir_goto_open_term_noconj _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_s_ _v _menhir_s _tok
        | _ ->
            _eRR 33
    
    and _menhir_run_133 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term_noconj -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell0_FAMILY_MINUS (_menhir_stack, _v, _startpos, _endpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v_0 ->
            let _startpos_1 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_2 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_2, _startpos_1, _v_0) in
            let _v = _menhir_action_068 x in
            _menhir_run_120_spec_133 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.SIGMA ->
            let _startpos_4 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_5 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_5, _startpos_4) in
            let _v = _menhir_action_085 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState133 _tok
        | Elpi_lexer_config.Tokens.REPLACE ->
            let _startpos_7 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_8 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_8, _startpos_7) in
            let _v = _menhir_action_080 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState133 _tok
        | Elpi_lexer_config.Tokens.QUOTED _v_10 ->
            let _startpos_11 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_12 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_12, _startpos_11, _v_10) in
            let _v = _menhir_action_069 _endpos_x_ _startpos_x_ x in
            _menhir_run_120_spec_133 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.PI ->
            let _startpos_14 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_15 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_15, _startpos_14) in
            let _v = _menhir_action_084 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState133 _tok
        | Elpi_lexer_config.Tokens.NIL ->
            let _startpos_17 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_18 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_18, _startpos_17) in
            let _v = _menhir_action_089 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState133 _tok
        | Elpi_lexer_config.Tokens.NAME ->
            let _startpos_20 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_21 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_21, _startpos_20) in
            let _v = _menhir_action_077 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState133 _tok
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState133
        | Elpi_lexer_config.Tokens.LCURLY ->
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState133
        | Elpi_lexer_config.Tokens.LBRACKET ->
            _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState133
        | Elpi_lexer_config.Tokens.IO _v_23 ->
            let _startpos_24 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_25 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_25, _startpos_24, _v_23) in
            let _v = _menhir_action_082 c in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState133 _tok
        | Elpi_lexer_config.Tokens.INTEGER _v_27 ->
            let _startpos_28 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_29 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_29, _startpos_28, _v_27) in
            let _v = _menhir_action_066 x in
            _menhir_run_120_spec_133 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.INDEX ->
            let _startpos_31 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_32 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_32, _startpos_31) in
            let _v = _menhir_action_081 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState133 _tok
        | Elpi_lexer_config.Tokens.IF ->
            let _startpos_34 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_35 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_35, _startpos_34) in
            let _v = _menhir_action_076 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState133 _tok
        | Elpi_lexer_config.Tokens.FRESHUV ->
            let _startpos_37 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_38 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_38, _startpos_37) in
            let _v = _menhir_action_086 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState133 _tok
        | Elpi_lexer_config.Tokens.FLOAT _v_40 ->
            let _startpos_41 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_42 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_42, _startpos_41, _v_40) in
            let _v = _menhir_action_067 x in
            _menhir_run_120_spec_133 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_TILDE _v_44 ->
            _menhir_run_028 _menhir_stack _menhir_lexbuf _menhir_lexer _v_44 MenhirState133
        | Elpi_lexer_config.Tokens.CUT ->
            let _startpos_45 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_46 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_46, _startpos_45) in
            let _v = _menhir_action_083 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState133 _tok
        | Elpi_lexer_config.Tokens.CONSTANT _v_48 ->
            let _startpos_49 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_50 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_50, _startpos_49, _v_48) in
            let _v = _menhir_action_075 c in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState133 _tok
        | Elpi_lexer_config.Tokens.BEFORE ->
            let _startpos_52 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_53 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_53, _startpos_52) in
            let _v = _menhir_action_078 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState133 _tok
        | Elpi_lexer_config.Tokens.AFTER ->
            let _startpos_55 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_56 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_56, _startpos_55) in
            let _v = _menhir_action_079 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState133 _tok
        | _ ->
            _eRR 133
    
    and _menhir_run_120_spec_133 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term_noconj _menhir_cell0_FAMILY_MINUS -> _ -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_320 t in
        _menhir_run_134 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v MenhirState133 _tok
    
    and _menhir_run_134 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_term_noconj _menhir_cell0_FAMILY_MINUS as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_0 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_127 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_1 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_034 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_2 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_129 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_3 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_133 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_4 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_135 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_5 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_137 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_6 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_131 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.CONS | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.DIV | Elpi_lexer_config.Tokens.EQ | Elpi_lexer_config.Tokens.EQ2 | Elpi_lexer_config.Tokens.FAMILY_EXP _ | Elpi_lexer_config.Tokens.FAMILY_GT _ | Elpi_lexer_config.Tokens.FAMILY_LT _ | Elpi_lexer_config.Tokens.FAMILY_PLUS _ | Elpi_lexer_config.Tokens.FAMILY_TICK _ | Elpi_lexer_config.Tokens.FAMILY_TIMES _ | Elpi_lexer_config.Tokens.IS | Elpi_lexer_config.Tokens.MINUS | Elpi_lexer_config.Tokens.MINUSi | Elpi_lexer_config.Tokens.MINUSr | Elpi_lexer_config.Tokens.MINUSs | Elpi_lexer_config.Tokens.MOD | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.PIPE | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.RBRACKET | Elpi_lexer_config.Tokens.SLASH | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_FAMILY_MINUS (_menhir_stack, s, _, _) = _menhir_stack in
            let MenhirCell1_term_noconj (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_253 _endpos_r_ _startpos_l_ l r s in
            _menhir_goto_open_term_noconj _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 134
    
    and _menhir_run_135 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term_noconj -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell0_FAMILY_EQ (_menhir_stack, _v, _startpos, _endpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v_0 ->
            let _startpos_1 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_2 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_2, _startpos_1, _v_0) in
            let _v = _menhir_action_068 x in
            _menhir_run_120_spec_135 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.SIGMA ->
            let _startpos_4 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_5 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_5, _startpos_4) in
            let _v = _menhir_action_085 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState135 _tok
        | Elpi_lexer_config.Tokens.REPLACE ->
            let _startpos_7 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_8 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_8, _startpos_7) in
            let _v = _menhir_action_080 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState135 _tok
        | Elpi_lexer_config.Tokens.QUOTED _v_10 ->
            let _startpos_11 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_12 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_12, _startpos_11, _v_10) in
            let _v = _menhir_action_069 _endpos_x_ _startpos_x_ x in
            _menhir_run_120_spec_135 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.PI ->
            let _startpos_14 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_15 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_15, _startpos_14) in
            let _v = _menhir_action_084 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState135 _tok
        | Elpi_lexer_config.Tokens.NIL ->
            let _startpos_17 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_18 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_18, _startpos_17) in
            let _v = _menhir_action_089 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState135 _tok
        | Elpi_lexer_config.Tokens.NAME ->
            let _startpos_20 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_21 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_21, _startpos_20) in
            let _v = _menhir_action_077 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState135 _tok
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState135
        | Elpi_lexer_config.Tokens.LCURLY ->
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState135
        | Elpi_lexer_config.Tokens.LBRACKET ->
            _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState135
        | Elpi_lexer_config.Tokens.IO _v_23 ->
            let _startpos_24 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_25 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_25, _startpos_24, _v_23) in
            let _v = _menhir_action_082 c in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState135 _tok
        | Elpi_lexer_config.Tokens.INTEGER _v_27 ->
            let _startpos_28 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_29 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_29, _startpos_28, _v_27) in
            let _v = _menhir_action_066 x in
            _menhir_run_120_spec_135 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.INDEX ->
            let _startpos_31 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_32 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_32, _startpos_31) in
            let _v = _menhir_action_081 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState135 _tok
        | Elpi_lexer_config.Tokens.IF ->
            let _startpos_34 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_35 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_35, _startpos_34) in
            let _v = _menhir_action_076 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState135 _tok
        | Elpi_lexer_config.Tokens.FRESHUV ->
            let _startpos_37 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_38 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_38, _startpos_37) in
            let _v = _menhir_action_086 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState135 _tok
        | Elpi_lexer_config.Tokens.FLOAT _v_40 ->
            let _startpos_41 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_42 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_42, _startpos_41, _v_40) in
            let _v = _menhir_action_067 x in
            _menhir_run_120_spec_135 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_TILDE _v_44 ->
            _menhir_run_028 _menhir_stack _menhir_lexbuf _menhir_lexer _v_44 MenhirState135
        | Elpi_lexer_config.Tokens.CUT ->
            let _startpos_45 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_46 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_46, _startpos_45) in
            let _v = _menhir_action_083 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState135 _tok
        | Elpi_lexer_config.Tokens.CONSTANT _v_48 ->
            let _startpos_49 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_50 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_50, _startpos_49, _v_48) in
            let _v = _menhir_action_075 c in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState135 _tok
        | Elpi_lexer_config.Tokens.BEFORE ->
            let _startpos_52 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_53 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_53, _startpos_52) in
            let _v = _menhir_action_078 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState135 _tok
        | Elpi_lexer_config.Tokens.AFTER ->
            let _startpos_55 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_56 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_56, _startpos_55) in
            let _v = _menhir_action_079 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState135 _tok
        | _ ->
            _eRR 135
    
    and _menhir_run_120_spec_135 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term_noconj _menhir_cell0_FAMILY_EQ -> _ -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_320 t in
        _menhir_run_136 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v MenhirState135 _tok
    
    and _menhir_run_136 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_term_noconj _menhir_cell0_FAMILY_EQ as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_0 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_127 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_1 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_034 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_2 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_129 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_3 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_135 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_4 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_131 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.CONS | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.DIV | Elpi_lexer_config.Tokens.EQ | Elpi_lexer_config.Tokens.EQ2 | Elpi_lexer_config.Tokens.FAMILY_BTICK _ | Elpi_lexer_config.Tokens.FAMILY_EXP _ | Elpi_lexer_config.Tokens.FAMILY_GT _ | Elpi_lexer_config.Tokens.FAMILY_LT _ | Elpi_lexer_config.Tokens.FAMILY_MINUS _ | Elpi_lexer_config.Tokens.FAMILY_PLUS _ | Elpi_lexer_config.Tokens.FAMILY_TICK _ | Elpi_lexer_config.Tokens.FAMILY_TIMES _ | Elpi_lexer_config.Tokens.IS | Elpi_lexer_config.Tokens.MINUS | Elpi_lexer_config.Tokens.MINUSi | Elpi_lexer_config.Tokens.MINUSr | Elpi_lexer_config.Tokens.MINUSs | Elpi_lexer_config.Tokens.MOD | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.PIPE | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.RBRACKET | Elpi_lexer_config.Tokens.SLASH | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_FAMILY_EQ (_menhir_stack, s, _, _) = _menhir_stack in
            let MenhirCell1_term_noconj (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_257 _endpos_r_ _startpos_l_ l r s in
            _menhir_goto_open_term_noconj _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 136
    
    and _menhir_run_137 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term_noconj -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell0_FAMILY_BTICK (_menhir_stack, _v, _startpos, _endpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v_0 ->
            let _startpos_1 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_2 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_2, _startpos_1, _v_0) in
            let _v = _menhir_action_068 x in
            _menhir_run_120_spec_137 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.SIGMA ->
            let _startpos_4 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_5 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_5, _startpos_4) in
            let _v = _menhir_action_085 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState137 _tok
        | Elpi_lexer_config.Tokens.REPLACE ->
            let _startpos_7 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_8 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_8, _startpos_7) in
            let _v = _menhir_action_080 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState137 _tok
        | Elpi_lexer_config.Tokens.QUOTED _v_10 ->
            let _startpos_11 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_12 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_12, _startpos_11, _v_10) in
            let _v = _menhir_action_069 _endpos_x_ _startpos_x_ x in
            _menhir_run_120_spec_137 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.PI ->
            let _startpos_14 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_15 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_15, _startpos_14) in
            let _v = _menhir_action_084 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState137 _tok
        | Elpi_lexer_config.Tokens.NIL ->
            let _startpos_17 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_18 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_18, _startpos_17) in
            let _v = _menhir_action_089 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState137 _tok
        | Elpi_lexer_config.Tokens.NAME ->
            let _startpos_20 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_21 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_21, _startpos_20) in
            let _v = _menhir_action_077 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState137 _tok
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState137
        | Elpi_lexer_config.Tokens.LCURLY ->
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState137
        | Elpi_lexer_config.Tokens.LBRACKET ->
            _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState137
        | Elpi_lexer_config.Tokens.IO _v_23 ->
            let _startpos_24 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_25 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_25, _startpos_24, _v_23) in
            let _v = _menhir_action_082 c in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState137 _tok
        | Elpi_lexer_config.Tokens.INTEGER _v_27 ->
            let _startpos_28 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_29 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_29, _startpos_28, _v_27) in
            let _v = _menhir_action_066 x in
            _menhir_run_120_spec_137 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.INDEX ->
            let _startpos_31 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_32 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_32, _startpos_31) in
            let _v = _menhir_action_081 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState137 _tok
        | Elpi_lexer_config.Tokens.IF ->
            let _startpos_34 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_35 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_35, _startpos_34) in
            let _v = _menhir_action_076 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState137 _tok
        | Elpi_lexer_config.Tokens.FRESHUV ->
            let _startpos_37 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_38 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_38, _startpos_37) in
            let _v = _menhir_action_086 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState137 _tok
        | Elpi_lexer_config.Tokens.FLOAT _v_40 ->
            let _startpos_41 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_42 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_42, _startpos_41, _v_40) in
            let _v = _menhir_action_067 x in
            _menhir_run_120_spec_137 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_TILDE _v_44 ->
            _menhir_run_028 _menhir_stack _menhir_lexbuf _menhir_lexer _v_44 MenhirState137
        | Elpi_lexer_config.Tokens.CUT ->
            let _startpos_45 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_46 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_46, _startpos_45) in
            let _v = _menhir_action_083 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState137 _tok
        | Elpi_lexer_config.Tokens.CONSTANT _v_48 ->
            let _startpos_49 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_50 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_50, _startpos_49, _v_48) in
            let _v = _menhir_action_075 c in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState137 _tok
        | Elpi_lexer_config.Tokens.BEFORE ->
            let _startpos_52 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_53 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_53, _startpos_52) in
            let _v = _menhir_action_078 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState137 _tok
        | Elpi_lexer_config.Tokens.AFTER ->
            let _startpos_55 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_56 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_56, _startpos_55) in
            let _v = _menhir_action_079 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState137 _tok
        | _ ->
            _eRR 137
    
    and _menhir_run_120_spec_137 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term_noconj _menhir_cell0_FAMILY_BTICK -> _ -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_320 t in
        _menhir_run_138 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v MenhirState137 _tok
    
    and _menhir_run_138 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_term_noconj _menhir_cell0_FAMILY_BTICK as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_0 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_127 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_1 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_034 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_2 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_129 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_3 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_135 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_4 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_131 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.CONS | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.DIV | Elpi_lexer_config.Tokens.EQ | Elpi_lexer_config.Tokens.EQ2 | Elpi_lexer_config.Tokens.FAMILY_EXP _ | Elpi_lexer_config.Tokens.FAMILY_GT _ | Elpi_lexer_config.Tokens.FAMILY_LT _ | Elpi_lexer_config.Tokens.FAMILY_MINUS _ | Elpi_lexer_config.Tokens.FAMILY_PLUS _ | Elpi_lexer_config.Tokens.FAMILY_TICK _ | Elpi_lexer_config.Tokens.FAMILY_TIMES _ | Elpi_lexer_config.Tokens.IS | Elpi_lexer_config.Tokens.MINUS | Elpi_lexer_config.Tokens.MINUSi | Elpi_lexer_config.Tokens.MINUSr | Elpi_lexer_config.Tokens.MINUSs | Elpi_lexer_config.Tokens.MOD | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.PIPE | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.RBRACKET | Elpi_lexer_config.Tokens.SLASH | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_FAMILY_BTICK (_menhir_stack, s, _, _) = _menhir_stack in
            let MenhirCell1_term_noconj (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_261 _endpos_r_ _startpos_l_ l r s in
            _menhir_goto_open_term_noconj _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 138
    
    and _menhir_run_143 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term_noconj -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell0_MINUSs (_menhir_stack, _startpos, _endpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v ->
            let _startpos_0 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_1 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_1, _startpos_0, _v) in
            let _v = _menhir_action_068 x in
            _menhir_run_120_spec_143 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.SIGMA ->
            let _startpos_2 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_3 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_3, _startpos_2) in
            let _v = _menhir_action_085 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState143 _tok
        | Elpi_lexer_config.Tokens.REPLACE ->
            let _startpos_4 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_5 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_5, _startpos_4) in
            let _v = _menhir_action_080 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState143 _tok
        | Elpi_lexer_config.Tokens.QUOTED _v ->
            let _startpos_6 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_7 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_7, _startpos_6, _v) in
            let _v = _menhir_action_069 _endpos_x_ _startpos_x_ x in
            _menhir_run_120_spec_143 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.PI ->
            let _startpos_8 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_9 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_9, _startpos_8) in
            let _v = _menhir_action_084 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState143 _tok
        | Elpi_lexer_config.Tokens.NIL ->
            let _startpos_10 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_11 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_11, _startpos_10) in
            let _v = _menhir_action_089 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState143 _tok
        | Elpi_lexer_config.Tokens.NAME ->
            let _startpos_12 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_13 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_13, _startpos_12) in
            let _v = _menhir_action_077 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState143 _tok
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState143
        | Elpi_lexer_config.Tokens.LCURLY ->
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState143
        | Elpi_lexer_config.Tokens.LBRACKET ->
            _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState143
        | Elpi_lexer_config.Tokens.IO _v ->
            let _startpos_14 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_15 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_15, _startpos_14, _v) in
            let _v = _menhir_action_082 c in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState143 _tok
        | Elpi_lexer_config.Tokens.INTEGER _v ->
            let _startpos_16 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_17 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_17, _startpos_16, _v) in
            let _v = _menhir_action_066 x in
            _menhir_run_120_spec_143 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.INDEX ->
            let _startpos_18 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_19 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_19, _startpos_18) in
            let _v = _menhir_action_081 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState143 _tok
        | Elpi_lexer_config.Tokens.IF ->
            let _startpos_20 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_21 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_21, _startpos_20) in
            let _v = _menhir_action_076 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState143 _tok
        | Elpi_lexer_config.Tokens.FRESHUV ->
            let _startpos_22 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_23 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_23, _startpos_22) in
            let _v = _menhir_action_086 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState143 _tok
        | Elpi_lexer_config.Tokens.FLOAT _v ->
            let _startpos_24 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_25 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_25, _startpos_24, _v) in
            let _v = _menhir_action_067 x in
            _menhir_run_120_spec_143 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_TILDE _v ->
            _menhir_run_028 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState143
        | Elpi_lexer_config.Tokens.CUT ->
            let _startpos_26 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_27 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_27, _startpos_26) in
            let _v = _menhir_action_083 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState143 _tok
        | Elpi_lexer_config.Tokens.CONSTANT _v ->
            let _startpos_28 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_29 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_29, _startpos_28, _v) in
            let _v = _menhir_action_075 c in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState143 _tok
        | Elpi_lexer_config.Tokens.BEFORE ->
            let _startpos_30 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_31 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_31, _startpos_30) in
            let _v = _menhir_action_078 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState143 _tok
        | Elpi_lexer_config.Tokens.AFTER ->
            let _startpos_32 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_33 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_33, _startpos_32) in
            let _v = _menhir_action_079 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState143 _tok
        | _ ->
            _eRR 143
    
    and _menhir_run_120_spec_143 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term_noconj _menhir_cell0_MINUSs -> _ -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_320 t in
        _menhir_run_144 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v MenhirState143 _tok
    
    and _menhir_run_144 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_term_noconj _menhir_cell0_MINUSs as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.SLASH ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_125 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MOD ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_141 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FAMILY_TIMES _v_0 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_145 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_1 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_127 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_2 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_034 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_3 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_129 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_4 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_133 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_5 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_135 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_6 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_137 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_7 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_131 _menhir_stack _menhir_lexbuf _menhir_lexer _v_7
        | Elpi_lexer_config.Tokens.DIV ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_147 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.CONS | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.EQ | Elpi_lexer_config.Tokens.EQ2 | Elpi_lexer_config.Tokens.FAMILY_EXP _ | Elpi_lexer_config.Tokens.FAMILY_GT _ | Elpi_lexer_config.Tokens.FAMILY_LT _ | Elpi_lexer_config.Tokens.FAMILY_PLUS _ | Elpi_lexer_config.Tokens.FAMILY_TICK _ | Elpi_lexer_config.Tokens.IS | Elpi_lexer_config.Tokens.MINUS | Elpi_lexer_config.Tokens.MINUSi | Elpi_lexer_config.Tokens.MINUSr | Elpi_lexer_config.Tokens.MINUSs | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.PIPE | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.RBRACKET | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_MINUSs (_menhir_stack, _, _) = _menhir_stack in
            let MenhirCell1_term_noconj (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_268 _endpos_r_ _startpos_l_ l r in
            _menhir_goto_open_term_noconj _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 144
    
    and _menhir_run_145 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term_noconj -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell0_FAMILY_TIMES (_menhir_stack, _v, _startpos, _endpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v_0 ->
            let _startpos_1 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_2 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_2, _startpos_1, _v_0) in
            let _v = _menhir_action_068 x in
            _menhir_run_120_spec_145 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.SIGMA ->
            let _startpos_4 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_5 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_5, _startpos_4) in
            let _v = _menhir_action_085 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState145 _tok
        | Elpi_lexer_config.Tokens.REPLACE ->
            let _startpos_7 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_8 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_8, _startpos_7) in
            let _v = _menhir_action_080 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState145 _tok
        | Elpi_lexer_config.Tokens.QUOTED _v_10 ->
            let _startpos_11 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_12 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_12, _startpos_11, _v_10) in
            let _v = _menhir_action_069 _endpos_x_ _startpos_x_ x in
            _menhir_run_120_spec_145 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.PI ->
            let _startpos_14 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_15 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_15, _startpos_14) in
            let _v = _menhir_action_084 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState145 _tok
        | Elpi_lexer_config.Tokens.NIL ->
            let _startpos_17 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_18 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_18, _startpos_17) in
            let _v = _menhir_action_089 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState145 _tok
        | Elpi_lexer_config.Tokens.NAME ->
            let _startpos_20 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_21 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_21, _startpos_20) in
            let _v = _menhir_action_077 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState145 _tok
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState145
        | Elpi_lexer_config.Tokens.LCURLY ->
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState145
        | Elpi_lexer_config.Tokens.LBRACKET ->
            _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState145
        | Elpi_lexer_config.Tokens.IO _v_23 ->
            let _startpos_24 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_25 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_25, _startpos_24, _v_23) in
            let _v = _menhir_action_082 c in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState145 _tok
        | Elpi_lexer_config.Tokens.INTEGER _v_27 ->
            let _startpos_28 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_29 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_29, _startpos_28, _v_27) in
            let _v = _menhir_action_066 x in
            _menhir_run_120_spec_145 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.INDEX ->
            let _startpos_31 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_32 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_32, _startpos_31) in
            let _v = _menhir_action_081 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState145 _tok
        | Elpi_lexer_config.Tokens.IF ->
            let _startpos_34 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_35 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_35, _startpos_34) in
            let _v = _menhir_action_076 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState145 _tok
        | Elpi_lexer_config.Tokens.FRESHUV ->
            let _startpos_37 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_38 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_38, _startpos_37) in
            let _v = _menhir_action_086 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState145 _tok
        | Elpi_lexer_config.Tokens.FLOAT _v_40 ->
            let _startpos_41 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_42 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_42, _startpos_41, _v_40) in
            let _v = _menhir_action_067 x in
            _menhir_run_120_spec_145 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_TILDE _v_44 ->
            _menhir_run_028 _menhir_stack _menhir_lexbuf _menhir_lexer _v_44 MenhirState145
        | Elpi_lexer_config.Tokens.CUT ->
            let _startpos_45 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_46 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_46, _startpos_45) in
            let _v = _menhir_action_083 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState145 _tok
        | Elpi_lexer_config.Tokens.CONSTANT _v_48 ->
            let _startpos_49 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_50 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_50, _startpos_49, _v_48) in
            let _v = _menhir_action_075 c in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState145 _tok
        | Elpi_lexer_config.Tokens.BEFORE ->
            let _startpos_52 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_53 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_53, _startpos_52) in
            let _v = _menhir_action_078 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState145 _tok
        | Elpi_lexer_config.Tokens.AFTER ->
            let _startpos_55 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_56 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_56, _startpos_55) in
            let _v = _menhir_action_079 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState145 _tok
        | _ ->
            _eRR 145
    
    and _menhir_run_120_spec_145 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term_noconj _menhir_cell0_FAMILY_TIMES -> _ -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_320 t in
        _menhir_run_146 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v MenhirState145 _tok
    
    and _menhir_run_146 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_term_noconj _menhir_cell0_FAMILY_TIMES as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_0 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_127 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_1 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_034 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_2 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_129 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_3 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_133 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_4 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_135 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_5 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_137 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_6 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_131 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.CONS | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.DIV | Elpi_lexer_config.Tokens.EQ | Elpi_lexer_config.Tokens.EQ2 | Elpi_lexer_config.Tokens.FAMILY_EXP _ | Elpi_lexer_config.Tokens.FAMILY_GT _ | Elpi_lexer_config.Tokens.FAMILY_LT _ | Elpi_lexer_config.Tokens.FAMILY_PLUS _ | Elpi_lexer_config.Tokens.FAMILY_TICK _ | Elpi_lexer_config.Tokens.FAMILY_TIMES _ | Elpi_lexer_config.Tokens.IS | Elpi_lexer_config.Tokens.MINUS | Elpi_lexer_config.Tokens.MINUSi | Elpi_lexer_config.Tokens.MINUSr | Elpi_lexer_config.Tokens.MINUSs | Elpi_lexer_config.Tokens.MOD | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.PIPE | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.RBRACKET | Elpi_lexer_config.Tokens.SLASH | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_FAMILY_TIMES (_menhir_stack, s, _, _) = _menhir_stack in
            let MenhirCell1_term_noconj (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_252 _endpos_r_ _startpos_l_ l r s in
            _menhir_goto_open_term_noconj _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 146
    
    and _menhir_run_147 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term_noconj -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell0_DIV (_menhir_stack, _startpos, _endpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v ->
            let _startpos_0 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_1 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_1, _startpos_0, _v) in
            let _v = _menhir_action_068 x in
            _menhir_run_120_spec_147 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.SIGMA ->
            let _startpos_2 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_3 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_3, _startpos_2) in
            let _v = _menhir_action_085 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState147 _tok
        | Elpi_lexer_config.Tokens.REPLACE ->
            let _startpos_4 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_5 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_5, _startpos_4) in
            let _v = _menhir_action_080 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState147 _tok
        | Elpi_lexer_config.Tokens.QUOTED _v ->
            let _startpos_6 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_7 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_7, _startpos_6, _v) in
            let _v = _menhir_action_069 _endpos_x_ _startpos_x_ x in
            _menhir_run_120_spec_147 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.PI ->
            let _startpos_8 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_9 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_9, _startpos_8) in
            let _v = _menhir_action_084 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState147 _tok
        | Elpi_lexer_config.Tokens.NIL ->
            let _startpos_10 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_11 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_11, _startpos_10) in
            let _v = _menhir_action_089 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState147 _tok
        | Elpi_lexer_config.Tokens.NAME ->
            let _startpos_12 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_13 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_13, _startpos_12) in
            let _v = _menhir_action_077 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState147 _tok
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState147
        | Elpi_lexer_config.Tokens.LCURLY ->
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState147
        | Elpi_lexer_config.Tokens.LBRACKET ->
            _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState147
        | Elpi_lexer_config.Tokens.IO _v ->
            let _startpos_14 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_15 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_15, _startpos_14, _v) in
            let _v = _menhir_action_082 c in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState147 _tok
        | Elpi_lexer_config.Tokens.INTEGER _v ->
            let _startpos_16 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_17 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_17, _startpos_16, _v) in
            let _v = _menhir_action_066 x in
            _menhir_run_120_spec_147 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.INDEX ->
            let _startpos_18 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_19 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_19, _startpos_18) in
            let _v = _menhir_action_081 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState147 _tok
        | Elpi_lexer_config.Tokens.IF ->
            let _startpos_20 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_21 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_21, _startpos_20) in
            let _v = _menhir_action_076 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState147 _tok
        | Elpi_lexer_config.Tokens.FRESHUV ->
            let _startpos_22 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_23 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_23, _startpos_22) in
            let _v = _menhir_action_086 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState147 _tok
        | Elpi_lexer_config.Tokens.FLOAT _v ->
            let _startpos_24 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_25 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_25, _startpos_24, _v) in
            let _v = _menhir_action_067 x in
            _menhir_run_120_spec_147 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_TILDE _v ->
            _menhir_run_028 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState147
        | Elpi_lexer_config.Tokens.CUT ->
            let _startpos_26 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_27 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_27, _startpos_26) in
            let _v = _menhir_action_083 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState147 _tok
        | Elpi_lexer_config.Tokens.CONSTANT _v ->
            let _startpos_28 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_29 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_29, _startpos_28, _v) in
            let _v = _menhir_action_075 c in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState147 _tok
        | Elpi_lexer_config.Tokens.BEFORE ->
            let _startpos_30 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_31 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_31, _startpos_30) in
            let _v = _menhir_action_078 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState147 _tok
        | Elpi_lexer_config.Tokens.AFTER ->
            let _startpos_32 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_33 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_33, _startpos_32) in
            let _v = _menhir_action_079 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState147 _tok
        | _ ->
            _eRR 147
    
    and _menhir_run_120_spec_147 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term_noconj _menhir_cell0_DIV -> _ -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_320 t in
        _menhir_run_148 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v MenhirState147 _tok
    
    and _menhir_run_148 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_term_noconj _menhir_cell0_DIV as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_0 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_127 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_1 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_034 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_2 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_129 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_3 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_133 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_4 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_135 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_5 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_137 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_6 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_131 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.CONS | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.DIV | Elpi_lexer_config.Tokens.EQ | Elpi_lexer_config.Tokens.EQ2 | Elpi_lexer_config.Tokens.FAMILY_EXP _ | Elpi_lexer_config.Tokens.FAMILY_GT _ | Elpi_lexer_config.Tokens.FAMILY_LT _ | Elpi_lexer_config.Tokens.FAMILY_PLUS _ | Elpi_lexer_config.Tokens.FAMILY_TICK _ | Elpi_lexer_config.Tokens.FAMILY_TIMES _ | Elpi_lexer_config.Tokens.IS | Elpi_lexer_config.Tokens.MINUS | Elpi_lexer_config.Tokens.MINUSi | Elpi_lexer_config.Tokens.MINUSr | Elpi_lexer_config.Tokens.MINUSs | Elpi_lexer_config.Tokens.MOD | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.PIPE | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.RBRACKET | Elpi_lexer_config.Tokens.SLASH | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_DIV (_menhir_stack, _, _) = _menhir_stack in
            let MenhirCell1_term_noconj (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_273 _endpos_r_ _startpos_l_ l r in
            _menhir_goto_open_term_noconj _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 148
    
    and _menhir_run_149 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term_noconj -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell0_MINUSr (_menhir_stack, _startpos, _endpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v ->
            let _startpos_0 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_1 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_1, _startpos_0, _v) in
            let _v = _menhir_action_068 x in
            _menhir_run_120_spec_149 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.SIGMA ->
            let _startpos_2 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_3 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_3, _startpos_2) in
            let _v = _menhir_action_085 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState149 _tok
        | Elpi_lexer_config.Tokens.REPLACE ->
            let _startpos_4 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_5 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_5, _startpos_4) in
            let _v = _menhir_action_080 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState149 _tok
        | Elpi_lexer_config.Tokens.QUOTED _v ->
            let _startpos_6 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_7 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_7, _startpos_6, _v) in
            let _v = _menhir_action_069 _endpos_x_ _startpos_x_ x in
            _menhir_run_120_spec_149 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.PI ->
            let _startpos_8 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_9 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_9, _startpos_8) in
            let _v = _menhir_action_084 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState149 _tok
        | Elpi_lexer_config.Tokens.NIL ->
            let _startpos_10 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_11 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_11, _startpos_10) in
            let _v = _menhir_action_089 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState149 _tok
        | Elpi_lexer_config.Tokens.NAME ->
            let _startpos_12 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_13 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_13, _startpos_12) in
            let _v = _menhir_action_077 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState149 _tok
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState149
        | Elpi_lexer_config.Tokens.LCURLY ->
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState149
        | Elpi_lexer_config.Tokens.LBRACKET ->
            _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState149
        | Elpi_lexer_config.Tokens.IO _v ->
            let _startpos_14 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_15 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_15, _startpos_14, _v) in
            let _v = _menhir_action_082 c in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState149 _tok
        | Elpi_lexer_config.Tokens.INTEGER _v ->
            let _startpos_16 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_17 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_17, _startpos_16, _v) in
            let _v = _menhir_action_066 x in
            _menhir_run_120_spec_149 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.INDEX ->
            let _startpos_18 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_19 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_19, _startpos_18) in
            let _v = _menhir_action_081 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState149 _tok
        | Elpi_lexer_config.Tokens.IF ->
            let _startpos_20 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_21 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_21, _startpos_20) in
            let _v = _menhir_action_076 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState149 _tok
        | Elpi_lexer_config.Tokens.FRESHUV ->
            let _startpos_22 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_23 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_23, _startpos_22) in
            let _v = _menhir_action_086 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState149 _tok
        | Elpi_lexer_config.Tokens.FLOAT _v ->
            let _startpos_24 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_25 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_25, _startpos_24, _v) in
            let _v = _menhir_action_067 x in
            _menhir_run_120_spec_149 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_TILDE _v ->
            _menhir_run_028 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState149
        | Elpi_lexer_config.Tokens.CUT ->
            let _startpos_26 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_27 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_27, _startpos_26) in
            let _v = _menhir_action_083 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState149 _tok
        | Elpi_lexer_config.Tokens.CONSTANT _v ->
            let _startpos_28 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_29 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_29, _startpos_28, _v) in
            let _v = _menhir_action_075 c in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState149 _tok
        | Elpi_lexer_config.Tokens.BEFORE ->
            let _startpos_30 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_31 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_31, _startpos_30) in
            let _v = _menhir_action_078 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState149 _tok
        | Elpi_lexer_config.Tokens.AFTER ->
            let _startpos_32 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_33 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_33, _startpos_32) in
            let _v = _menhir_action_079 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState149 _tok
        | _ ->
            _eRR 149
    
    and _menhir_run_120_spec_149 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term_noconj _menhir_cell0_MINUSr -> _ -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_320 t in
        _menhir_run_150 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v MenhirState149 _tok
    
    and _menhir_run_150 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_term_noconj _menhir_cell0_MINUSr as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.SLASH ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_125 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MOD ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_141 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FAMILY_TIMES _v_0 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_145 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_1 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_127 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_2 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_034 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_3 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_129 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_4 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_133 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_5 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_135 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_6 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_137 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_7 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_131 _menhir_stack _menhir_lexbuf _menhir_lexer _v_7
        | Elpi_lexer_config.Tokens.DIV ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_147 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.CONS | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.EQ | Elpi_lexer_config.Tokens.EQ2 | Elpi_lexer_config.Tokens.FAMILY_EXP _ | Elpi_lexer_config.Tokens.FAMILY_GT _ | Elpi_lexer_config.Tokens.FAMILY_LT _ | Elpi_lexer_config.Tokens.FAMILY_PLUS _ | Elpi_lexer_config.Tokens.FAMILY_TICK _ | Elpi_lexer_config.Tokens.IS | Elpi_lexer_config.Tokens.MINUS | Elpi_lexer_config.Tokens.MINUSi | Elpi_lexer_config.Tokens.MINUSr | Elpi_lexer_config.Tokens.MINUSs | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.PIPE | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.RBRACKET | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_MINUSr (_menhir_stack, _, _) = _menhir_stack in
            let MenhirCell1_term_noconj (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_266 _endpos_r_ _startpos_l_ l r in
            _menhir_goto_open_term_noconj _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 150
    
    and _menhir_run_151 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term_noconj -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell0_MINUSi (_menhir_stack, _startpos, _endpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v ->
            let _startpos_0 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_1 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_1, _startpos_0, _v) in
            let _v = _menhir_action_068 x in
            _menhir_run_120_spec_151 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.SIGMA ->
            let _startpos_2 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_3 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_3, _startpos_2) in
            let _v = _menhir_action_085 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState151 _tok
        | Elpi_lexer_config.Tokens.REPLACE ->
            let _startpos_4 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_5 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_5, _startpos_4) in
            let _v = _menhir_action_080 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState151 _tok
        | Elpi_lexer_config.Tokens.QUOTED _v ->
            let _startpos_6 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_7 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_7, _startpos_6, _v) in
            let _v = _menhir_action_069 _endpos_x_ _startpos_x_ x in
            _menhir_run_120_spec_151 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.PI ->
            let _startpos_8 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_9 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_9, _startpos_8) in
            let _v = _menhir_action_084 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState151 _tok
        | Elpi_lexer_config.Tokens.NIL ->
            let _startpos_10 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_11 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_11, _startpos_10) in
            let _v = _menhir_action_089 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState151 _tok
        | Elpi_lexer_config.Tokens.NAME ->
            let _startpos_12 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_13 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_13, _startpos_12) in
            let _v = _menhir_action_077 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState151 _tok
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState151
        | Elpi_lexer_config.Tokens.LCURLY ->
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState151
        | Elpi_lexer_config.Tokens.LBRACKET ->
            _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState151
        | Elpi_lexer_config.Tokens.IO _v ->
            let _startpos_14 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_15 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_15, _startpos_14, _v) in
            let _v = _menhir_action_082 c in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState151 _tok
        | Elpi_lexer_config.Tokens.INTEGER _v ->
            let _startpos_16 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_17 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_17, _startpos_16, _v) in
            let _v = _menhir_action_066 x in
            _menhir_run_120_spec_151 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.INDEX ->
            let _startpos_18 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_19 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_19, _startpos_18) in
            let _v = _menhir_action_081 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState151 _tok
        | Elpi_lexer_config.Tokens.IF ->
            let _startpos_20 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_21 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_21, _startpos_20) in
            let _v = _menhir_action_076 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState151 _tok
        | Elpi_lexer_config.Tokens.FRESHUV ->
            let _startpos_22 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_23 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_23, _startpos_22) in
            let _v = _menhir_action_086 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState151 _tok
        | Elpi_lexer_config.Tokens.FLOAT _v ->
            let _startpos_24 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_25 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_25, _startpos_24, _v) in
            let _v = _menhir_action_067 x in
            _menhir_run_120_spec_151 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_TILDE _v ->
            _menhir_run_028 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState151
        | Elpi_lexer_config.Tokens.CUT ->
            let _startpos_26 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_27 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_27, _startpos_26) in
            let _v = _menhir_action_083 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState151 _tok
        | Elpi_lexer_config.Tokens.CONSTANT _v ->
            let _startpos_28 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_29 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_29, _startpos_28, _v) in
            let _v = _menhir_action_075 c in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState151 _tok
        | Elpi_lexer_config.Tokens.BEFORE ->
            let _startpos_30 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_31 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_31, _startpos_30) in
            let _v = _menhir_action_078 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState151 _tok
        | Elpi_lexer_config.Tokens.AFTER ->
            let _startpos_32 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_33 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_33, _startpos_32) in
            let _v = _menhir_action_079 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState151 _tok
        | _ ->
            _eRR 151
    
    and _menhir_run_120_spec_151 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term_noconj _menhir_cell0_MINUSi -> _ -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_320 t in
        _menhir_run_152 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v MenhirState151 _tok
    
    and _menhir_run_152 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_term_noconj _menhir_cell0_MINUSi as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.SLASH ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_125 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MOD ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_141 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FAMILY_TIMES _v_0 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_145 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_1 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_127 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_2 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_034 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_3 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_129 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_4 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_133 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_5 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_135 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_6 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_137 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_7 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_131 _menhir_stack _menhir_lexbuf _menhir_lexer _v_7
        | Elpi_lexer_config.Tokens.DIV ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_147 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.CONS | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.EQ | Elpi_lexer_config.Tokens.EQ2 | Elpi_lexer_config.Tokens.FAMILY_EXP _ | Elpi_lexer_config.Tokens.FAMILY_GT _ | Elpi_lexer_config.Tokens.FAMILY_LT _ | Elpi_lexer_config.Tokens.FAMILY_PLUS _ | Elpi_lexer_config.Tokens.FAMILY_TICK _ | Elpi_lexer_config.Tokens.IS | Elpi_lexer_config.Tokens.MINUS | Elpi_lexer_config.Tokens.MINUSi | Elpi_lexer_config.Tokens.MINUSr | Elpi_lexer_config.Tokens.MINUSs | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.PIPE | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.RBRACKET | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_MINUSi (_menhir_stack, _, _) = _menhir_stack in
            let MenhirCell1_term_noconj (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_267 _endpos_r_ _startpos_l_ l r in
            _menhir_goto_open_term_noconj _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 152
    
    and _menhir_run_153 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term_noconj -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell0_MINUS (_menhir_stack, _startpos, _endpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v ->
            let _startpos_0 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_1 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_1, _startpos_0, _v) in
            let _v = _menhir_action_068 x in
            _menhir_run_120_spec_153 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.SIGMA ->
            let _startpos_2 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_3 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_3, _startpos_2) in
            let _v = _menhir_action_085 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState153 _tok
        | Elpi_lexer_config.Tokens.REPLACE ->
            let _startpos_4 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_5 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_5, _startpos_4) in
            let _v = _menhir_action_080 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState153 _tok
        | Elpi_lexer_config.Tokens.QUOTED _v ->
            let _startpos_6 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_7 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_7, _startpos_6, _v) in
            let _v = _menhir_action_069 _endpos_x_ _startpos_x_ x in
            _menhir_run_120_spec_153 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.PI ->
            let _startpos_8 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_9 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_9, _startpos_8) in
            let _v = _menhir_action_084 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState153 _tok
        | Elpi_lexer_config.Tokens.NIL ->
            let _startpos_10 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_11 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_11, _startpos_10) in
            let _v = _menhir_action_089 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState153 _tok
        | Elpi_lexer_config.Tokens.NAME ->
            let _startpos_12 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_13 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_13, _startpos_12) in
            let _v = _menhir_action_077 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState153 _tok
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState153
        | Elpi_lexer_config.Tokens.LCURLY ->
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState153
        | Elpi_lexer_config.Tokens.LBRACKET ->
            _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState153
        | Elpi_lexer_config.Tokens.IO _v ->
            let _startpos_14 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_15 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_15, _startpos_14, _v) in
            let _v = _menhir_action_082 c in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState153 _tok
        | Elpi_lexer_config.Tokens.INTEGER _v ->
            let _startpos_16 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_17 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_17, _startpos_16, _v) in
            let _v = _menhir_action_066 x in
            _menhir_run_120_spec_153 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.INDEX ->
            let _startpos_18 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_19 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_19, _startpos_18) in
            let _v = _menhir_action_081 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState153 _tok
        | Elpi_lexer_config.Tokens.IF ->
            let _startpos_20 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_21 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_21, _startpos_20) in
            let _v = _menhir_action_076 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState153 _tok
        | Elpi_lexer_config.Tokens.FRESHUV ->
            let _startpos_22 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_23 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_23, _startpos_22) in
            let _v = _menhir_action_086 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState153 _tok
        | Elpi_lexer_config.Tokens.FLOAT _v ->
            let _startpos_24 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_25 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_25, _startpos_24, _v) in
            let _v = _menhir_action_067 x in
            _menhir_run_120_spec_153 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_TILDE _v ->
            _menhir_run_028 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState153
        | Elpi_lexer_config.Tokens.CUT ->
            let _startpos_26 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_27 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_27, _startpos_26) in
            let _v = _menhir_action_083 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState153 _tok
        | Elpi_lexer_config.Tokens.CONSTANT _v ->
            let _startpos_28 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_29 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_29, _startpos_28, _v) in
            let _v = _menhir_action_075 c in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState153 _tok
        | Elpi_lexer_config.Tokens.BEFORE ->
            let _startpos_30 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_31 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_31, _startpos_30) in
            let _v = _menhir_action_078 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState153 _tok
        | Elpi_lexer_config.Tokens.AFTER ->
            let _startpos_32 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_33 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_33, _startpos_32) in
            let _v = _menhir_action_079 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState153 _tok
        | _ ->
            _eRR 153
    
    and _menhir_run_120_spec_153 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term_noconj _menhir_cell0_MINUS -> _ -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_320 t in
        _menhir_run_154 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v MenhirState153 _tok
    
    and _menhir_run_154 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_term_noconj _menhir_cell0_MINUS as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.SLASH ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_125 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MOD ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_141 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FAMILY_TIMES _v_0 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_145 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_1 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_127 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_2 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_034 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_3 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_129 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_4 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_133 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_5 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_135 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_6 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_137 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_7 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_131 _menhir_stack _menhir_lexbuf _menhir_lexer _v_7
        | Elpi_lexer_config.Tokens.DIV ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_147 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.CONS | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.EQ | Elpi_lexer_config.Tokens.EQ2 | Elpi_lexer_config.Tokens.FAMILY_EXP _ | Elpi_lexer_config.Tokens.FAMILY_GT _ | Elpi_lexer_config.Tokens.FAMILY_LT _ | Elpi_lexer_config.Tokens.FAMILY_PLUS _ | Elpi_lexer_config.Tokens.FAMILY_TICK _ | Elpi_lexer_config.Tokens.IS | Elpi_lexer_config.Tokens.MINUS | Elpi_lexer_config.Tokens.MINUSi | Elpi_lexer_config.Tokens.MINUSr | Elpi_lexer_config.Tokens.MINUSs | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.PIPE | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.RBRACKET | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_MINUS (_menhir_stack, _, _) = _menhir_stack in
            let MenhirCell1_term_noconj (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_265 _endpos_r_ _startpos_l_ l r in
            _menhir_goto_open_term_noconj _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 154
    
    and _menhir_run_155 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term_noconj -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell0_IS (_menhir_stack, _startpos, _endpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v ->
            let _startpos_0 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_1 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_1, _startpos_0, _v) in
            let _v = _menhir_action_068 x in
            _menhir_run_120_spec_155 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.SIGMA ->
            let _startpos_2 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_3 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_3, _startpos_2) in
            let _v = _menhir_action_085 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState155 _tok
        | Elpi_lexer_config.Tokens.REPLACE ->
            let _startpos_4 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_5 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_5, _startpos_4) in
            let _v = _menhir_action_080 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState155 _tok
        | Elpi_lexer_config.Tokens.QUOTED _v ->
            let _startpos_6 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_7 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_7, _startpos_6, _v) in
            let _v = _menhir_action_069 _endpos_x_ _startpos_x_ x in
            _menhir_run_120_spec_155 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.PI ->
            let _startpos_8 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_9 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_9, _startpos_8) in
            let _v = _menhir_action_084 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState155 _tok
        | Elpi_lexer_config.Tokens.NIL ->
            let _startpos_10 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_11 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_11, _startpos_10) in
            let _v = _menhir_action_089 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState155 _tok
        | Elpi_lexer_config.Tokens.NAME ->
            let _startpos_12 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_13 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_13, _startpos_12) in
            let _v = _menhir_action_077 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState155 _tok
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState155
        | Elpi_lexer_config.Tokens.LCURLY ->
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState155
        | Elpi_lexer_config.Tokens.LBRACKET ->
            _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState155
        | Elpi_lexer_config.Tokens.IO _v ->
            let _startpos_14 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_15 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_15, _startpos_14, _v) in
            let _v = _menhir_action_082 c in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState155 _tok
        | Elpi_lexer_config.Tokens.INTEGER _v ->
            let _startpos_16 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_17 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_17, _startpos_16, _v) in
            let _v = _menhir_action_066 x in
            _menhir_run_120_spec_155 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.INDEX ->
            let _startpos_18 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_19 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_19, _startpos_18) in
            let _v = _menhir_action_081 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState155 _tok
        | Elpi_lexer_config.Tokens.IF ->
            let _startpos_20 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_21 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_21, _startpos_20) in
            let _v = _menhir_action_076 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState155 _tok
        | Elpi_lexer_config.Tokens.FRESHUV ->
            let _startpos_22 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_23 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_23, _startpos_22) in
            let _v = _menhir_action_086 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState155 _tok
        | Elpi_lexer_config.Tokens.FLOAT _v ->
            let _startpos_24 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_25 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_25, _startpos_24, _v) in
            let _v = _menhir_action_067 x in
            _menhir_run_120_spec_155 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_TILDE _v ->
            _menhir_run_028 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState155
        | Elpi_lexer_config.Tokens.CUT ->
            let _startpos_26 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_27 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_27, _startpos_26) in
            let _v = _menhir_action_083 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState155 _tok
        | Elpi_lexer_config.Tokens.CONSTANT _v ->
            let _startpos_28 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_29 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_29, _startpos_28, _v) in
            let _v = _menhir_action_075 c in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState155 _tok
        | Elpi_lexer_config.Tokens.BEFORE ->
            let _startpos_30 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_31 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_31, _startpos_30) in
            let _v = _menhir_action_078 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState155 _tok
        | Elpi_lexer_config.Tokens.AFTER ->
            let _startpos_32 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_33 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_33, _startpos_32) in
            let _v = _menhir_action_079 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState155 _tok
        | _ ->
            _eRR 155
    
    and _menhir_run_120_spec_155 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term_noconj _menhir_cell0_IS -> _ -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_320 t in
        _menhir_run_156 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v MenhirState155 _tok
    
    and _menhir_run_156 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_term_noconj _menhir_cell0_IS as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.SLASH ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_125 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MOD ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_141 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSs ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_143 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSr ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_149 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSi ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_151 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_153 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FAMILY_TIMES _v_0 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_145 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_TICK _v_1 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_157 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_2 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_127 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_3 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_034 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_PLUS _v_4 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_159 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_5 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_129 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_6 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_133 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.FAMILY_EXP _v_7 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_161 _menhir_stack _menhir_lexbuf _menhir_lexer _v_7
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_8 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_135 _menhir_stack _menhir_lexbuf _menhir_lexer _v_8
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_9 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_137 _menhir_stack _menhir_lexbuf _menhir_lexer _v_9
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_10 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_131 _menhir_stack _menhir_lexbuf _menhir_lexer _v_10
        | Elpi_lexer_config.Tokens.DIV ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_147 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONS ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_163 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.PIPE | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.RBRACKET | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_IS (_menhir_stack, _, _) = _menhir_stack in
            let MenhirCell1_term_noconj (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_271 _endpos_r_ _startpos_l_ l r in
            _menhir_goto_open_term_noconj _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 156
    
    and _menhir_run_157 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term_noconj -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell0_FAMILY_TICK (_menhir_stack, _v, _startpos, _endpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v_0 ->
            let _startpos_1 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_2 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_2, _startpos_1, _v_0) in
            let _v = _menhir_action_068 x in
            _menhir_run_120_spec_157 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.SIGMA ->
            let _startpos_4 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_5 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_5, _startpos_4) in
            let _v = _menhir_action_085 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState157 _tok
        | Elpi_lexer_config.Tokens.REPLACE ->
            let _startpos_7 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_8 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_8, _startpos_7) in
            let _v = _menhir_action_080 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState157 _tok
        | Elpi_lexer_config.Tokens.QUOTED _v_10 ->
            let _startpos_11 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_12 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_12, _startpos_11, _v_10) in
            let _v = _menhir_action_069 _endpos_x_ _startpos_x_ x in
            _menhir_run_120_spec_157 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.PI ->
            let _startpos_14 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_15 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_15, _startpos_14) in
            let _v = _menhir_action_084 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState157 _tok
        | Elpi_lexer_config.Tokens.NIL ->
            let _startpos_17 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_18 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_18, _startpos_17) in
            let _v = _menhir_action_089 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState157 _tok
        | Elpi_lexer_config.Tokens.NAME ->
            let _startpos_20 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_21 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_21, _startpos_20) in
            let _v = _menhir_action_077 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState157 _tok
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState157
        | Elpi_lexer_config.Tokens.LCURLY ->
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState157
        | Elpi_lexer_config.Tokens.LBRACKET ->
            _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState157
        | Elpi_lexer_config.Tokens.IO _v_23 ->
            let _startpos_24 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_25 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_25, _startpos_24, _v_23) in
            let _v = _menhir_action_082 c in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState157 _tok
        | Elpi_lexer_config.Tokens.INTEGER _v_27 ->
            let _startpos_28 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_29 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_29, _startpos_28, _v_27) in
            let _v = _menhir_action_066 x in
            _menhir_run_120_spec_157 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.INDEX ->
            let _startpos_31 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_32 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_32, _startpos_31) in
            let _v = _menhir_action_081 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState157 _tok
        | Elpi_lexer_config.Tokens.IF ->
            let _startpos_34 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_35 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_35, _startpos_34) in
            let _v = _menhir_action_076 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState157 _tok
        | Elpi_lexer_config.Tokens.FRESHUV ->
            let _startpos_37 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_38 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_38, _startpos_37) in
            let _v = _menhir_action_086 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState157 _tok
        | Elpi_lexer_config.Tokens.FLOAT _v_40 ->
            let _startpos_41 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_42 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_42, _startpos_41, _v_40) in
            let _v = _menhir_action_067 x in
            _menhir_run_120_spec_157 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_TILDE _v_44 ->
            _menhir_run_028 _menhir_stack _menhir_lexbuf _menhir_lexer _v_44 MenhirState157
        | Elpi_lexer_config.Tokens.CUT ->
            let _startpos_45 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_46 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_46, _startpos_45) in
            let _v = _menhir_action_083 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState157 _tok
        | Elpi_lexer_config.Tokens.CONSTANT _v_48 ->
            let _startpos_49 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_50 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_50, _startpos_49, _v_48) in
            let _v = _menhir_action_075 c in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState157 _tok
        | Elpi_lexer_config.Tokens.BEFORE ->
            let _startpos_52 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_53 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_53, _startpos_52) in
            let _v = _menhir_action_078 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState157 _tok
        | Elpi_lexer_config.Tokens.AFTER ->
            let _startpos_55 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_56 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_56, _startpos_55) in
            let _v = _menhir_action_079 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState157 _tok
        | _ ->
            _eRR 157
    
    and _menhir_run_120_spec_157 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term_noconj _menhir_cell0_FAMILY_TICK -> _ -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_320 t in
        _menhir_run_158 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v MenhirState157 _tok
    
    and _menhir_run_158 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_term_noconj _menhir_cell0_FAMILY_TICK as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.SLASH ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_125 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MOD ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_141 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSs ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_143 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSr ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_149 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSi ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_151 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_153 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FAMILY_TIMES _v_0 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_145 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_1 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_127 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_2 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_034 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_PLUS _v_3 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_159 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_4 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_129 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_5 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_133 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_EXP _v_6 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_161 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_7 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_135 _menhir_stack _menhir_lexbuf _menhir_lexer _v_7
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_8 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_137 _menhir_stack _menhir_lexbuf _menhir_lexer _v_8
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_9 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_131 _menhir_stack _menhir_lexbuf _menhir_lexer _v_9
        | Elpi_lexer_config.Tokens.DIV ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_147 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.CONS | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.EQ | Elpi_lexer_config.Tokens.EQ2 | Elpi_lexer_config.Tokens.FAMILY_GT _ | Elpi_lexer_config.Tokens.FAMILY_LT _ | Elpi_lexer_config.Tokens.IS | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.PIPE | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.RBRACKET | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_FAMILY_TICK (_menhir_stack, s, _, _) = _menhir_stack in
            let MenhirCell1_term_noconj (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_262 _endpos_r_ _startpos_l_ l r s in
            _menhir_goto_open_term_noconj _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 158
    
    and _menhir_run_159 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term_noconj -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell0_FAMILY_PLUS (_menhir_stack, _v, _startpos, _endpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v_0 ->
            let _startpos_1 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_2 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_2, _startpos_1, _v_0) in
            let _v = _menhir_action_068 x in
            _menhir_run_120_spec_159 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.SIGMA ->
            let _startpos_4 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_5 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_5, _startpos_4) in
            let _v = _menhir_action_085 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState159 _tok
        | Elpi_lexer_config.Tokens.REPLACE ->
            let _startpos_7 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_8 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_8, _startpos_7) in
            let _v = _menhir_action_080 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState159 _tok
        | Elpi_lexer_config.Tokens.QUOTED _v_10 ->
            let _startpos_11 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_12 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_12, _startpos_11, _v_10) in
            let _v = _menhir_action_069 _endpos_x_ _startpos_x_ x in
            _menhir_run_120_spec_159 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.PI ->
            let _startpos_14 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_15 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_15, _startpos_14) in
            let _v = _menhir_action_084 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState159 _tok
        | Elpi_lexer_config.Tokens.NIL ->
            let _startpos_17 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_18 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_18, _startpos_17) in
            let _v = _menhir_action_089 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState159 _tok
        | Elpi_lexer_config.Tokens.NAME ->
            let _startpos_20 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_21 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_21, _startpos_20) in
            let _v = _menhir_action_077 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState159 _tok
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState159
        | Elpi_lexer_config.Tokens.LCURLY ->
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState159
        | Elpi_lexer_config.Tokens.LBRACKET ->
            _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState159
        | Elpi_lexer_config.Tokens.IO _v_23 ->
            let _startpos_24 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_25 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_25, _startpos_24, _v_23) in
            let _v = _menhir_action_082 c in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState159 _tok
        | Elpi_lexer_config.Tokens.INTEGER _v_27 ->
            let _startpos_28 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_29 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_29, _startpos_28, _v_27) in
            let _v = _menhir_action_066 x in
            _menhir_run_120_spec_159 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.INDEX ->
            let _startpos_31 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_32 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_32, _startpos_31) in
            let _v = _menhir_action_081 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState159 _tok
        | Elpi_lexer_config.Tokens.IF ->
            let _startpos_34 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_35 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_35, _startpos_34) in
            let _v = _menhir_action_076 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState159 _tok
        | Elpi_lexer_config.Tokens.FRESHUV ->
            let _startpos_37 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_38 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_38, _startpos_37) in
            let _v = _menhir_action_086 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState159 _tok
        | Elpi_lexer_config.Tokens.FLOAT _v_40 ->
            let _startpos_41 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_42 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_42, _startpos_41, _v_40) in
            let _v = _menhir_action_067 x in
            _menhir_run_120_spec_159 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_TILDE _v_44 ->
            _menhir_run_028 _menhir_stack _menhir_lexbuf _menhir_lexer _v_44 MenhirState159
        | Elpi_lexer_config.Tokens.CUT ->
            let _startpos_45 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_46 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_46, _startpos_45) in
            let _v = _menhir_action_083 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState159 _tok
        | Elpi_lexer_config.Tokens.CONSTANT _v_48 ->
            let _startpos_49 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_50 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_50, _startpos_49, _v_48) in
            let _v = _menhir_action_075 c in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState159 _tok
        | Elpi_lexer_config.Tokens.BEFORE ->
            let _startpos_52 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_53 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_53, _startpos_52) in
            let _v = _menhir_action_078 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState159 _tok
        | Elpi_lexer_config.Tokens.AFTER ->
            let _startpos_55 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_56 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_56, _startpos_55) in
            let _v = _menhir_action_079 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState159 _tok
        | _ ->
            _eRR 159
    
    and _menhir_run_120_spec_159 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term_noconj _menhir_cell0_FAMILY_PLUS -> _ -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_320 t in
        _menhir_run_160 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v MenhirState159 _tok
    
    and _menhir_run_160 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_term_noconj _menhir_cell0_FAMILY_PLUS as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.SLASH ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_125 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MOD ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_141 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FAMILY_TIMES _v_0 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_145 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_1 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_127 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_2 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_034 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_3 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_129 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_4 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_133 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_5 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_135 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_6 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_137 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_7 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_131 _menhir_stack _menhir_lexbuf _menhir_lexer _v_7
        | Elpi_lexer_config.Tokens.DIV ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_147 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.CONS | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.EQ | Elpi_lexer_config.Tokens.EQ2 | Elpi_lexer_config.Tokens.FAMILY_EXP _ | Elpi_lexer_config.Tokens.FAMILY_GT _ | Elpi_lexer_config.Tokens.FAMILY_LT _ | Elpi_lexer_config.Tokens.FAMILY_PLUS _ | Elpi_lexer_config.Tokens.FAMILY_TICK _ | Elpi_lexer_config.Tokens.IS | Elpi_lexer_config.Tokens.MINUS | Elpi_lexer_config.Tokens.MINUSi | Elpi_lexer_config.Tokens.MINUSr | Elpi_lexer_config.Tokens.MINUSs | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.PIPE | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.RBRACKET | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_FAMILY_PLUS (_menhir_stack, s, _, _) = _menhir_stack in
            let MenhirCell1_term_noconj (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_251 _endpos_r_ _startpos_l_ l r s in
            _menhir_goto_open_term_noconj _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 160
    
    and _menhir_run_161 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term_noconj -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell0_FAMILY_EXP (_menhir_stack, _v, _startpos, _endpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v_0 ->
            let _startpos_1 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_2 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_2, _startpos_1, _v_0) in
            let _v = _menhir_action_068 x in
            _menhir_run_120_spec_161 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.SIGMA ->
            let _startpos_4 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_5 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_5, _startpos_4) in
            let _v = _menhir_action_085 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState161 _tok
        | Elpi_lexer_config.Tokens.REPLACE ->
            let _startpos_7 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_8 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_8, _startpos_7) in
            let _v = _menhir_action_080 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState161 _tok
        | Elpi_lexer_config.Tokens.QUOTED _v_10 ->
            let _startpos_11 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_12 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_12, _startpos_11, _v_10) in
            let _v = _menhir_action_069 _endpos_x_ _startpos_x_ x in
            _menhir_run_120_spec_161 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.PI ->
            let _startpos_14 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_15 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_15, _startpos_14) in
            let _v = _menhir_action_084 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState161 _tok
        | Elpi_lexer_config.Tokens.NIL ->
            let _startpos_17 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_18 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_18, _startpos_17) in
            let _v = _menhir_action_089 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState161 _tok
        | Elpi_lexer_config.Tokens.NAME ->
            let _startpos_20 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_21 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_21, _startpos_20) in
            let _v = _menhir_action_077 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState161 _tok
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState161
        | Elpi_lexer_config.Tokens.LCURLY ->
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState161
        | Elpi_lexer_config.Tokens.LBRACKET ->
            _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState161
        | Elpi_lexer_config.Tokens.IO _v_23 ->
            let _startpos_24 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_25 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_25, _startpos_24, _v_23) in
            let _v = _menhir_action_082 c in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState161 _tok
        | Elpi_lexer_config.Tokens.INTEGER _v_27 ->
            let _startpos_28 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_29 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_29, _startpos_28, _v_27) in
            let _v = _menhir_action_066 x in
            _menhir_run_120_spec_161 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.INDEX ->
            let _startpos_31 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_32 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_32, _startpos_31) in
            let _v = _menhir_action_081 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState161 _tok
        | Elpi_lexer_config.Tokens.IF ->
            let _startpos_34 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_35 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_35, _startpos_34) in
            let _v = _menhir_action_076 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState161 _tok
        | Elpi_lexer_config.Tokens.FRESHUV ->
            let _startpos_37 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_38 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_38, _startpos_37) in
            let _v = _menhir_action_086 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState161 _tok
        | Elpi_lexer_config.Tokens.FLOAT _v_40 ->
            let _startpos_41 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_42 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_42, _startpos_41, _v_40) in
            let _v = _menhir_action_067 x in
            _menhir_run_120_spec_161 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_TILDE _v_44 ->
            _menhir_run_028 _menhir_stack _menhir_lexbuf _menhir_lexer _v_44 MenhirState161
        | Elpi_lexer_config.Tokens.CUT ->
            let _startpos_45 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_46 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_46, _startpos_45) in
            let _v = _menhir_action_083 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState161 _tok
        | Elpi_lexer_config.Tokens.CONSTANT _v_48 ->
            let _startpos_49 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_50 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_50, _startpos_49, _v_48) in
            let _v = _menhir_action_075 c in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState161 _tok
        | Elpi_lexer_config.Tokens.BEFORE ->
            let _startpos_52 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_53 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_53, _startpos_52) in
            let _v = _menhir_action_078 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState161 _tok
        | Elpi_lexer_config.Tokens.AFTER ->
            let _startpos_55 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_56 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_56, _startpos_55) in
            let _v = _menhir_action_079 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState161 _tok
        | _ ->
            _eRR 161
    
    and _menhir_run_120_spec_161 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term_noconj _menhir_cell0_FAMILY_EXP -> _ -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_320 t in
        _menhir_run_162 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v MenhirState161 _tok
    
    and _menhir_run_162 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_term_noconj _menhir_cell0_FAMILY_EXP as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.SLASH ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_125 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MOD ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_141 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FAMILY_TIMES _v_0 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_145 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_1 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_127 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_2 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_034 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_3 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_129 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_4 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_133 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_5 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_135 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_6 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_137 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_7 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_131 _menhir_stack _menhir_lexbuf _menhir_lexer _v_7
        | Elpi_lexer_config.Tokens.DIV ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_147 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.CONS | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.EQ | Elpi_lexer_config.Tokens.EQ2 | Elpi_lexer_config.Tokens.FAMILY_EXP _ | Elpi_lexer_config.Tokens.FAMILY_GT _ | Elpi_lexer_config.Tokens.FAMILY_LT _ | Elpi_lexer_config.Tokens.FAMILY_PLUS _ | Elpi_lexer_config.Tokens.FAMILY_TICK _ | Elpi_lexer_config.Tokens.IS | Elpi_lexer_config.Tokens.MINUS | Elpi_lexer_config.Tokens.MINUSi | Elpi_lexer_config.Tokens.MINUSr | Elpi_lexer_config.Tokens.MINUSs | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.PIPE | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.RBRACKET | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_FAMILY_EXP (_menhir_stack, s, _, _) = _menhir_stack in
            let MenhirCell1_term_noconj (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_254 _endpos_r_ _startpos_l_ l r s in
            _menhir_goto_open_term_noconj _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 162
    
    and _menhir_run_163 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term_noconj -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell0_CONS (_menhir_stack, _startpos, _endpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v ->
            let _startpos_0 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_1 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_1, _startpos_0, _v) in
            let _v = _menhir_action_068 x in
            _menhir_run_120_spec_163 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.SIGMA ->
            let _startpos_2 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_3 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_3, _startpos_2) in
            let _v = _menhir_action_085 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState163 _tok
        | Elpi_lexer_config.Tokens.REPLACE ->
            let _startpos_4 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_5 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_5, _startpos_4) in
            let _v = _menhir_action_080 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState163 _tok
        | Elpi_lexer_config.Tokens.QUOTED _v ->
            let _startpos_6 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_7 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_7, _startpos_6, _v) in
            let _v = _menhir_action_069 _endpos_x_ _startpos_x_ x in
            _menhir_run_120_spec_163 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.PI ->
            let _startpos_8 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_9 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_9, _startpos_8) in
            let _v = _menhir_action_084 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState163 _tok
        | Elpi_lexer_config.Tokens.NIL ->
            let _startpos_10 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_11 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_11, _startpos_10) in
            let _v = _menhir_action_089 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState163 _tok
        | Elpi_lexer_config.Tokens.NAME ->
            let _startpos_12 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_13 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_13, _startpos_12) in
            let _v = _menhir_action_077 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState163 _tok
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState163
        | Elpi_lexer_config.Tokens.LCURLY ->
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState163
        | Elpi_lexer_config.Tokens.LBRACKET ->
            _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState163
        | Elpi_lexer_config.Tokens.IO _v ->
            let _startpos_14 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_15 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_15, _startpos_14, _v) in
            let _v = _menhir_action_082 c in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState163 _tok
        | Elpi_lexer_config.Tokens.INTEGER _v ->
            let _startpos_16 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_17 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_17, _startpos_16, _v) in
            let _v = _menhir_action_066 x in
            _menhir_run_120_spec_163 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.INDEX ->
            let _startpos_18 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_19 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_19, _startpos_18) in
            let _v = _menhir_action_081 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState163 _tok
        | Elpi_lexer_config.Tokens.IF ->
            let _startpos_20 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_21 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_21, _startpos_20) in
            let _v = _menhir_action_076 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState163 _tok
        | Elpi_lexer_config.Tokens.FRESHUV ->
            let _startpos_22 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_23 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_23, _startpos_22) in
            let _v = _menhir_action_086 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState163 _tok
        | Elpi_lexer_config.Tokens.FLOAT _v ->
            let _startpos_24 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_25 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_25, _startpos_24, _v) in
            let _v = _menhir_action_067 x in
            _menhir_run_120_spec_163 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_TILDE _v ->
            _menhir_run_028 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState163
        | Elpi_lexer_config.Tokens.CUT ->
            let _startpos_26 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_27 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_27, _startpos_26) in
            let _v = _menhir_action_083 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState163 _tok
        | Elpi_lexer_config.Tokens.CONSTANT _v ->
            let _startpos_28 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_29 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_29, _startpos_28, _v) in
            let _v = _menhir_action_075 c in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState163 _tok
        | Elpi_lexer_config.Tokens.BEFORE ->
            let _startpos_30 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_31 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_31, _startpos_30) in
            let _v = _menhir_action_078 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState163 _tok
        | Elpi_lexer_config.Tokens.AFTER ->
            let _startpos_32 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_33 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_33, _startpos_32) in
            let _v = _menhir_action_079 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState163 _tok
        | _ ->
            _eRR 163
    
    and _menhir_run_120_spec_163 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term_noconj _menhir_cell0_CONS -> _ -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_320 t in
        _menhir_run_164 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v MenhirState163 _tok
    
    and _menhir_run_164 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_term_noconj _menhir_cell0_CONS as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.SLASH ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_125 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MOD ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_141 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSs ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_143 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSr ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_149 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSi ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_151 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_153 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FAMILY_TIMES _v_0 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_145 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_TICK _v_1 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_157 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_2 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_127 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_3 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_034 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_PLUS _v_4 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_159 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_5 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_129 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_6 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_133 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.FAMILY_EXP _v_7 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_161 _menhir_stack _menhir_lexbuf _menhir_lexer _v_7
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_8 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_135 _menhir_stack _menhir_lexbuf _menhir_lexer _v_8
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_9 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_137 _menhir_stack _menhir_lexbuf _menhir_lexer _v_9
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_10 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_131 _menhir_stack _menhir_lexbuf _menhir_lexer _v_10
        | Elpi_lexer_config.Tokens.DIV ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_147 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONS ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_163 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.EQ | Elpi_lexer_config.Tokens.EQ2 | Elpi_lexer_config.Tokens.FAMILY_GT _ | Elpi_lexer_config.Tokens.FAMILY_LT _ | Elpi_lexer_config.Tokens.IS | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.PIPE | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.RBRACKET | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_CONS (_menhir_stack, _, _) = _menhir_stack in
            let MenhirCell1_term_noconj (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_263 _endpos_r_ _startpos_l_ l r in
            _menhir_goto_open_term_noconj _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 164
    
    and _menhir_run_165 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term_noconj -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell0_FAMILY_LT (_menhir_stack, _v, _startpos, _endpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v_0 ->
            let _startpos_1 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_2 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_2, _startpos_1, _v_0) in
            let _v = _menhir_action_068 x in
            _menhir_run_120_spec_165 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.SIGMA ->
            let _startpos_4 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_5 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_5, _startpos_4) in
            let _v = _menhir_action_085 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState165 _tok
        | Elpi_lexer_config.Tokens.REPLACE ->
            let _startpos_7 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_8 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_8, _startpos_7) in
            let _v = _menhir_action_080 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState165 _tok
        | Elpi_lexer_config.Tokens.QUOTED _v_10 ->
            let _startpos_11 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_12 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_12, _startpos_11, _v_10) in
            let _v = _menhir_action_069 _endpos_x_ _startpos_x_ x in
            _menhir_run_120_spec_165 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.PI ->
            let _startpos_14 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_15 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_15, _startpos_14) in
            let _v = _menhir_action_084 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState165 _tok
        | Elpi_lexer_config.Tokens.NIL ->
            let _startpos_17 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_18 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_18, _startpos_17) in
            let _v = _menhir_action_089 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState165 _tok
        | Elpi_lexer_config.Tokens.NAME ->
            let _startpos_20 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_21 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_21, _startpos_20) in
            let _v = _menhir_action_077 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState165 _tok
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState165
        | Elpi_lexer_config.Tokens.LCURLY ->
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState165
        | Elpi_lexer_config.Tokens.LBRACKET ->
            _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState165
        | Elpi_lexer_config.Tokens.IO _v_23 ->
            let _startpos_24 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_25 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_25, _startpos_24, _v_23) in
            let _v = _menhir_action_082 c in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState165 _tok
        | Elpi_lexer_config.Tokens.INTEGER _v_27 ->
            let _startpos_28 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_29 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_29, _startpos_28, _v_27) in
            let _v = _menhir_action_066 x in
            _menhir_run_120_spec_165 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.INDEX ->
            let _startpos_31 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_32 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_32, _startpos_31) in
            let _v = _menhir_action_081 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState165 _tok
        | Elpi_lexer_config.Tokens.IF ->
            let _startpos_34 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_35 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_35, _startpos_34) in
            let _v = _menhir_action_076 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState165 _tok
        | Elpi_lexer_config.Tokens.FRESHUV ->
            let _startpos_37 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_38 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_38, _startpos_37) in
            let _v = _menhir_action_086 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState165 _tok
        | Elpi_lexer_config.Tokens.FLOAT _v_40 ->
            let _startpos_41 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_42 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_42, _startpos_41, _v_40) in
            let _v = _menhir_action_067 x in
            _menhir_run_120_spec_165 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_TILDE _v_44 ->
            _menhir_run_028 _menhir_stack _menhir_lexbuf _menhir_lexer _v_44 MenhirState165
        | Elpi_lexer_config.Tokens.CUT ->
            let _startpos_45 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_46 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_46, _startpos_45) in
            let _v = _menhir_action_083 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState165 _tok
        | Elpi_lexer_config.Tokens.CONSTANT _v_48 ->
            let _startpos_49 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_50 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_50, _startpos_49, _v_48) in
            let _v = _menhir_action_075 c in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState165 _tok
        | Elpi_lexer_config.Tokens.BEFORE ->
            let _startpos_52 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_53 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_53, _startpos_52) in
            let _v = _menhir_action_078 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState165 _tok
        | Elpi_lexer_config.Tokens.AFTER ->
            let _startpos_55 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_56 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_56, _startpos_55) in
            let _v = _menhir_action_079 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState165 _tok
        | _ ->
            _eRR 165
    
    and _menhir_run_120_spec_165 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term_noconj _menhir_cell0_FAMILY_LT -> _ -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_320 t in
        _menhir_run_166 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v MenhirState165 _tok
    
    and _menhir_run_166 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_term_noconj _menhir_cell0_FAMILY_LT as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.SLASH ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_125 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MOD ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_141 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSs ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_143 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSr ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_149 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSi ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_151 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_153 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FAMILY_TIMES _v_0 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_145 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_TICK _v_1 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_157 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_2 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_127 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_3 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_034 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_PLUS _v_4 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_159 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_5 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_129 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_6 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_133 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.FAMILY_EXP _v_7 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_161 _menhir_stack _menhir_lexbuf _menhir_lexer _v_7
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_8 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_135 _menhir_stack _menhir_lexbuf _menhir_lexer _v_8
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_9 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_137 _menhir_stack _menhir_lexbuf _menhir_lexer _v_9
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_10 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_131 _menhir_stack _menhir_lexbuf _menhir_lexer _v_10
        | Elpi_lexer_config.Tokens.DIV ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_147 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONS ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_163 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.PIPE | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.RBRACKET | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_FAMILY_LT (_menhir_stack, s, _, _) = _menhir_stack in
            let MenhirCell1_term_noconj (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_255 _endpos_r_ _startpos_l_ l r s in
            _menhir_goto_open_term_noconj _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 166
    
    and _menhir_run_167 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term_noconj -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell0_FAMILY_GT (_menhir_stack, _v, _startpos, _endpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v_0 ->
            let _startpos_1 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_2 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_2, _startpos_1, _v_0) in
            let _v = _menhir_action_068 x in
            _menhir_run_120_spec_167 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.SIGMA ->
            let _startpos_4 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_5 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_5, _startpos_4) in
            let _v = _menhir_action_085 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState167 _tok
        | Elpi_lexer_config.Tokens.REPLACE ->
            let _startpos_7 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_8 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_8, _startpos_7) in
            let _v = _menhir_action_080 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState167 _tok
        | Elpi_lexer_config.Tokens.QUOTED _v_10 ->
            let _startpos_11 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_12 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_12, _startpos_11, _v_10) in
            let _v = _menhir_action_069 _endpos_x_ _startpos_x_ x in
            _menhir_run_120_spec_167 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.PI ->
            let _startpos_14 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_15 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_15, _startpos_14) in
            let _v = _menhir_action_084 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState167 _tok
        | Elpi_lexer_config.Tokens.NIL ->
            let _startpos_17 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_18 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_18, _startpos_17) in
            let _v = _menhir_action_089 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState167 _tok
        | Elpi_lexer_config.Tokens.NAME ->
            let _startpos_20 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_21 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_21, _startpos_20) in
            let _v = _menhir_action_077 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState167 _tok
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState167
        | Elpi_lexer_config.Tokens.LCURLY ->
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState167
        | Elpi_lexer_config.Tokens.LBRACKET ->
            _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState167
        | Elpi_lexer_config.Tokens.IO _v_23 ->
            let _startpos_24 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_25 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_25, _startpos_24, _v_23) in
            let _v = _menhir_action_082 c in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState167 _tok
        | Elpi_lexer_config.Tokens.INTEGER _v_27 ->
            let _startpos_28 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_29 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_29, _startpos_28, _v_27) in
            let _v = _menhir_action_066 x in
            _menhir_run_120_spec_167 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.INDEX ->
            let _startpos_31 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_32 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_32, _startpos_31) in
            let _v = _menhir_action_081 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState167 _tok
        | Elpi_lexer_config.Tokens.IF ->
            let _startpos_34 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_35 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_35, _startpos_34) in
            let _v = _menhir_action_076 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState167 _tok
        | Elpi_lexer_config.Tokens.FRESHUV ->
            let _startpos_37 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_38 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_38, _startpos_37) in
            let _v = _menhir_action_086 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState167 _tok
        | Elpi_lexer_config.Tokens.FLOAT _v_40 ->
            let _startpos_41 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_42 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_42, _startpos_41, _v_40) in
            let _v = _menhir_action_067 x in
            _menhir_run_120_spec_167 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_TILDE _v_44 ->
            _menhir_run_028 _menhir_stack _menhir_lexbuf _menhir_lexer _v_44 MenhirState167
        | Elpi_lexer_config.Tokens.CUT ->
            let _startpos_45 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_46 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_46, _startpos_45) in
            let _v = _menhir_action_083 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState167 _tok
        | Elpi_lexer_config.Tokens.CONSTANT _v_48 ->
            let _startpos_49 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_50 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_50, _startpos_49, _v_48) in
            let _v = _menhir_action_075 c in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState167 _tok
        | Elpi_lexer_config.Tokens.BEFORE ->
            let _startpos_52 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_53 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_53, _startpos_52) in
            let _v = _menhir_action_078 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState167 _tok
        | Elpi_lexer_config.Tokens.AFTER ->
            let _startpos_55 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_56 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_56, _startpos_55) in
            let _v = _menhir_action_079 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState167 _tok
        | _ ->
            _eRR 167
    
    and _menhir_run_120_spec_167 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term_noconj _menhir_cell0_FAMILY_GT -> _ -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_320 t in
        _menhir_run_168 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v MenhirState167 _tok
    
    and _menhir_run_168 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_term_noconj _menhir_cell0_FAMILY_GT as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.SLASH ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_125 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MOD ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_141 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSs ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_143 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSr ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_149 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSi ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_151 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_153 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FAMILY_TIMES _v_0 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_145 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_TICK _v_1 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_157 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_2 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_127 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_3 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_034 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_PLUS _v_4 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_159 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_5 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_129 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_6 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_133 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.FAMILY_EXP _v_7 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_161 _menhir_stack _menhir_lexbuf _menhir_lexer _v_7
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_8 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_135 _menhir_stack _menhir_lexbuf _menhir_lexer _v_8
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_9 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_137 _menhir_stack _menhir_lexbuf _menhir_lexer _v_9
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_10 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_131 _menhir_stack _menhir_lexbuf _menhir_lexer _v_10
        | Elpi_lexer_config.Tokens.DIV ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_147 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONS ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_163 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.PIPE | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.RBRACKET | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_FAMILY_GT (_menhir_stack, s, _, _) = _menhir_stack in
            let MenhirCell1_term_noconj (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_256 _endpos_r_ _startpos_l_ l r s in
            _menhir_goto_open_term_noconj _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 168
    
    and _menhir_run_169 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term_noconj -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell0_EQ2 (_menhir_stack, _startpos, _endpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v ->
            let _startpos_0 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_1 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_1, _startpos_0, _v) in
            let _v = _menhir_action_068 x in
            _menhir_run_120_spec_169 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.SIGMA ->
            let _startpos_2 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_3 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_3, _startpos_2) in
            let _v = _menhir_action_085 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState169 _tok
        | Elpi_lexer_config.Tokens.REPLACE ->
            let _startpos_4 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_5 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_5, _startpos_4) in
            let _v = _menhir_action_080 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState169 _tok
        | Elpi_lexer_config.Tokens.QUOTED _v ->
            let _startpos_6 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_7 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_7, _startpos_6, _v) in
            let _v = _menhir_action_069 _endpos_x_ _startpos_x_ x in
            _menhir_run_120_spec_169 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.PI ->
            let _startpos_8 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_9 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_9, _startpos_8) in
            let _v = _menhir_action_084 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState169 _tok
        | Elpi_lexer_config.Tokens.NIL ->
            let _startpos_10 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_11 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_11, _startpos_10) in
            let _v = _menhir_action_089 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState169 _tok
        | Elpi_lexer_config.Tokens.NAME ->
            let _startpos_12 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_13 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_13, _startpos_12) in
            let _v = _menhir_action_077 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState169 _tok
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState169
        | Elpi_lexer_config.Tokens.LCURLY ->
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState169
        | Elpi_lexer_config.Tokens.LBRACKET ->
            _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState169
        | Elpi_lexer_config.Tokens.IO _v ->
            let _startpos_14 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_15 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_15, _startpos_14, _v) in
            let _v = _menhir_action_082 c in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState169 _tok
        | Elpi_lexer_config.Tokens.INTEGER _v ->
            let _startpos_16 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_17 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_17, _startpos_16, _v) in
            let _v = _menhir_action_066 x in
            _menhir_run_120_spec_169 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.INDEX ->
            let _startpos_18 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_19 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_19, _startpos_18) in
            let _v = _menhir_action_081 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState169 _tok
        | Elpi_lexer_config.Tokens.IF ->
            let _startpos_20 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_21 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_21, _startpos_20) in
            let _v = _menhir_action_076 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState169 _tok
        | Elpi_lexer_config.Tokens.FRESHUV ->
            let _startpos_22 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_23 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_23, _startpos_22) in
            let _v = _menhir_action_086 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState169 _tok
        | Elpi_lexer_config.Tokens.FLOAT _v ->
            let _startpos_24 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_25 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_25, _startpos_24, _v) in
            let _v = _menhir_action_067 x in
            _menhir_run_120_spec_169 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_TILDE _v ->
            _menhir_run_028 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState169
        | Elpi_lexer_config.Tokens.CUT ->
            let _startpos_26 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_27 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_27, _startpos_26) in
            let _v = _menhir_action_083 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState169 _tok
        | Elpi_lexer_config.Tokens.CONSTANT _v ->
            let _startpos_28 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_29 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_29, _startpos_28, _v) in
            let _v = _menhir_action_075 c in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState169 _tok
        | Elpi_lexer_config.Tokens.BEFORE ->
            let _startpos_30 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_31 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_31, _startpos_30) in
            let _v = _menhir_action_078 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState169 _tok
        | Elpi_lexer_config.Tokens.AFTER ->
            let _startpos_32 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_33 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_33, _startpos_32) in
            let _v = _menhir_action_079 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState169 _tok
        | _ ->
            _eRR 169
    
    and _menhir_run_120_spec_169 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term_noconj _menhir_cell0_EQ2 -> _ -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_320 t in
        _menhir_run_170 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v MenhirState169 _tok
    
    and _menhir_run_170 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_term_noconj _menhir_cell0_EQ2 as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.SLASH ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_125 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MOD ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_141 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSs ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_143 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSr ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_149 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSi ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_151 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_153 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FAMILY_TIMES _v_0 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_145 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_TICK _v_1 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_157 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_2 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_127 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_3 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_034 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_PLUS _v_4 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_159 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_5 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_129 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_6 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_133 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.FAMILY_EXP _v_7 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_161 _menhir_stack _menhir_lexbuf _menhir_lexer _v_7
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_8 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_135 _menhir_stack _menhir_lexbuf _menhir_lexer _v_8
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_9 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_137 _menhir_stack _menhir_lexbuf _menhir_lexer _v_9
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_10 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_131 _menhir_stack _menhir_lexbuf _menhir_lexer _v_10
        | Elpi_lexer_config.Tokens.DIV ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_147 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONS ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_163 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.PIPE | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.RBRACKET | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_EQ2 (_menhir_stack, _, _) = _menhir_stack in
            let MenhirCell1_term_noconj (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_269 _endpos_r_ _startpos_l_ l r in
            _menhir_goto_open_term_noconj _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 170
    
    and _menhir_run_171 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term_noconj -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell0_EQ (_menhir_stack, _startpos, _endpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v ->
            let _startpos_0 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_1 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_1, _startpos_0, _v) in
            let _v = _menhir_action_068 x in
            _menhir_run_120_spec_171 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.SIGMA ->
            let _startpos_2 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_3 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_3, _startpos_2) in
            let _v = _menhir_action_085 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState171 _tok
        | Elpi_lexer_config.Tokens.REPLACE ->
            let _startpos_4 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_5 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_5, _startpos_4) in
            let _v = _menhir_action_080 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState171 _tok
        | Elpi_lexer_config.Tokens.QUOTED _v ->
            let _startpos_6 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_7 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_7, _startpos_6, _v) in
            let _v = _menhir_action_069 _endpos_x_ _startpos_x_ x in
            _menhir_run_120_spec_171 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.PI ->
            let _startpos_8 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_9 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_9, _startpos_8) in
            let _v = _menhir_action_084 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState171 _tok
        | Elpi_lexer_config.Tokens.NIL ->
            let _startpos_10 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_11 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_11, _startpos_10) in
            let _v = _menhir_action_089 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState171 _tok
        | Elpi_lexer_config.Tokens.NAME ->
            let _startpos_12 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_13 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_13, _startpos_12) in
            let _v = _menhir_action_077 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState171 _tok
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState171
        | Elpi_lexer_config.Tokens.LCURLY ->
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState171
        | Elpi_lexer_config.Tokens.LBRACKET ->
            _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState171
        | Elpi_lexer_config.Tokens.IO _v ->
            let _startpos_14 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_15 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_15, _startpos_14, _v) in
            let _v = _menhir_action_082 c in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState171 _tok
        | Elpi_lexer_config.Tokens.INTEGER _v ->
            let _startpos_16 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_17 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_17, _startpos_16, _v) in
            let _v = _menhir_action_066 x in
            _menhir_run_120_spec_171 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.INDEX ->
            let _startpos_18 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_19 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_19, _startpos_18) in
            let _v = _menhir_action_081 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState171 _tok
        | Elpi_lexer_config.Tokens.IF ->
            let _startpos_20 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_21 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_21, _startpos_20) in
            let _v = _menhir_action_076 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState171 _tok
        | Elpi_lexer_config.Tokens.FRESHUV ->
            let _startpos_22 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_23 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_23, _startpos_22) in
            let _v = _menhir_action_086 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState171 _tok
        | Elpi_lexer_config.Tokens.FLOAT _v ->
            let _startpos_24 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_25 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_25, _startpos_24, _v) in
            let _v = _menhir_action_067 x in
            _menhir_run_120_spec_171 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_TILDE _v ->
            _menhir_run_028 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState171
        | Elpi_lexer_config.Tokens.CUT ->
            let _startpos_26 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_27 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_27, _startpos_26) in
            let _v = _menhir_action_083 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState171 _tok
        | Elpi_lexer_config.Tokens.CONSTANT _v ->
            let _startpos_28 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_29 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_29, _startpos_28, _v) in
            let _v = _menhir_action_075 c in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState171 _tok
        | Elpi_lexer_config.Tokens.BEFORE ->
            let _startpos_30 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_31 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_31, _startpos_30) in
            let _v = _menhir_action_078 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState171 _tok
        | Elpi_lexer_config.Tokens.AFTER ->
            let _startpos_32 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_33 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_33, _startpos_32) in
            let _v = _menhir_action_079 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState171 _tok
        | _ ->
            _eRR 171
    
    and _menhir_run_120_spec_171 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term_noconj _menhir_cell0_EQ -> _ -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_320 t in
        _menhir_run_172 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v MenhirState171 _tok
    
    and _menhir_run_172 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_term_noconj _menhir_cell0_EQ as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.SLASH ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_125 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MOD ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_141 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSs ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_143 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSr ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_149 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSi ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_151 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_153 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FAMILY_TIMES _v_0 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_145 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_TICK _v_1 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_157 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_2 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_127 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_3 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_034 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_PLUS _v_4 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_159 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_5 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_129 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_6 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_133 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.FAMILY_EXP _v_7 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_161 _menhir_stack _menhir_lexbuf _menhir_lexer _v_7
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_8 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_135 _menhir_stack _menhir_lexbuf _menhir_lexer _v_8
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_9 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_137 _menhir_stack _menhir_lexbuf _menhir_lexer _v_9
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_10 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_131 _menhir_stack _menhir_lexbuf _menhir_lexer _v_10
        | Elpi_lexer_config.Tokens.DIV ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_147 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONS ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_163 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.PIPE | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.RBRACKET | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_EQ (_menhir_stack, _, _) = _menhir_stack in
            let MenhirCell1_term_noconj (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_264 _endpos_r_ _startpos_l_ l r in
            _menhir_goto_open_term_noconj _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 172
    
    and _menhir_run_173 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term_noconj -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell0_DARROW (_menhir_stack, _startpos, _endpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v ->
            let _startpos_0 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_1 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_1, _startpos_0, _v) in
            let _v = _menhir_action_068 x in
            _menhir_run_120_spec_173 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.SIGMA ->
            let _startpos_2 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_3 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_3, _startpos_2) in
            let _v = _menhir_action_085 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState173 _tok
        | Elpi_lexer_config.Tokens.REPLACE ->
            let _startpos_4 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_5 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_5, _startpos_4) in
            let _v = _menhir_action_080 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState173 _tok
        | Elpi_lexer_config.Tokens.QUOTED _v ->
            let _startpos_6 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_7 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_7, _startpos_6, _v) in
            let _v = _menhir_action_069 _endpos_x_ _startpos_x_ x in
            _menhir_run_120_spec_173 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.PI ->
            let _startpos_8 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_9 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_9, _startpos_8) in
            let _v = _menhir_action_084 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState173 _tok
        | Elpi_lexer_config.Tokens.NIL ->
            let _startpos_10 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_11 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_11, _startpos_10) in
            let _v = _menhir_action_089 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState173 _tok
        | Elpi_lexer_config.Tokens.NAME ->
            let _startpos_12 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_13 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_13, _startpos_12) in
            let _v = _menhir_action_077 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState173 _tok
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState173
        | Elpi_lexer_config.Tokens.LCURLY ->
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState173
        | Elpi_lexer_config.Tokens.LBRACKET ->
            _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState173
        | Elpi_lexer_config.Tokens.IO _v ->
            let _startpos_14 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_15 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_15, _startpos_14, _v) in
            let _v = _menhir_action_082 c in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState173 _tok
        | Elpi_lexer_config.Tokens.INTEGER _v ->
            let _startpos_16 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_17 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_17, _startpos_16, _v) in
            let _v = _menhir_action_066 x in
            _menhir_run_120_spec_173 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.INDEX ->
            let _startpos_18 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_19 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_19, _startpos_18) in
            let _v = _menhir_action_081 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState173 _tok
        | Elpi_lexer_config.Tokens.IF ->
            let _startpos_20 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_21 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_21, _startpos_20) in
            let _v = _menhir_action_076 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState173 _tok
        | Elpi_lexer_config.Tokens.FRESHUV ->
            let _startpos_22 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_23 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_23, _startpos_22) in
            let _v = _menhir_action_086 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState173 _tok
        | Elpi_lexer_config.Tokens.FLOAT _v ->
            let _startpos_24 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_25 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_25, _startpos_24, _v) in
            let _v = _menhir_action_067 x in
            _menhir_run_120_spec_173 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_TILDE _v ->
            _menhir_run_028 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState173
        | Elpi_lexer_config.Tokens.CUT ->
            let _startpos_26 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_27 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_27, _startpos_26) in
            let _v = _menhir_action_083 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState173 _tok
        | Elpi_lexer_config.Tokens.CONSTANT _v ->
            let _startpos_28 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_29 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_29, _startpos_28, _v) in
            let _v = _menhir_action_075 c in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState173 _tok
        | Elpi_lexer_config.Tokens.BEFORE ->
            let _startpos_30 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_31 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_31, _startpos_30) in
            let _v = _menhir_action_078 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState173 _tok
        | Elpi_lexer_config.Tokens.AFTER ->
            let _startpos_32 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_33 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_33, _startpos_32) in
            let _v = _menhir_action_079 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState173 _tok
        | _ ->
            _eRR 173
    
    and _menhir_run_120_spec_173 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term_noconj _menhir_cell0_DARROW -> _ -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_320 t in
        _menhir_run_174 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v MenhirState173 _tok
    
    and _menhir_run_174 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_term_noconj _menhir_cell0_DARROW as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.SLASH ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_125 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MOD ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_141 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSs ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_143 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSr ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_149 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSi ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_151 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_153 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.IS ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_155 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FAMILY_TIMES _v_0 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_145 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_TICK _v_1 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_157 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_2 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_127 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_3 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_034 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_PLUS _v_4 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_159 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_5 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_129 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_6 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_133 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.FAMILY_LT _v_7 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_165 _menhir_stack _menhir_lexbuf _menhir_lexer _v_7
        | Elpi_lexer_config.Tokens.FAMILY_GT _v_8 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_167 _menhir_stack _menhir_lexbuf _menhir_lexer _v_8
        | Elpi_lexer_config.Tokens.FAMILY_EXP _v_9 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_161 _menhir_stack _menhir_lexbuf _menhir_lexer _v_9
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_10 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_135 _menhir_stack _menhir_lexbuf _menhir_lexer _v_10
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_11 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_137 _menhir_stack _menhir_lexbuf _menhir_lexer _v_11
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_12 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_131 _menhir_stack _menhir_lexbuf _menhir_lexer _v_12
        | Elpi_lexer_config.Tokens.EQ2 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_169 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.EQ ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_171 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.DIV ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_147 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.DARROW ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_173 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONS ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_163 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.PIPE | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.RBRACKET | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_DARROW (_menhir_stack, _, _) = _menhir_stack in
            let MenhirCell1_term_noconj (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_275 _endpos_r_ _startpos_l_ l r in
            _menhir_goto_open_term_noconj _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 174
    
    and _menhir_run_175 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term_noconj -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell0_CONJ2 (_menhir_stack, _startpos, _endpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v ->
            let _startpos_0 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_1 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_1, _startpos_0, _v) in
            let _v = _menhir_action_068 x in
            _menhir_run_120_spec_175 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.SIGMA ->
            let _startpos_2 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_3 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_3, _startpos_2) in
            let _v = _menhir_action_085 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState175 _tok
        | Elpi_lexer_config.Tokens.REPLACE ->
            let _startpos_4 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_5 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_5, _startpos_4) in
            let _v = _menhir_action_080 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState175 _tok
        | Elpi_lexer_config.Tokens.QUOTED _v ->
            let _startpos_6 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_7 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_7, _startpos_6, _v) in
            let _v = _menhir_action_069 _endpos_x_ _startpos_x_ x in
            _menhir_run_120_spec_175 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.PI ->
            let _startpos_8 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_9 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_9, _startpos_8) in
            let _v = _menhir_action_084 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState175 _tok
        | Elpi_lexer_config.Tokens.NIL ->
            let _startpos_10 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_11 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_11, _startpos_10) in
            let _v = _menhir_action_089 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState175 _tok
        | Elpi_lexer_config.Tokens.NAME ->
            let _startpos_12 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_13 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_13, _startpos_12) in
            let _v = _menhir_action_077 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState175 _tok
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState175
        | Elpi_lexer_config.Tokens.LCURLY ->
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState175
        | Elpi_lexer_config.Tokens.LBRACKET ->
            _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState175
        | Elpi_lexer_config.Tokens.IO _v ->
            let _startpos_14 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_15 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_15, _startpos_14, _v) in
            let _v = _menhir_action_082 c in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState175 _tok
        | Elpi_lexer_config.Tokens.INTEGER _v ->
            let _startpos_16 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_17 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_17, _startpos_16, _v) in
            let _v = _menhir_action_066 x in
            _menhir_run_120_spec_175 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.INDEX ->
            let _startpos_18 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_19 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_19, _startpos_18) in
            let _v = _menhir_action_081 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState175 _tok
        | Elpi_lexer_config.Tokens.IF ->
            let _startpos_20 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_21 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_21, _startpos_20) in
            let _v = _menhir_action_076 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState175 _tok
        | Elpi_lexer_config.Tokens.FRESHUV ->
            let _startpos_22 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_23 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_23, _startpos_22) in
            let _v = _menhir_action_086 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState175 _tok
        | Elpi_lexer_config.Tokens.FLOAT _v ->
            let _startpos_24 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_25 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_25, _startpos_24, _v) in
            let _v = _menhir_action_067 x in
            _menhir_run_120_spec_175 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_TILDE _v ->
            _menhir_run_028 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState175
        | Elpi_lexer_config.Tokens.CUT ->
            let _startpos_26 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_27 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_27, _startpos_26) in
            let _v = _menhir_action_083 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState175 _tok
        | Elpi_lexer_config.Tokens.CONSTANT _v ->
            let _startpos_28 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_29 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_29, _startpos_28, _v) in
            let _v = _menhir_action_075 c in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState175 _tok
        | Elpi_lexer_config.Tokens.BEFORE ->
            let _startpos_30 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_31 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_31, _startpos_30) in
            let _v = _menhir_action_078 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState175 _tok
        | Elpi_lexer_config.Tokens.AFTER ->
            let _startpos_32 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_33 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_33, _startpos_32) in
            let _v = _menhir_action_079 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState175 _tok
        | _ ->
            _eRR 175
    
    and _menhir_run_120_spec_175 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term_noconj _menhir_cell0_CONJ2 -> _ -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_320 t in
        _menhir_run_176 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v MenhirState175 _tok
    
    and _menhir_run_176 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_term_noconj _menhir_cell0_CONJ2 as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.SLASH ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_125 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MOD ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_141 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSs ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_143 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSr ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_149 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSi ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_151 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_153 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.IS ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_155 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FAMILY_TIMES _v_0 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_145 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_TICK _v_1 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_157 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_2 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_127 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_3 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_034 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_PLUS _v_4 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_159 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_5 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_129 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_6 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_133 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.FAMILY_LT _v_7 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_165 _menhir_stack _menhir_lexbuf _menhir_lexer _v_7
        | Elpi_lexer_config.Tokens.FAMILY_GT _v_8 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_167 _menhir_stack _menhir_lexbuf _menhir_lexer _v_8
        | Elpi_lexer_config.Tokens.FAMILY_EXP _v_9 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_161 _menhir_stack _menhir_lexbuf _menhir_lexer _v_9
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_10 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_135 _menhir_stack _menhir_lexbuf _menhir_lexer _v_10
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_11 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_137 _menhir_stack _menhir_lexbuf _menhir_lexer _v_11
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_12 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_131 _menhir_stack _menhir_lexbuf _menhir_lexer _v_12
        | Elpi_lexer_config.Tokens.EQ2 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_169 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.EQ ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_171 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.DIV ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_147 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.DARROW ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_173 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONS ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_163 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONJ2 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_175 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.ARROW ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_177 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.PIPE | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.RBRACKET | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_CONJ2 (_menhir_stack, _, _) = _menhir_stack in
            let MenhirCell1_term_noconj (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_278 _endpos_r_ _startpos_l_ l r in
            _menhir_goto_open_term_noconj _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 176
    
    and _menhir_run_177 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term_noconj -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell0_ARROW (_menhir_stack, _startpos, _endpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v ->
            let _startpos_0 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_1 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_1, _startpos_0, _v) in
            let _v = _menhir_action_068 x in
            _menhir_run_120_spec_177 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.SIGMA ->
            let _startpos_2 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_3 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_3, _startpos_2) in
            let _v = _menhir_action_085 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState177 _tok
        | Elpi_lexer_config.Tokens.REPLACE ->
            let _startpos_4 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_5 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_5, _startpos_4) in
            let _v = _menhir_action_080 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState177 _tok
        | Elpi_lexer_config.Tokens.QUOTED _v ->
            let _startpos_6 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_7 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_7, _startpos_6, _v) in
            let _v = _menhir_action_069 _endpos_x_ _startpos_x_ x in
            _menhir_run_120_spec_177 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.PI ->
            let _startpos_8 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_9 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_9, _startpos_8) in
            let _v = _menhir_action_084 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState177 _tok
        | Elpi_lexer_config.Tokens.NIL ->
            let _startpos_10 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_11 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_11, _startpos_10) in
            let _v = _menhir_action_089 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState177 _tok
        | Elpi_lexer_config.Tokens.NAME ->
            let _startpos_12 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_13 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_13, _startpos_12) in
            let _v = _menhir_action_077 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState177 _tok
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState177
        | Elpi_lexer_config.Tokens.LCURLY ->
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState177
        | Elpi_lexer_config.Tokens.LBRACKET ->
            _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState177
        | Elpi_lexer_config.Tokens.IO _v ->
            let _startpos_14 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_15 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_15, _startpos_14, _v) in
            let _v = _menhir_action_082 c in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState177 _tok
        | Elpi_lexer_config.Tokens.INTEGER _v ->
            let _startpos_16 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_17 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_17, _startpos_16, _v) in
            let _v = _menhir_action_066 x in
            _menhir_run_120_spec_177 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.INDEX ->
            let _startpos_18 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_19 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_19, _startpos_18) in
            let _v = _menhir_action_081 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState177 _tok
        | Elpi_lexer_config.Tokens.IF ->
            let _startpos_20 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_21 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_21, _startpos_20) in
            let _v = _menhir_action_076 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState177 _tok
        | Elpi_lexer_config.Tokens.FRESHUV ->
            let _startpos_22 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_23 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_23, _startpos_22) in
            let _v = _menhir_action_086 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState177 _tok
        | Elpi_lexer_config.Tokens.FLOAT _v ->
            let _startpos_24 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_25 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_25, _startpos_24, _v) in
            let _v = _menhir_action_067 x in
            _menhir_run_120_spec_177 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_TILDE _v ->
            _menhir_run_028 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState177
        | Elpi_lexer_config.Tokens.CUT ->
            let _startpos_26 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_27 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_27, _startpos_26) in
            let _v = _menhir_action_083 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState177 _tok
        | Elpi_lexer_config.Tokens.CONSTANT _v ->
            let _startpos_28 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_29 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_29, _startpos_28, _v) in
            let _v = _menhir_action_075 c in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState177 _tok
        | Elpi_lexer_config.Tokens.BEFORE ->
            let _startpos_30 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_31 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_31, _startpos_30) in
            let _v = _menhir_action_078 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState177 _tok
        | Elpi_lexer_config.Tokens.AFTER ->
            let _startpos_32 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_33 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_33, _startpos_32) in
            let _v = _menhir_action_079 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState177 _tok
        | _ ->
            _eRR 177
    
    and _menhir_run_120_spec_177 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term_noconj _menhir_cell0_ARROW -> _ -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_320 t in
        _menhir_run_178 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v MenhirState177 _tok
    
    and _menhir_run_178 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_term_noconj _menhir_cell0_ARROW as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.SLASH ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_125 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MOD ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_141 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSs ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_143 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSr ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_149 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSi ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_151 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_153 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.IS ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_155 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FAMILY_TIMES _v_0 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_145 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_TICK _v_1 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_157 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_2 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_127 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_3 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_034 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_PLUS _v_4 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_159 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_5 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_129 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_6 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_133 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.FAMILY_LT _v_7 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_165 _menhir_stack _menhir_lexbuf _menhir_lexer _v_7
        | Elpi_lexer_config.Tokens.FAMILY_GT _v_8 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_167 _menhir_stack _menhir_lexbuf _menhir_lexer _v_8
        | Elpi_lexer_config.Tokens.FAMILY_EXP _v_9 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_161 _menhir_stack _menhir_lexbuf _menhir_lexer _v_9
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_10 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_135 _menhir_stack _menhir_lexbuf _menhir_lexer _v_10
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_11 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_137 _menhir_stack _menhir_lexbuf _menhir_lexer _v_11
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_12 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_131 _menhir_stack _menhir_lexbuf _menhir_lexer _v_12
        | Elpi_lexer_config.Tokens.EQ2 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_169 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.EQ ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_171 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.DIV ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_147 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.DARROW ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_173 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONS ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_163 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.ARROW ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_177 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.PIPE | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.RBRACKET | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_ARROW (_menhir_stack, _, _) = _menhir_stack in
            let MenhirCell1_term_noconj (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_274 _endpos_r_ _startpos_l_ l r in
            _menhir_goto_open_term_noconj _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 178
    
    and _menhir_run_122 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_PIPE as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.VDASH ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_123 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.SLASH ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_125 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.RBRACKET ->
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let MenhirCell1_PIPE (_menhir_stack, _menhir_s) = _menhir_stack in
            let (x, _endpos__3_) = (_v, _endpos_0) in
            let _v = _menhir_action_166 x in
            _menhir_goto_list_items_tail _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__3_ _v _menhir_s _tok
        | Elpi_lexer_config.Tokens.QDASH ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_180 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.OR ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_139 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MOD ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_141 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSs ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_143 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSr ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_149 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSi ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_151 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_153 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.IS ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_155 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FAMILY_TIMES _v_1 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_145 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_TICK _v_2 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_157 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_3 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_127 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_4 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_034 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_PLUS _v_5 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_159 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_6 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_129 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_7 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_133 _menhir_stack _menhir_lexbuf _menhir_lexer _v_7
        | Elpi_lexer_config.Tokens.FAMILY_LT _v_8 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_165 _menhir_stack _menhir_lexbuf _menhir_lexer _v_8
        | Elpi_lexer_config.Tokens.FAMILY_GT _v_9 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_167 _menhir_stack _menhir_lexbuf _menhir_lexer _v_9
        | Elpi_lexer_config.Tokens.FAMILY_EXP _v_10 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_161 _menhir_stack _menhir_lexbuf _menhir_lexer _v_10
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_11 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_135 _menhir_stack _menhir_lexbuf _menhir_lexer _v_11
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_12 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_137 _menhir_stack _menhir_lexbuf _menhir_lexer _v_12
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_13 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_131 _menhir_stack _menhir_lexbuf _menhir_lexer _v_13
        | Elpi_lexer_config.Tokens.EQ2 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_169 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.EQ ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_171 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.DIV ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_147 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.DARROW ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_173 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONS ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_163 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONJ2 ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_175 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.ARROW ->
            let _menhir_stack = MenhirCell1_term_noconj (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_177 _menhir_stack _menhir_lexbuf _menhir_lexer
        | _ ->
            _eRR 122
    
    and _menhir_goto_list_items : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        match _menhir_s with
        | MenhirState019 ->
            _menhir_run_191 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState187 ->
            _menhir_run_189 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_191 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_LBRACKET -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let MenhirCell1_LBRACKET (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
        let (_endpos_l_, l) = (_endpos, _v) in
        let _v = _menhir_action_071 l in
        _menhir_goto_closed_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_l_ _startpos__1_ _v _menhir_s _tok
    
    and _menhir_run_189 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term_noconj _menhir_cell0_CONJ -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let MenhirCell0_CONJ (_menhir_stack, _, _) = _menhir_stack in
        let MenhirCell1_term_noconj (_menhir_stack, _menhir_s, x, _, _) = _menhir_stack in
        let (_endpos_xs_, xs) = (_endpos, _v) in
        let _v = _menhir_action_165 x xs in
        _menhir_goto_list_items _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_xs_ _v _menhir_s _tok
    
    and _menhir_run_120_spec_184 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term_noconj -> _ -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_320 t in
        _menhir_run_185 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v MenhirState184 _tok
    
    and _menhir_run_120_spec_187 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_term_noconj _menhir_cell0_CONJ -> _ -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_320 t in
        _menhir_run_182 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v MenhirState187 _tok
    
    and _menhir_run_021 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _menhir_stack = MenhirCell1_PIPE (_menhir_stack, _menhir_s) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos, _startpos, _v) in
            let _v = _menhir_action_068 x in
            _menhir_run_120_spec_021 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.SIGMA ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos) in
            let _v = _menhir_action_085 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState021 _tok
        | Elpi_lexer_config.Tokens.REPLACE ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos) in
            let _v = _menhir_action_080 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState021 _tok
        | Elpi_lexer_config.Tokens.QUOTED _v ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos, _startpos, _v) in
            let _v = _menhir_action_069 _endpos_x_ _startpos_x_ x in
            _menhir_run_120_spec_021 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.PI ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos) in
            let _v = _menhir_action_084 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState021 _tok
        | Elpi_lexer_config.Tokens.NIL ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos) in
            let _v = _menhir_action_089 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState021 _tok
        | Elpi_lexer_config.Tokens.NAME ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos) in
            let _v = _menhir_action_077 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState021 _tok
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState021
        | Elpi_lexer_config.Tokens.LCURLY ->
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState021
        | Elpi_lexer_config.Tokens.LBRACKET ->
            _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState021
        | Elpi_lexer_config.Tokens.IO _v ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos, _startpos, _v) in
            let _v = _menhir_action_082 c in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState021 _tok
        | Elpi_lexer_config.Tokens.INTEGER _v ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos, _startpos, _v) in
            let _v = _menhir_action_066 x in
            _menhir_run_120_spec_021 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.INDEX ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos) in
            let _v = _menhir_action_081 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState021 _tok
        | Elpi_lexer_config.Tokens.IF ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos) in
            let _v = _menhir_action_076 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState021 _tok
        | Elpi_lexer_config.Tokens.FRESHUV ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos) in
            let _v = _menhir_action_086 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState021 _tok
        | Elpi_lexer_config.Tokens.FLOAT _v ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos, _startpos, _v) in
            let _v = _menhir_action_067 x in
            _menhir_run_120_spec_021 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_TILDE _v ->
            _menhir_run_028 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState021
        | Elpi_lexer_config.Tokens.CUT ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos) in
            let _v = _menhir_action_083 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState021 _tok
        | Elpi_lexer_config.Tokens.CONSTANT _v ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos, _startpos, _v) in
            let _v = _menhir_action_075 c in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState021 _tok
        | Elpi_lexer_config.Tokens.BEFORE ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos) in
            let _v = _menhir_action_078 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState021 _tok
        | Elpi_lexer_config.Tokens.AFTER ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos) in
            let _v = _menhir_action_079 () in
            _menhir_run_117 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState021 _tok
        | _ ->
            _eRR 21
    
    and _menhir_run_120_spec_021 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_PIPE -> _ -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_320 t in
        _menhir_run_122 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v MenhirState021 _tok
    
    and _menhir_goto_nonempty_list_closed_term_ : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        match _menhir_s with
        | MenhirState460 ->
            _menhir_run_461 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState049 ->
            _menhir_run_050 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState043 ->
            _menhir_run_044 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState036 ->
            _menhir_run_037 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_461 : type  ttv_stack. (((ttv_stack, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_head_term as 'stack) -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_nonempty_list_closed_term_ (_menhir_stack, _menhir_s, _v) in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.BIND ->
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState461
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.CONS | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.DIV | Elpi_lexer_config.Tokens.EQ | Elpi_lexer_config.Tokens.EQ2 | Elpi_lexer_config.Tokens.FAMILY_AND _ | Elpi_lexer_config.Tokens.FAMILY_BTICK _ | Elpi_lexer_config.Tokens.FAMILY_EQ _ | Elpi_lexer_config.Tokens.FAMILY_EXP _ | Elpi_lexer_config.Tokens.FAMILY_GT _ | Elpi_lexer_config.Tokens.FAMILY_LT _ | Elpi_lexer_config.Tokens.FAMILY_MINUS _ | Elpi_lexer_config.Tokens.FAMILY_OR _ | Elpi_lexer_config.Tokens.FAMILY_PLUS _ | Elpi_lexer_config.Tokens.FAMILY_QMARK _ | Elpi_lexer_config.Tokens.FAMILY_SHARP _ | Elpi_lexer_config.Tokens.FAMILY_TICK _ | Elpi_lexer_config.Tokens.FAMILY_TIMES _ | Elpi_lexer_config.Tokens.FULLSTOP | Elpi_lexer_config.Tokens.IS | Elpi_lexer_config.Tokens.MINUS | Elpi_lexer_config.Tokens.MINUSi | Elpi_lexer_config.Tokens.MINUSr | Elpi_lexer_config.Tokens.MINUSs | Elpi_lexer_config.Tokens.MOD | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.SLASH | Elpi_lexer_config.Tokens.VDASH ->
            let _v = _menhir_action_284 () in
            _menhir_run_462 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | _ ->
            _eRR 461
    
    and _menhir_run_462 : type  ttv_stack. (((ttv_stack, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_head_term, _menhir_box_program) _menhir_cell1_nonempty_list_closed_term_ -> _ -> _ -> _ -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let MenhirCell1_nonempty_list_closed_term_ (_menhir_stack, _, args) = _menhir_stack in
        let MenhirCell1_head_term (_menhir_stack, _menhir_s, hd, _startpos_hd_, _endpos_hd_) = _menhir_stack in
        let (_endpos_b_, b) = (_endpos, _v) in
        let _v = _menhir_action_032 _endpos_hd_ _startpos_hd_ args b hd in
        _menhir_goto_clause_hd_open_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_b_ _startpos_hd_ _v _menhir_s _tok
    
    and _menhir_goto_clause_hd_open_term : type  ttv_stack. ((ttv_stack, _menhir_box_program) _menhir_cell1_attributes as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_064 t in
        _menhir_goto_clause_hd_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v _menhir_s _tok
    
    and _menhir_goto_clause_hd_term : type  ttv_stack. ((ttv_stack, _menhir_box_program) _menhir_cell1_attributes as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.VDASH ->
            let _menhir_stack = MenhirCell1_clause_hd_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos_0 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_1 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell0_VDASH (_menhir_stack, _startpos_0, _endpos_1) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Elpi_lexer_config.Tokens.STRING _v_2 ->
                let _startpos_3 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_4 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_4, _startpos_3, _v_2) in
                let _v = _menhir_action_068 x in
                _menhir_run_053_spec_465 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.SIGMA ->
                let _startpos_6 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_7 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_7, _startpos_6) in
                let _v = _menhir_action_085 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState465 _tok
            | Elpi_lexer_config.Tokens.REPLACE ->
                let _startpos_9 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_10 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_10, _startpos_9) in
                let _v = _menhir_action_080 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState465 _tok
            | Elpi_lexer_config.Tokens.QUOTED _v_12 ->
                let _startpos_13 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_14 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_14, _startpos_13, _v_12) in
                let _v = _menhir_action_069 _endpos_x_ _startpos_x_ x in
                _menhir_run_053_spec_465 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.PI ->
                let _startpos_16 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_17 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_17, _startpos_16) in
                let _v = _menhir_action_084 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState465 _tok
            | Elpi_lexer_config.Tokens.NIL ->
                let _startpos_19 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_20 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_20, _startpos_19) in
                let _v = _menhir_action_089 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState465 _tok
            | Elpi_lexer_config.Tokens.NAME ->
                let _startpos_22 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_23 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_23, _startpos_22) in
                let _v = _menhir_action_077 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState465 _tok
            | Elpi_lexer_config.Tokens.LPAREN ->
                _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState465
            | Elpi_lexer_config.Tokens.LCURLY ->
                _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState465
            | Elpi_lexer_config.Tokens.LBRACKET ->
                _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState465
            | Elpi_lexer_config.Tokens.IO _v_25 ->
                let _startpos_26 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_27 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_c_, _startpos_c_, c) = (_endpos_27, _startpos_26, _v_25) in
                let _v = _menhir_action_082 c in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState465 _tok
            | Elpi_lexer_config.Tokens.INTEGER _v_29 ->
                let _startpos_30 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_31 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_31, _startpos_30, _v_29) in
                let _v = _menhir_action_066 x in
                _menhir_run_053_spec_465 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.INDEX ->
                let _startpos_33 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_34 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_34, _startpos_33) in
                let _v = _menhir_action_081 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState465 _tok
            | Elpi_lexer_config.Tokens.IF ->
                let _startpos_36 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_37 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_37, _startpos_36) in
                let _v = _menhir_action_076 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState465 _tok
            | Elpi_lexer_config.Tokens.FRESHUV ->
                let _startpos_39 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_40 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_40, _startpos_39) in
                let _v = _menhir_action_086 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState465 _tok
            | Elpi_lexer_config.Tokens.FLOAT _v_42 ->
                let _startpos_43 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_44 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_44, _startpos_43, _v_42) in
                let _v = _menhir_action_067 x in
                _menhir_run_053_spec_465 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.FAMILY_TILDE _v_46 ->
                _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer _v_46 MenhirState465
            | Elpi_lexer_config.Tokens.CUT ->
                let _startpos_47 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_48 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_48, _startpos_47) in
                let _v = _menhir_action_083 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState465 _tok
            | Elpi_lexer_config.Tokens.CONSTANT _v_50 ->
                let _startpos_51 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_52 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_c_, _startpos_c_, c) = (_endpos_52, _startpos_51, _v_50) in
                let _v = _menhir_action_075 c in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState465 _tok
            | Elpi_lexer_config.Tokens.BEFORE ->
                let _startpos_54 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_55 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_55, _startpos_54) in
                let _v = _menhir_action_078 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState465 _tok
            | Elpi_lexer_config.Tokens.AFTER ->
                let _startpos_57 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_58 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_58, _startpos_57) in
                let _v = _menhir_action_079 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState465 _tok
            | _ ->
                _eRR 465)
        | Elpi_lexer_config.Tokens.SLASH ->
            let _menhir_stack = MenhirCell1_clause_hd_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos_60 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_61 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell0_SLASH (_menhir_stack, _startpos_60, _endpos_61) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Elpi_lexer_config.Tokens.STRING _v_62 ->
                let _startpos_63 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_64 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_64, _startpos_63, _v_62) in
                let _v = _menhir_action_068 x in
                _menhir_run_053_spec_467 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.SIGMA ->
                let _startpos_66 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_67 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_67, _startpos_66) in
                let _v = _menhir_action_085 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState467 _tok
            | Elpi_lexer_config.Tokens.REPLACE ->
                let _startpos_69 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_70 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_70, _startpos_69) in
                let _v = _menhir_action_080 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState467 _tok
            | Elpi_lexer_config.Tokens.QUOTED _v_72 ->
                let _startpos_73 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_74 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_74, _startpos_73, _v_72) in
                let _v = _menhir_action_069 _endpos_x_ _startpos_x_ x in
                _menhir_run_053_spec_467 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.PI ->
                let _startpos_76 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_77 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_77, _startpos_76) in
                let _v = _menhir_action_084 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState467 _tok
            | Elpi_lexer_config.Tokens.NIL ->
                let _startpos_79 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_80 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_80, _startpos_79) in
                let _v = _menhir_action_089 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState467 _tok
            | Elpi_lexer_config.Tokens.NAME ->
                let _startpos_82 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_83 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_83, _startpos_82) in
                let _v = _menhir_action_077 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState467 _tok
            | Elpi_lexer_config.Tokens.LPAREN ->
                _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState467
            | Elpi_lexer_config.Tokens.LCURLY ->
                _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState467
            | Elpi_lexer_config.Tokens.LBRACKET ->
                _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState467
            | Elpi_lexer_config.Tokens.IO _v_85 ->
                let _startpos_86 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_87 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_c_, _startpos_c_, c) = (_endpos_87, _startpos_86, _v_85) in
                let _v = _menhir_action_082 c in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState467 _tok
            | Elpi_lexer_config.Tokens.INTEGER _v_89 ->
                let _startpos_90 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_91 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_91, _startpos_90, _v_89) in
                let _v = _menhir_action_066 x in
                _menhir_run_053_spec_467 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.INDEX ->
                let _startpos_93 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_94 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_94, _startpos_93) in
                let _v = _menhir_action_081 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState467 _tok
            | Elpi_lexer_config.Tokens.IF ->
                let _startpos_96 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_97 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_97, _startpos_96) in
                let _v = _menhir_action_076 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState467 _tok
            | Elpi_lexer_config.Tokens.FRESHUV ->
                let _startpos_99 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_100 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_100, _startpos_99) in
                let _v = _menhir_action_086 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState467 _tok
            | Elpi_lexer_config.Tokens.FLOAT _v_102 ->
                let _startpos_103 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_104 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_104, _startpos_103, _v_102) in
                let _v = _menhir_action_067 x in
                _menhir_run_053_spec_467 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.FAMILY_TILDE _v_106 ->
                _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer _v_106 MenhirState467
            | Elpi_lexer_config.Tokens.CUT ->
                let _startpos_107 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_108 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_108, _startpos_107) in
                let _v = _menhir_action_083 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState467 _tok
            | Elpi_lexer_config.Tokens.CONSTANT _v_110 ->
                let _startpos_111 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_112 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_c_, _startpos_c_, c) = (_endpos_112, _startpos_111, _v_110) in
                let _v = _menhir_action_075 c in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState467 _tok
            | Elpi_lexer_config.Tokens.BEFORE ->
                let _startpos_114 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_115 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_115, _startpos_114) in
                let _v = _menhir_action_078 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState467 _tok
            | Elpi_lexer_config.Tokens.AFTER ->
                let _startpos_117 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_118 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_118, _startpos_117) in
                let _v = _menhir_action_079 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState467 _tok
            | _ ->
                _eRR 467)
        | Elpi_lexer_config.Tokens.QDASH ->
            let _menhir_stack = MenhirCell1_clause_hd_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos_120 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_121 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell0_QDASH (_menhir_stack, _startpos_120, _endpos_121) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Elpi_lexer_config.Tokens.STRING _v_122 ->
                let _startpos_123 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_124 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_124, _startpos_123, _v_122) in
                let _v = _menhir_action_068 x in
                _menhir_run_053_spec_469 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.SIGMA ->
                let _startpos_126 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_127 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_127, _startpos_126) in
                let _v = _menhir_action_085 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState469 _tok
            | Elpi_lexer_config.Tokens.REPLACE ->
                let _startpos_129 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_130 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_130, _startpos_129) in
                let _v = _menhir_action_080 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState469 _tok
            | Elpi_lexer_config.Tokens.QUOTED _v_132 ->
                let _startpos_133 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_134 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_134, _startpos_133, _v_132) in
                let _v = _menhir_action_069 _endpos_x_ _startpos_x_ x in
                _menhir_run_053_spec_469 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.PI ->
                let _startpos_136 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_137 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_137, _startpos_136) in
                let _v = _menhir_action_084 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState469 _tok
            | Elpi_lexer_config.Tokens.NIL ->
                let _startpos_139 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_140 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_140, _startpos_139) in
                let _v = _menhir_action_089 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState469 _tok
            | Elpi_lexer_config.Tokens.NAME ->
                let _startpos_142 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_143 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_143, _startpos_142) in
                let _v = _menhir_action_077 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState469 _tok
            | Elpi_lexer_config.Tokens.LPAREN ->
                _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState469
            | Elpi_lexer_config.Tokens.LCURLY ->
                _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState469
            | Elpi_lexer_config.Tokens.LBRACKET ->
                _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState469
            | Elpi_lexer_config.Tokens.IO _v_145 ->
                let _startpos_146 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_147 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_c_, _startpos_c_, c) = (_endpos_147, _startpos_146, _v_145) in
                let _v = _menhir_action_082 c in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState469 _tok
            | Elpi_lexer_config.Tokens.INTEGER _v_149 ->
                let _startpos_150 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_151 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_151, _startpos_150, _v_149) in
                let _v = _menhir_action_066 x in
                _menhir_run_053_spec_469 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.INDEX ->
                let _startpos_153 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_154 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_154, _startpos_153) in
                let _v = _menhir_action_081 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState469 _tok
            | Elpi_lexer_config.Tokens.IF ->
                let _startpos_156 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_157 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_157, _startpos_156) in
                let _v = _menhir_action_076 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState469 _tok
            | Elpi_lexer_config.Tokens.FRESHUV ->
                let _startpos_159 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_160 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_160, _startpos_159) in
                let _v = _menhir_action_086 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState469 _tok
            | Elpi_lexer_config.Tokens.FLOAT _v_162 ->
                let _startpos_163 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_164 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_164, _startpos_163, _v_162) in
                let _v = _menhir_action_067 x in
                _menhir_run_053_spec_469 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.FAMILY_TILDE _v_166 ->
                _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer _v_166 MenhirState469
            | Elpi_lexer_config.Tokens.CUT ->
                let _startpos_167 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_168 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_168, _startpos_167) in
                let _v = _menhir_action_083 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState469 _tok
            | Elpi_lexer_config.Tokens.CONSTANT _v_170 ->
                let _startpos_171 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_172 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_c_, _startpos_c_, c) = (_endpos_172, _startpos_171, _v_170) in
                let _v = _menhir_action_075 c in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState469 _tok
            | Elpi_lexer_config.Tokens.BEFORE ->
                let _startpos_174 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_175 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_175, _startpos_174) in
                let _v = _menhir_action_078 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState469 _tok
            | Elpi_lexer_config.Tokens.AFTER ->
                let _startpos_177 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_178 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_178, _startpos_177) in
                let _v = _menhir_action_079 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState469 _tok
            | _ ->
                _eRR 469)
        | Elpi_lexer_config.Tokens.OR ->
            let _menhir_stack = MenhirCell1_clause_hd_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos_180 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_181 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell0_OR (_menhir_stack, _startpos_180, _endpos_181) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Elpi_lexer_config.Tokens.STRING _v_182 ->
                let _startpos_183 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_184 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_184, _startpos_183, _v_182) in
                let _v = _menhir_action_068 x in
                _menhir_run_053_spec_471 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.SIGMA ->
                let _startpos_186 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_187 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_187, _startpos_186) in
                let _v = _menhir_action_085 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState471 _tok
            | Elpi_lexer_config.Tokens.REPLACE ->
                let _startpos_189 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_190 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_190, _startpos_189) in
                let _v = _menhir_action_080 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState471 _tok
            | Elpi_lexer_config.Tokens.QUOTED _v_192 ->
                let _startpos_193 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_194 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_194, _startpos_193, _v_192) in
                let _v = _menhir_action_069 _endpos_x_ _startpos_x_ x in
                _menhir_run_053_spec_471 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.PI ->
                let _startpos_196 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_197 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_197, _startpos_196) in
                let _v = _menhir_action_084 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState471 _tok
            | Elpi_lexer_config.Tokens.NIL ->
                let _startpos_199 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_200 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_200, _startpos_199) in
                let _v = _menhir_action_089 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState471 _tok
            | Elpi_lexer_config.Tokens.NAME ->
                let _startpos_202 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_203 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_203, _startpos_202) in
                let _v = _menhir_action_077 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState471 _tok
            | Elpi_lexer_config.Tokens.LPAREN ->
                _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState471
            | Elpi_lexer_config.Tokens.LCURLY ->
                _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState471
            | Elpi_lexer_config.Tokens.LBRACKET ->
                _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState471
            | Elpi_lexer_config.Tokens.IO _v_205 ->
                let _startpos_206 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_207 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_c_, _startpos_c_, c) = (_endpos_207, _startpos_206, _v_205) in
                let _v = _menhir_action_082 c in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState471 _tok
            | Elpi_lexer_config.Tokens.INTEGER _v_209 ->
                let _startpos_210 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_211 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_211, _startpos_210, _v_209) in
                let _v = _menhir_action_066 x in
                _menhir_run_053_spec_471 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.INDEX ->
                let _startpos_213 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_214 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_214, _startpos_213) in
                let _v = _menhir_action_081 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState471 _tok
            | Elpi_lexer_config.Tokens.IF ->
                let _startpos_216 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_217 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_217, _startpos_216) in
                let _v = _menhir_action_076 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState471 _tok
            | Elpi_lexer_config.Tokens.FRESHUV ->
                let _startpos_219 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_220 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_220, _startpos_219) in
                let _v = _menhir_action_086 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState471 _tok
            | Elpi_lexer_config.Tokens.FLOAT _v_222 ->
                let _startpos_223 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_224 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_224, _startpos_223, _v_222) in
                let _v = _menhir_action_067 x in
                _menhir_run_053_spec_471 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.FAMILY_TILDE _v_226 ->
                _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer _v_226 MenhirState471
            | Elpi_lexer_config.Tokens.CUT ->
                let _startpos_227 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_228 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_228, _startpos_227) in
                let _v = _menhir_action_083 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState471 _tok
            | Elpi_lexer_config.Tokens.CONSTANT _v_230 ->
                let _startpos_231 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_232 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_c_, _startpos_c_, c) = (_endpos_232, _startpos_231, _v_230) in
                let _v = _menhir_action_075 c in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState471 _tok
            | Elpi_lexer_config.Tokens.BEFORE ->
                let _startpos_234 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_235 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_235, _startpos_234) in
                let _v = _menhir_action_078 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState471 _tok
            | Elpi_lexer_config.Tokens.AFTER ->
                let _startpos_237 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_238 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_238, _startpos_237) in
                let _v = _menhir_action_079 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState471 _tok
            | _ ->
                _eRR 471)
        | Elpi_lexer_config.Tokens.MOD ->
            let _menhir_stack = MenhirCell1_clause_hd_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos_240 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_241 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell0_MOD (_menhir_stack, _startpos_240, _endpos_241) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Elpi_lexer_config.Tokens.STRING _v_242 ->
                let _startpos_243 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_244 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_244, _startpos_243, _v_242) in
                let _v = _menhir_action_068 x in
                _menhir_run_053_spec_473 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.SIGMA ->
                let _startpos_246 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_247 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_247, _startpos_246) in
                let _v = _menhir_action_085 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState473 _tok
            | Elpi_lexer_config.Tokens.REPLACE ->
                let _startpos_249 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_250 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_250, _startpos_249) in
                let _v = _menhir_action_080 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState473 _tok
            | Elpi_lexer_config.Tokens.QUOTED _v_252 ->
                let _startpos_253 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_254 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_254, _startpos_253, _v_252) in
                let _v = _menhir_action_069 _endpos_x_ _startpos_x_ x in
                _menhir_run_053_spec_473 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.PI ->
                let _startpos_256 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_257 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_257, _startpos_256) in
                let _v = _menhir_action_084 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState473 _tok
            | Elpi_lexer_config.Tokens.NIL ->
                let _startpos_259 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_260 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_260, _startpos_259) in
                let _v = _menhir_action_089 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState473 _tok
            | Elpi_lexer_config.Tokens.NAME ->
                let _startpos_262 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_263 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_263, _startpos_262) in
                let _v = _menhir_action_077 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState473 _tok
            | Elpi_lexer_config.Tokens.LPAREN ->
                _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState473
            | Elpi_lexer_config.Tokens.LCURLY ->
                _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState473
            | Elpi_lexer_config.Tokens.LBRACKET ->
                _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState473
            | Elpi_lexer_config.Tokens.IO _v_265 ->
                let _startpos_266 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_267 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_c_, _startpos_c_, c) = (_endpos_267, _startpos_266, _v_265) in
                let _v = _menhir_action_082 c in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState473 _tok
            | Elpi_lexer_config.Tokens.INTEGER _v_269 ->
                let _startpos_270 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_271 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_271, _startpos_270, _v_269) in
                let _v = _menhir_action_066 x in
                _menhir_run_053_spec_473 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.INDEX ->
                let _startpos_273 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_274 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_274, _startpos_273) in
                let _v = _menhir_action_081 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState473 _tok
            | Elpi_lexer_config.Tokens.IF ->
                let _startpos_276 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_277 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_277, _startpos_276) in
                let _v = _menhir_action_076 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState473 _tok
            | Elpi_lexer_config.Tokens.FRESHUV ->
                let _startpos_279 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_280 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_280, _startpos_279) in
                let _v = _menhir_action_086 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState473 _tok
            | Elpi_lexer_config.Tokens.FLOAT _v_282 ->
                let _startpos_283 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_284 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_284, _startpos_283, _v_282) in
                let _v = _menhir_action_067 x in
                _menhir_run_053_spec_473 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.FAMILY_TILDE _v_286 ->
                _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer _v_286 MenhirState473
            | Elpi_lexer_config.Tokens.CUT ->
                let _startpos_287 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_288 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_288, _startpos_287) in
                let _v = _menhir_action_083 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState473 _tok
            | Elpi_lexer_config.Tokens.CONSTANT _v_290 ->
                let _startpos_291 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_292 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_c_, _startpos_c_, c) = (_endpos_292, _startpos_291, _v_290) in
                let _v = _menhir_action_075 c in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState473 _tok
            | Elpi_lexer_config.Tokens.BEFORE ->
                let _startpos_294 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_295 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_295, _startpos_294) in
                let _v = _menhir_action_078 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState473 _tok
            | Elpi_lexer_config.Tokens.AFTER ->
                let _startpos_297 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_298 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_298, _startpos_297) in
                let _v = _menhir_action_079 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState473 _tok
            | _ ->
                _eRR 473)
        | Elpi_lexer_config.Tokens.MINUSs ->
            let _menhir_stack = MenhirCell1_clause_hd_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos_300 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_301 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell0_MINUSs (_menhir_stack, _startpos_300, _endpos_301) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Elpi_lexer_config.Tokens.STRING _v_302 ->
                let _startpos_303 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_304 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_304, _startpos_303, _v_302) in
                let _v = _menhir_action_068 x in
                _menhir_run_053_spec_475 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.SIGMA ->
                let _startpos_306 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_307 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_307, _startpos_306) in
                let _v = _menhir_action_085 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState475 _tok
            | Elpi_lexer_config.Tokens.REPLACE ->
                let _startpos_309 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_310 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_310, _startpos_309) in
                let _v = _menhir_action_080 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState475 _tok
            | Elpi_lexer_config.Tokens.QUOTED _v_312 ->
                let _startpos_313 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_314 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_314, _startpos_313, _v_312) in
                let _v = _menhir_action_069 _endpos_x_ _startpos_x_ x in
                _menhir_run_053_spec_475 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.PI ->
                let _startpos_316 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_317 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_317, _startpos_316) in
                let _v = _menhir_action_084 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState475 _tok
            | Elpi_lexer_config.Tokens.NIL ->
                let _startpos_319 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_320 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_320, _startpos_319) in
                let _v = _menhir_action_089 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState475 _tok
            | Elpi_lexer_config.Tokens.NAME ->
                let _startpos_322 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_323 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_323, _startpos_322) in
                let _v = _menhir_action_077 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState475 _tok
            | Elpi_lexer_config.Tokens.LPAREN ->
                _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState475
            | Elpi_lexer_config.Tokens.LCURLY ->
                _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState475
            | Elpi_lexer_config.Tokens.LBRACKET ->
                _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState475
            | Elpi_lexer_config.Tokens.IO _v_325 ->
                let _startpos_326 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_327 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_c_, _startpos_c_, c) = (_endpos_327, _startpos_326, _v_325) in
                let _v = _menhir_action_082 c in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState475 _tok
            | Elpi_lexer_config.Tokens.INTEGER _v_329 ->
                let _startpos_330 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_331 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_331, _startpos_330, _v_329) in
                let _v = _menhir_action_066 x in
                _menhir_run_053_spec_475 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.INDEX ->
                let _startpos_333 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_334 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_334, _startpos_333) in
                let _v = _menhir_action_081 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState475 _tok
            | Elpi_lexer_config.Tokens.IF ->
                let _startpos_336 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_337 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_337, _startpos_336) in
                let _v = _menhir_action_076 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState475 _tok
            | Elpi_lexer_config.Tokens.FRESHUV ->
                let _startpos_339 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_340 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_340, _startpos_339) in
                let _v = _menhir_action_086 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState475 _tok
            | Elpi_lexer_config.Tokens.FLOAT _v_342 ->
                let _startpos_343 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_344 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_344, _startpos_343, _v_342) in
                let _v = _menhir_action_067 x in
                _menhir_run_053_spec_475 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.FAMILY_TILDE _v_346 ->
                _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer _v_346 MenhirState475
            | Elpi_lexer_config.Tokens.CUT ->
                let _startpos_347 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_348 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_348, _startpos_347) in
                let _v = _menhir_action_083 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState475 _tok
            | Elpi_lexer_config.Tokens.CONSTANT _v_350 ->
                let _startpos_351 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_352 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_c_, _startpos_c_, c) = (_endpos_352, _startpos_351, _v_350) in
                let _v = _menhir_action_075 c in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState475 _tok
            | Elpi_lexer_config.Tokens.BEFORE ->
                let _startpos_354 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_355 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_355, _startpos_354) in
                let _v = _menhir_action_078 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState475 _tok
            | Elpi_lexer_config.Tokens.AFTER ->
                let _startpos_357 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_358 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_358, _startpos_357) in
                let _v = _menhir_action_079 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState475 _tok
            | _ ->
                _eRR 475)
        | Elpi_lexer_config.Tokens.MINUSr ->
            let _menhir_stack = MenhirCell1_clause_hd_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos_360 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_361 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell0_MINUSr (_menhir_stack, _startpos_360, _endpos_361) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Elpi_lexer_config.Tokens.STRING _v_362 ->
                let _startpos_363 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_364 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_364, _startpos_363, _v_362) in
                let _v = _menhir_action_068 x in
                _menhir_run_053_spec_477 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.SIGMA ->
                let _startpos_366 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_367 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_367, _startpos_366) in
                let _v = _menhir_action_085 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState477 _tok
            | Elpi_lexer_config.Tokens.REPLACE ->
                let _startpos_369 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_370 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_370, _startpos_369) in
                let _v = _menhir_action_080 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState477 _tok
            | Elpi_lexer_config.Tokens.QUOTED _v_372 ->
                let _startpos_373 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_374 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_374, _startpos_373, _v_372) in
                let _v = _menhir_action_069 _endpos_x_ _startpos_x_ x in
                _menhir_run_053_spec_477 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.PI ->
                let _startpos_376 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_377 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_377, _startpos_376) in
                let _v = _menhir_action_084 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState477 _tok
            | Elpi_lexer_config.Tokens.NIL ->
                let _startpos_379 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_380 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_380, _startpos_379) in
                let _v = _menhir_action_089 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState477 _tok
            | Elpi_lexer_config.Tokens.NAME ->
                let _startpos_382 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_383 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_383, _startpos_382) in
                let _v = _menhir_action_077 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState477 _tok
            | Elpi_lexer_config.Tokens.LPAREN ->
                _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState477
            | Elpi_lexer_config.Tokens.LCURLY ->
                _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState477
            | Elpi_lexer_config.Tokens.LBRACKET ->
                _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState477
            | Elpi_lexer_config.Tokens.IO _v_385 ->
                let _startpos_386 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_387 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_c_, _startpos_c_, c) = (_endpos_387, _startpos_386, _v_385) in
                let _v = _menhir_action_082 c in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState477 _tok
            | Elpi_lexer_config.Tokens.INTEGER _v_389 ->
                let _startpos_390 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_391 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_391, _startpos_390, _v_389) in
                let _v = _menhir_action_066 x in
                _menhir_run_053_spec_477 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.INDEX ->
                let _startpos_393 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_394 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_394, _startpos_393) in
                let _v = _menhir_action_081 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState477 _tok
            | Elpi_lexer_config.Tokens.IF ->
                let _startpos_396 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_397 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_397, _startpos_396) in
                let _v = _menhir_action_076 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState477 _tok
            | Elpi_lexer_config.Tokens.FRESHUV ->
                let _startpos_399 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_400 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_400, _startpos_399) in
                let _v = _menhir_action_086 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState477 _tok
            | Elpi_lexer_config.Tokens.FLOAT _v_402 ->
                let _startpos_403 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_404 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_404, _startpos_403, _v_402) in
                let _v = _menhir_action_067 x in
                _menhir_run_053_spec_477 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.FAMILY_TILDE _v_406 ->
                _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer _v_406 MenhirState477
            | Elpi_lexer_config.Tokens.CUT ->
                let _startpos_407 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_408 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_408, _startpos_407) in
                let _v = _menhir_action_083 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState477 _tok
            | Elpi_lexer_config.Tokens.CONSTANT _v_410 ->
                let _startpos_411 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_412 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_c_, _startpos_c_, c) = (_endpos_412, _startpos_411, _v_410) in
                let _v = _menhir_action_075 c in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState477 _tok
            | Elpi_lexer_config.Tokens.BEFORE ->
                let _startpos_414 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_415 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_415, _startpos_414) in
                let _v = _menhir_action_078 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState477 _tok
            | Elpi_lexer_config.Tokens.AFTER ->
                let _startpos_417 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_418 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_418, _startpos_417) in
                let _v = _menhir_action_079 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState477 _tok
            | _ ->
                _eRR 477)
        | Elpi_lexer_config.Tokens.MINUSi ->
            let _menhir_stack = MenhirCell1_clause_hd_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos_420 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_421 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell0_MINUSi (_menhir_stack, _startpos_420, _endpos_421) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Elpi_lexer_config.Tokens.STRING _v_422 ->
                let _startpos_423 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_424 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_424, _startpos_423, _v_422) in
                let _v = _menhir_action_068 x in
                _menhir_run_053_spec_479 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.SIGMA ->
                let _startpos_426 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_427 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_427, _startpos_426) in
                let _v = _menhir_action_085 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState479 _tok
            | Elpi_lexer_config.Tokens.REPLACE ->
                let _startpos_429 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_430 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_430, _startpos_429) in
                let _v = _menhir_action_080 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState479 _tok
            | Elpi_lexer_config.Tokens.QUOTED _v_432 ->
                let _startpos_433 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_434 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_434, _startpos_433, _v_432) in
                let _v = _menhir_action_069 _endpos_x_ _startpos_x_ x in
                _menhir_run_053_spec_479 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.PI ->
                let _startpos_436 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_437 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_437, _startpos_436) in
                let _v = _menhir_action_084 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState479 _tok
            | Elpi_lexer_config.Tokens.NIL ->
                let _startpos_439 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_440 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_440, _startpos_439) in
                let _v = _menhir_action_089 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState479 _tok
            | Elpi_lexer_config.Tokens.NAME ->
                let _startpos_442 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_443 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_443, _startpos_442) in
                let _v = _menhir_action_077 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState479 _tok
            | Elpi_lexer_config.Tokens.LPAREN ->
                _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState479
            | Elpi_lexer_config.Tokens.LCURLY ->
                _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState479
            | Elpi_lexer_config.Tokens.LBRACKET ->
                _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState479
            | Elpi_lexer_config.Tokens.IO _v_445 ->
                let _startpos_446 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_447 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_c_, _startpos_c_, c) = (_endpos_447, _startpos_446, _v_445) in
                let _v = _menhir_action_082 c in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState479 _tok
            | Elpi_lexer_config.Tokens.INTEGER _v_449 ->
                let _startpos_450 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_451 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_451, _startpos_450, _v_449) in
                let _v = _menhir_action_066 x in
                _menhir_run_053_spec_479 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.INDEX ->
                let _startpos_453 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_454 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_454, _startpos_453) in
                let _v = _menhir_action_081 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState479 _tok
            | Elpi_lexer_config.Tokens.IF ->
                let _startpos_456 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_457 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_457, _startpos_456) in
                let _v = _menhir_action_076 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState479 _tok
            | Elpi_lexer_config.Tokens.FRESHUV ->
                let _startpos_459 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_460 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_460, _startpos_459) in
                let _v = _menhir_action_086 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState479 _tok
            | Elpi_lexer_config.Tokens.FLOAT _v_462 ->
                let _startpos_463 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_464 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_464, _startpos_463, _v_462) in
                let _v = _menhir_action_067 x in
                _menhir_run_053_spec_479 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.FAMILY_TILDE _v_466 ->
                _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer _v_466 MenhirState479
            | Elpi_lexer_config.Tokens.CUT ->
                let _startpos_467 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_468 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_468, _startpos_467) in
                let _v = _menhir_action_083 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState479 _tok
            | Elpi_lexer_config.Tokens.CONSTANT _v_470 ->
                let _startpos_471 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_472 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_c_, _startpos_c_, c) = (_endpos_472, _startpos_471, _v_470) in
                let _v = _menhir_action_075 c in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState479 _tok
            | Elpi_lexer_config.Tokens.BEFORE ->
                let _startpos_474 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_475 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_475, _startpos_474) in
                let _v = _menhir_action_078 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState479 _tok
            | Elpi_lexer_config.Tokens.AFTER ->
                let _startpos_477 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_478 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_478, _startpos_477) in
                let _v = _menhir_action_079 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState479 _tok
            | _ ->
                _eRR 479)
        | Elpi_lexer_config.Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_clause_hd_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos_480 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_481 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell0_MINUS (_menhir_stack, _startpos_480, _endpos_481) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Elpi_lexer_config.Tokens.STRING _v_482 ->
                let _startpos_483 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_484 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_484, _startpos_483, _v_482) in
                let _v = _menhir_action_068 x in
                _menhir_run_053_spec_481 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.SIGMA ->
                let _startpos_486 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_487 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_487, _startpos_486) in
                let _v = _menhir_action_085 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState481 _tok
            | Elpi_lexer_config.Tokens.REPLACE ->
                let _startpos_489 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_490 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_490, _startpos_489) in
                let _v = _menhir_action_080 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState481 _tok
            | Elpi_lexer_config.Tokens.QUOTED _v_492 ->
                let _startpos_493 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_494 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_494, _startpos_493, _v_492) in
                let _v = _menhir_action_069 _endpos_x_ _startpos_x_ x in
                _menhir_run_053_spec_481 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.PI ->
                let _startpos_496 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_497 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_497, _startpos_496) in
                let _v = _menhir_action_084 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState481 _tok
            | Elpi_lexer_config.Tokens.NIL ->
                let _startpos_499 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_500 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_500, _startpos_499) in
                let _v = _menhir_action_089 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState481 _tok
            | Elpi_lexer_config.Tokens.NAME ->
                let _startpos_502 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_503 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_503, _startpos_502) in
                let _v = _menhir_action_077 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState481 _tok
            | Elpi_lexer_config.Tokens.LPAREN ->
                _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState481
            | Elpi_lexer_config.Tokens.LCURLY ->
                _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState481
            | Elpi_lexer_config.Tokens.LBRACKET ->
                _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState481
            | Elpi_lexer_config.Tokens.IO _v_505 ->
                let _startpos_506 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_507 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_c_, _startpos_c_, c) = (_endpos_507, _startpos_506, _v_505) in
                let _v = _menhir_action_082 c in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState481 _tok
            | Elpi_lexer_config.Tokens.INTEGER _v_509 ->
                let _startpos_510 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_511 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_511, _startpos_510, _v_509) in
                let _v = _menhir_action_066 x in
                _menhir_run_053_spec_481 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.INDEX ->
                let _startpos_513 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_514 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_514, _startpos_513) in
                let _v = _menhir_action_081 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState481 _tok
            | Elpi_lexer_config.Tokens.IF ->
                let _startpos_516 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_517 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_517, _startpos_516) in
                let _v = _menhir_action_076 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState481 _tok
            | Elpi_lexer_config.Tokens.FRESHUV ->
                let _startpos_519 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_520 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_520, _startpos_519) in
                let _v = _menhir_action_086 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState481 _tok
            | Elpi_lexer_config.Tokens.FLOAT _v_522 ->
                let _startpos_523 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_524 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_524, _startpos_523, _v_522) in
                let _v = _menhir_action_067 x in
                _menhir_run_053_spec_481 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.FAMILY_TILDE _v_526 ->
                _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer _v_526 MenhirState481
            | Elpi_lexer_config.Tokens.CUT ->
                let _startpos_527 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_528 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_528, _startpos_527) in
                let _v = _menhir_action_083 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState481 _tok
            | Elpi_lexer_config.Tokens.CONSTANT _v_530 ->
                let _startpos_531 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_532 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_c_, _startpos_c_, c) = (_endpos_532, _startpos_531, _v_530) in
                let _v = _menhir_action_075 c in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState481 _tok
            | Elpi_lexer_config.Tokens.BEFORE ->
                let _startpos_534 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_535 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_535, _startpos_534) in
                let _v = _menhir_action_078 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState481 _tok
            | Elpi_lexer_config.Tokens.AFTER ->
                let _startpos_537 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_538 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_538, _startpos_537) in
                let _v = _menhir_action_079 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState481 _tok
            | _ ->
                _eRR 481)
        | Elpi_lexer_config.Tokens.IS ->
            let _menhir_stack = MenhirCell1_clause_hd_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos_540 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_541 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell0_IS (_menhir_stack, _startpos_540, _endpos_541) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Elpi_lexer_config.Tokens.STRING _v_542 ->
                let _startpos_543 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_544 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_544, _startpos_543, _v_542) in
                let _v = _menhir_action_068 x in
                _menhir_run_053_spec_483 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.SIGMA ->
                let _startpos_546 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_547 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_547, _startpos_546) in
                let _v = _menhir_action_085 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState483 _tok
            | Elpi_lexer_config.Tokens.REPLACE ->
                let _startpos_549 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_550 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_550, _startpos_549) in
                let _v = _menhir_action_080 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState483 _tok
            | Elpi_lexer_config.Tokens.QUOTED _v_552 ->
                let _startpos_553 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_554 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_554, _startpos_553, _v_552) in
                let _v = _menhir_action_069 _endpos_x_ _startpos_x_ x in
                _menhir_run_053_spec_483 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.PI ->
                let _startpos_556 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_557 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_557, _startpos_556) in
                let _v = _menhir_action_084 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState483 _tok
            | Elpi_lexer_config.Tokens.NIL ->
                let _startpos_559 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_560 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_560, _startpos_559) in
                let _v = _menhir_action_089 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState483 _tok
            | Elpi_lexer_config.Tokens.NAME ->
                let _startpos_562 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_563 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_563, _startpos_562) in
                let _v = _menhir_action_077 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState483 _tok
            | Elpi_lexer_config.Tokens.LPAREN ->
                _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState483
            | Elpi_lexer_config.Tokens.LCURLY ->
                _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState483
            | Elpi_lexer_config.Tokens.LBRACKET ->
                _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState483
            | Elpi_lexer_config.Tokens.IO _v_565 ->
                let _startpos_566 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_567 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_c_, _startpos_c_, c) = (_endpos_567, _startpos_566, _v_565) in
                let _v = _menhir_action_082 c in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState483 _tok
            | Elpi_lexer_config.Tokens.INTEGER _v_569 ->
                let _startpos_570 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_571 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_571, _startpos_570, _v_569) in
                let _v = _menhir_action_066 x in
                _menhir_run_053_spec_483 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.INDEX ->
                let _startpos_573 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_574 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_574, _startpos_573) in
                let _v = _menhir_action_081 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState483 _tok
            | Elpi_lexer_config.Tokens.IF ->
                let _startpos_576 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_577 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_577, _startpos_576) in
                let _v = _menhir_action_076 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState483 _tok
            | Elpi_lexer_config.Tokens.FRESHUV ->
                let _startpos_579 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_580 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_580, _startpos_579) in
                let _v = _menhir_action_086 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState483 _tok
            | Elpi_lexer_config.Tokens.FLOAT _v_582 ->
                let _startpos_583 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_584 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_584, _startpos_583, _v_582) in
                let _v = _menhir_action_067 x in
                _menhir_run_053_spec_483 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.FAMILY_TILDE _v_586 ->
                _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer _v_586 MenhirState483
            | Elpi_lexer_config.Tokens.CUT ->
                let _startpos_587 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_588 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_588, _startpos_587) in
                let _v = _menhir_action_083 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState483 _tok
            | Elpi_lexer_config.Tokens.CONSTANT _v_590 ->
                let _startpos_591 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_592 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_c_, _startpos_c_, c) = (_endpos_592, _startpos_591, _v_590) in
                let _v = _menhir_action_075 c in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState483 _tok
            | Elpi_lexer_config.Tokens.BEFORE ->
                let _startpos_594 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_595 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_595, _startpos_594) in
                let _v = _menhir_action_078 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState483 _tok
            | Elpi_lexer_config.Tokens.AFTER ->
                let _startpos_597 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_598 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_598, _startpos_597) in
                let _v = _menhir_action_079 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState483 _tok
            | _ ->
                _eRR 483)
        | Elpi_lexer_config.Tokens.FAMILY_TIMES _v_600 ->
            let _menhir_stack = MenhirCell1_clause_hd_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos_601 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_602 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell0_FAMILY_TIMES (_menhir_stack, _v_600, _startpos_601, _endpos_602) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Elpi_lexer_config.Tokens.STRING _v_603 ->
                let _startpos_604 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_605 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_605, _startpos_604, _v_603) in
                let _v = _menhir_action_068 x in
                _menhir_run_053_spec_485 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.SIGMA ->
                let _startpos_607 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_608 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_608, _startpos_607) in
                let _v = _menhir_action_085 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState485 _tok
            | Elpi_lexer_config.Tokens.REPLACE ->
                let _startpos_610 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_611 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_611, _startpos_610) in
                let _v = _menhir_action_080 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState485 _tok
            | Elpi_lexer_config.Tokens.QUOTED _v_613 ->
                let _startpos_614 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_615 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_615, _startpos_614, _v_613) in
                let _v = _menhir_action_069 _endpos_x_ _startpos_x_ x in
                _menhir_run_053_spec_485 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.PI ->
                let _startpos_617 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_618 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_618, _startpos_617) in
                let _v = _menhir_action_084 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState485 _tok
            | Elpi_lexer_config.Tokens.NIL ->
                let _startpos_620 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_621 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_621, _startpos_620) in
                let _v = _menhir_action_089 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState485 _tok
            | Elpi_lexer_config.Tokens.NAME ->
                let _startpos_623 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_624 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_624, _startpos_623) in
                let _v = _menhir_action_077 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState485 _tok
            | Elpi_lexer_config.Tokens.LPAREN ->
                _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState485
            | Elpi_lexer_config.Tokens.LCURLY ->
                _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState485
            | Elpi_lexer_config.Tokens.LBRACKET ->
                _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState485
            | Elpi_lexer_config.Tokens.IO _v_626 ->
                let _startpos_627 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_628 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_c_, _startpos_c_, c) = (_endpos_628, _startpos_627, _v_626) in
                let _v = _menhir_action_082 c in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState485 _tok
            | Elpi_lexer_config.Tokens.INTEGER _v_630 ->
                let _startpos_631 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_632 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_632, _startpos_631, _v_630) in
                let _v = _menhir_action_066 x in
                _menhir_run_053_spec_485 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.INDEX ->
                let _startpos_634 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_635 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_635, _startpos_634) in
                let _v = _menhir_action_081 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState485 _tok
            | Elpi_lexer_config.Tokens.IF ->
                let _startpos_637 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_638 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_638, _startpos_637) in
                let _v = _menhir_action_076 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState485 _tok
            | Elpi_lexer_config.Tokens.FRESHUV ->
                let _startpos_640 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_641 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_641, _startpos_640) in
                let _v = _menhir_action_086 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState485 _tok
            | Elpi_lexer_config.Tokens.FLOAT _v_643 ->
                let _startpos_644 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_645 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_645, _startpos_644, _v_643) in
                let _v = _menhir_action_067 x in
                _menhir_run_053_spec_485 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.FAMILY_TILDE _v_647 ->
                _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer _v_647 MenhirState485
            | Elpi_lexer_config.Tokens.CUT ->
                let _startpos_648 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_649 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_649, _startpos_648) in
                let _v = _menhir_action_083 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState485 _tok
            | Elpi_lexer_config.Tokens.CONSTANT _v_651 ->
                let _startpos_652 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_653 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_c_, _startpos_c_, c) = (_endpos_653, _startpos_652, _v_651) in
                let _v = _menhir_action_075 c in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState485 _tok
            | Elpi_lexer_config.Tokens.BEFORE ->
                let _startpos_655 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_656 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_656, _startpos_655) in
                let _v = _menhir_action_078 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState485 _tok
            | Elpi_lexer_config.Tokens.AFTER ->
                let _startpos_658 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_659 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_659, _startpos_658) in
                let _v = _menhir_action_079 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState485 _tok
            | _ ->
                _eRR 485)
        | Elpi_lexer_config.Tokens.FAMILY_TICK _v_661 ->
            let _menhir_stack = MenhirCell1_clause_hd_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos_662 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_663 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell0_FAMILY_TICK (_menhir_stack, _v_661, _startpos_662, _endpos_663) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Elpi_lexer_config.Tokens.STRING _v_664 ->
                let _startpos_665 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_666 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_666, _startpos_665, _v_664) in
                let _v = _menhir_action_068 x in
                _menhir_run_053_spec_487 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.SIGMA ->
                let _startpos_668 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_669 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_669, _startpos_668) in
                let _v = _menhir_action_085 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState487 _tok
            | Elpi_lexer_config.Tokens.REPLACE ->
                let _startpos_671 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_672 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_672, _startpos_671) in
                let _v = _menhir_action_080 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState487 _tok
            | Elpi_lexer_config.Tokens.QUOTED _v_674 ->
                let _startpos_675 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_676 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_676, _startpos_675, _v_674) in
                let _v = _menhir_action_069 _endpos_x_ _startpos_x_ x in
                _menhir_run_053_spec_487 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.PI ->
                let _startpos_678 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_679 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_679, _startpos_678) in
                let _v = _menhir_action_084 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState487 _tok
            | Elpi_lexer_config.Tokens.NIL ->
                let _startpos_681 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_682 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_682, _startpos_681) in
                let _v = _menhir_action_089 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState487 _tok
            | Elpi_lexer_config.Tokens.NAME ->
                let _startpos_684 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_685 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_685, _startpos_684) in
                let _v = _menhir_action_077 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState487 _tok
            | Elpi_lexer_config.Tokens.LPAREN ->
                _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState487
            | Elpi_lexer_config.Tokens.LCURLY ->
                _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState487
            | Elpi_lexer_config.Tokens.LBRACKET ->
                _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState487
            | Elpi_lexer_config.Tokens.IO _v_687 ->
                let _startpos_688 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_689 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_c_, _startpos_c_, c) = (_endpos_689, _startpos_688, _v_687) in
                let _v = _menhir_action_082 c in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState487 _tok
            | Elpi_lexer_config.Tokens.INTEGER _v_691 ->
                let _startpos_692 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_693 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_693, _startpos_692, _v_691) in
                let _v = _menhir_action_066 x in
                _menhir_run_053_spec_487 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.INDEX ->
                let _startpos_695 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_696 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_696, _startpos_695) in
                let _v = _menhir_action_081 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState487 _tok
            | Elpi_lexer_config.Tokens.IF ->
                let _startpos_698 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_699 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_699, _startpos_698) in
                let _v = _menhir_action_076 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState487 _tok
            | Elpi_lexer_config.Tokens.FRESHUV ->
                let _startpos_701 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_702 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_702, _startpos_701) in
                let _v = _menhir_action_086 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState487 _tok
            | Elpi_lexer_config.Tokens.FLOAT _v_704 ->
                let _startpos_705 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_706 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_706, _startpos_705, _v_704) in
                let _v = _menhir_action_067 x in
                _menhir_run_053_spec_487 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.FAMILY_TILDE _v_708 ->
                _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer _v_708 MenhirState487
            | Elpi_lexer_config.Tokens.CUT ->
                let _startpos_709 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_710 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_710, _startpos_709) in
                let _v = _menhir_action_083 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState487 _tok
            | Elpi_lexer_config.Tokens.CONSTANT _v_712 ->
                let _startpos_713 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_714 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_c_, _startpos_c_, c) = (_endpos_714, _startpos_713, _v_712) in
                let _v = _menhir_action_075 c in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState487 _tok
            | Elpi_lexer_config.Tokens.BEFORE ->
                let _startpos_716 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_717 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_717, _startpos_716) in
                let _v = _menhir_action_078 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState487 _tok
            | Elpi_lexer_config.Tokens.AFTER ->
                let _startpos_719 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_720 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_720, _startpos_719) in
                let _v = _menhir_action_079 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState487 _tok
            | _ ->
                _eRR 487)
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_722 ->
            let _menhir_stack = MenhirCell1_clause_hd_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos_723 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_724 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell0_FAMILY_SHARP (_menhir_stack, _v_722, _startpos_723, _endpos_724) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Elpi_lexer_config.Tokens.STRING _v_725 ->
                let _startpos_726 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_727 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_727, _startpos_726, _v_725) in
                let _v = _menhir_action_068 x in
                _menhir_run_053_spec_489 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.SIGMA ->
                let _startpos_729 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_730 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_730, _startpos_729) in
                let _v = _menhir_action_085 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState489 _tok
            | Elpi_lexer_config.Tokens.REPLACE ->
                let _startpos_732 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_733 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_733, _startpos_732) in
                let _v = _menhir_action_080 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState489 _tok
            | Elpi_lexer_config.Tokens.QUOTED _v_735 ->
                let _startpos_736 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_737 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_737, _startpos_736, _v_735) in
                let _v = _menhir_action_069 _endpos_x_ _startpos_x_ x in
                _menhir_run_053_spec_489 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.PI ->
                let _startpos_739 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_740 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_740, _startpos_739) in
                let _v = _menhir_action_084 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState489 _tok
            | Elpi_lexer_config.Tokens.NIL ->
                let _startpos_742 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_743 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_743, _startpos_742) in
                let _v = _menhir_action_089 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState489 _tok
            | Elpi_lexer_config.Tokens.NAME ->
                let _startpos_745 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_746 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_746, _startpos_745) in
                let _v = _menhir_action_077 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState489 _tok
            | Elpi_lexer_config.Tokens.LPAREN ->
                _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState489
            | Elpi_lexer_config.Tokens.LCURLY ->
                _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState489
            | Elpi_lexer_config.Tokens.LBRACKET ->
                _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState489
            | Elpi_lexer_config.Tokens.IO _v_748 ->
                let _startpos_749 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_750 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_c_, _startpos_c_, c) = (_endpos_750, _startpos_749, _v_748) in
                let _v = _menhir_action_082 c in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState489 _tok
            | Elpi_lexer_config.Tokens.INTEGER _v_752 ->
                let _startpos_753 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_754 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_754, _startpos_753, _v_752) in
                let _v = _menhir_action_066 x in
                _menhir_run_053_spec_489 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.INDEX ->
                let _startpos_756 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_757 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_757, _startpos_756) in
                let _v = _menhir_action_081 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState489 _tok
            | Elpi_lexer_config.Tokens.IF ->
                let _startpos_759 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_760 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_760, _startpos_759) in
                let _v = _menhir_action_076 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState489 _tok
            | Elpi_lexer_config.Tokens.FRESHUV ->
                let _startpos_762 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_763 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_763, _startpos_762) in
                let _v = _menhir_action_086 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState489 _tok
            | Elpi_lexer_config.Tokens.FLOAT _v_765 ->
                let _startpos_766 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_767 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_767, _startpos_766, _v_765) in
                let _v = _menhir_action_067 x in
                _menhir_run_053_spec_489 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.FAMILY_TILDE _v_769 ->
                _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer _v_769 MenhirState489
            | Elpi_lexer_config.Tokens.CUT ->
                let _startpos_770 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_771 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_771, _startpos_770) in
                let _v = _menhir_action_083 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState489 _tok
            | Elpi_lexer_config.Tokens.CONSTANT _v_773 ->
                let _startpos_774 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_775 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_c_, _startpos_c_, c) = (_endpos_775, _startpos_774, _v_773) in
                let _v = _menhir_action_075 c in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState489 _tok
            | Elpi_lexer_config.Tokens.BEFORE ->
                let _startpos_777 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_778 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_778, _startpos_777) in
                let _v = _menhir_action_078 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState489 _tok
            | Elpi_lexer_config.Tokens.AFTER ->
                let _startpos_780 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_781 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_781, _startpos_780) in
                let _v = _menhir_action_079 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState489 _tok
            | _ ->
                _eRR 489)
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_783 ->
            let _endpos_785 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_s_, s, _startpos_l_, l) = (_endpos_785, _v_783, _startpos, _v) in
            let _v = _menhir_action_063 l s in
            _menhir_goto_clause_hd_open_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_s_ _startpos_l_ _v _menhir_s _tok
        | Elpi_lexer_config.Tokens.FAMILY_PLUS _v_786 ->
            let _menhir_stack = MenhirCell1_clause_hd_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos_787 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_788 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell0_FAMILY_PLUS (_menhir_stack, _v_786, _startpos_787, _endpos_788) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Elpi_lexer_config.Tokens.STRING _v_789 ->
                let _startpos_790 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_791 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_791, _startpos_790, _v_789) in
                let _v = _menhir_action_068 x in
                _menhir_run_053_spec_492 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.SIGMA ->
                let _startpos_793 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_794 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_794, _startpos_793) in
                let _v = _menhir_action_085 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState492 _tok
            | Elpi_lexer_config.Tokens.REPLACE ->
                let _startpos_796 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_797 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_797, _startpos_796) in
                let _v = _menhir_action_080 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState492 _tok
            | Elpi_lexer_config.Tokens.QUOTED _v_799 ->
                let _startpos_800 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_801 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_801, _startpos_800, _v_799) in
                let _v = _menhir_action_069 _endpos_x_ _startpos_x_ x in
                _menhir_run_053_spec_492 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.PI ->
                let _startpos_803 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_804 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_804, _startpos_803) in
                let _v = _menhir_action_084 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState492 _tok
            | Elpi_lexer_config.Tokens.NIL ->
                let _startpos_806 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_807 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_807, _startpos_806) in
                let _v = _menhir_action_089 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState492 _tok
            | Elpi_lexer_config.Tokens.NAME ->
                let _startpos_809 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_810 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_810, _startpos_809) in
                let _v = _menhir_action_077 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState492 _tok
            | Elpi_lexer_config.Tokens.LPAREN ->
                _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState492
            | Elpi_lexer_config.Tokens.LCURLY ->
                _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState492
            | Elpi_lexer_config.Tokens.LBRACKET ->
                _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState492
            | Elpi_lexer_config.Tokens.IO _v_812 ->
                let _startpos_813 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_814 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_c_, _startpos_c_, c) = (_endpos_814, _startpos_813, _v_812) in
                let _v = _menhir_action_082 c in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState492 _tok
            | Elpi_lexer_config.Tokens.INTEGER _v_816 ->
                let _startpos_817 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_818 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_818, _startpos_817, _v_816) in
                let _v = _menhir_action_066 x in
                _menhir_run_053_spec_492 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.INDEX ->
                let _startpos_820 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_821 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_821, _startpos_820) in
                let _v = _menhir_action_081 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState492 _tok
            | Elpi_lexer_config.Tokens.IF ->
                let _startpos_823 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_824 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_824, _startpos_823) in
                let _v = _menhir_action_076 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState492 _tok
            | Elpi_lexer_config.Tokens.FRESHUV ->
                let _startpos_826 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_827 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_827, _startpos_826) in
                let _v = _menhir_action_086 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState492 _tok
            | Elpi_lexer_config.Tokens.FLOAT _v_829 ->
                let _startpos_830 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_831 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_831, _startpos_830, _v_829) in
                let _v = _menhir_action_067 x in
                _menhir_run_053_spec_492 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.FAMILY_TILDE _v_833 ->
                _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer _v_833 MenhirState492
            | Elpi_lexer_config.Tokens.CUT ->
                let _startpos_834 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_835 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_835, _startpos_834) in
                let _v = _menhir_action_083 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState492 _tok
            | Elpi_lexer_config.Tokens.CONSTANT _v_837 ->
                let _startpos_838 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_839 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_c_, _startpos_c_, c) = (_endpos_839, _startpos_838, _v_837) in
                let _v = _menhir_action_075 c in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState492 _tok
            | Elpi_lexer_config.Tokens.BEFORE ->
                let _startpos_841 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_842 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_842, _startpos_841) in
                let _v = _menhir_action_078 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState492 _tok
            | Elpi_lexer_config.Tokens.AFTER ->
                let _startpos_844 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_845 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_845, _startpos_844) in
                let _v = _menhir_action_079 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState492 _tok
            | _ ->
                _eRR 492)
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_847 ->
            let _menhir_stack = MenhirCell1_clause_hd_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos_848 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_849 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell0_FAMILY_OR (_menhir_stack, _v_847, _startpos_848, _endpos_849) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Elpi_lexer_config.Tokens.STRING _v_850 ->
                let _startpos_851 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_852 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_852, _startpos_851, _v_850) in
                let _v = _menhir_action_068 x in
                _menhir_run_053_spec_494 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.SIGMA ->
                let _startpos_854 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_855 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_855, _startpos_854) in
                let _v = _menhir_action_085 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState494 _tok
            | Elpi_lexer_config.Tokens.REPLACE ->
                let _startpos_857 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_858 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_858, _startpos_857) in
                let _v = _menhir_action_080 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState494 _tok
            | Elpi_lexer_config.Tokens.QUOTED _v_860 ->
                let _startpos_861 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_862 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_862, _startpos_861, _v_860) in
                let _v = _menhir_action_069 _endpos_x_ _startpos_x_ x in
                _menhir_run_053_spec_494 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.PI ->
                let _startpos_864 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_865 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_865, _startpos_864) in
                let _v = _menhir_action_084 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState494 _tok
            | Elpi_lexer_config.Tokens.NIL ->
                let _startpos_867 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_868 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_868, _startpos_867) in
                let _v = _menhir_action_089 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState494 _tok
            | Elpi_lexer_config.Tokens.NAME ->
                let _startpos_870 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_871 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_871, _startpos_870) in
                let _v = _menhir_action_077 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState494 _tok
            | Elpi_lexer_config.Tokens.LPAREN ->
                _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState494
            | Elpi_lexer_config.Tokens.LCURLY ->
                _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState494
            | Elpi_lexer_config.Tokens.LBRACKET ->
                _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState494
            | Elpi_lexer_config.Tokens.IO _v_873 ->
                let _startpos_874 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_875 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_c_, _startpos_c_, c) = (_endpos_875, _startpos_874, _v_873) in
                let _v = _menhir_action_082 c in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState494 _tok
            | Elpi_lexer_config.Tokens.INTEGER _v_877 ->
                let _startpos_878 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_879 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_879, _startpos_878, _v_877) in
                let _v = _menhir_action_066 x in
                _menhir_run_053_spec_494 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.INDEX ->
                let _startpos_881 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_882 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_882, _startpos_881) in
                let _v = _menhir_action_081 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState494 _tok
            | Elpi_lexer_config.Tokens.IF ->
                let _startpos_884 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_885 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_885, _startpos_884) in
                let _v = _menhir_action_076 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState494 _tok
            | Elpi_lexer_config.Tokens.FRESHUV ->
                let _startpos_887 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_888 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_888, _startpos_887) in
                let _v = _menhir_action_086 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState494 _tok
            | Elpi_lexer_config.Tokens.FLOAT _v_890 ->
                let _startpos_891 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_892 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_892, _startpos_891, _v_890) in
                let _v = _menhir_action_067 x in
                _menhir_run_053_spec_494 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.FAMILY_TILDE _v_894 ->
                _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer _v_894 MenhirState494
            | Elpi_lexer_config.Tokens.CUT ->
                let _startpos_895 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_896 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_896, _startpos_895) in
                let _v = _menhir_action_083 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState494 _tok
            | Elpi_lexer_config.Tokens.CONSTANT _v_898 ->
                let _startpos_899 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_900 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_c_, _startpos_c_, c) = (_endpos_900, _startpos_899, _v_898) in
                let _v = _menhir_action_075 c in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState494 _tok
            | Elpi_lexer_config.Tokens.BEFORE ->
                let _startpos_902 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_903 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_903, _startpos_902) in
                let _v = _menhir_action_078 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState494 _tok
            | Elpi_lexer_config.Tokens.AFTER ->
                let _startpos_905 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_906 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_906, _startpos_905) in
                let _v = _menhir_action_079 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState494 _tok
            | _ ->
                _eRR 494)
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_908 ->
            let _menhir_stack = MenhirCell1_clause_hd_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos_909 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_910 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell0_FAMILY_MINUS (_menhir_stack, _v_908, _startpos_909, _endpos_910) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Elpi_lexer_config.Tokens.STRING _v_911 ->
                let _startpos_912 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_913 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_913, _startpos_912, _v_911) in
                let _v = _menhir_action_068 x in
                _menhir_run_053_spec_496 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.SIGMA ->
                let _startpos_915 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_916 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_916, _startpos_915) in
                let _v = _menhir_action_085 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState496 _tok
            | Elpi_lexer_config.Tokens.REPLACE ->
                let _startpos_918 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_919 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_919, _startpos_918) in
                let _v = _menhir_action_080 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState496 _tok
            | Elpi_lexer_config.Tokens.QUOTED _v_921 ->
                let _startpos_922 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_923 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_923, _startpos_922, _v_921) in
                let _v = _menhir_action_069 _endpos_x_ _startpos_x_ x in
                _menhir_run_053_spec_496 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.PI ->
                let _startpos_925 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_926 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_926, _startpos_925) in
                let _v = _menhir_action_084 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState496 _tok
            | Elpi_lexer_config.Tokens.NIL ->
                let _startpos_928 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_929 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_929, _startpos_928) in
                let _v = _menhir_action_089 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState496 _tok
            | Elpi_lexer_config.Tokens.NAME ->
                let _startpos_931 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_932 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_932, _startpos_931) in
                let _v = _menhir_action_077 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState496 _tok
            | Elpi_lexer_config.Tokens.LPAREN ->
                _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState496
            | Elpi_lexer_config.Tokens.LCURLY ->
                _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState496
            | Elpi_lexer_config.Tokens.LBRACKET ->
                _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState496
            | Elpi_lexer_config.Tokens.IO _v_934 ->
                let _startpos_935 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_936 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_c_, _startpos_c_, c) = (_endpos_936, _startpos_935, _v_934) in
                let _v = _menhir_action_082 c in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState496 _tok
            | Elpi_lexer_config.Tokens.INTEGER _v_938 ->
                let _startpos_939 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_940 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_940, _startpos_939, _v_938) in
                let _v = _menhir_action_066 x in
                _menhir_run_053_spec_496 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.INDEX ->
                let _startpos_942 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_943 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_943, _startpos_942) in
                let _v = _menhir_action_081 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState496 _tok
            | Elpi_lexer_config.Tokens.IF ->
                let _startpos_945 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_946 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_946, _startpos_945) in
                let _v = _menhir_action_076 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState496 _tok
            | Elpi_lexer_config.Tokens.FRESHUV ->
                let _startpos_948 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_949 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_949, _startpos_948) in
                let _v = _menhir_action_086 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState496 _tok
            | Elpi_lexer_config.Tokens.FLOAT _v_951 ->
                let _startpos_952 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_953 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_953, _startpos_952, _v_951) in
                let _v = _menhir_action_067 x in
                _menhir_run_053_spec_496 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.FAMILY_TILDE _v_955 ->
                _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer _v_955 MenhirState496
            | Elpi_lexer_config.Tokens.CUT ->
                let _startpos_956 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_957 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_957, _startpos_956) in
                let _v = _menhir_action_083 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState496 _tok
            | Elpi_lexer_config.Tokens.CONSTANT _v_959 ->
                let _startpos_960 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_961 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_c_, _startpos_c_, c) = (_endpos_961, _startpos_960, _v_959) in
                let _v = _menhir_action_075 c in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState496 _tok
            | Elpi_lexer_config.Tokens.BEFORE ->
                let _startpos_963 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_964 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_964, _startpos_963) in
                let _v = _menhir_action_078 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState496 _tok
            | Elpi_lexer_config.Tokens.AFTER ->
                let _startpos_966 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_967 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_967, _startpos_966) in
                let _v = _menhir_action_079 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState496 _tok
            | _ ->
                _eRR 496)
        | Elpi_lexer_config.Tokens.FAMILY_LT _v_969 ->
            let _menhir_stack = MenhirCell1_clause_hd_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos_970 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_971 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell0_FAMILY_LT (_menhir_stack, _v_969, _startpos_970, _endpos_971) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Elpi_lexer_config.Tokens.STRING _v_972 ->
                let _startpos_973 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_974 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_974, _startpos_973, _v_972) in
                let _v = _menhir_action_068 x in
                _menhir_run_053_spec_498 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.SIGMA ->
                let _startpos_976 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_977 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_977, _startpos_976) in
                let _v = _menhir_action_085 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState498 _tok
            | Elpi_lexer_config.Tokens.REPLACE ->
                let _startpos_979 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_980 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_980, _startpos_979) in
                let _v = _menhir_action_080 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState498 _tok
            | Elpi_lexer_config.Tokens.QUOTED _v_982 ->
                let _startpos_983 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_984 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_984, _startpos_983, _v_982) in
                let _v = _menhir_action_069 _endpos_x_ _startpos_x_ x in
                _menhir_run_053_spec_498 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.PI ->
                let _startpos_986 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_987 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_987, _startpos_986) in
                let _v = _menhir_action_084 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState498 _tok
            | Elpi_lexer_config.Tokens.NIL ->
                let _startpos_989 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_990 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_990, _startpos_989) in
                let _v = _menhir_action_089 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState498 _tok
            | Elpi_lexer_config.Tokens.NAME ->
                let _startpos_992 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_993 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_993, _startpos_992) in
                let _v = _menhir_action_077 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState498 _tok
            | Elpi_lexer_config.Tokens.LPAREN ->
                _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState498
            | Elpi_lexer_config.Tokens.LCURLY ->
                _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState498
            | Elpi_lexer_config.Tokens.LBRACKET ->
                _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState498
            | Elpi_lexer_config.Tokens.IO _v_995 ->
                let _startpos_996 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_997 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_c_, _startpos_c_, c) = (_endpos_997, _startpos_996, _v_995) in
                let _v = _menhir_action_082 c in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState498 _tok
            | Elpi_lexer_config.Tokens.INTEGER _v_999 ->
                let _startpos_1000 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1001 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_1001, _startpos_1000, _v_999) in
                let _v = _menhir_action_066 x in
                _menhir_run_053_spec_498 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.INDEX ->
                let _startpos_1003 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1004 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1004, _startpos_1003) in
                let _v = _menhir_action_081 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState498 _tok
            | Elpi_lexer_config.Tokens.IF ->
                let _startpos_1006 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1007 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1007, _startpos_1006) in
                let _v = _menhir_action_076 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState498 _tok
            | Elpi_lexer_config.Tokens.FRESHUV ->
                let _startpos_1009 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1010 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1010, _startpos_1009) in
                let _v = _menhir_action_086 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState498 _tok
            | Elpi_lexer_config.Tokens.FLOAT _v_1012 ->
                let _startpos_1013 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1014 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_1014, _startpos_1013, _v_1012) in
                let _v = _menhir_action_067 x in
                _menhir_run_053_spec_498 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.FAMILY_TILDE _v_1016 ->
                _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1016 MenhirState498
            | Elpi_lexer_config.Tokens.CUT ->
                let _startpos_1017 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1018 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1018, _startpos_1017) in
                let _v = _menhir_action_083 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState498 _tok
            | Elpi_lexer_config.Tokens.CONSTANT _v_1020 ->
                let _startpos_1021 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1022 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_c_, _startpos_c_, c) = (_endpos_1022, _startpos_1021, _v_1020) in
                let _v = _menhir_action_075 c in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState498 _tok
            | Elpi_lexer_config.Tokens.BEFORE ->
                let _startpos_1024 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1025 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1025, _startpos_1024) in
                let _v = _menhir_action_078 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState498 _tok
            | Elpi_lexer_config.Tokens.AFTER ->
                let _startpos_1027 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1028 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1028, _startpos_1027) in
                let _v = _menhir_action_079 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState498 _tok
            | _ ->
                _eRR 498)
        | Elpi_lexer_config.Tokens.FAMILY_GT _v_1030 ->
            let _menhir_stack = MenhirCell1_clause_hd_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos_1031 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_1032 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell0_FAMILY_GT (_menhir_stack, _v_1030, _startpos_1031, _endpos_1032) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Elpi_lexer_config.Tokens.STRING _v_1033 ->
                let _startpos_1034 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1035 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_1035, _startpos_1034, _v_1033) in
                let _v = _menhir_action_068 x in
                _menhir_run_053_spec_500 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.SIGMA ->
                let _startpos_1037 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1038 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1038, _startpos_1037) in
                let _v = _menhir_action_085 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState500 _tok
            | Elpi_lexer_config.Tokens.REPLACE ->
                let _startpos_1040 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1041 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1041, _startpos_1040) in
                let _v = _menhir_action_080 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState500 _tok
            | Elpi_lexer_config.Tokens.QUOTED _v_1043 ->
                let _startpos_1044 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1045 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_1045, _startpos_1044, _v_1043) in
                let _v = _menhir_action_069 _endpos_x_ _startpos_x_ x in
                _menhir_run_053_spec_500 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.PI ->
                let _startpos_1047 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1048 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1048, _startpos_1047) in
                let _v = _menhir_action_084 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState500 _tok
            | Elpi_lexer_config.Tokens.NIL ->
                let _startpos_1050 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1051 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1051, _startpos_1050) in
                let _v = _menhir_action_089 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState500 _tok
            | Elpi_lexer_config.Tokens.NAME ->
                let _startpos_1053 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1054 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1054, _startpos_1053) in
                let _v = _menhir_action_077 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState500 _tok
            | Elpi_lexer_config.Tokens.LPAREN ->
                _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState500
            | Elpi_lexer_config.Tokens.LCURLY ->
                _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState500
            | Elpi_lexer_config.Tokens.LBRACKET ->
                _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState500
            | Elpi_lexer_config.Tokens.IO _v_1056 ->
                let _startpos_1057 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1058 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_c_, _startpos_c_, c) = (_endpos_1058, _startpos_1057, _v_1056) in
                let _v = _menhir_action_082 c in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState500 _tok
            | Elpi_lexer_config.Tokens.INTEGER _v_1060 ->
                let _startpos_1061 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1062 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_1062, _startpos_1061, _v_1060) in
                let _v = _menhir_action_066 x in
                _menhir_run_053_spec_500 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.INDEX ->
                let _startpos_1064 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1065 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1065, _startpos_1064) in
                let _v = _menhir_action_081 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState500 _tok
            | Elpi_lexer_config.Tokens.IF ->
                let _startpos_1067 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1068 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1068, _startpos_1067) in
                let _v = _menhir_action_076 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState500 _tok
            | Elpi_lexer_config.Tokens.FRESHUV ->
                let _startpos_1070 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1071 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1071, _startpos_1070) in
                let _v = _menhir_action_086 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState500 _tok
            | Elpi_lexer_config.Tokens.FLOAT _v_1073 ->
                let _startpos_1074 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1075 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_1075, _startpos_1074, _v_1073) in
                let _v = _menhir_action_067 x in
                _menhir_run_053_spec_500 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.FAMILY_TILDE _v_1077 ->
                _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1077 MenhirState500
            | Elpi_lexer_config.Tokens.CUT ->
                let _startpos_1078 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1079 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1079, _startpos_1078) in
                let _v = _menhir_action_083 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState500 _tok
            | Elpi_lexer_config.Tokens.CONSTANT _v_1081 ->
                let _startpos_1082 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1083 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_c_, _startpos_c_, c) = (_endpos_1083, _startpos_1082, _v_1081) in
                let _v = _menhir_action_075 c in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState500 _tok
            | Elpi_lexer_config.Tokens.BEFORE ->
                let _startpos_1085 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1086 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1086, _startpos_1085) in
                let _v = _menhir_action_078 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState500 _tok
            | Elpi_lexer_config.Tokens.AFTER ->
                let _startpos_1088 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1089 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1089, _startpos_1088) in
                let _v = _menhir_action_079 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState500 _tok
            | _ ->
                _eRR 500)
        | Elpi_lexer_config.Tokens.FAMILY_EXP _v_1091 ->
            let _menhir_stack = MenhirCell1_clause_hd_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos_1092 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_1093 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell0_FAMILY_EXP (_menhir_stack, _v_1091, _startpos_1092, _endpos_1093) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Elpi_lexer_config.Tokens.STRING _v_1094 ->
                let _startpos_1095 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1096 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_1096, _startpos_1095, _v_1094) in
                let _v = _menhir_action_068 x in
                _menhir_run_053_spec_502 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.SIGMA ->
                let _startpos_1098 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1099 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1099, _startpos_1098) in
                let _v = _menhir_action_085 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState502 _tok
            | Elpi_lexer_config.Tokens.REPLACE ->
                let _startpos_1101 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1102 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1102, _startpos_1101) in
                let _v = _menhir_action_080 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState502 _tok
            | Elpi_lexer_config.Tokens.QUOTED _v_1104 ->
                let _startpos_1105 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1106 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_1106, _startpos_1105, _v_1104) in
                let _v = _menhir_action_069 _endpos_x_ _startpos_x_ x in
                _menhir_run_053_spec_502 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.PI ->
                let _startpos_1108 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1109 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1109, _startpos_1108) in
                let _v = _menhir_action_084 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState502 _tok
            | Elpi_lexer_config.Tokens.NIL ->
                let _startpos_1111 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1112 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1112, _startpos_1111) in
                let _v = _menhir_action_089 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState502 _tok
            | Elpi_lexer_config.Tokens.NAME ->
                let _startpos_1114 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1115 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1115, _startpos_1114) in
                let _v = _menhir_action_077 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState502 _tok
            | Elpi_lexer_config.Tokens.LPAREN ->
                _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState502
            | Elpi_lexer_config.Tokens.LCURLY ->
                _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState502
            | Elpi_lexer_config.Tokens.LBRACKET ->
                _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState502
            | Elpi_lexer_config.Tokens.IO _v_1117 ->
                let _startpos_1118 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1119 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_c_, _startpos_c_, c) = (_endpos_1119, _startpos_1118, _v_1117) in
                let _v = _menhir_action_082 c in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState502 _tok
            | Elpi_lexer_config.Tokens.INTEGER _v_1121 ->
                let _startpos_1122 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1123 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_1123, _startpos_1122, _v_1121) in
                let _v = _menhir_action_066 x in
                _menhir_run_053_spec_502 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.INDEX ->
                let _startpos_1125 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1126 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1126, _startpos_1125) in
                let _v = _menhir_action_081 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState502 _tok
            | Elpi_lexer_config.Tokens.IF ->
                let _startpos_1128 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1129 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1129, _startpos_1128) in
                let _v = _menhir_action_076 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState502 _tok
            | Elpi_lexer_config.Tokens.FRESHUV ->
                let _startpos_1131 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1132 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1132, _startpos_1131) in
                let _v = _menhir_action_086 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState502 _tok
            | Elpi_lexer_config.Tokens.FLOAT _v_1134 ->
                let _startpos_1135 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1136 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_1136, _startpos_1135, _v_1134) in
                let _v = _menhir_action_067 x in
                _menhir_run_053_spec_502 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.FAMILY_TILDE _v_1138 ->
                _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1138 MenhirState502
            | Elpi_lexer_config.Tokens.CUT ->
                let _startpos_1139 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1140 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1140, _startpos_1139) in
                let _v = _menhir_action_083 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState502 _tok
            | Elpi_lexer_config.Tokens.CONSTANT _v_1142 ->
                let _startpos_1143 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1144 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_c_, _startpos_c_, c) = (_endpos_1144, _startpos_1143, _v_1142) in
                let _v = _menhir_action_075 c in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState502 _tok
            | Elpi_lexer_config.Tokens.BEFORE ->
                let _startpos_1146 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1147 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1147, _startpos_1146) in
                let _v = _menhir_action_078 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState502 _tok
            | Elpi_lexer_config.Tokens.AFTER ->
                let _startpos_1149 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1150 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1150, _startpos_1149) in
                let _v = _menhir_action_079 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState502 _tok
            | _ ->
                _eRR 502)
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_1152 ->
            let _menhir_stack = MenhirCell1_clause_hd_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos_1153 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_1154 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell0_FAMILY_EQ (_menhir_stack, _v_1152, _startpos_1153, _endpos_1154) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Elpi_lexer_config.Tokens.STRING _v_1155 ->
                let _startpos_1156 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1157 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_1157, _startpos_1156, _v_1155) in
                let _v = _menhir_action_068 x in
                _menhir_run_053_spec_504 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.SIGMA ->
                let _startpos_1159 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1160 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1160, _startpos_1159) in
                let _v = _menhir_action_085 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState504 _tok
            | Elpi_lexer_config.Tokens.REPLACE ->
                let _startpos_1162 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1163 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1163, _startpos_1162) in
                let _v = _menhir_action_080 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState504 _tok
            | Elpi_lexer_config.Tokens.QUOTED _v_1165 ->
                let _startpos_1166 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1167 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_1167, _startpos_1166, _v_1165) in
                let _v = _menhir_action_069 _endpos_x_ _startpos_x_ x in
                _menhir_run_053_spec_504 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.PI ->
                let _startpos_1169 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1170 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1170, _startpos_1169) in
                let _v = _menhir_action_084 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState504 _tok
            | Elpi_lexer_config.Tokens.NIL ->
                let _startpos_1172 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1173 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1173, _startpos_1172) in
                let _v = _menhir_action_089 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState504 _tok
            | Elpi_lexer_config.Tokens.NAME ->
                let _startpos_1175 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1176 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1176, _startpos_1175) in
                let _v = _menhir_action_077 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState504 _tok
            | Elpi_lexer_config.Tokens.LPAREN ->
                _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState504
            | Elpi_lexer_config.Tokens.LCURLY ->
                _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState504
            | Elpi_lexer_config.Tokens.LBRACKET ->
                _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState504
            | Elpi_lexer_config.Tokens.IO _v_1178 ->
                let _startpos_1179 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1180 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_c_, _startpos_c_, c) = (_endpos_1180, _startpos_1179, _v_1178) in
                let _v = _menhir_action_082 c in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState504 _tok
            | Elpi_lexer_config.Tokens.INTEGER _v_1182 ->
                let _startpos_1183 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1184 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_1184, _startpos_1183, _v_1182) in
                let _v = _menhir_action_066 x in
                _menhir_run_053_spec_504 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.INDEX ->
                let _startpos_1186 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1187 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1187, _startpos_1186) in
                let _v = _menhir_action_081 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState504 _tok
            | Elpi_lexer_config.Tokens.IF ->
                let _startpos_1189 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1190 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1190, _startpos_1189) in
                let _v = _menhir_action_076 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState504 _tok
            | Elpi_lexer_config.Tokens.FRESHUV ->
                let _startpos_1192 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1193 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1193, _startpos_1192) in
                let _v = _menhir_action_086 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState504 _tok
            | Elpi_lexer_config.Tokens.FLOAT _v_1195 ->
                let _startpos_1196 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1197 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_1197, _startpos_1196, _v_1195) in
                let _v = _menhir_action_067 x in
                _menhir_run_053_spec_504 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.FAMILY_TILDE _v_1199 ->
                _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1199 MenhirState504
            | Elpi_lexer_config.Tokens.CUT ->
                let _startpos_1200 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1201 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1201, _startpos_1200) in
                let _v = _menhir_action_083 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState504 _tok
            | Elpi_lexer_config.Tokens.CONSTANT _v_1203 ->
                let _startpos_1204 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1205 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_c_, _startpos_c_, c) = (_endpos_1205, _startpos_1204, _v_1203) in
                let _v = _menhir_action_075 c in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState504 _tok
            | Elpi_lexer_config.Tokens.BEFORE ->
                let _startpos_1207 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1208 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1208, _startpos_1207) in
                let _v = _menhir_action_078 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState504 _tok
            | Elpi_lexer_config.Tokens.AFTER ->
                let _startpos_1210 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1211 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1211, _startpos_1210) in
                let _v = _menhir_action_079 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState504 _tok
            | _ ->
                _eRR 504)
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_1213 ->
            let _menhir_stack = MenhirCell1_clause_hd_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos_1214 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_1215 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell0_FAMILY_BTICK (_menhir_stack, _v_1213, _startpos_1214, _endpos_1215) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Elpi_lexer_config.Tokens.STRING _v_1216 ->
                let _startpos_1217 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1218 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_1218, _startpos_1217, _v_1216) in
                let _v = _menhir_action_068 x in
                _menhir_run_053_spec_506 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.SIGMA ->
                let _startpos_1220 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1221 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1221, _startpos_1220) in
                let _v = _menhir_action_085 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState506 _tok
            | Elpi_lexer_config.Tokens.REPLACE ->
                let _startpos_1223 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1224 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1224, _startpos_1223) in
                let _v = _menhir_action_080 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState506 _tok
            | Elpi_lexer_config.Tokens.QUOTED _v_1226 ->
                let _startpos_1227 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1228 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_1228, _startpos_1227, _v_1226) in
                let _v = _menhir_action_069 _endpos_x_ _startpos_x_ x in
                _menhir_run_053_spec_506 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.PI ->
                let _startpos_1230 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1231 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1231, _startpos_1230) in
                let _v = _menhir_action_084 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState506 _tok
            | Elpi_lexer_config.Tokens.NIL ->
                let _startpos_1233 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1234 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1234, _startpos_1233) in
                let _v = _menhir_action_089 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState506 _tok
            | Elpi_lexer_config.Tokens.NAME ->
                let _startpos_1236 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1237 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1237, _startpos_1236) in
                let _v = _menhir_action_077 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState506 _tok
            | Elpi_lexer_config.Tokens.LPAREN ->
                _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState506
            | Elpi_lexer_config.Tokens.LCURLY ->
                _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState506
            | Elpi_lexer_config.Tokens.LBRACKET ->
                _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState506
            | Elpi_lexer_config.Tokens.IO _v_1239 ->
                let _startpos_1240 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1241 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_c_, _startpos_c_, c) = (_endpos_1241, _startpos_1240, _v_1239) in
                let _v = _menhir_action_082 c in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState506 _tok
            | Elpi_lexer_config.Tokens.INTEGER _v_1243 ->
                let _startpos_1244 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1245 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_1245, _startpos_1244, _v_1243) in
                let _v = _menhir_action_066 x in
                _menhir_run_053_spec_506 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.INDEX ->
                let _startpos_1247 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1248 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1248, _startpos_1247) in
                let _v = _menhir_action_081 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState506 _tok
            | Elpi_lexer_config.Tokens.IF ->
                let _startpos_1250 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1251 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1251, _startpos_1250) in
                let _v = _menhir_action_076 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState506 _tok
            | Elpi_lexer_config.Tokens.FRESHUV ->
                let _startpos_1253 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1254 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1254, _startpos_1253) in
                let _v = _menhir_action_086 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState506 _tok
            | Elpi_lexer_config.Tokens.FLOAT _v_1256 ->
                let _startpos_1257 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1258 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_1258, _startpos_1257, _v_1256) in
                let _v = _menhir_action_067 x in
                _menhir_run_053_spec_506 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.FAMILY_TILDE _v_1260 ->
                _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1260 MenhirState506
            | Elpi_lexer_config.Tokens.CUT ->
                let _startpos_1261 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1262 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1262, _startpos_1261) in
                let _v = _menhir_action_083 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState506 _tok
            | Elpi_lexer_config.Tokens.CONSTANT _v_1264 ->
                let _startpos_1265 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1266 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_c_, _startpos_c_, c) = (_endpos_1266, _startpos_1265, _v_1264) in
                let _v = _menhir_action_075 c in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState506 _tok
            | Elpi_lexer_config.Tokens.BEFORE ->
                let _startpos_1268 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1269 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1269, _startpos_1268) in
                let _v = _menhir_action_078 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState506 _tok
            | Elpi_lexer_config.Tokens.AFTER ->
                let _startpos_1271 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1272 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1272, _startpos_1271) in
                let _v = _menhir_action_079 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState506 _tok
            | _ ->
                _eRR 506)
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_1274 ->
            let _menhir_stack = MenhirCell1_clause_hd_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos_1275 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_1276 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell0_FAMILY_AND (_menhir_stack, _v_1274, _startpos_1275, _endpos_1276) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Elpi_lexer_config.Tokens.STRING _v_1277 ->
                let _startpos_1278 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1279 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_1279, _startpos_1278, _v_1277) in
                let _v = _menhir_action_068 x in
                _menhir_run_053_spec_508 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.SIGMA ->
                let _startpos_1281 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1282 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1282, _startpos_1281) in
                let _v = _menhir_action_085 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState508 _tok
            | Elpi_lexer_config.Tokens.REPLACE ->
                let _startpos_1284 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1285 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1285, _startpos_1284) in
                let _v = _menhir_action_080 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState508 _tok
            | Elpi_lexer_config.Tokens.QUOTED _v_1287 ->
                let _startpos_1288 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1289 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_1289, _startpos_1288, _v_1287) in
                let _v = _menhir_action_069 _endpos_x_ _startpos_x_ x in
                _menhir_run_053_spec_508 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.PI ->
                let _startpos_1291 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1292 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1292, _startpos_1291) in
                let _v = _menhir_action_084 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState508 _tok
            | Elpi_lexer_config.Tokens.NIL ->
                let _startpos_1294 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1295 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1295, _startpos_1294) in
                let _v = _menhir_action_089 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState508 _tok
            | Elpi_lexer_config.Tokens.NAME ->
                let _startpos_1297 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1298 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1298, _startpos_1297) in
                let _v = _menhir_action_077 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState508 _tok
            | Elpi_lexer_config.Tokens.LPAREN ->
                _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState508
            | Elpi_lexer_config.Tokens.LCURLY ->
                _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState508
            | Elpi_lexer_config.Tokens.LBRACKET ->
                _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState508
            | Elpi_lexer_config.Tokens.IO _v_1300 ->
                let _startpos_1301 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1302 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_c_, _startpos_c_, c) = (_endpos_1302, _startpos_1301, _v_1300) in
                let _v = _menhir_action_082 c in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState508 _tok
            | Elpi_lexer_config.Tokens.INTEGER _v_1304 ->
                let _startpos_1305 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1306 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_1306, _startpos_1305, _v_1304) in
                let _v = _menhir_action_066 x in
                _menhir_run_053_spec_508 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.INDEX ->
                let _startpos_1308 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1309 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1309, _startpos_1308) in
                let _v = _menhir_action_081 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState508 _tok
            | Elpi_lexer_config.Tokens.IF ->
                let _startpos_1311 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1312 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1312, _startpos_1311) in
                let _v = _menhir_action_076 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState508 _tok
            | Elpi_lexer_config.Tokens.FRESHUV ->
                let _startpos_1314 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1315 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1315, _startpos_1314) in
                let _v = _menhir_action_086 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState508 _tok
            | Elpi_lexer_config.Tokens.FLOAT _v_1317 ->
                let _startpos_1318 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1319 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_1319, _startpos_1318, _v_1317) in
                let _v = _menhir_action_067 x in
                _menhir_run_053_spec_508 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.FAMILY_TILDE _v_1321 ->
                _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1321 MenhirState508
            | Elpi_lexer_config.Tokens.CUT ->
                let _startpos_1322 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1323 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1323, _startpos_1322) in
                let _v = _menhir_action_083 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState508 _tok
            | Elpi_lexer_config.Tokens.CONSTANT _v_1325 ->
                let _startpos_1326 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1327 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_c_, _startpos_c_, c) = (_endpos_1327, _startpos_1326, _v_1325) in
                let _v = _menhir_action_075 c in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState508 _tok
            | Elpi_lexer_config.Tokens.BEFORE ->
                let _startpos_1329 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1330 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1330, _startpos_1329) in
                let _v = _menhir_action_078 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState508 _tok
            | Elpi_lexer_config.Tokens.AFTER ->
                let _startpos_1332 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1333 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1333, _startpos_1332) in
                let _v = _menhir_action_079 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState508 _tok
            | _ ->
                _eRR 508)
        | Elpi_lexer_config.Tokens.EQ2 ->
            let _menhir_stack = MenhirCell1_clause_hd_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos_1335 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_1336 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell0_EQ2 (_menhir_stack, _startpos_1335, _endpos_1336) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Elpi_lexer_config.Tokens.STRING _v_1337 ->
                let _startpos_1338 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1339 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_1339, _startpos_1338, _v_1337) in
                let _v = _menhir_action_068 x in
                _menhir_run_053_spec_510 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.SIGMA ->
                let _startpos_1341 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1342 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1342, _startpos_1341) in
                let _v = _menhir_action_085 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState510 _tok
            | Elpi_lexer_config.Tokens.REPLACE ->
                let _startpos_1344 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1345 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1345, _startpos_1344) in
                let _v = _menhir_action_080 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState510 _tok
            | Elpi_lexer_config.Tokens.QUOTED _v_1347 ->
                let _startpos_1348 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1349 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_1349, _startpos_1348, _v_1347) in
                let _v = _menhir_action_069 _endpos_x_ _startpos_x_ x in
                _menhir_run_053_spec_510 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.PI ->
                let _startpos_1351 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1352 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1352, _startpos_1351) in
                let _v = _menhir_action_084 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState510 _tok
            | Elpi_lexer_config.Tokens.NIL ->
                let _startpos_1354 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1355 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1355, _startpos_1354) in
                let _v = _menhir_action_089 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState510 _tok
            | Elpi_lexer_config.Tokens.NAME ->
                let _startpos_1357 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1358 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1358, _startpos_1357) in
                let _v = _menhir_action_077 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState510 _tok
            | Elpi_lexer_config.Tokens.LPAREN ->
                _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState510
            | Elpi_lexer_config.Tokens.LCURLY ->
                _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState510
            | Elpi_lexer_config.Tokens.LBRACKET ->
                _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState510
            | Elpi_lexer_config.Tokens.IO _v_1360 ->
                let _startpos_1361 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1362 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_c_, _startpos_c_, c) = (_endpos_1362, _startpos_1361, _v_1360) in
                let _v = _menhir_action_082 c in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState510 _tok
            | Elpi_lexer_config.Tokens.INTEGER _v_1364 ->
                let _startpos_1365 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1366 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_1366, _startpos_1365, _v_1364) in
                let _v = _menhir_action_066 x in
                _menhir_run_053_spec_510 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.INDEX ->
                let _startpos_1368 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1369 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1369, _startpos_1368) in
                let _v = _menhir_action_081 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState510 _tok
            | Elpi_lexer_config.Tokens.IF ->
                let _startpos_1371 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1372 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1372, _startpos_1371) in
                let _v = _menhir_action_076 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState510 _tok
            | Elpi_lexer_config.Tokens.FRESHUV ->
                let _startpos_1374 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1375 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1375, _startpos_1374) in
                let _v = _menhir_action_086 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState510 _tok
            | Elpi_lexer_config.Tokens.FLOAT _v_1377 ->
                let _startpos_1378 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1379 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_1379, _startpos_1378, _v_1377) in
                let _v = _menhir_action_067 x in
                _menhir_run_053_spec_510 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.FAMILY_TILDE _v_1381 ->
                _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1381 MenhirState510
            | Elpi_lexer_config.Tokens.CUT ->
                let _startpos_1382 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1383 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1383, _startpos_1382) in
                let _v = _menhir_action_083 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState510 _tok
            | Elpi_lexer_config.Tokens.CONSTANT _v_1385 ->
                let _startpos_1386 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1387 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_c_, _startpos_c_, c) = (_endpos_1387, _startpos_1386, _v_1385) in
                let _v = _menhir_action_075 c in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState510 _tok
            | Elpi_lexer_config.Tokens.BEFORE ->
                let _startpos_1389 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1390 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1390, _startpos_1389) in
                let _v = _menhir_action_078 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState510 _tok
            | Elpi_lexer_config.Tokens.AFTER ->
                let _startpos_1392 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1393 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1393, _startpos_1392) in
                let _v = _menhir_action_079 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState510 _tok
            | _ ->
                _eRR 510)
        | Elpi_lexer_config.Tokens.EQ ->
            let _menhir_stack = MenhirCell1_clause_hd_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos_1395 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_1396 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell0_EQ (_menhir_stack, _startpos_1395, _endpos_1396) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Elpi_lexer_config.Tokens.STRING _v_1397 ->
                let _startpos_1398 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1399 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_1399, _startpos_1398, _v_1397) in
                let _v = _menhir_action_068 x in
                _menhir_run_053_spec_512 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.SIGMA ->
                let _startpos_1401 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1402 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1402, _startpos_1401) in
                let _v = _menhir_action_085 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState512 _tok
            | Elpi_lexer_config.Tokens.REPLACE ->
                let _startpos_1404 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1405 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1405, _startpos_1404) in
                let _v = _menhir_action_080 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState512 _tok
            | Elpi_lexer_config.Tokens.QUOTED _v_1407 ->
                let _startpos_1408 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1409 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_1409, _startpos_1408, _v_1407) in
                let _v = _menhir_action_069 _endpos_x_ _startpos_x_ x in
                _menhir_run_053_spec_512 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.PI ->
                let _startpos_1411 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1412 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1412, _startpos_1411) in
                let _v = _menhir_action_084 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState512 _tok
            | Elpi_lexer_config.Tokens.NIL ->
                let _startpos_1414 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1415 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1415, _startpos_1414) in
                let _v = _menhir_action_089 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState512 _tok
            | Elpi_lexer_config.Tokens.NAME ->
                let _startpos_1417 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1418 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1418, _startpos_1417) in
                let _v = _menhir_action_077 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState512 _tok
            | Elpi_lexer_config.Tokens.LPAREN ->
                _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState512
            | Elpi_lexer_config.Tokens.LCURLY ->
                _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState512
            | Elpi_lexer_config.Tokens.LBRACKET ->
                _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState512
            | Elpi_lexer_config.Tokens.IO _v_1420 ->
                let _startpos_1421 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1422 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_c_, _startpos_c_, c) = (_endpos_1422, _startpos_1421, _v_1420) in
                let _v = _menhir_action_082 c in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState512 _tok
            | Elpi_lexer_config.Tokens.INTEGER _v_1424 ->
                let _startpos_1425 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1426 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_1426, _startpos_1425, _v_1424) in
                let _v = _menhir_action_066 x in
                _menhir_run_053_spec_512 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.INDEX ->
                let _startpos_1428 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1429 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1429, _startpos_1428) in
                let _v = _menhir_action_081 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState512 _tok
            | Elpi_lexer_config.Tokens.IF ->
                let _startpos_1431 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1432 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1432, _startpos_1431) in
                let _v = _menhir_action_076 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState512 _tok
            | Elpi_lexer_config.Tokens.FRESHUV ->
                let _startpos_1434 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1435 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1435, _startpos_1434) in
                let _v = _menhir_action_086 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState512 _tok
            | Elpi_lexer_config.Tokens.FLOAT _v_1437 ->
                let _startpos_1438 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1439 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_1439, _startpos_1438, _v_1437) in
                let _v = _menhir_action_067 x in
                _menhir_run_053_spec_512 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.FAMILY_TILDE _v_1441 ->
                _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1441 MenhirState512
            | Elpi_lexer_config.Tokens.CUT ->
                let _startpos_1442 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1443 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1443, _startpos_1442) in
                let _v = _menhir_action_083 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState512 _tok
            | Elpi_lexer_config.Tokens.CONSTANT _v_1445 ->
                let _startpos_1446 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1447 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_c_, _startpos_c_, c) = (_endpos_1447, _startpos_1446, _v_1445) in
                let _v = _menhir_action_075 c in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState512 _tok
            | Elpi_lexer_config.Tokens.BEFORE ->
                let _startpos_1449 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1450 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1450, _startpos_1449) in
                let _v = _menhir_action_078 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState512 _tok
            | Elpi_lexer_config.Tokens.AFTER ->
                let _startpos_1452 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1453 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1453, _startpos_1452) in
                let _v = _menhir_action_079 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState512 _tok
            | _ ->
                _eRR 512)
        | Elpi_lexer_config.Tokens.DIV ->
            let _menhir_stack = MenhirCell1_clause_hd_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos_1455 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_1456 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell0_DIV (_menhir_stack, _startpos_1455, _endpos_1456) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Elpi_lexer_config.Tokens.STRING _v_1457 ->
                let _startpos_1458 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1459 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_1459, _startpos_1458, _v_1457) in
                let _v = _menhir_action_068 x in
                _menhir_run_053_spec_514 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.SIGMA ->
                let _startpos_1461 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1462 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1462, _startpos_1461) in
                let _v = _menhir_action_085 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState514 _tok
            | Elpi_lexer_config.Tokens.REPLACE ->
                let _startpos_1464 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1465 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1465, _startpos_1464) in
                let _v = _menhir_action_080 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState514 _tok
            | Elpi_lexer_config.Tokens.QUOTED _v_1467 ->
                let _startpos_1468 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1469 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_1469, _startpos_1468, _v_1467) in
                let _v = _menhir_action_069 _endpos_x_ _startpos_x_ x in
                _menhir_run_053_spec_514 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.PI ->
                let _startpos_1471 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1472 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1472, _startpos_1471) in
                let _v = _menhir_action_084 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState514 _tok
            | Elpi_lexer_config.Tokens.NIL ->
                let _startpos_1474 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1475 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1475, _startpos_1474) in
                let _v = _menhir_action_089 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState514 _tok
            | Elpi_lexer_config.Tokens.NAME ->
                let _startpos_1477 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1478 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1478, _startpos_1477) in
                let _v = _menhir_action_077 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState514 _tok
            | Elpi_lexer_config.Tokens.LPAREN ->
                _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState514
            | Elpi_lexer_config.Tokens.LCURLY ->
                _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState514
            | Elpi_lexer_config.Tokens.LBRACKET ->
                _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState514
            | Elpi_lexer_config.Tokens.IO _v_1480 ->
                let _startpos_1481 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1482 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_c_, _startpos_c_, c) = (_endpos_1482, _startpos_1481, _v_1480) in
                let _v = _menhir_action_082 c in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState514 _tok
            | Elpi_lexer_config.Tokens.INTEGER _v_1484 ->
                let _startpos_1485 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1486 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_1486, _startpos_1485, _v_1484) in
                let _v = _menhir_action_066 x in
                _menhir_run_053_spec_514 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.INDEX ->
                let _startpos_1488 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1489 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1489, _startpos_1488) in
                let _v = _menhir_action_081 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState514 _tok
            | Elpi_lexer_config.Tokens.IF ->
                let _startpos_1491 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1492 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1492, _startpos_1491) in
                let _v = _menhir_action_076 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState514 _tok
            | Elpi_lexer_config.Tokens.FRESHUV ->
                let _startpos_1494 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1495 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1495, _startpos_1494) in
                let _v = _menhir_action_086 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState514 _tok
            | Elpi_lexer_config.Tokens.FLOAT _v_1497 ->
                let _startpos_1498 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1499 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_1499, _startpos_1498, _v_1497) in
                let _v = _menhir_action_067 x in
                _menhir_run_053_spec_514 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.FAMILY_TILDE _v_1501 ->
                _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1501 MenhirState514
            | Elpi_lexer_config.Tokens.CUT ->
                let _startpos_1502 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1503 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1503, _startpos_1502) in
                let _v = _menhir_action_083 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState514 _tok
            | Elpi_lexer_config.Tokens.CONSTANT _v_1505 ->
                let _startpos_1506 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1507 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_c_, _startpos_c_, c) = (_endpos_1507, _startpos_1506, _v_1505) in
                let _v = _menhir_action_075 c in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState514 _tok
            | Elpi_lexer_config.Tokens.BEFORE ->
                let _startpos_1509 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1510 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1510, _startpos_1509) in
                let _v = _menhir_action_078 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState514 _tok
            | Elpi_lexer_config.Tokens.AFTER ->
                let _startpos_1512 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1513 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1513, _startpos_1512) in
                let _v = _menhir_action_079 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState514 _tok
            | _ ->
                _eRR 514)
        | Elpi_lexer_config.Tokens.DARROW ->
            let _menhir_stack = MenhirCell1_clause_hd_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos_1515 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_1516 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell0_DARROW (_menhir_stack, _startpos_1515, _endpos_1516) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Elpi_lexer_config.Tokens.STRING _v_1517 ->
                let _startpos_1518 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1519 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_1519, _startpos_1518, _v_1517) in
                let _v = _menhir_action_068 x in
                _menhir_run_053_spec_516 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.SIGMA ->
                let _startpos_1521 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1522 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1522, _startpos_1521) in
                let _v = _menhir_action_085 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState516 _tok
            | Elpi_lexer_config.Tokens.REPLACE ->
                let _startpos_1524 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1525 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1525, _startpos_1524) in
                let _v = _menhir_action_080 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState516 _tok
            | Elpi_lexer_config.Tokens.QUOTED _v_1527 ->
                let _startpos_1528 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1529 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_1529, _startpos_1528, _v_1527) in
                let _v = _menhir_action_069 _endpos_x_ _startpos_x_ x in
                _menhir_run_053_spec_516 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.PI ->
                let _startpos_1531 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1532 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1532, _startpos_1531) in
                let _v = _menhir_action_084 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState516 _tok
            | Elpi_lexer_config.Tokens.NIL ->
                let _startpos_1534 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1535 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1535, _startpos_1534) in
                let _v = _menhir_action_089 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState516 _tok
            | Elpi_lexer_config.Tokens.NAME ->
                let _startpos_1537 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1538 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1538, _startpos_1537) in
                let _v = _menhir_action_077 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState516 _tok
            | Elpi_lexer_config.Tokens.LPAREN ->
                _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState516
            | Elpi_lexer_config.Tokens.LCURLY ->
                _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState516
            | Elpi_lexer_config.Tokens.LBRACKET ->
                _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState516
            | Elpi_lexer_config.Tokens.IO _v_1540 ->
                let _startpos_1541 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1542 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_c_, _startpos_c_, c) = (_endpos_1542, _startpos_1541, _v_1540) in
                let _v = _menhir_action_082 c in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState516 _tok
            | Elpi_lexer_config.Tokens.INTEGER _v_1544 ->
                let _startpos_1545 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1546 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_1546, _startpos_1545, _v_1544) in
                let _v = _menhir_action_066 x in
                _menhir_run_053_spec_516 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.INDEX ->
                let _startpos_1548 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1549 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1549, _startpos_1548) in
                let _v = _menhir_action_081 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState516 _tok
            | Elpi_lexer_config.Tokens.IF ->
                let _startpos_1551 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1552 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1552, _startpos_1551) in
                let _v = _menhir_action_076 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState516 _tok
            | Elpi_lexer_config.Tokens.FRESHUV ->
                let _startpos_1554 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1555 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1555, _startpos_1554) in
                let _v = _menhir_action_086 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState516 _tok
            | Elpi_lexer_config.Tokens.FLOAT _v_1557 ->
                let _startpos_1558 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1559 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_1559, _startpos_1558, _v_1557) in
                let _v = _menhir_action_067 x in
                _menhir_run_053_spec_516 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.FAMILY_TILDE _v_1561 ->
                _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1561 MenhirState516
            | Elpi_lexer_config.Tokens.CUT ->
                let _startpos_1562 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1563 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1563, _startpos_1562) in
                let _v = _menhir_action_083 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState516 _tok
            | Elpi_lexer_config.Tokens.CONSTANT _v_1565 ->
                let _startpos_1566 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1567 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_c_, _startpos_c_, c) = (_endpos_1567, _startpos_1566, _v_1565) in
                let _v = _menhir_action_075 c in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState516 _tok
            | Elpi_lexer_config.Tokens.BEFORE ->
                let _startpos_1569 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1570 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1570, _startpos_1569) in
                let _v = _menhir_action_078 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState516 _tok
            | Elpi_lexer_config.Tokens.AFTER ->
                let _startpos_1572 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1573 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1573, _startpos_1572) in
                let _v = _menhir_action_079 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState516 _tok
            | _ ->
                _eRR 516)
        | Elpi_lexer_config.Tokens.CONS ->
            let _menhir_stack = MenhirCell1_clause_hd_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos_1575 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_1576 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell0_CONS (_menhir_stack, _startpos_1575, _endpos_1576) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Elpi_lexer_config.Tokens.STRING _v_1577 ->
                let _startpos_1578 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1579 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_1579, _startpos_1578, _v_1577) in
                let _v = _menhir_action_068 x in
                _menhir_run_053_spec_518 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.SIGMA ->
                let _startpos_1581 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1582 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1582, _startpos_1581) in
                let _v = _menhir_action_085 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState518 _tok
            | Elpi_lexer_config.Tokens.REPLACE ->
                let _startpos_1584 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1585 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1585, _startpos_1584) in
                let _v = _menhir_action_080 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState518 _tok
            | Elpi_lexer_config.Tokens.QUOTED _v_1587 ->
                let _startpos_1588 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1589 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_1589, _startpos_1588, _v_1587) in
                let _v = _menhir_action_069 _endpos_x_ _startpos_x_ x in
                _menhir_run_053_spec_518 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.PI ->
                let _startpos_1591 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1592 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1592, _startpos_1591) in
                let _v = _menhir_action_084 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState518 _tok
            | Elpi_lexer_config.Tokens.NIL ->
                let _startpos_1594 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1595 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1595, _startpos_1594) in
                let _v = _menhir_action_089 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState518 _tok
            | Elpi_lexer_config.Tokens.NAME ->
                let _startpos_1597 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1598 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1598, _startpos_1597) in
                let _v = _menhir_action_077 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState518 _tok
            | Elpi_lexer_config.Tokens.LPAREN ->
                _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState518
            | Elpi_lexer_config.Tokens.LCURLY ->
                _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState518
            | Elpi_lexer_config.Tokens.LBRACKET ->
                _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState518
            | Elpi_lexer_config.Tokens.IO _v_1600 ->
                let _startpos_1601 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1602 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_c_, _startpos_c_, c) = (_endpos_1602, _startpos_1601, _v_1600) in
                let _v = _menhir_action_082 c in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState518 _tok
            | Elpi_lexer_config.Tokens.INTEGER _v_1604 ->
                let _startpos_1605 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1606 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_1606, _startpos_1605, _v_1604) in
                let _v = _menhir_action_066 x in
                _menhir_run_053_spec_518 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.INDEX ->
                let _startpos_1608 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1609 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1609, _startpos_1608) in
                let _v = _menhir_action_081 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState518 _tok
            | Elpi_lexer_config.Tokens.IF ->
                let _startpos_1611 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1612 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1612, _startpos_1611) in
                let _v = _menhir_action_076 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState518 _tok
            | Elpi_lexer_config.Tokens.FRESHUV ->
                let _startpos_1614 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1615 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1615, _startpos_1614) in
                let _v = _menhir_action_086 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState518 _tok
            | Elpi_lexer_config.Tokens.FLOAT _v_1617 ->
                let _startpos_1618 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1619 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_1619, _startpos_1618, _v_1617) in
                let _v = _menhir_action_067 x in
                _menhir_run_053_spec_518 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.FAMILY_TILDE _v_1621 ->
                _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1621 MenhirState518
            | Elpi_lexer_config.Tokens.CUT ->
                let _startpos_1622 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1623 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1623, _startpos_1622) in
                let _v = _menhir_action_083 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState518 _tok
            | Elpi_lexer_config.Tokens.CONSTANT _v_1625 ->
                let _startpos_1626 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1627 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_c_, _startpos_c_, c) = (_endpos_1627, _startpos_1626, _v_1625) in
                let _v = _menhir_action_075 c in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState518 _tok
            | Elpi_lexer_config.Tokens.BEFORE ->
                let _startpos_1629 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1630 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1630, _startpos_1629) in
                let _v = _menhir_action_078 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState518 _tok
            | Elpi_lexer_config.Tokens.AFTER ->
                let _startpos_1632 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1633 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1633, _startpos_1632) in
                let _v = _menhir_action_079 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState518 _tok
            | _ ->
                _eRR 518)
        | Elpi_lexer_config.Tokens.CONJ2 ->
            let _menhir_stack = MenhirCell1_clause_hd_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos_1635 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_1636 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell0_CONJ2 (_menhir_stack, _startpos_1635, _endpos_1636) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Elpi_lexer_config.Tokens.STRING _v_1637 ->
                let _startpos_1638 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1639 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_1639, _startpos_1638, _v_1637) in
                let _v = _menhir_action_068 x in
                _menhir_run_053_spec_520 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.SIGMA ->
                let _startpos_1641 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1642 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1642, _startpos_1641) in
                let _v = _menhir_action_085 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState520 _tok
            | Elpi_lexer_config.Tokens.REPLACE ->
                let _startpos_1644 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1645 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1645, _startpos_1644) in
                let _v = _menhir_action_080 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState520 _tok
            | Elpi_lexer_config.Tokens.QUOTED _v_1647 ->
                let _startpos_1648 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1649 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_1649, _startpos_1648, _v_1647) in
                let _v = _menhir_action_069 _endpos_x_ _startpos_x_ x in
                _menhir_run_053_spec_520 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.PI ->
                let _startpos_1651 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1652 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1652, _startpos_1651) in
                let _v = _menhir_action_084 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState520 _tok
            | Elpi_lexer_config.Tokens.NIL ->
                let _startpos_1654 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1655 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1655, _startpos_1654) in
                let _v = _menhir_action_089 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState520 _tok
            | Elpi_lexer_config.Tokens.NAME ->
                let _startpos_1657 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1658 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1658, _startpos_1657) in
                let _v = _menhir_action_077 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState520 _tok
            | Elpi_lexer_config.Tokens.LPAREN ->
                _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState520
            | Elpi_lexer_config.Tokens.LCURLY ->
                _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState520
            | Elpi_lexer_config.Tokens.LBRACKET ->
                _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState520
            | Elpi_lexer_config.Tokens.IO _v_1660 ->
                let _startpos_1661 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1662 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_c_, _startpos_c_, c) = (_endpos_1662, _startpos_1661, _v_1660) in
                let _v = _menhir_action_082 c in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState520 _tok
            | Elpi_lexer_config.Tokens.INTEGER _v_1664 ->
                let _startpos_1665 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1666 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_1666, _startpos_1665, _v_1664) in
                let _v = _menhir_action_066 x in
                _menhir_run_053_spec_520 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.INDEX ->
                let _startpos_1668 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1669 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1669, _startpos_1668) in
                let _v = _menhir_action_081 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState520 _tok
            | Elpi_lexer_config.Tokens.IF ->
                let _startpos_1671 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1672 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1672, _startpos_1671) in
                let _v = _menhir_action_076 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState520 _tok
            | Elpi_lexer_config.Tokens.FRESHUV ->
                let _startpos_1674 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1675 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1675, _startpos_1674) in
                let _v = _menhir_action_086 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState520 _tok
            | Elpi_lexer_config.Tokens.FLOAT _v_1677 ->
                let _startpos_1678 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1679 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_1679, _startpos_1678, _v_1677) in
                let _v = _menhir_action_067 x in
                _menhir_run_053_spec_520 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.FAMILY_TILDE _v_1681 ->
                _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1681 MenhirState520
            | Elpi_lexer_config.Tokens.CUT ->
                let _startpos_1682 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1683 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1683, _startpos_1682) in
                let _v = _menhir_action_083 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState520 _tok
            | Elpi_lexer_config.Tokens.CONSTANT _v_1685 ->
                let _startpos_1686 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1687 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_c_, _startpos_c_, c) = (_endpos_1687, _startpos_1686, _v_1685) in
                let _v = _menhir_action_075 c in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState520 _tok
            | Elpi_lexer_config.Tokens.BEFORE ->
                let _startpos_1689 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1690 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1690, _startpos_1689) in
                let _v = _menhir_action_078 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState520 _tok
            | Elpi_lexer_config.Tokens.AFTER ->
                let _startpos_1692 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1693 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1693, _startpos_1692) in
                let _v = _menhir_action_079 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState520 _tok
            | _ ->
                _eRR 520)
        | Elpi_lexer_config.Tokens.CONJ ->
            let _menhir_stack = MenhirCell1_clause_hd_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos_1695 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_1696 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell0_CONJ (_menhir_stack, _startpos_1695, _endpos_1696) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Elpi_lexer_config.Tokens.STRING _v_1697 ->
                let _startpos_1698 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1699 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_1699, _startpos_1698, _v_1697) in
                let _v = _menhir_action_068 x in
                _menhir_run_053_spec_522 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.SIGMA ->
                let _startpos_1701 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1702 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1702, _startpos_1701) in
                let _v = _menhir_action_085 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState522 _tok
            | Elpi_lexer_config.Tokens.REPLACE ->
                let _startpos_1704 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1705 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1705, _startpos_1704) in
                let _v = _menhir_action_080 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState522 _tok
            | Elpi_lexer_config.Tokens.QUOTED _v_1707 ->
                let _startpos_1708 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1709 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_1709, _startpos_1708, _v_1707) in
                let _v = _menhir_action_069 _endpos_x_ _startpos_x_ x in
                _menhir_run_053_spec_522 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.PI ->
                let _startpos_1711 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1712 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1712, _startpos_1711) in
                let _v = _menhir_action_084 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState522 _tok
            | Elpi_lexer_config.Tokens.NIL ->
                let _startpos_1714 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1715 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1715, _startpos_1714) in
                let _v = _menhir_action_089 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState522 _tok
            | Elpi_lexer_config.Tokens.NAME ->
                let _startpos_1717 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1718 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1718, _startpos_1717) in
                let _v = _menhir_action_077 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState522 _tok
            | Elpi_lexer_config.Tokens.LPAREN ->
                _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState522
            | Elpi_lexer_config.Tokens.LCURLY ->
                _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState522
            | Elpi_lexer_config.Tokens.LBRACKET ->
                _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState522
            | Elpi_lexer_config.Tokens.IO _v_1720 ->
                let _startpos_1721 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1722 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_c_, _startpos_c_, c) = (_endpos_1722, _startpos_1721, _v_1720) in
                let _v = _menhir_action_082 c in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState522 _tok
            | Elpi_lexer_config.Tokens.INTEGER _v_1724 ->
                let _startpos_1725 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1726 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_1726, _startpos_1725, _v_1724) in
                let _v = _menhir_action_066 x in
                _menhir_run_053_spec_522 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.INDEX ->
                let _startpos_1728 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1729 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1729, _startpos_1728) in
                let _v = _menhir_action_081 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState522 _tok
            | Elpi_lexer_config.Tokens.IF ->
                let _startpos_1731 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1732 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1732, _startpos_1731) in
                let _v = _menhir_action_076 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState522 _tok
            | Elpi_lexer_config.Tokens.FRESHUV ->
                let _startpos_1734 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1735 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1735, _startpos_1734) in
                let _v = _menhir_action_086 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState522 _tok
            | Elpi_lexer_config.Tokens.FLOAT _v_1737 ->
                let _startpos_1738 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1739 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_1739, _startpos_1738, _v_1737) in
                let _v = _menhir_action_067 x in
                _menhir_run_053_spec_522 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.FAMILY_TILDE _v_1741 ->
                _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1741 MenhirState522
            | Elpi_lexer_config.Tokens.CUT ->
                let _startpos_1742 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1743 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1743, _startpos_1742) in
                let _v = _menhir_action_083 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState522 _tok
            | Elpi_lexer_config.Tokens.CONSTANT _v_1745 ->
                let _startpos_1746 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1747 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_c_, _startpos_c_, c) = (_endpos_1747, _startpos_1746, _v_1745) in
                let _v = _menhir_action_075 c in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState522 _tok
            | Elpi_lexer_config.Tokens.BEFORE ->
                let _startpos_1749 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1750 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1750, _startpos_1749) in
                let _v = _menhir_action_078 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState522 _tok
            | Elpi_lexer_config.Tokens.AFTER ->
                let _startpos_1752 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1753 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1753, _startpos_1752) in
                let _v = _menhir_action_079 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState522 _tok
            | _ ->
                _eRR 522)
        | Elpi_lexer_config.Tokens.ARROW ->
            let _menhir_stack = MenhirCell1_clause_hd_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos_1755 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_1756 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell0_ARROW (_menhir_stack, _startpos_1755, _endpos_1756) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Elpi_lexer_config.Tokens.STRING _v_1757 ->
                let _startpos_1758 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1759 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_1759, _startpos_1758, _v_1757) in
                let _v = _menhir_action_068 x in
                _menhir_run_053_spec_524 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.SIGMA ->
                let _startpos_1761 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1762 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1762, _startpos_1761) in
                let _v = _menhir_action_085 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState524 _tok
            | Elpi_lexer_config.Tokens.REPLACE ->
                let _startpos_1764 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1765 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1765, _startpos_1764) in
                let _v = _menhir_action_080 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState524 _tok
            | Elpi_lexer_config.Tokens.QUOTED _v_1767 ->
                let _startpos_1768 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1769 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_1769, _startpos_1768, _v_1767) in
                let _v = _menhir_action_069 _endpos_x_ _startpos_x_ x in
                _menhir_run_053_spec_524 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.PI ->
                let _startpos_1771 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1772 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1772, _startpos_1771) in
                let _v = _menhir_action_084 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState524 _tok
            | Elpi_lexer_config.Tokens.NIL ->
                let _startpos_1774 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1775 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1775, _startpos_1774) in
                let _v = _menhir_action_089 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState524 _tok
            | Elpi_lexer_config.Tokens.NAME ->
                let _startpos_1777 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1778 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1778, _startpos_1777) in
                let _v = _menhir_action_077 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState524 _tok
            | Elpi_lexer_config.Tokens.LPAREN ->
                _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState524
            | Elpi_lexer_config.Tokens.LCURLY ->
                _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState524
            | Elpi_lexer_config.Tokens.LBRACKET ->
                _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState524
            | Elpi_lexer_config.Tokens.IO _v_1780 ->
                let _startpos_1781 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1782 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_c_, _startpos_c_, c) = (_endpos_1782, _startpos_1781, _v_1780) in
                let _v = _menhir_action_082 c in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState524 _tok
            | Elpi_lexer_config.Tokens.INTEGER _v_1784 ->
                let _startpos_1785 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1786 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_1786, _startpos_1785, _v_1784) in
                let _v = _menhir_action_066 x in
                _menhir_run_053_spec_524 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.INDEX ->
                let _startpos_1788 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1789 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1789, _startpos_1788) in
                let _v = _menhir_action_081 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState524 _tok
            | Elpi_lexer_config.Tokens.IF ->
                let _startpos_1791 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1792 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1792, _startpos_1791) in
                let _v = _menhir_action_076 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState524 _tok
            | Elpi_lexer_config.Tokens.FRESHUV ->
                let _startpos_1794 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1795 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1795, _startpos_1794) in
                let _v = _menhir_action_086 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState524 _tok
            | Elpi_lexer_config.Tokens.FLOAT _v_1797 ->
                let _startpos_1798 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1799 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_1799, _startpos_1798, _v_1797) in
                let _v = _menhir_action_067 x in
                _menhir_run_053_spec_524 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.FAMILY_TILDE _v_1801 ->
                _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1801 MenhirState524
            | Elpi_lexer_config.Tokens.CUT ->
                let _startpos_1802 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1803 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1803, _startpos_1802) in
                let _v = _menhir_action_083 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState524 _tok
            | Elpi_lexer_config.Tokens.CONSTANT _v_1805 ->
                let _startpos_1806 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1807 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_c_, _startpos_c_, c) = (_endpos_1807, _startpos_1806, _v_1805) in
                let _v = _menhir_action_075 c in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState524 _tok
            | Elpi_lexer_config.Tokens.BEFORE ->
                let _startpos_1809 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1810 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1810, _startpos_1809) in
                let _v = _menhir_action_078 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState524 _tok
            | Elpi_lexer_config.Tokens.AFTER ->
                let _startpos_1812 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_1813 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_1813, _startpos_1812) in
                let _v = _menhir_action_079 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState524 _tok
            | _ ->
                _eRR 524)
        | Elpi_lexer_config.Tokens.FULLSTOP ->
            let MenhirCell1_attributes (_menhir_stack, _menhir_s, attributes, _startpos_attributes_, _endpos_attributes_) = _menhir_stack in
            let (_endpos_body_, _startpos_body_, body) = (_endpos, _startpos, _v) in
            let _v = _menhir_action_028 _endpos_attributes_ _endpos_body_ _startpos_attributes_ _startpos_body_ attributes body in
            _menhir_goto_clause _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | _ ->
            _eRR 464
    
    and _menhir_run_053_spec_465 : type  ttv_stack. ((ttv_stack, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_clause_hd_term _menhir_cell0_VDASH -> _ -> _ -> _ -> _ -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_317 t in
        _menhir_run_466 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v MenhirState465 _tok
    
    and _menhir_run_466 : type  ttv_stack. (((ttv_stack, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_clause_hd_term _menhir_cell0_VDASH as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.VDASH ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_056 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.SLASH ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.QDASH ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_114 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.OR ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_072 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MOD ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_074 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSs ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_076 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSr ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_082 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSi ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_084 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_086 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.IS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_088 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FAMILY_TIMES _v_0 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_078 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_TICK _v_1 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_090 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_3 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_041 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_PLUS _v_4 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_092 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_5 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_6 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.FAMILY_LT _v_7 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_098 _menhir_stack _menhir_lexbuf _menhir_lexer _v_7
        | Elpi_lexer_config.Tokens.FAMILY_GT _v_8 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_100 _menhir_stack _menhir_lexbuf _menhir_lexer _v_8
        | Elpi_lexer_config.Tokens.FAMILY_EXP _v_9 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_094 _menhir_stack _menhir_lexbuf _menhir_lexer _v_9
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_10 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer _v_10
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_11 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer _v_11
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_12 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer _v_12
        | Elpi_lexer_config.Tokens.EQ2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_102 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.EQ ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_104 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.DIV ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_080 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.DARROW ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_106 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_096 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONJ2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_108 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONJ ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_110 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.ARROW ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_112 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FULLSTOP ->
            let MenhirCell0_VDASH (_menhir_stack, _, _) = _menhir_stack in
            let MenhirCell1_clause_hd_term (_menhir_stack, _, l, _startpos_l_, _) = _menhir_stack in
            let MenhirCell1_attributes (_menhir_stack, _menhir_s, attributes, _startpos_attributes_, _endpos_attributes_) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_029 _endpos_attributes_ _endpos_r_ _startpos_attributes_ _startpos_l_ attributes l r in
            _menhir_goto_clause _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | _ ->
            _eRR 466
    
    and _menhir_goto_clause : type  ttv_stack. ttv_stack -> _ -> _ -> _ -> (ttv_stack, _menhir_box_program) _menhir_state -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s ->
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        let c = _v in
        let _v = _menhir_action_090 c in
        _menhir_goto_decl _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
    
    and _menhir_run_053_spec_467 : type  ttv_stack. ((ttv_stack, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_clause_hd_term _menhir_cell0_SLASH -> _ -> _ -> _ -> _ -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_317 t in
        _menhir_run_468 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v MenhirState467 _tok
    
    and _menhir_run_468 : type  ttv_stack. (((ttv_stack, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_clause_hd_term _menhir_cell0_SLASH as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_0 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_1 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_041 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_3 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_4 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_5 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_6 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.CONS | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.DIV | Elpi_lexer_config.Tokens.EQ | Elpi_lexer_config.Tokens.EQ2 | Elpi_lexer_config.Tokens.FAMILY_EXP _ | Elpi_lexer_config.Tokens.FAMILY_GT _ | Elpi_lexer_config.Tokens.FAMILY_LT _ | Elpi_lexer_config.Tokens.FAMILY_PLUS _ | Elpi_lexer_config.Tokens.FAMILY_TICK _ | Elpi_lexer_config.Tokens.FAMILY_TIMES _ | Elpi_lexer_config.Tokens.FULLSTOP | Elpi_lexer_config.Tokens.IS | Elpi_lexer_config.Tokens.MINUS | Elpi_lexer_config.Tokens.MINUSi | Elpi_lexer_config.Tokens.MINUSr | Elpi_lexer_config.Tokens.MINUSs | Elpi_lexer_config.Tokens.MOD | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.SLASH | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_SLASH (_menhir_stack, _, _) = _menhir_stack in
            let MenhirCell1_clause_hd_term (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_059 _endpos_r_ _startpos_l_ l r in
            _menhir_goto_clause_hd_open_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 468
    
    and _menhir_run_053_spec_469 : type  ttv_stack. ((ttv_stack, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_clause_hd_term _menhir_cell0_QDASH -> _ -> _ -> _ -> _ -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_317 t in
        _menhir_run_470 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v MenhirState469 _tok
    
    and _menhir_run_470 : type  ttv_stack. (((ttv_stack, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_clause_hd_term _menhir_cell0_QDASH as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.SLASH ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.OR ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_072 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MOD ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_074 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSs ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_076 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSr ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_082 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSi ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_084 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_086 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.IS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_088 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FAMILY_TIMES _v_0 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_078 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_TICK _v_1 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_090 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_3 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_041 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_PLUS _v_4 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_092 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_5 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_6 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.FAMILY_LT _v_7 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_098 _menhir_stack _menhir_lexbuf _menhir_lexer _v_7
        | Elpi_lexer_config.Tokens.FAMILY_GT _v_8 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_100 _menhir_stack _menhir_lexbuf _menhir_lexer _v_8
        | Elpi_lexer_config.Tokens.FAMILY_EXP _v_9 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_094 _menhir_stack _menhir_lexbuf _menhir_lexer _v_9
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_10 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer _v_10
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_11 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer _v_11
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_12 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer _v_12
        | Elpi_lexer_config.Tokens.EQ2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_102 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.EQ ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_104 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.DIV ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_080 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.DARROW ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_106 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_096 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONJ2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_108 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONJ ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_110 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.ARROW ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_112 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FULLSTOP ->
            let MenhirCell0_QDASH (_menhir_stack, _, _) = _menhir_stack in
            let MenhirCell1_clause_hd_term (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_058 _endpos_r_ _startpos_l_ l r in
            _menhir_goto_clause_hd_open_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 470
    
    and _menhir_run_053_spec_471 : type  ttv_stack. ((ttv_stack, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_clause_hd_term _menhir_cell0_OR -> _ -> _ -> _ -> _ -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_317 t in
        _menhir_run_472 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v MenhirState471 _tok
    
    and _menhir_run_472 : type  ttv_stack. (((ttv_stack, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_clause_hd_term _menhir_cell0_OR as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.SLASH ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.OR ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_072 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MOD ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_074 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSs ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_076 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSr ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_082 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSi ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_084 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_086 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.IS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_088 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FAMILY_TIMES _v_0 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_078 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_TICK _v_1 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_090 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_3 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_041 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_PLUS _v_4 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_092 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_5 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_6 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.FAMILY_LT _v_7 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_098 _menhir_stack _menhir_lexbuf _menhir_lexer _v_7
        | Elpi_lexer_config.Tokens.FAMILY_GT _v_8 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_100 _menhir_stack _menhir_lexbuf _menhir_lexer _v_8
        | Elpi_lexer_config.Tokens.FAMILY_EXP _v_9 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_094 _menhir_stack _menhir_lexbuf _menhir_lexer _v_9
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_10 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer _v_10
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_11 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer _v_11
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_12 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer _v_12
        | Elpi_lexer_config.Tokens.EQ2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_102 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.EQ ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_104 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.DIV ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_080 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.DARROW ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_106 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_096 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONJ2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_108 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONJ ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_110 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.ARROW ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_112 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FULLSTOP | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_OR (_menhir_stack, _, _) = _menhir_stack in
            let MenhirCell1_clause_hd_term (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_052 _endpos_r_ _startpos_l_ l r in
            _menhir_goto_clause_hd_open_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 472
    
    and _menhir_run_053_spec_473 : type  ttv_stack. ((ttv_stack, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_clause_hd_term _menhir_cell0_MOD -> _ -> _ -> _ -> _ -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_317 t in
        _menhir_run_474 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v MenhirState473 _tok
    
    and _menhir_run_474 : type  ttv_stack. (((ttv_stack, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_clause_hd_term _menhir_cell0_MOD as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_0 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_1 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_041 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_3 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_4 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_5 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_6 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.CONS | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.DIV | Elpi_lexer_config.Tokens.EQ | Elpi_lexer_config.Tokens.EQ2 | Elpi_lexer_config.Tokens.FAMILY_EXP _ | Elpi_lexer_config.Tokens.FAMILY_GT _ | Elpi_lexer_config.Tokens.FAMILY_LT _ | Elpi_lexer_config.Tokens.FAMILY_PLUS _ | Elpi_lexer_config.Tokens.FAMILY_TICK _ | Elpi_lexer_config.Tokens.FAMILY_TIMES _ | Elpi_lexer_config.Tokens.FULLSTOP | Elpi_lexer_config.Tokens.IS | Elpi_lexer_config.Tokens.MINUS | Elpi_lexer_config.Tokens.MINUSi | Elpi_lexer_config.Tokens.MINUSr | Elpi_lexer_config.Tokens.MINUSs | Elpi_lexer_config.Tokens.MOD | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.SLASH | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_MOD (_menhir_stack, _, _) = _menhir_stack in
            let MenhirCell1_clause_hd_term (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_054 _endpos_r_ _startpos_l_ l r in
            _menhir_goto_clause_hd_open_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 474
    
    and _menhir_run_053_spec_475 : type  ttv_stack. ((ttv_stack, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_clause_hd_term _menhir_cell0_MINUSs -> _ -> _ -> _ -> _ -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_317 t in
        _menhir_run_476 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v MenhirState475 _tok
    
    and _menhir_run_476 : type  ttv_stack. (((ttv_stack, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_clause_hd_term _menhir_cell0_MINUSs as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.SLASH ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MOD ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_074 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FAMILY_TIMES _v_0 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_078 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_1 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_041 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_3 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_4 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_5 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_6 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_7 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer _v_7
        | Elpi_lexer_config.Tokens.DIV ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_080 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.CONS | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.EQ | Elpi_lexer_config.Tokens.EQ2 | Elpi_lexer_config.Tokens.FAMILY_EXP _ | Elpi_lexer_config.Tokens.FAMILY_GT _ | Elpi_lexer_config.Tokens.FAMILY_LT _ | Elpi_lexer_config.Tokens.FAMILY_PLUS _ | Elpi_lexer_config.Tokens.FAMILY_TICK _ | Elpi_lexer_config.Tokens.FULLSTOP | Elpi_lexer_config.Tokens.IS | Elpi_lexer_config.Tokens.MINUS | Elpi_lexer_config.Tokens.MINUSi | Elpi_lexer_config.Tokens.MINUSr | Elpi_lexer_config.Tokens.MINUSs | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_MINUSs (_menhir_stack, _, _) = _menhir_stack in
            let MenhirCell1_clause_hd_term (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_050 _endpos_r_ _startpos_l_ l r in
            _menhir_goto_clause_hd_open_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 476
    
    and _menhir_run_053_spec_477 : type  ttv_stack. ((ttv_stack, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_clause_hd_term _menhir_cell0_MINUSr -> _ -> _ -> _ -> _ -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_317 t in
        _menhir_run_478 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v MenhirState477 _tok
    
    and _menhir_run_478 : type  ttv_stack. (((ttv_stack, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_clause_hd_term _menhir_cell0_MINUSr as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.SLASH ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MOD ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_074 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FAMILY_TIMES _v_0 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_078 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_1 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_041 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_3 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_4 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_5 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_6 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_7 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer _v_7
        | Elpi_lexer_config.Tokens.DIV ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_080 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.CONS | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.EQ | Elpi_lexer_config.Tokens.EQ2 | Elpi_lexer_config.Tokens.FAMILY_EXP _ | Elpi_lexer_config.Tokens.FAMILY_GT _ | Elpi_lexer_config.Tokens.FAMILY_LT _ | Elpi_lexer_config.Tokens.FAMILY_PLUS _ | Elpi_lexer_config.Tokens.FAMILY_TICK _ | Elpi_lexer_config.Tokens.FULLSTOP | Elpi_lexer_config.Tokens.IS | Elpi_lexer_config.Tokens.MINUS | Elpi_lexer_config.Tokens.MINUSi | Elpi_lexer_config.Tokens.MINUSr | Elpi_lexer_config.Tokens.MINUSs | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_MINUSr (_menhir_stack, _, _) = _menhir_stack in
            let MenhirCell1_clause_hd_term (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_048 _endpos_r_ _startpos_l_ l r in
            _menhir_goto_clause_hd_open_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 478
    
    and _menhir_run_053_spec_479 : type  ttv_stack. ((ttv_stack, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_clause_hd_term _menhir_cell0_MINUSi -> _ -> _ -> _ -> _ -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_317 t in
        _menhir_run_480 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v MenhirState479 _tok
    
    and _menhir_run_480 : type  ttv_stack. (((ttv_stack, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_clause_hd_term _menhir_cell0_MINUSi as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.SLASH ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MOD ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_074 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FAMILY_TIMES _v_0 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_078 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_1 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_041 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_3 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_4 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_5 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_6 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_7 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer _v_7
        | Elpi_lexer_config.Tokens.DIV ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_080 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.CONS | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.EQ | Elpi_lexer_config.Tokens.EQ2 | Elpi_lexer_config.Tokens.FAMILY_EXP _ | Elpi_lexer_config.Tokens.FAMILY_GT _ | Elpi_lexer_config.Tokens.FAMILY_LT _ | Elpi_lexer_config.Tokens.FAMILY_PLUS _ | Elpi_lexer_config.Tokens.FAMILY_TICK _ | Elpi_lexer_config.Tokens.FULLSTOP | Elpi_lexer_config.Tokens.IS | Elpi_lexer_config.Tokens.MINUS | Elpi_lexer_config.Tokens.MINUSi | Elpi_lexer_config.Tokens.MINUSr | Elpi_lexer_config.Tokens.MINUSs | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_MINUSi (_menhir_stack, _, _) = _menhir_stack in
            let MenhirCell1_clause_hd_term (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_049 _endpos_r_ _startpos_l_ l r in
            _menhir_goto_clause_hd_open_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 480
    
    and _menhir_run_053_spec_481 : type  ttv_stack. ((ttv_stack, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_clause_hd_term _menhir_cell0_MINUS -> _ -> _ -> _ -> _ -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_317 t in
        _menhir_run_482 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v MenhirState481 _tok
    
    and _menhir_run_482 : type  ttv_stack. (((ttv_stack, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_clause_hd_term _menhir_cell0_MINUS as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.SLASH ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MOD ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_074 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FAMILY_TIMES _v_0 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_078 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_1 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_041 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_3 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_4 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_5 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_6 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_7 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer _v_7
        | Elpi_lexer_config.Tokens.DIV ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_080 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.CONS | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.EQ | Elpi_lexer_config.Tokens.EQ2 | Elpi_lexer_config.Tokens.FAMILY_EXP _ | Elpi_lexer_config.Tokens.FAMILY_GT _ | Elpi_lexer_config.Tokens.FAMILY_LT _ | Elpi_lexer_config.Tokens.FAMILY_PLUS _ | Elpi_lexer_config.Tokens.FAMILY_TICK _ | Elpi_lexer_config.Tokens.FULLSTOP | Elpi_lexer_config.Tokens.IS | Elpi_lexer_config.Tokens.MINUS | Elpi_lexer_config.Tokens.MINUSi | Elpi_lexer_config.Tokens.MINUSr | Elpi_lexer_config.Tokens.MINUSs | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_MINUS (_menhir_stack, _, _) = _menhir_stack in
            let MenhirCell1_clause_hd_term (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_047 _endpos_r_ _startpos_l_ l r in
            _menhir_goto_clause_hd_open_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 482
    
    and _menhir_run_053_spec_483 : type  ttv_stack. ((ttv_stack, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_clause_hd_term _menhir_cell0_IS -> _ -> _ -> _ -> _ -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_317 t in
        _menhir_run_484 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v MenhirState483 _tok
    
    and _menhir_run_484 : type  ttv_stack. (((ttv_stack, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_clause_hd_term _menhir_cell0_IS as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.SLASH ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MOD ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_074 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSs ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_076 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSr ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_082 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSi ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_084 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_086 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FAMILY_TIMES _v_0 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_078 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_TICK _v_1 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_090 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_3 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_041 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_PLUS _v_4 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_092 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_5 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_6 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.FAMILY_EXP _v_7 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_094 _menhir_stack _menhir_lexbuf _menhir_lexer _v_7
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_8 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer _v_8
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_9 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer _v_9
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_10 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer _v_10
        | Elpi_lexer_config.Tokens.DIV ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_080 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_096 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.FULLSTOP | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_IS (_menhir_stack, _, _) = _menhir_stack in
            let MenhirCell1_clause_hd_term (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_053 _endpos_r_ _startpos_l_ l r in
            _menhir_goto_clause_hd_open_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 484
    
    and _menhir_run_053_spec_485 : type  ttv_stack. ((ttv_stack, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_clause_hd_term _menhir_cell0_FAMILY_TIMES -> _ -> _ -> _ -> _ -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_317 t in
        _menhir_run_486 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v MenhirState485 _tok
    
    and _menhir_run_486 : type  ttv_stack. (((ttv_stack, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_clause_hd_term _menhir_cell0_FAMILY_TIMES as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_0 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_1 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_041 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_3 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_4 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_5 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_6 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.CONS | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.DIV | Elpi_lexer_config.Tokens.EQ | Elpi_lexer_config.Tokens.EQ2 | Elpi_lexer_config.Tokens.FAMILY_EXP _ | Elpi_lexer_config.Tokens.FAMILY_GT _ | Elpi_lexer_config.Tokens.FAMILY_LT _ | Elpi_lexer_config.Tokens.FAMILY_PLUS _ | Elpi_lexer_config.Tokens.FAMILY_TICK _ | Elpi_lexer_config.Tokens.FAMILY_TIMES _ | Elpi_lexer_config.Tokens.FULLSTOP | Elpi_lexer_config.Tokens.IS | Elpi_lexer_config.Tokens.MINUS | Elpi_lexer_config.Tokens.MINUSi | Elpi_lexer_config.Tokens.MINUSr | Elpi_lexer_config.Tokens.MINUSs | Elpi_lexer_config.Tokens.MOD | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.SLASH | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_FAMILY_TIMES (_menhir_stack, s, _, _) = _menhir_stack in
            let MenhirCell1_clause_hd_term (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_034 _endpos_r_ _startpos_l_ l r s in
            _menhir_goto_clause_hd_open_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 486
    
    and _menhir_run_053_spec_487 : type  ttv_stack. ((ttv_stack, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_clause_hd_term _menhir_cell0_FAMILY_TICK -> _ -> _ -> _ -> _ -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_317 t in
        _menhir_run_488 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v MenhirState487 _tok
    
    and _menhir_run_488 : type  ttv_stack. (((ttv_stack, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_clause_hd_term _menhir_cell0_FAMILY_TICK as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.SLASH ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MOD ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_074 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSs ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_076 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSr ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_082 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSi ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_084 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_086 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FAMILY_TIMES _v_0 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_078 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_1 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_041 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_PLUS _v_3 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_092 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_4 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_5 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_EXP _v_6 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_094 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_7 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer _v_7
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_8 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer _v_8
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_9 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer _v_9
        | Elpi_lexer_config.Tokens.DIV ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_080 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.CONS | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.EQ | Elpi_lexer_config.Tokens.EQ2 | Elpi_lexer_config.Tokens.FAMILY_GT _ | Elpi_lexer_config.Tokens.FAMILY_LT _ | Elpi_lexer_config.Tokens.FULLSTOP | Elpi_lexer_config.Tokens.IS | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_FAMILY_TICK (_menhir_stack, s, _, _) = _menhir_stack in
            let MenhirCell1_clause_hd_term (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_044 _endpos_r_ _startpos_l_ l r s in
            _menhir_goto_clause_hd_open_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 488
    
    and _menhir_run_053_spec_489 : type  ttv_stack. ((ttv_stack, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_clause_hd_term _menhir_cell0_FAMILY_SHARP -> _ -> _ -> _ -> _ -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_317 t in
        _menhir_run_490 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v MenhirState489 _tok
    
    and _menhir_run_490 : type  ttv_stack. (((ttv_stack, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_clause_hd_term _menhir_cell0_FAMILY_SHARP as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_0 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_041 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.CONS | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.DIV | Elpi_lexer_config.Tokens.EQ | Elpi_lexer_config.Tokens.EQ2 | Elpi_lexer_config.Tokens.FAMILY_AND _ | Elpi_lexer_config.Tokens.FAMILY_BTICK _ | Elpi_lexer_config.Tokens.FAMILY_EQ _ | Elpi_lexer_config.Tokens.FAMILY_EXP _ | Elpi_lexer_config.Tokens.FAMILY_GT _ | Elpi_lexer_config.Tokens.FAMILY_LT _ | Elpi_lexer_config.Tokens.FAMILY_MINUS _ | Elpi_lexer_config.Tokens.FAMILY_OR _ | Elpi_lexer_config.Tokens.FAMILY_PLUS _ | Elpi_lexer_config.Tokens.FAMILY_SHARP _ | Elpi_lexer_config.Tokens.FAMILY_TICK _ | Elpi_lexer_config.Tokens.FAMILY_TIMES _ | Elpi_lexer_config.Tokens.FULLSTOP | Elpi_lexer_config.Tokens.IS | Elpi_lexer_config.Tokens.MINUS | Elpi_lexer_config.Tokens.MINUSi | Elpi_lexer_config.Tokens.MINUSr | Elpi_lexer_config.Tokens.MINUSs | Elpi_lexer_config.Tokens.MOD | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.SLASH | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_FAMILY_SHARP (_menhir_stack, s, _, _) = _menhir_stack in
            let MenhirCell1_clause_hd_term (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_042 _endpos_r_ _startpos_l_ l r s in
            _menhir_goto_clause_hd_open_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 490
    
    and _menhir_run_053_spec_492 : type  ttv_stack. ((ttv_stack, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_clause_hd_term _menhir_cell0_FAMILY_PLUS -> _ -> _ -> _ -> _ -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_317 t in
        _menhir_run_493 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v MenhirState492 _tok
    
    and _menhir_run_493 : type  ttv_stack. (((ttv_stack, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_clause_hd_term _menhir_cell0_FAMILY_PLUS as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.SLASH ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MOD ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_074 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FAMILY_TIMES _v_0 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_078 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_1 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_041 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_3 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_4 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_5 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_6 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_7 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer _v_7
        | Elpi_lexer_config.Tokens.DIV ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_080 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.CONS | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.EQ | Elpi_lexer_config.Tokens.EQ2 | Elpi_lexer_config.Tokens.FAMILY_EXP _ | Elpi_lexer_config.Tokens.FAMILY_GT _ | Elpi_lexer_config.Tokens.FAMILY_LT _ | Elpi_lexer_config.Tokens.FAMILY_PLUS _ | Elpi_lexer_config.Tokens.FAMILY_TICK _ | Elpi_lexer_config.Tokens.FULLSTOP | Elpi_lexer_config.Tokens.IS | Elpi_lexer_config.Tokens.MINUS | Elpi_lexer_config.Tokens.MINUSi | Elpi_lexer_config.Tokens.MINUSr | Elpi_lexer_config.Tokens.MINUSs | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_FAMILY_PLUS (_menhir_stack, s, _, _) = _menhir_stack in
            let MenhirCell1_clause_hd_term (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_033 _endpos_r_ _startpos_l_ l r s in
            _menhir_goto_clause_hd_open_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 493
    
    and _menhir_run_053_spec_494 : type  ttv_stack. ((ttv_stack, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_clause_hd_term _menhir_cell0_FAMILY_OR -> _ -> _ -> _ -> _ -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_317 t in
        _menhir_run_495 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v MenhirState494 _tok
    
    and _menhir_run_495 : type  ttv_stack. (((ttv_stack, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_clause_hd_term _menhir_cell0_FAMILY_OR as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_0 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_1 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_041 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_3 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.CONS | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.DIV | Elpi_lexer_config.Tokens.EQ | Elpi_lexer_config.Tokens.EQ2 | Elpi_lexer_config.Tokens.FAMILY_BTICK _ | Elpi_lexer_config.Tokens.FAMILY_EQ _ | Elpi_lexer_config.Tokens.FAMILY_EXP _ | Elpi_lexer_config.Tokens.FAMILY_GT _ | Elpi_lexer_config.Tokens.FAMILY_LT _ | Elpi_lexer_config.Tokens.FAMILY_MINUS _ | Elpi_lexer_config.Tokens.FAMILY_PLUS _ | Elpi_lexer_config.Tokens.FAMILY_TICK _ | Elpi_lexer_config.Tokens.FAMILY_TIMES _ | Elpi_lexer_config.Tokens.FULLSTOP | Elpi_lexer_config.Tokens.IS | Elpi_lexer_config.Tokens.MINUS | Elpi_lexer_config.Tokens.MINUSi | Elpi_lexer_config.Tokens.MINUSr | Elpi_lexer_config.Tokens.MINUSs | Elpi_lexer_config.Tokens.MOD | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.SLASH | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_FAMILY_OR (_menhir_stack, s, _, _) = _menhir_stack in
            let MenhirCell1_clause_hd_term (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_041 _endpos_r_ _startpos_l_ l r s in
            _menhir_goto_clause_hd_open_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 495
    
    and _menhir_run_053_spec_496 : type  ttv_stack. ((ttv_stack, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_clause_hd_term _menhir_cell0_FAMILY_MINUS -> _ -> _ -> _ -> _ -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_317 t in
        _menhir_run_497 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v MenhirState496 _tok
    
    and _menhir_run_497 : type  ttv_stack. (((ttv_stack, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_clause_hd_term _menhir_cell0_FAMILY_MINUS as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_0 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_1 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_041 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_3 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_4 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_5 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_6 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.CONS | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.DIV | Elpi_lexer_config.Tokens.EQ | Elpi_lexer_config.Tokens.EQ2 | Elpi_lexer_config.Tokens.FAMILY_EXP _ | Elpi_lexer_config.Tokens.FAMILY_GT _ | Elpi_lexer_config.Tokens.FAMILY_LT _ | Elpi_lexer_config.Tokens.FAMILY_PLUS _ | Elpi_lexer_config.Tokens.FAMILY_TICK _ | Elpi_lexer_config.Tokens.FAMILY_TIMES _ | Elpi_lexer_config.Tokens.FULLSTOP | Elpi_lexer_config.Tokens.IS | Elpi_lexer_config.Tokens.MINUS | Elpi_lexer_config.Tokens.MINUSi | Elpi_lexer_config.Tokens.MINUSr | Elpi_lexer_config.Tokens.MINUSs | Elpi_lexer_config.Tokens.MOD | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.SLASH | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_FAMILY_MINUS (_menhir_stack, s, _, _) = _menhir_stack in
            let MenhirCell1_clause_hd_term (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_035 _endpos_r_ _startpos_l_ l r s in
            _menhir_goto_clause_hd_open_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 497
    
    and _menhir_run_053_spec_498 : type  ttv_stack. ((ttv_stack, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_clause_hd_term _menhir_cell0_FAMILY_LT -> _ -> _ -> _ -> _ -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_317 t in
        _menhir_run_499 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v MenhirState498 _tok
    
    and _menhir_run_499 : type  ttv_stack. (((ttv_stack, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_clause_hd_term _menhir_cell0_FAMILY_LT as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.SLASH ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MOD ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_074 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSs ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_076 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSr ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_082 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSi ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_084 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_086 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FAMILY_TIMES _v_0 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_078 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_TICK _v_1 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_090 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_3 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_041 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_PLUS _v_4 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_092 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_5 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_6 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.FAMILY_EXP _v_7 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_094 _menhir_stack _menhir_lexbuf _menhir_lexer _v_7
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_8 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer _v_8
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_9 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer _v_9
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_10 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer _v_10
        | Elpi_lexer_config.Tokens.DIV ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_080 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_096 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.FULLSTOP | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_FAMILY_LT (_menhir_stack, s, _, _) = _menhir_stack in
            let MenhirCell1_clause_hd_term (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_037 _endpos_r_ _startpos_l_ l r s in
            _menhir_goto_clause_hd_open_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 499
    
    and _menhir_run_053_spec_500 : type  ttv_stack. ((ttv_stack, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_clause_hd_term _menhir_cell0_FAMILY_GT -> _ -> _ -> _ -> _ -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_317 t in
        _menhir_run_501 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v MenhirState500 _tok
    
    and _menhir_run_501 : type  ttv_stack. (((ttv_stack, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_clause_hd_term _menhir_cell0_FAMILY_GT as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.SLASH ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MOD ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_074 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSs ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_076 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSr ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_082 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSi ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_084 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_086 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FAMILY_TIMES _v_0 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_078 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_TICK _v_1 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_090 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_3 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_041 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_PLUS _v_4 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_092 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_5 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_6 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.FAMILY_EXP _v_7 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_094 _menhir_stack _menhir_lexbuf _menhir_lexer _v_7
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_8 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer _v_8
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_9 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer _v_9
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_10 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer _v_10
        | Elpi_lexer_config.Tokens.DIV ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_080 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_096 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.FULLSTOP | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_FAMILY_GT (_menhir_stack, s, _, _) = _menhir_stack in
            let MenhirCell1_clause_hd_term (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_038 _endpos_r_ _startpos_l_ l r s in
            _menhir_goto_clause_hd_open_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 501
    
    and _menhir_run_053_spec_502 : type  ttv_stack. ((ttv_stack, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_clause_hd_term _menhir_cell0_FAMILY_EXP -> _ -> _ -> _ -> _ -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_317 t in
        _menhir_run_503 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v MenhirState502 _tok
    
    and _menhir_run_503 : type  ttv_stack. (((ttv_stack, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_clause_hd_term _menhir_cell0_FAMILY_EXP as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.SLASH ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MOD ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_074 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FAMILY_TIMES _v_0 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_078 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_1 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_041 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_3 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_4 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_5 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_6 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_7 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer _v_7
        | Elpi_lexer_config.Tokens.DIV ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_080 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.CONS | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.EQ | Elpi_lexer_config.Tokens.EQ2 | Elpi_lexer_config.Tokens.FAMILY_EXP _ | Elpi_lexer_config.Tokens.FAMILY_GT _ | Elpi_lexer_config.Tokens.FAMILY_LT _ | Elpi_lexer_config.Tokens.FAMILY_PLUS _ | Elpi_lexer_config.Tokens.FAMILY_TICK _ | Elpi_lexer_config.Tokens.FULLSTOP | Elpi_lexer_config.Tokens.IS | Elpi_lexer_config.Tokens.MINUS | Elpi_lexer_config.Tokens.MINUSi | Elpi_lexer_config.Tokens.MINUSr | Elpi_lexer_config.Tokens.MINUSs | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_FAMILY_EXP (_menhir_stack, s, _, _) = _menhir_stack in
            let MenhirCell1_clause_hd_term (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_036 _endpos_r_ _startpos_l_ l r s in
            _menhir_goto_clause_hd_open_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 503
    
    and _menhir_run_053_spec_504 : type  ttv_stack. ((ttv_stack, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_clause_hd_term _menhir_cell0_FAMILY_EQ -> _ -> _ -> _ -> _ -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_317 t in
        _menhir_run_505 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v MenhirState504 _tok
    
    and _menhir_run_505 : type  ttv_stack. (((ttv_stack, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_clause_hd_term _menhir_cell0_FAMILY_EQ as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_0 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_1 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_041 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_3 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_4 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.CONS | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.DIV | Elpi_lexer_config.Tokens.EQ | Elpi_lexer_config.Tokens.EQ2 | Elpi_lexer_config.Tokens.FAMILY_BTICK _ | Elpi_lexer_config.Tokens.FAMILY_EXP _ | Elpi_lexer_config.Tokens.FAMILY_GT _ | Elpi_lexer_config.Tokens.FAMILY_LT _ | Elpi_lexer_config.Tokens.FAMILY_MINUS _ | Elpi_lexer_config.Tokens.FAMILY_PLUS _ | Elpi_lexer_config.Tokens.FAMILY_TICK _ | Elpi_lexer_config.Tokens.FAMILY_TIMES _ | Elpi_lexer_config.Tokens.FULLSTOP | Elpi_lexer_config.Tokens.IS | Elpi_lexer_config.Tokens.MINUS | Elpi_lexer_config.Tokens.MINUSi | Elpi_lexer_config.Tokens.MINUSr | Elpi_lexer_config.Tokens.MINUSs | Elpi_lexer_config.Tokens.MOD | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.SLASH | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_FAMILY_EQ (_menhir_stack, s, _, _) = _menhir_stack in
            let MenhirCell1_clause_hd_term (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_039 _endpos_r_ _startpos_l_ l r s in
            _menhir_goto_clause_hd_open_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 505
    
    and _menhir_run_053_spec_506 : type  ttv_stack. ((ttv_stack, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_clause_hd_term _menhir_cell0_FAMILY_BTICK -> _ -> _ -> _ -> _ -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_317 t in
        _menhir_run_507 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v MenhirState506 _tok
    
    and _menhir_run_507 : type  ttv_stack. (((ttv_stack, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_clause_hd_term _menhir_cell0_FAMILY_BTICK as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_0 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_1 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_041 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_3 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_4 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.CONS | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.DIV | Elpi_lexer_config.Tokens.EQ | Elpi_lexer_config.Tokens.EQ2 | Elpi_lexer_config.Tokens.FAMILY_EXP _ | Elpi_lexer_config.Tokens.FAMILY_GT _ | Elpi_lexer_config.Tokens.FAMILY_LT _ | Elpi_lexer_config.Tokens.FAMILY_MINUS _ | Elpi_lexer_config.Tokens.FAMILY_PLUS _ | Elpi_lexer_config.Tokens.FAMILY_TICK _ | Elpi_lexer_config.Tokens.FAMILY_TIMES _ | Elpi_lexer_config.Tokens.FULLSTOP | Elpi_lexer_config.Tokens.IS | Elpi_lexer_config.Tokens.MINUS | Elpi_lexer_config.Tokens.MINUSi | Elpi_lexer_config.Tokens.MINUSr | Elpi_lexer_config.Tokens.MINUSs | Elpi_lexer_config.Tokens.MOD | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.SLASH | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_FAMILY_BTICK (_menhir_stack, s, _, _) = _menhir_stack in
            let MenhirCell1_clause_hd_term (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_043 _endpos_r_ _startpos_l_ l r s in
            _menhir_goto_clause_hd_open_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 507
    
    and _menhir_run_053_spec_508 : type  ttv_stack. ((ttv_stack, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_clause_hd_term _menhir_cell0_FAMILY_AND -> _ -> _ -> _ -> _ -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_317 t in
        _menhir_run_509 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v MenhirState508 _tok
    
    and _menhir_run_509 : type  ttv_stack. (((ttv_stack, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_clause_hd_term _menhir_cell0_FAMILY_AND as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_0 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_1 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_041 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.CONS | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.DIV | Elpi_lexer_config.Tokens.EQ | Elpi_lexer_config.Tokens.EQ2 | Elpi_lexer_config.Tokens.FAMILY_BTICK _ | Elpi_lexer_config.Tokens.FAMILY_EQ _ | Elpi_lexer_config.Tokens.FAMILY_EXP _ | Elpi_lexer_config.Tokens.FAMILY_GT _ | Elpi_lexer_config.Tokens.FAMILY_LT _ | Elpi_lexer_config.Tokens.FAMILY_MINUS _ | Elpi_lexer_config.Tokens.FAMILY_OR _ | Elpi_lexer_config.Tokens.FAMILY_PLUS _ | Elpi_lexer_config.Tokens.FAMILY_TICK _ | Elpi_lexer_config.Tokens.FAMILY_TIMES _ | Elpi_lexer_config.Tokens.FULLSTOP | Elpi_lexer_config.Tokens.IS | Elpi_lexer_config.Tokens.MINUS | Elpi_lexer_config.Tokens.MINUSi | Elpi_lexer_config.Tokens.MINUSr | Elpi_lexer_config.Tokens.MINUSs | Elpi_lexer_config.Tokens.MOD | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.SLASH | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_FAMILY_AND (_menhir_stack, s, _, _) = _menhir_stack in
            let MenhirCell1_clause_hd_term (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_040 _endpos_r_ _startpos_l_ l r s in
            _menhir_goto_clause_hd_open_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 509
    
    and _menhir_run_053_spec_510 : type  ttv_stack. ((ttv_stack, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_clause_hd_term _menhir_cell0_EQ2 -> _ -> _ -> _ -> _ -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_317 t in
        _menhir_run_511 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v MenhirState510 _tok
    
    and _menhir_run_511 : type  ttv_stack. (((ttv_stack, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_clause_hd_term _menhir_cell0_EQ2 as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.SLASH ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MOD ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_074 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSs ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_076 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSr ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_082 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSi ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_084 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_086 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FAMILY_TIMES _v_0 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_078 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_TICK _v_1 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_090 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_3 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_041 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_PLUS _v_4 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_092 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_5 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_6 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.FAMILY_EXP _v_7 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_094 _menhir_stack _menhir_lexbuf _menhir_lexer _v_7
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_8 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer _v_8
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_9 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer _v_9
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_10 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer _v_10
        | Elpi_lexer_config.Tokens.DIV ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_080 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_096 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.FULLSTOP | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_EQ2 (_menhir_stack, _, _) = _menhir_stack in
            let MenhirCell1_clause_hd_term (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_051 _endpos_r_ _startpos_l_ l r in
            _menhir_goto_clause_hd_open_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 511
    
    and _menhir_run_053_spec_512 : type  ttv_stack. ((ttv_stack, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_clause_hd_term _menhir_cell0_EQ -> _ -> _ -> _ -> _ -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_317 t in
        _menhir_run_513 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v MenhirState512 _tok
    
    and _menhir_run_513 : type  ttv_stack. (((ttv_stack, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_clause_hd_term _menhir_cell0_EQ as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.SLASH ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MOD ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_074 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSs ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_076 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSr ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_082 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSi ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_084 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_086 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FAMILY_TIMES _v_0 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_078 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_TICK _v_1 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_090 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_3 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_041 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_PLUS _v_4 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_092 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_5 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_6 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.FAMILY_EXP _v_7 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_094 _menhir_stack _menhir_lexbuf _menhir_lexer _v_7
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_8 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer _v_8
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_9 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer _v_9
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_10 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer _v_10
        | Elpi_lexer_config.Tokens.DIV ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_080 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_096 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.FULLSTOP | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_EQ (_menhir_stack, _, _) = _menhir_stack in
            let MenhirCell1_clause_hd_term (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_046 _endpos_r_ _startpos_l_ l r in
            _menhir_goto_clause_hd_open_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 513
    
    and _menhir_run_053_spec_514 : type  ttv_stack. ((ttv_stack, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_clause_hd_term _menhir_cell0_DIV -> _ -> _ -> _ -> _ -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_317 t in
        _menhir_run_515 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v MenhirState514 _tok
    
    and _menhir_run_515 : type  ttv_stack. (((ttv_stack, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_clause_hd_term _menhir_cell0_DIV as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_0 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_1 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_041 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_3 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_4 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_5 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_6 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.CONS | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.DIV | Elpi_lexer_config.Tokens.EQ | Elpi_lexer_config.Tokens.EQ2 | Elpi_lexer_config.Tokens.FAMILY_EXP _ | Elpi_lexer_config.Tokens.FAMILY_GT _ | Elpi_lexer_config.Tokens.FAMILY_LT _ | Elpi_lexer_config.Tokens.FAMILY_PLUS _ | Elpi_lexer_config.Tokens.FAMILY_TICK _ | Elpi_lexer_config.Tokens.FAMILY_TIMES _ | Elpi_lexer_config.Tokens.FULLSTOP | Elpi_lexer_config.Tokens.IS | Elpi_lexer_config.Tokens.MINUS | Elpi_lexer_config.Tokens.MINUSi | Elpi_lexer_config.Tokens.MINUSr | Elpi_lexer_config.Tokens.MINUSs | Elpi_lexer_config.Tokens.MOD | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.SLASH | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_DIV (_menhir_stack, _, _) = _menhir_stack in
            let MenhirCell1_clause_hd_term (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_055 _endpos_r_ _startpos_l_ l r in
            _menhir_goto_clause_hd_open_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 515
    
    and _menhir_run_053_spec_516 : type  ttv_stack. ((ttv_stack, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_clause_hd_term _menhir_cell0_DARROW -> _ -> _ -> _ -> _ -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_317 t in
        _menhir_run_517 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v MenhirState516 _tok
    
    and _menhir_run_517 : type  ttv_stack. (((ttv_stack, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_clause_hd_term _menhir_cell0_DARROW as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.SLASH ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MOD ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_074 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSs ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_076 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSr ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_082 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSi ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_084 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_086 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.IS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_088 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FAMILY_TIMES _v_0 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_078 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_TICK _v_1 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_090 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_3 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_041 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_PLUS _v_4 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_092 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_5 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_6 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.FAMILY_LT _v_7 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_098 _menhir_stack _menhir_lexbuf _menhir_lexer _v_7
        | Elpi_lexer_config.Tokens.FAMILY_GT _v_8 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_100 _menhir_stack _menhir_lexbuf _menhir_lexer _v_8
        | Elpi_lexer_config.Tokens.FAMILY_EXP _v_9 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_094 _menhir_stack _menhir_lexbuf _menhir_lexer _v_9
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_10 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer _v_10
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_11 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer _v_11
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_12 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer _v_12
        | Elpi_lexer_config.Tokens.EQ2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_102 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.EQ ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_104 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.DIV ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_080 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.DARROW ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_106 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_096 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.FULLSTOP | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_DARROW (_menhir_stack, _, _) = _menhir_stack in
            let MenhirCell1_clause_hd_term (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_057 _endpos_r_ _startpos_l_ l r in
            _menhir_goto_clause_hd_open_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 517
    
    and _menhir_run_053_spec_518 : type  ttv_stack. ((ttv_stack, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_clause_hd_term _menhir_cell0_CONS -> _ -> _ -> _ -> _ -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_317 t in
        _menhir_run_519 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v MenhirState518 _tok
    
    and _menhir_run_519 : type  ttv_stack. (((ttv_stack, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_clause_hd_term _menhir_cell0_CONS as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.SLASH ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MOD ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_074 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSs ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_076 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSr ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_082 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSi ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_084 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_086 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FAMILY_TIMES _v_0 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_078 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_TICK _v_1 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_090 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_3 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_041 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_PLUS _v_4 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_092 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_5 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_6 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.FAMILY_EXP _v_7 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_094 _menhir_stack _menhir_lexbuf _menhir_lexer _v_7
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_8 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer _v_8
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_9 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer _v_9
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_10 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer _v_10
        | Elpi_lexer_config.Tokens.DIV ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_080 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_096 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.EQ | Elpi_lexer_config.Tokens.EQ2 | Elpi_lexer_config.Tokens.FAMILY_GT _ | Elpi_lexer_config.Tokens.FAMILY_LT _ | Elpi_lexer_config.Tokens.FULLSTOP | Elpi_lexer_config.Tokens.IS | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_CONS (_menhir_stack, _, _) = _menhir_stack in
            let MenhirCell1_clause_hd_term (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_045 _endpos_r_ _startpos_l_ l r in
            _menhir_goto_clause_hd_open_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 519
    
    and _menhir_run_053_spec_520 : type  ttv_stack. ((ttv_stack, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_clause_hd_term _menhir_cell0_CONJ2 -> _ -> _ -> _ -> _ -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_317 t in
        _menhir_run_521 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v MenhirState520 _tok
    
    and _menhir_run_521 : type  ttv_stack. (((ttv_stack, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_clause_hd_term _menhir_cell0_CONJ2 as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.SLASH ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MOD ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_074 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSs ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_076 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSr ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_082 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSi ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_084 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_086 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.IS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_088 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FAMILY_TIMES _v_0 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_078 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_TICK _v_1 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_090 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_3 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_041 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_PLUS _v_4 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_092 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_5 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_6 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.FAMILY_LT _v_7 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_098 _menhir_stack _menhir_lexbuf _menhir_lexer _v_7
        | Elpi_lexer_config.Tokens.FAMILY_GT _v_8 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_100 _menhir_stack _menhir_lexbuf _menhir_lexer _v_8
        | Elpi_lexer_config.Tokens.FAMILY_EXP _v_9 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_094 _menhir_stack _menhir_lexbuf _menhir_lexer _v_9
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_10 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer _v_10
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_11 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer _v_11
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_12 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer _v_12
        | Elpi_lexer_config.Tokens.EQ2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_102 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.EQ ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_104 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.DIV ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_080 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.DARROW ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_106 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_096 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONJ2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_108 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONJ ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_110 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.ARROW ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_112 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FULLSTOP | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_CONJ2 (_menhir_stack, _, _) = _menhir_stack in
            let MenhirCell1_clause_hd_term (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_060 _endpos_r_ _startpos_l_ l r in
            _menhir_goto_clause_hd_open_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 521
    
    and _menhir_run_053_spec_522 : type  ttv_stack. ((ttv_stack, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_clause_hd_term _menhir_cell0_CONJ -> _ -> _ -> _ -> _ -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_317 t in
        _menhir_run_523 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v MenhirState522 _tok
    
    and _menhir_run_523 : type  ttv_stack. (((ttv_stack, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_clause_hd_term _menhir_cell0_CONJ as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.SLASH ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MOD ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_074 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSs ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_076 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSr ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_082 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSi ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_084 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_086 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.IS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_088 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FAMILY_TIMES _v_0 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_078 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_TICK _v_1 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_090 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_3 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_041 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_PLUS _v_4 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_092 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_5 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_6 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.FAMILY_LT _v_7 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_098 _menhir_stack _menhir_lexbuf _menhir_lexer _v_7
        | Elpi_lexer_config.Tokens.FAMILY_GT _v_8 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_100 _menhir_stack _menhir_lexbuf _menhir_lexer _v_8
        | Elpi_lexer_config.Tokens.FAMILY_EXP _v_9 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_094 _menhir_stack _menhir_lexbuf _menhir_lexer _v_9
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_10 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer _v_10
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_11 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer _v_11
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_12 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer _v_12
        | Elpi_lexer_config.Tokens.EQ2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_102 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.EQ ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_104 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.DIV ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_080 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.DARROW ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_106 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_096 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONJ2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_108 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONJ ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_110 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.ARROW ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_112 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FULLSTOP | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell0_CONJ (_menhir_stack, _, _) = _menhir_stack in
            let MenhirCell1_clause_hd_term (_menhir_stack, _menhir_s, l, _startpos_l_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_061 _endpos_r_ _startpos_l_ l r in
            _menhir_goto_clause_hd_open_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_l_ _v _menhir_s _tok
        | _ ->
            _eRR 523
    
    and _menhir_run_053_spec_524 : type  ttv_stack. ((ttv_stack, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_clause_hd_term _menhir_cell0_ARROW -> _ -> _ -> _ -> _ -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_317 t in
        _menhir_run_525 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v MenhirState524 _tok
    
    and _menhir_run_050 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_closed_term -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let MenhirCell1_closed_term (_menhir_stack, _menhir_s, x, _, _) = _menhir_stack in
        let xs = _v in
        let _v = _menhir_action_208 x xs in
        _menhir_goto_nonempty_list_closed_term_ _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
    
    and _menhir_run_044 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_head_term as 'stack) -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_nonempty_list_closed_term_ (_menhir_stack, _menhir_s, _v) in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.BIND ->
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState044
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.AS | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.CONS | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.DIV | Elpi_lexer_config.Tokens.EOF | Elpi_lexer_config.Tokens.EQ | Elpi_lexer_config.Tokens.EQ2 | Elpi_lexer_config.Tokens.FAMILY_AND _ | Elpi_lexer_config.Tokens.FAMILY_BTICK _ | Elpi_lexer_config.Tokens.FAMILY_EQ _ | Elpi_lexer_config.Tokens.FAMILY_EXP _ | Elpi_lexer_config.Tokens.FAMILY_GT _ | Elpi_lexer_config.Tokens.FAMILY_LT _ | Elpi_lexer_config.Tokens.FAMILY_MINUS _ | Elpi_lexer_config.Tokens.FAMILY_OR _ | Elpi_lexer_config.Tokens.FAMILY_PLUS _ | Elpi_lexer_config.Tokens.FAMILY_QMARK _ | Elpi_lexer_config.Tokens.FAMILY_SHARP _ | Elpi_lexer_config.Tokens.FAMILY_TICK _ | Elpi_lexer_config.Tokens.FAMILY_TIMES _ | Elpi_lexer_config.Tokens.FULLSTOP | Elpi_lexer_config.Tokens.IFF | Elpi_lexer_config.Tokens.IS | Elpi_lexer_config.Tokens.MINUS | Elpi_lexer_config.Tokens.MINUSi | Elpi_lexer_config.Tokens.MINUSr | Elpi_lexer_config.Tokens.MINUSs | Elpi_lexer_config.Tokens.MOD | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.PIPE | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.RBRACKET | Elpi_lexer_config.Tokens.RCURLY | Elpi_lexer_config.Tokens.RPAREN | Elpi_lexer_config.Tokens.SLASH | Elpi_lexer_config.Tokens.VDASH ->
            let _v = _menhir_action_284 () in
            _menhir_run_045 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_045 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_head_term, ttv_result) _menhir_cell1_nonempty_list_closed_term_ -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let MenhirCell1_nonempty_list_closed_term_ (_menhir_stack, _, args) = _menhir_stack in
        let MenhirCell1_head_term (_menhir_stack, _menhir_s, hd, _startpos_hd_, _endpos_hd_) = _menhir_stack in
        let (_endpos_b_, b) = (_endpos, _v) in
        let _v = _menhir_action_217 _endpos_hd_ _startpos_hd_ args b hd in
        _menhir_goto_open_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_b_ _startpos_hd_ _v _menhir_s _tok
    
    and _menhir_run_037 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_head_term as 'stack) -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_nonempty_list_closed_term_ (_menhir_stack, _menhir_s, _v) in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.BIND ->
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState037
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.CONS | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.DIV | Elpi_lexer_config.Tokens.EQ | Elpi_lexer_config.Tokens.EQ2 | Elpi_lexer_config.Tokens.FAMILY_AND _ | Elpi_lexer_config.Tokens.FAMILY_BTICK _ | Elpi_lexer_config.Tokens.FAMILY_EQ _ | Elpi_lexer_config.Tokens.FAMILY_EXP _ | Elpi_lexer_config.Tokens.FAMILY_GT _ | Elpi_lexer_config.Tokens.FAMILY_LT _ | Elpi_lexer_config.Tokens.FAMILY_MINUS _ | Elpi_lexer_config.Tokens.FAMILY_OR _ | Elpi_lexer_config.Tokens.FAMILY_PLUS _ | Elpi_lexer_config.Tokens.FAMILY_QMARK _ | Elpi_lexer_config.Tokens.FAMILY_SHARP _ | Elpi_lexer_config.Tokens.FAMILY_TICK _ | Elpi_lexer_config.Tokens.FAMILY_TIMES _ | Elpi_lexer_config.Tokens.IS | Elpi_lexer_config.Tokens.MINUS | Elpi_lexer_config.Tokens.MINUSi | Elpi_lexer_config.Tokens.MINUSr | Elpi_lexer_config.Tokens.MINUSs | Elpi_lexer_config.Tokens.MOD | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.PIPE | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.RBRACKET | Elpi_lexer_config.Tokens.SLASH | Elpi_lexer_config.Tokens.VDASH ->
            let _v = _menhir_action_284 () in
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | _ ->
            _eRR 37
    
    and _menhir_run_116 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_head_term, ttv_result) _menhir_cell1_nonempty_list_closed_term_ -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let MenhirCell1_nonempty_list_closed_term_ (_menhir_stack, _, args) = _menhir_stack in
        let MenhirCell1_head_term (_menhir_stack, _menhir_s, hd, _startpos_hd_, _endpos_hd_) = _menhir_stack in
        let (_endpos_b_, b) = (_endpos, _v) in
        let _v = _menhir_action_250 _endpos_hd_ _startpos_hd_ args b hd in
        _menhir_goto_open_term_noconj _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_b_ _startpos_hd_ _v _menhir_s _tok
    
    and _menhir_run_048_spec_460 : type  ttv_stack. ((ttv_stack, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_head_term -> _ -> _ -> _ -> _ -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_113 t in
        _menhir_run_047_spec_460 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v _tok
    
    and _menhir_run_047_spec_460 : type  ttv_stack. ((ttv_stack, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_head_term -> _ -> _ -> _ -> _ -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_074 t in
        _menhir_run_049 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v MenhirState460 _tok
    
    and _menhir_run_047_spec_424 : type  ttv_stack. ((ttv_stack, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_RULE -> _ -> _ -> _ -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let (_endpos_t_, t) = (_endpos, _v) in
        let _v = _menhir_action_074 t in
        _menhir_run_432_spec_424 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _v _tok
    
    and _menhir_run_047_spec_442 : type  ttv_stack. (((ttv_stack, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_RULE, _menhir_box_program) _menhir_cell1_list_sequent_ _menhir_cell0_option_preceded_BIND_nonempty_list_sequent___ _menhir_cell0_option_preceded_PIPE_term__ -> _ -> _ -> _ -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let (_endpos_t_, t) = (_endpos, _v) in
        let _v = _menhir_action_074 t in
        _menhir_run_432_spec_442 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _v _tok
    
    and _menhir_run_432_spec_442 : type  ttv_stack. (((ttv_stack, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_RULE, _menhir_box_program) _menhir_cell1_list_sequent_ _menhir_cell0_option_preceded_BIND_nonempty_list_sequent___ _menhir_cell0_option_preceded_PIPE_term__ -> _ -> _ -> _ -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let (_endpos_t_, t) = (_endpos, _v) in
        let _v = _menhir_action_310 t in
        _menhir_run_443 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _v _tok
    
    and _menhir_run_443 : type  ttv_stack. (((ttv_stack, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_RULE, _menhir_box_program) _menhir_cell1_list_sequent_ _menhir_cell0_option_preceded_BIND_nonempty_list_sequent___ _menhir_cell0_option_preceded_PIPE_term__ -> _ -> _ -> _ -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let (_endpos_x_, x) = (_endpos, _v) in
        let _v = _menhir_action_289 x in
        _menhir_goto_option_preceded_IFF_sequent__ _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _v _tok
    
    and _menhir_goto_option_preceded_IFF_sequent__ : type  ttv_stack. (((ttv_stack, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_RULE, _menhir_box_program) _menhir_cell1_list_sequent_ _menhir_cell0_option_preceded_BIND_nonempty_list_sequent___ _menhir_cell0_option_preceded_PIPE_term__ -> _ -> _ -> _ -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let MenhirCell0_option_preceded_PIPE_term__ (_menhir_stack, guard) = _menhir_stack in
        let MenhirCell0_option_preceded_BIND_nonempty_list_sequent___ (_menhir_stack, to_remove) = _menhir_stack in
        let MenhirCell1_list_sequent_ (_menhir_stack, _, to_match) = _menhir_stack in
        let MenhirCell1_RULE (_menhir_stack, _, _startpos__2_) = _menhir_stack in
        let MenhirCell1_attributes (_menhir_stack, _menhir_s, attributes, _startpos_attributes_, _endpos_attributes_) = _menhir_stack in
        let (_endpos_new_goal_, new_goal) = (_endpos, _v) in
        let _v = _menhir_action_027 _endpos_attributes_ _endpos_new_goal_ _startpos__2_ _startpos_attributes_ attributes guard new_goal to_match to_remove in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.FULLSTOP ->
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let r = _v in
            let _v = _menhir_action_091 r in
            _menhir_goto_decl _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | _ ->
            _eRR 418
    
    and _menhir_run_047_spec_434 : type  ttv_stack. (((ttv_stack, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_RULE, _menhir_box_program) _menhir_cell1_list_sequent_ _menhir_cell0_BIND -> _ -> _ -> _ -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let (_endpos_t_, t) = (_endpos, _v) in
        let _v = _menhir_action_074 t in
        _menhir_run_432_spec_434 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _v _tok
    
    and _menhir_run_432_spec_434 : type  ttv_stack. (((ttv_stack, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_RULE, _menhir_box_program) _menhir_cell1_list_sequent_ _menhir_cell0_BIND -> _ -> _ -> _ -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let (_endpos_t_, t) = (_endpos, _v) in
        let _v = _menhir_action_310 t in
        _menhir_run_435 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _v MenhirState434 _tok
    
    and _menhir_run_435 : type  ttv_stack. ttv_stack -> _ -> _ -> _ -> _ -> (ttv_stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v_0 ->
            let _menhir_stack = MenhirCell1_sequent (_menhir_stack, _menhir_s, _v, _endpos) in
            let _endpos_1 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, x) = (_endpos_1, _v_0) in
            let _v = _menhir_action_068 x in
            _menhir_run_432_spec_435 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.SIGMA ->
            let _menhir_stack = MenhirCell1_sequent (_menhir_stack, _menhir_s, _v, _endpos) in
            let _endpos_3 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _endpos__1_ = _endpos_3 in
            let _v = _menhir_action_085 () in
            _menhir_run_048_spec_435 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _v _tok
        | Elpi_lexer_config.Tokens.REPLACE ->
            let _menhir_stack = MenhirCell1_sequent (_menhir_stack, _menhir_s, _v, _endpos) in
            let _endpos_5 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _endpos__1_ = _endpos_5 in
            let _v = _menhir_action_080 () in
            _menhir_run_048_spec_435 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _v _tok
        | Elpi_lexer_config.Tokens.QUOTED _v_7 ->
            let _menhir_stack = MenhirCell1_sequent (_menhir_stack, _menhir_s, _v, _endpos) in
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_8 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_8, _startpos, _v_7) in
            let _v = _menhir_action_069 _endpos_x_ _startpos_x_ x in
            _menhir_run_432_spec_435 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.PI ->
            let _menhir_stack = MenhirCell1_sequent (_menhir_stack, _menhir_s, _v, _endpos) in
            let _endpos_10 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _endpos__1_ = _endpos_10 in
            let _v = _menhir_action_084 () in
            _menhir_run_048_spec_435 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _v _tok
        | Elpi_lexer_config.Tokens.NIL ->
            let _menhir_stack = MenhirCell1_sequent (_menhir_stack, _menhir_s, _v, _endpos) in
            let _endpos_12 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _endpos__1_ = _endpos_12 in
            let _v = _menhir_action_089 () in
            _menhir_run_048_spec_435 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _v _tok
        | Elpi_lexer_config.Tokens.NAME ->
            let _menhir_stack = MenhirCell1_sequent (_menhir_stack, _menhir_s, _v, _endpos) in
            let _endpos_14 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _endpos__1_ = _endpos_14 in
            let _v = _menhir_action_077 () in
            _menhir_run_048_spec_435 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _v _tok
        | Elpi_lexer_config.Tokens.LPAREN ->
            let _menhir_stack = MenhirCell1_sequent (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_425 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState435
        | Elpi_lexer_config.Tokens.LCURLY ->
            let _menhir_stack = MenhirCell1_sequent (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState435
        | Elpi_lexer_config.Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_sequent (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState435
        | Elpi_lexer_config.Tokens.IO _v_16 ->
            let _menhir_stack = MenhirCell1_sequent (_menhir_stack, _menhir_s, _v, _endpos) in
            let _endpos_17 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, c) = (_endpos_17, _v_16) in
            let _v = _menhir_action_082 c in
            _menhir_run_048_spec_435 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _v _tok
        | Elpi_lexer_config.Tokens.INTEGER _v_19 ->
            let _menhir_stack = MenhirCell1_sequent (_menhir_stack, _menhir_s, _v, _endpos) in
            let _endpos_20 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, x) = (_endpos_20, _v_19) in
            let _v = _menhir_action_066 x in
            _menhir_run_432_spec_435 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.INDEX ->
            let _menhir_stack = MenhirCell1_sequent (_menhir_stack, _menhir_s, _v, _endpos) in
            let _endpos_22 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _endpos__1_ = _endpos_22 in
            let _v = _menhir_action_081 () in
            _menhir_run_048_spec_435 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _v _tok
        | Elpi_lexer_config.Tokens.IF ->
            let _menhir_stack = MenhirCell1_sequent (_menhir_stack, _menhir_s, _v, _endpos) in
            let _endpos_24 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _endpos__1_ = _endpos_24 in
            let _v = _menhir_action_076 () in
            _menhir_run_048_spec_435 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _v _tok
        | Elpi_lexer_config.Tokens.FRESHUV ->
            let _menhir_stack = MenhirCell1_sequent (_menhir_stack, _menhir_s, _v, _endpos) in
            let _endpos_26 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _endpos__1_ = _endpos_26 in
            let _v = _menhir_action_086 () in
            _menhir_run_048_spec_435 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _v _tok
        | Elpi_lexer_config.Tokens.FLOAT _v_28 ->
            let _menhir_stack = MenhirCell1_sequent (_menhir_stack, _menhir_s, _v, _endpos) in
            let _endpos_29 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, x) = (_endpos_29, _v_28) in
            let _v = _menhir_action_067 x in
            _menhir_run_432_spec_435 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.CUT ->
            let _menhir_stack = MenhirCell1_sequent (_menhir_stack, _menhir_s, _v, _endpos) in
            let _endpos_31 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _endpos__1_ = _endpos_31 in
            let _v = _menhir_action_083 () in
            _menhir_run_048_spec_435 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _v _tok
        | Elpi_lexer_config.Tokens.CONSTANT _v_33 ->
            let _menhir_stack = MenhirCell1_sequent (_menhir_stack, _menhir_s, _v, _endpos) in
            let _endpos_34 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, c) = (_endpos_34, _v_33) in
            let _v = _menhir_action_075 c in
            _menhir_run_048_spec_435 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _v _tok
        | Elpi_lexer_config.Tokens.BEFORE ->
            let _menhir_stack = MenhirCell1_sequent (_menhir_stack, _menhir_s, _v, _endpos) in
            let _endpos_36 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _endpos__1_ = _endpos_36 in
            let _v = _menhir_action_078 () in
            _menhir_run_048_spec_435 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _v _tok
        | Elpi_lexer_config.Tokens.AFTER ->
            let _menhir_stack = MenhirCell1_sequent (_menhir_stack, _menhir_s, _v, _endpos) in
            let _endpos_38 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _endpos__1_ = _endpos_38 in
            let _v = _menhir_action_079 () in
            _menhir_run_048_spec_435 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _v _tok
        | Elpi_lexer_config.Tokens.FULLSTOP | Elpi_lexer_config.Tokens.IFF | Elpi_lexer_config.Tokens.PIPE ->
            let x = _v in
            let _v = _menhir_action_215 x in
            _menhir_goto_nonempty_list_sequent_ _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | _ ->
            _eRR 435
    
    and _menhir_run_432_spec_435 : type  ttv_stack. (ttv_stack, _menhir_box_program) _menhir_cell1_sequent -> _ -> _ -> _ -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let (_endpos_t_, t) = (_endpos, _v) in
        let _v = _menhir_action_310 t in
        _menhir_run_435 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _v MenhirState435 _tok
    
    and _menhir_run_048_spec_435 : type  ttv_stack. (ttv_stack, _menhir_box_program) _menhir_cell1_sequent -> _ -> _ -> _ -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let (_endpos_t_, t) = (_endpos, _v) in
        let _v = _menhir_action_113 t in
        _menhir_run_047_spec_435 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _v _tok
    
    and _menhir_run_047_spec_435 : type  ttv_stack. (ttv_stack, _menhir_box_program) _menhir_cell1_sequent -> _ -> _ -> _ -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let (_endpos_t_, t) = (_endpos, _v) in
        let _v = _menhir_action_074 t in
        _menhir_run_432_spec_435 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _v _tok
    
    and _menhir_goto_nonempty_list_sequent_ : type  ttv_stack. ttv_stack -> _ -> _ -> _ -> _ -> (ttv_stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        match _menhir_s with
        | MenhirState434 ->
            _menhir_run_437 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState435 ->
            _menhir_run_436 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_437 : type  ttv_stack. (((ttv_stack, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_RULE, _menhir_box_program) _menhir_cell1_list_sequent_ _menhir_cell0_BIND -> _ -> _ -> _ -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let MenhirCell0_BIND (_menhir_stack, _, _) = _menhir_stack in
        let x = _v in
        let _v = _menhir_action_287 x in
        _menhir_goto_option_preceded_BIND_nonempty_list_sequent___ _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
    
    and _menhir_goto_option_preceded_BIND_nonempty_list_sequent___ : type  ttv_stack. (((ttv_stack, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_RULE, _menhir_box_program) _menhir_cell1_list_sequent_ -> _ -> _ -> _ -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let _menhir_stack = MenhirCell0_option_preceded_BIND_nonempty_list_sequent___ (_menhir_stack, _v) in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.PIPE ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Elpi_lexer_config.Tokens.STRING _v_0 ->
                let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos, _startpos, _v_0) in
                let _v = _menhir_action_068 x in
                _menhir_run_053_spec_439 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.SIGMA ->
                let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos, _startpos) in
                let _v = _menhir_action_085 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState439 _tok
            | Elpi_lexer_config.Tokens.REPLACE ->
                let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos, _startpos) in
                let _v = _menhir_action_080 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState439 _tok
            | Elpi_lexer_config.Tokens.QUOTED _v_4 ->
                let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos, _startpos, _v_4) in
                let _v = _menhir_action_069 _endpos_x_ _startpos_x_ x in
                _menhir_run_053_spec_439 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.PI ->
                let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos, _startpos) in
                let _v = _menhir_action_084 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState439 _tok
            | Elpi_lexer_config.Tokens.NIL ->
                let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos, _startpos) in
                let _v = _menhir_action_089 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState439 _tok
            | Elpi_lexer_config.Tokens.NAME ->
                let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos, _startpos) in
                let _v = _menhir_action_077 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState439 _tok
            | Elpi_lexer_config.Tokens.LPAREN ->
                _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState439
            | Elpi_lexer_config.Tokens.LCURLY ->
                _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState439
            | Elpi_lexer_config.Tokens.LBRACKET ->
                _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState439
            | Elpi_lexer_config.Tokens.IO _v_9 ->
                let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_c_, _startpos_c_, c) = (_endpos, _startpos, _v_9) in
                let _v = _menhir_action_082 c in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState439 _tok
            | Elpi_lexer_config.Tokens.INTEGER _v_11 ->
                let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos, _startpos, _v_11) in
                let _v = _menhir_action_066 x in
                _menhir_run_053_spec_439 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.INDEX ->
                let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos, _startpos) in
                let _v = _menhir_action_081 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState439 _tok
            | Elpi_lexer_config.Tokens.IF ->
                let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos, _startpos) in
                let _v = _menhir_action_076 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState439 _tok
            | Elpi_lexer_config.Tokens.FRESHUV ->
                let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos, _startpos) in
                let _v = _menhir_action_086 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState439 _tok
            | Elpi_lexer_config.Tokens.FLOAT _v_16 ->
                let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos, _startpos, _v_16) in
                let _v = _menhir_action_067 x in
                _menhir_run_053_spec_439 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.FAMILY_TILDE _v_18 ->
                _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer _v_18 MenhirState439
            | Elpi_lexer_config.Tokens.CUT ->
                let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos, _startpos) in
                let _v = _menhir_action_083 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState439 _tok
            | Elpi_lexer_config.Tokens.CONSTANT _v_20 ->
                let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_c_, _startpos_c_, c) = (_endpos, _startpos, _v_20) in
                let _v = _menhir_action_075 c in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState439 _tok
            | Elpi_lexer_config.Tokens.BEFORE ->
                let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos, _startpos) in
                let _v = _menhir_action_078 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState439 _tok
            | Elpi_lexer_config.Tokens.AFTER ->
                let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos, _startpos) in
                let _v = _menhir_action_079 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState439 _tok
            | _ ->
                _eRR 439)
        | Elpi_lexer_config.Tokens.FULLSTOP | Elpi_lexer_config.Tokens.IFF ->
            let _v = _menhir_action_290 () in
            _menhir_goto_option_preceded_PIPE_term__ _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_053_spec_439 : type  ttv_stack. (((ttv_stack, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_RULE, _menhir_box_program) _menhir_cell1_list_sequent_ _menhir_cell0_option_preceded_BIND_nonempty_list_sequent___ -> _ -> _ -> _ -> _ -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_317 t in
        _menhir_run_440 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v MenhirState439 _tok
    
    and _menhir_run_440 : type  ttv_stack. ((((ttv_stack, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_RULE, _menhir_box_program) _menhir_cell1_list_sequent_ _menhir_cell0_option_preceded_BIND_nonempty_list_sequent___ as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.VDASH ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_056 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.SLASH ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.QDASH ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_114 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.OR ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_072 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MOD ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_074 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSs ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_076 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSr ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_082 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSi ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_084 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_086 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.IS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_088 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FAMILY_TIMES _v_0 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_078 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.FAMILY_TICK _v_1 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_090 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_3 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_041 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_PLUS _v_4 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_092 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_5 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_6 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.FAMILY_LT _v_7 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_098 _menhir_stack _menhir_lexbuf _menhir_lexer _v_7
        | Elpi_lexer_config.Tokens.FAMILY_GT _v_8 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_100 _menhir_stack _menhir_lexbuf _menhir_lexer _v_8
        | Elpi_lexer_config.Tokens.FAMILY_EXP _v_9 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_094 _menhir_stack _menhir_lexbuf _menhir_lexer _v_9
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_10 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer _v_10
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_11 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer _v_11
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_12 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer _v_12
        | Elpi_lexer_config.Tokens.EQ2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_102 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.EQ ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_104 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.DIV ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_080 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.DARROW ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_106 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_096 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONJ2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_108 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONJ ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_110 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.ARROW ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_112 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FULLSTOP | Elpi_lexer_config.Tokens.IFF ->
            let x = _v in
            let _v = _menhir_action_291 x in
            _menhir_goto_option_preceded_PIPE_term__ _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | _ ->
            _eRR 440
    
    and _menhir_goto_option_preceded_PIPE_term__ : type  ttv_stack. (((ttv_stack, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_RULE, _menhir_box_program) _menhir_cell1_list_sequent_ _menhir_cell0_option_preceded_BIND_nonempty_list_sequent___ -> _ -> _ -> _ -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let _menhir_stack = MenhirCell0_option_preceded_PIPE_term__ (_menhir_stack, _v) in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.IFF ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Elpi_lexer_config.Tokens.STRING _v_0 ->
                let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, x) = (_endpos, _v_0) in
                let _v = _menhir_action_068 x in
                _menhir_run_432_spec_442 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.SIGMA ->
                let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let _endpos__1_ = _endpos in
                let _v = _menhir_action_085 () in
                _menhir_run_048_spec_442 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _v _tok
            | Elpi_lexer_config.Tokens.REPLACE ->
                let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let _endpos__1_ = _endpos in
                let _v = _menhir_action_080 () in
                _menhir_run_048_spec_442 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _v _tok
            | Elpi_lexer_config.Tokens.QUOTED _v_4 ->
                let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos, _startpos, _v_4) in
                let _v = _menhir_action_069 _endpos_x_ _startpos_x_ x in
                _menhir_run_432_spec_442 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.PI ->
                let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let _endpos__1_ = _endpos in
                let _v = _menhir_action_084 () in
                _menhir_run_048_spec_442 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _v _tok
            | Elpi_lexer_config.Tokens.NIL ->
                let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let _endpos__1_ = _endpos in
                let _v = _menhir_action_089 () in
                _menhir_run_048_spec_442 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _v _tok
            | Elpi_lexer_config.Tokens.NAME ->
                let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let _endpos__1_ = _endpos in
                let _v = _menhir_action_077 () in
                _menhir_run_048_spec_442 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _v _tok
            | Elpi_lexer_config.Tokens.LPAREN ->
                _menhir_run_425 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState442
            | Elpi_lexer_config.Tokens.LCURLY ->
                _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState442
            | Elpi_lexer_config.Tokens.LBRACKET ->
                _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState442
            | Elpi_lexer_config.Tokens.IO _v_9 ->
                let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_c_, c) = (_endpos, _v_9) in
                let _v = _menhir_action_082 c in
                _menhir_run_048_spec_442 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _v _tok
            | Elpi_lexer_config.Tokens.INTEGER _v_11 ->
                let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, x) = (_endpos, _v_11) in
                let _v = _menhir_action_066 x in
                _menhir_run_432_spec_442 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.INDEX ->
                let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let _endpos__1_ = _endpos in
                let _v = _menhir_action_081 () in
                _menhir_run_048_spec_442 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _v _tok
            | Elpi_lexer_config.Tokens.IF ->
                let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let _endpos__1_ = _endpos in
                let _v = _menhir_action_076 () in
                _menhir_run_048_spec_442 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _v _tok
            | Elpi_lexer_config.Tokens.FRESHUV ->
                let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let _endpos__1_ = _endpos in
                let _v = _menhir_action_086 () in
                _menhir_run_048_spec_442 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _v _tok
            | Elpi_lexer_config.Tokens.FLOAT _v_16 ->
                let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, x) = (_endpos, _v_16) in
                let _v = _menhir_action_067 x in
                _menhir_run_432_spec_442 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.CUT ->
                let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let _endpos__1_ = _endpos in
                let _v = _menhir_action_083 () in
                _menhir_run_048_spec_442 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _v _tok
            | Elpi_lexer_config.Tokens.CONSTANT _v_19 ->
                let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_c_, c) = (_endpos, _v_19) in
                let _v = _menhir_action_075 c in
                _menhir_run_048_spec_442 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _v _tok
            | Elpi_lexer_config.Tokens.BEFORE ->
                let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let _endpos__1_ = _endpos in
                let _v = _menhir_action_078 () in
                _menhir_run_048_spec_442 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _v _tok
            | Elpi_lexer_config.Tokens.AFTER ->
                let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let _endpos__1_ = _endpos in
                let _v = _menhir_action_079 () in
                _menhir_run_048_spec_442 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _v _tok
            | _ ->
                _eRR 442)
        | Elpi_lexer_config.Tokens.FULLSTOP ->
            let _v = _menhir_action_288 () in
            _menhir_goto_option_preceded_IFF_sequent__ _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_048_spec_442 : type  ttv_stack. (((ttv_stack, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_RULE, _menhir_box_program) _menhir_cell1_list_sequent_ _menhir_cell0_option_preceded_BIND_nonempty_list_sequent___ _menhir_cell0_option_preceded_PIPE_term__ -> _ -> _ -> _ -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let (_endpos_t_, t) = (_endpos, _v) in
        let _v = _menhir_action_113 t in
        _menhir_run_047_spec_442 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _v _tok
    
    and _menhir_run_436 : type  ttv_stack. (ttv_stack, _menhir_box_program) _menhir_cell1_sequent -> _ -> _ -> _ -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let MenhirCell1_sequent (_menhir_stack, _menhir_s, x, _) = _menhir_stack in
        let xs = _v in
        let _v = _menhir_action_216 x xs in
        _menhir_goto_nonempty_list_sequent_ _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
    
    and _menhir_run_047_spec_036 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_head_term -> _ -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_074 t in
        _menhir_run_049 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v MenhirState036 _tok
    
    and _menhir_run_047_spec_043 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_head_term -> _ -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_074 t in
        _menhir_run_049 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v MenhirState043 _tok
    
    and _menhir_run_043 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v_0 ->
            let _menhir_stack = MenhirCell1_head_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos_1 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_2 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_2, _startpos_1, _v_0) in
            let _v = _menhir_action_068 x in
            _menhir_run_049 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v MenhirState043 _tok
        | Elpi_lexer_config.Tokens.SIGMA ->
            let _menhir_stack = MenhirCell1_head_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos_4 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_5 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_5, _startpos_4) in
            let _v = _menhir_action_085 () in
            _menhir_run_048_spec_043 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v _tok
        | Elpi_lexer_config.Tokens.REPLACE ->
            let _menhir_stack = MenhirCell1_head_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos_7 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_8 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_8, _startpos_7) in
            let _v = _menhir_action_080 () in
            _menhir_run_048_spec_043 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v _tok
        | Elpi_lexer_config.Tokens.QUOTED _v_10 ->
            let _menhir_stack = MenhirCell1_head_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos_11 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_12 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_12, _startpos_11, _v_10) in
            let _v = _menhir_action_069 _endpos_x_ _startpos_x_ x in
            _menhir_run_049 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v MenhirState043 _tok
        | Elpi_lexer_config.Tokens.PI ->
            let _menhir_stack = MenhirCell1_head_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos_14 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_15 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_15, _startpos_14) in
            let _v = _menhir_action_084 () in
            _menhir_run_048_spec_043 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v _tok
        | Elpi_lexer_config.Tokens.NIL ->
            let _menhir_stack = MenhirCell1_head_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos_17 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_18 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_18, _startpos_17) in
            let _v = _menhir_action_089 () in
            _menhir_run_048_spec_043 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v _tok
        | Elpi_lexer_config.Tokens.NAME ->
            let _menhir_stack = MenhirCell1_head_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos_20 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_21 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_21, _startpos_20) in
            let _v = _menhir_action_077 () in
            _menhir_run_048_spec_043 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v _tok
        | Elpi_lexer_config.Tokens.LPAREN ->
            let _menhir_stack = MenhirCell1_head_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState043
        | Elpi_lexer_config.Tokens.LCURLY ->
            let _menhir_stack = MenhirCell1_head_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState043
        | Elpi_lexer_config.Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_head_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState043
        | Elpi_lexer_config.Tokens.IO _v_23 ->
            let _menhir_stack = MenhirCell1_head_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos_24 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_25 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_25, _startpos_24, _v_23) in
            let _v = _menhir_action_082 c in
            _menhir_run_048_spec_043 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v _tok
        | Elpi_lexer_config.Tokens.INTEGER _v_27 ->
            let _menhir_stack = MenhirCell1_head_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos_28 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_29 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_29, _startpos_28, _v_27) in
            let _v = _menhir_action_066 x in
            _menhir_run_049 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v MenhirState043 _tok
        | Elpi_lexer_config.Tokens.INDEX ->
            let _menhir_stack = MenhirCell1_head_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos_31 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_32 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_32, _startpos_31) in
            let _v = _menhir_action_081 () in
            _menhir_run_048_spec_043 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v _tok
        | Elpi_lexer_config.Tokens.IF ->
            let _menhir_stack = MenhirCell1_head_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos_34 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_35 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_35, _startpos_34) in
            let _v = _menhir_action_076 () in
            _menhir_run_048_spec_043 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v _tok
        | Elpi_lexer_config.Tokens.FRESHUV ->
            let _menhir_stack = MenhirCell1_head_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos_37 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_38 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_38, _startpos_37) in
            let _v = _menhir_action_086 () in
            _menhir_run_048_spec_043 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v _tok
        | Elpi_lexer_config.Tokens.FLOAT _v_40 ->
            let _menhir_stack = MenhirCell1_head_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos_41 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_42 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_42, _startpos_41, _v_40) in
            let _v = _menhir_action_067 x in
            _menhir_run_049 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v MenhirState043 _tok
        | Elpi_lexer_config.Tokens.CUT ->
            let _menhir_stack = MenhirCell1_head_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos_44 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_45 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_45, _startpos_44) in
            let _v = _menhir_action_083 () in
            _menhir_run_048_spec_043 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v _tok
        | Elpi_lexer_config.Tokens.CONSTANT _v_47 ->
            let _menhir_stack = MenhirCell1_head_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos_48 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_49 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_49, _startpos_48, _v_47) in
            let _v = _menhir_action_075 c in
            _menhir_run_048_spec_043 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v _tok
        | Elpi_lexer_config.Tokens.BEFORE ->
            let _menhir_stack = MenhirCell1_head_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos_51 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_52 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_52, _startpos_51) in
            let _v = _menhir_action_078 () in
            _menhir_run_048_spec_043 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v _tok
        | Elpi_lexer_config.Tokens.AFTER ->
            let _menhir_stack = MenhirCell1_head_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos_54 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_55 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_55, _startpos_54) in
            let _v = _menhir_action_079 () in
            _menhir_run_048_spec_043 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v _tok
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.AS | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.CONS | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.DIV | Elpi_lexer_config.Tokens.EOF | Elpi_lexer_config.Tokens.EQ | Elpi_lexer_config.Tokens.EQ2 | Elpi_lexer_config.Tokens.FAMILY_AND _ | Elpi_lexer_config.Tokens.FAMILY_BTICK _ | Elpi_lexer_config.Tokens.FAMILY_EQ _ | Elpi_lexer_config.Tokens.FAMILY_EXP _ | Elpi_lexer_config.Tokens.FAMILY_GT _ | Elpi_lexer_config.Tokens.FAMILY_LT _ | Elpi_lexer_config.Tokens.FAMILY_MINUS _ | Elpi_lexer_config.Tokens.FAMILY_OR _ | Elpi_lexer_config.Tokens.FAMILY_PLUS _ | Elpi_lexer_config.Tokens.FAMILY_QMARK _ | Elpi_lexer_config.Tokens.FAMILY_SHARP _ | Elpi_lexer_config.Tokens.FAMILY_TICK _ | Elpi_lexer_config.Tokens.FAMILY_TIMES _ | Elpi_lexer_config.Tokens.FULLSTOP | Elpi_lexer_config.Tokens.IFF | Elpi_lexer_config.Tokens.IS | Elpi_lexer_config.Tokens.MINUS | Elpi_lexer_config.Tokens.MINUSi | Elpi_lexer_config.Tokens.MINUSr | Elpi_lexer_config.Tokens.MINUSs | Elpi_lexer_config.Tokens.MOD | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.PIPE | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.RBRACKET | Elpi_lexer_config.Tokens.RCURLY | Elpi_lexer_config.Tokens.RPAREN | Elpi_lexer_config.Tokens.SLASH | Elpi_lexer_config.Tokens.VDASH ->
            let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
            let _v = _menhir_action_074 t in
            _menhir_goto_closed_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v _menhir_s _tok
        | _ ->
            _eRR 43
    
    and _menhir_run_048_spec_043 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_head_term -> _ -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_113 t in
        _menhir_run_047_spec_043 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v _tok
    
    and _menhir_run_036 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v_0 ->
            let _menhir_stack = MenhirCell1_head_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos_1 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_2 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_2, _startpos_1, _v_0) in
            let _v = _menhir_action_068 x in
            _menhir_run_049 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v MenhirState036 _tok
        | Elpi_lexer_config.Tokens.SIGMA ->
            let _menhir_stack = MenhirCell1_head_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos_4 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_5 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_5, _startpos_4) in
            let _v = _menhir_action_085 () in
            _menhir_run_048_spec_036 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v _tok
        | Elpi_lexer_config.Tokens.REPLACE ->
            let _menhir_stack = MenhirCell1_head_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos_7 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_8 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_8, _startpos_7) in
            let _v = _menhir_action_080 () in
            _menhir_run_048_spec_036 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v _tok
        | Elpi_lexer_config.Tokens.QUOTED _v_10 ->
            let _menhir_stack = MenhirCell1_head_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos_11 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_12 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_12, _startpos_11, _v_10) in
            let _v = _menhir_action_069 _endpos_x_ _startpos_x_ x in
            _menhir_run_049 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v MenhirState036 _tok
        | Elpi_lexer_config.Tokens.PI ->
            let _menhir_stack = MenhirCell1_head_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos_14 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_15 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_15, _startpos_14) in
            let _v = _menhir_action_084 () in
            _menhir_run_048_spec_036 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v _tok
        | Elpi_lexer_config.Tokens.NIL ->
            let _menhir_stack = MenhirCell1_head_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos_17 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_18 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_18, _startpos_17) in
            let _v = _menhir_action_089 () in
            _menhir_run_048_spec_036 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v _tok
        | Elpi_lexer_config.Tokens.NAME ->
            let _menhir_stack = MenhirCell1_head_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos_20 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_21 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_21, _startpos_20) in
            let _v = _menhir_action_077 () in
            _menhir_run_048_spec_036 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v _tok
        | Elpi_lexer_config.Tokens.LPAREN ->
            let _menhir_stack = MenhirCell1_head_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState036
        | Elpi_lexer_config.Tokens.LCURLY ->
            let _menhir_stack = MenhirCell1_head_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState036
        | Elpi_lexer_config.Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_head_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState036
        | Elpi_lexer_config.Tokens.IO _v_23 ->
            let _menhir_stack = MenhirCell1_head_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos_24 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_25 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_25, _startpos_24, _v_23) in
            let _v = _menhir_action_082 c in
            _menhir_run_048_spec_036 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v _tok
        | Elpi_lexer_config.Tokens.INTEGER _v_27 ->
            let _menhir_stack = MenhirCell1_head_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos_28 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_29 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_29, _startpos_28, _v_27) in
            let _v = _menhir_action_066 x in
            _menhir_run_049 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v MenhirState036 _tok
        | Elpi_lexer_config.Tokens.INDEX ->
            let _menhir_stack = MenhirCell1_head_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos_31 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_32 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_32, _startpos_31) in
            let _v = _menhir_action_081 () in
            _menhir_run_048_spec_036 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v _tok
        | Elpi_lexer_config.Tokens.IF ->
            let _menhir_stack = MenhirCell1_head_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos_34 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_35 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_35, _startpos_34) in
            let _v = _menhir_action_076 () in
            _menhir_run_048_spec_036 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v _tok
        | Elpi_lexer_config.Tokens.FRESHUV ->
            let _menhir_stack = MenhirCell1_head_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos_37 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_38 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_38, _startpos_37) in
            let _v = _menhir_action_086 () in
            _menhir_run_048_spec_036 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v _tok
        | Elpi_lexer_config.Tokens.FLOAT _v_40 ->
            let _menhir_stack = MenhirCell1_head_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos_41 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_42 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_42, _startpos_41, _v_40) in
            let _v = _menhir_action_067 x in
            _menhir_run_049 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v MenhirState036 _tok
        | Elpi_lexer_config.Tokens.CUT ->
            let _menhir_stack = MenhirCell1_head_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos_44 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_45 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_45, _startpos_44) in
            let _v = _menhir_action_083 () in
            _menhir_run_048_spec_036 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v _tok
        | Elpi_lexer_config.Tokens.CONSTANT _v_47 ->
            let _menhir_stack = MenhirCell1_head_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos_48 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_49 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_49, _startpos_48, _v_47) in
            let _v = _menhir_action_075 c in
            _menhir_run_048_spec_036 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v _tok
        | Elpi_lexer_config.Tokens.BEFORE ->
            let _menhir_stack = MenhirCell1_head_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos_51 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_52 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_52, _startpos_51) in
            let _v = _menhir_action_078 () in
            _menhir_run_048_spec_036 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v _tok
        | Elpi_lexer_config.Tokens.AFTER ->
            let _menhir_stack = MenhirCell1_head_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos_54 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_55 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_55, _startpos_54) in
            let _v = _menhir_action_079 () in
            _menhir_run_048_spec_036 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v _tok
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.CONS | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.DIV | Elpi_lexer_config.Tokens.EQ | Elpi_lexer_config.Tokens.EQ2 | Elpi_lexer_config.Tokens.FAMILY_AND _ | Elpi_lexer_config.Tokens.FAMILY_BTICK _ | Elpi_lexer_config.Tokens.FAMILY_EQ _ | Elpi_lexer_config.Tokens.FAMILY_EXP _ | Elpi_lexer_config.Tokens.FAMILY_GT _ | Elpi_lexer_config.Tokens.FAMILY_LT _ | Elpi_lexer_config.Tokens.FAMILY_MINUS _ | Elpi_lexer_config.Tokens.FAMILY_OR _ | Elpi_lexer_config.Tokens.FAMILY_PLUS _ | Elpi_lexer_config.Tokens.FAMILY_QMARK _ | Elpi_lexer_config.Tokens.FAMILY_SHARP _ | Elpi_lexer_config.Tokens.FAMILY_TICK _ | Elpi_lexer_config.Tokens.FAMILY_TIMES _ | Elpi_lexer_config.Tokens.IS | Elpi_lexer_config.Tokens.MINUS | Elpi_lexer_config.Tokens.MINUSi | Elpi_lexer_config.Tokens.MINUSr | Elpi_lexer_config.Tokens.MINUSs | Elpi_lexer_config.Tokens.MOD | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.PIPE | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.RBRACKET | Elpi_lexer_config.Tokens.SLASH | Elpi_lexer_config.Tokens.VDASH ->
            let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
            let _v = _menhir_action_074 t in
            _menhir_goto_closed_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v _menhir_s _tok
        | _ ->
            _eRR 36
    
    and _menhir_run_048_spec_036 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_head_term -> _ -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_113 t in
        _menhir_run_047_spec_036 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v _tok
    
    and _menhir_run_053_spec_221 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_LPAREN, ttv_result) _menhir_cell1_term -> _ -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_317 t in
        _menhir_run_222 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v MenhirState221 _tok
    
    and _menhir_run_222 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_LPAREN, ttv_result) _menhir_cell1_term as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.VDASH ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_056 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.SLASH ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.RPAREN ->
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let MenhirCell1_term (_menhir_stack, _, t, _, _) = _menhir_stack in
            let MenhirCell1_LPAREN (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
            let (c, _endpos__5_) = (_v, _endpos_0) in
            let _v = _menhir_action_070 c t in
            _menhir_goto_closed_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__5_ _startpos__1_ _v _menhir_s _tok
        | Elpi_lexer_config.Tokens.QDASH ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_114 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.OR ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_072 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MOD ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_074 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSs ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_076 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSr ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_082 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSi ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_084 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_086 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.IS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_088 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FAMILY_TIMES _v_1 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_078 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_TICK _v_2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_090 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_3 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_4 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_041 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_PLUS _v_5 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_092 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_6 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_7 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer _v_7
        | Elpi_lexer_config.Tokens.FAMILY_LT _v_8 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_098 _menhir_stack _menhir_lexbuf _menhir_lexer _v_8
        | Elpi_lexer_config.Tokens.FAMILY_GT _v_9 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_100 _menhir_stack _menhir_lexbuf _menhir_lexer _v_9
        | Elpi_lexer_config.Tokens.FAMILY_EXP _v_10 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_094 _menhir_stack _menhir_lexbuf _menhir_lexer _v_10
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_11 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer _v_11
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_12 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer _v_12
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_13 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer _v_13
        | Elpi_lexer_config.Tokens.EQ2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_102 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.EQ ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_104 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.DIV ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_080 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.DARROW ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_106 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_096 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONJ2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_108 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONJ ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_110 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.ARROW ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_112 _menhir_stack _menhir_lexbuf _menhir_lexer
        | _ ->
            _eRR 222
    
    and _menhir_run_426 : type  ttv_stack. ((ttv_stack, _menhir_box_program) _menhir_cell1_LPAREN as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.COLON ->
            let _menhir_stack = MenhirCell1_constant (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos_0 = _menhir_lexbuf.Lexing.lex_start_p in
            let _menhir_stack = MenhirCell1_COLON (_menhir_stack, MenhirState426, _startpos_0) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Elpi_lexer_config.Tokens.STRING _v_1 ->
                let _startpos_2 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_3 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_3, _startpos_2, _v_1) in
                let _v = _menhir_action_068 x in
                _menhir_run_053_spec_427 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.SIGMA ->
                let _startpos_5 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_6 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_6, _startpos_5) in
                let _v = _menhir_action_085 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState427 _tok
            | Elpi_lexer_config.Tokens.REPLACE ->
                let _startpos_8 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_9 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_9, _startpos_8) in
                let _v = _menhir_action_080 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState427 _tok
            | Elpi_lexer_config.Tokens.QUOTED _v_11 ->
                let _startpos_12 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_13 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_13, _startpos_12, _v_11) in
                let _v = _menhir_action_069 _endpos_x_ _startpos_x_ x in
                _menhir_run_053_spec_427 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.PI ->
                let _startpos_15 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_16 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_16, _startpos_15) in
                let _v = _menhir_action_084 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState427 _tok
            | Elpi_lexer_config.Tokens.NIL ->
                let _startpos_18 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_19 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_19, _startpos_18) in
                let _v = _menhir_action_089 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState427 _tok
            | Elpi_lexer_config.Tokens.NAME ->
                let _startpos_21 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_22 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_22, _startpos_21) in
                let _v = _menhir_action_077 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState427 _tok
            | Elpi_lexer_config.Tokens.LPAREN ->
                _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState427
            | Elpi_lexer_config.Tokens.LCURLY ->
                _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState427
            | Elpi_lexer_config.Tokens.LBRACKET ->
                _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState427
            | Elpi_lexer_config.Tokens.IO _v_24 ->
                let _startpos_25 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_26 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_c_, _startpos_c_, c) = (_endpos_26, _startpos_25, _v_24) in
                let _v = _menhir_action_082 c in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState427 _tok
            | Elpi_lexer_config.Tokens.INTEGER _v_28 ->
                let _startpos_29 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_30 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_30, _startpos_29, _v_28) in
                let _v = _menhir_action_066 x in
                _menhir_run_053_spec_427 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.INDEX ->
                let _startpos_32 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_33 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_33, _startpos_32) in
                let _v = _menhir_action_081 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState427 _tok
            | Elpi_lexer_config.Tokens.IF ->
                let _startpos_35 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_36 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_36, _startpos_35) in
                let _v = _menhir_action_076 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState427 _tok
            | Elpi_lexer_config.Tokens.FRESHUV ->
                let _startpos_38 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_39 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_39, _startpos_38) in
                let _v = _menhir_action_086 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState427 _tok
            | Elpi_lexer_config.Tokens.FLOAT _v_41 ->
                let _startpos_42 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_43 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_43, _startpos_42, _v_41) in
                let _v = _menhir_action_067 x in
                _menhir_run_053_spec_427 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.FAMILY_TILDE _v_45 ->
                _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer _v_45 MenhirState427
            | Elpi_lexer_config.Tokens.CUT ->
                let _startpos_46 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_47 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_47, _startpos_46) in
                let _v = _menhir_action_083 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState427 _tok
            | Elpi_lexer_config.Tokens.CONSTANT _v_49 ->
                let _startpos_50 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_51 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_c_, _startpos_c_, c) = (_endpos_51, _startpos_50, _v_49) in
                let _v = _menhir_action_075 c in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState427 _tok
            | Elpi_lexer_config.Tokens.BEFORE ->
                let _startpos_53 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_54 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_54, _startpos_53) in
                let _v = _menhir_action_078 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState427 _tok
            | Elpi_lexer_config.Tokens.AFTER ->
                let _startpos_56 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_57 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_57, _startpos_56) in
                let _v = _menhir_action_079 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState427 _tok
            | _ ->
                _eRR 427)
        | Elpi_lexer_config.Tokens.BIND ->
            let _menhir_stack = MenhirCell1_constant (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState426
        | Elpi_lexer_config.Tokens.AFTER | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.AS | Elpi_lexer_config.Tokens.BEFORE | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.CONS | Elpi_lexer_config.Tokens.CONSTANT _ | Elpi_lexer_config.Tokens.CUT | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.DIV | Elpi_lexer_config.Tokens.EQ | Elpi_lexer_config.Tokens.EQ2 | Elpi_lexer_config.Tokens.FAMILY_AND _ | Elpi_lexer_config.Tokens.FAMILY_BTICK _ | Elpi_lexer_config.Tokens.FAMILY_EQ _ | Elpi_lexer_config.Tokens.FAMILY_EXP _ | Elpi_lexer_config.Tokens.FAMILY_GT _ | Elpi_lexer_config.Tokens.FAMILY_LT _ | Elpi_lexer_config.Tokens.FAMILY_MINUS _ | Elpi_lexer_config.Tokens.FAMILY_OR _ | Elpi_lexer_config.Tokens.FAMILY_PLUS _ | Elpi_lexer_config.Tokens.FAMILY_QMARK _ | Elpi_lexer_config.Tokens.FAMILY_SHARP _ | Elpi_lexer_config.Tokens.FAMILY_TICK _ | Elpi_lexer_config.Tokens.FAMILY_TIMES _ | Elpi_lexer_config.Tokens.FLOAT _ | Elpi_lexer_config.Tokens.FRESHUV | Elpi_lexer_config.Tokens.IF | Elpi_lexer_config.Tokens.INDEX | Elpi_lexer_config.Tokens.INTEGER _ | Elpi_lexer_config.Tokens.IO _ | Elpi_lexer_config.Tokens.IS | Elpi_lexer_config.Tokens.LBRACKET | Elpi_lexer_config.Tokens.LCURLY | Elpi_lexer_config.Tokens.LPAREN | Elpi_lexer_config.Tokens.MINUS | Elpi_lexer_config.Tokens.MINUSi | Elpi_lexer_config.Tokens.MINUSr | Elpi_lexer_config.Tokens.MINUSs | Elpi_lexer_config.Tokens.MOD | Elpi_lexer_config.Tokens.NAME | Elpi_lexer_config.Tokens.NIL | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.PI | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.QUOTED _ | Elpi_lexer_config.Tokens.REPLACE | Elpi_lexer_config.Tokens.RPAREN | Elpi_lexer_config.Tokens.SIGMA | Elpi_lexer_config.Tokens.SLASH | Elpi_lexer_config.Tokens.STRING _ | Elpi_lexer_config.Tokens.VDASH ->
            let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
            let _v = _menhir_action_113 t in
            _menhir_goto_head_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v _menhir_s _tok
        | _ ->
            _eRR 426
    
    and _menhir_run_053_spec_427 : type  ttv_stack. (((ttv_stack, _menhir_box_program) _menhir_cell1_LPAREN, _menhir_box_program) _menhir_cell1_constant, _menhir_box_program) _menhir_cell1_COLON -> _ -> _ -> _ -> _ -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_317 t in
        _menhir_run_428 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v MenhirState427 _tok
    
    and _menhir_run_428 : type  ttv_stack. ((((ttv_stack, _menhir_box_program) _menhir_cell1_LPAREN, _menhir_box_program) _menhir_cell1_constant, _menhir_box_program) _menhir_cell1_COLON as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.VDASH ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_056 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.SLASH ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.RPAREN ->
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let MenhirCell1_COLON (_menhir_stack, _, _) = _menhir_stack in
            let MenhirCell1_constant (_menhir_stack, _, c, _, _) = _menhir_stack in
            let MenhirCell1_LPAREN (_menhir_stack, _menhir_s, _) = _menhir_stack in
            let (t, _endpos__5_) = (_v, _endpos_0) in
            let _v = _menhir_action_311 c t in
            _menhir_goto_sequent _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__5_ _v _menhir_s _tok
        | Elpi_lexer_config.Tokens.QDASH ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_114 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.OR ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_072 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MOD ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_074 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSs ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_076 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSr ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_082 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSi ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_084 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_086 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.IS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_088 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FAMILY_TIMES _v_1 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_078 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_TICK _v_2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_090 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_3 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_4 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_041 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_PLUS _v_5 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_092 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_6 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_7 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer _v_7
        | Elpi_lexer_config.Tokens.FAMILY_LT _v_8 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_098 _menhir_stack _menhir_lexbuf _menhir_lexer _v_8
        | Elpi_lexer_config.Tokens.FAMILY_GT _v_9 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_100 _menhir_stack _menhir_lexbuf _menhir_lexer _v_9
        | Elpi_lexer_config.Tokens.FAMILY_EXP _v_10 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_094 _menhir_stack _menhir_lexbuf _menhir_lexer _v_10
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_11 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer _v_11
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_12 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer _v_12
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_13 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer _v_13
        | Elpi_lexer_config.Tokens.EQ2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_102 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.EQ ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_104 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.DIV ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_080 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.DARROW ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_106 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_096 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONJ2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_108 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONJ ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_110 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.ARROW ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_112 _menhir_stack _menhir_lexbuf _menhir_lexer
        | _ ->
            _eRR 428
    
    and _menhir_goto_sequent : type  ttv_stack. ttv_stack -> _ -> _ -> _ -> _ -> (ttv_stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        match _menhir_s with
        | MenhirState442 ->
            _menhir_run_443 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState435 ->
            _menhir_run_435 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState434 ->
            _menhir_run_435 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState430 ->
            _menhir_run_430 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState424 ->
            _menhir_run_430 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_196 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_LPAREN as 'stack) -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v_0 ->
            let _menhir_stack = MenhirCell1_FAMILY_TILDE (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos_1 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_2 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_2, _startpos_1, _v_0) in
            let _v = _menhir_action_068 x in
            _menhir_run_053_spec_196 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.SIGMA ->
            let _menhir_stack = MenhirCell1_FAMILY_TILDE (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos_4 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_5 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_5, _startpos_4) in
            let _v = _menhir_action_085 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState196 _tok
        | Elpi_lexer_config.Tokens.REPLACE ->
            let _menhir_stack = MenhirCell1_FAMILY_TILDE (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos_7 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_8 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_8, _startpos_7) in
            let _v = _menhir_action_080 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState196 _tok
        | Elpi_lexer_config.Tokens.QUOTED _v_10 ->
            let _menhir_stack = MenhirCell1_FAMILY_TILDE (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos_11 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_12 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_12, _startpos_11, _v_10) in
            let _v = _menhir_action_069 _endpos_x_ _startpos_x_ x in
            _menhir_run_053_spec_196 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.PI ->
            let _menhir_stack = MenhirCell1_FAMILY_TILDE (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos_14 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_15 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_15, _startpos_14) in
            let _v = _menhir_action_084 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState196 _tok
        | Elpi_lexer_config.Tokens.NIL ->
            let _menhir_stack = MenhirCell1_FAMILY_TILDE (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos_17 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_18 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_18, _startpos_17) in
            let _v = _menhir_action_089 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState196 _tok
        | Elpi_lexer_config.Tokens.NAME ->
            let _menhir_stack = MenhirCell1_FAMILY_TILDE (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos_20 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_21 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_21, _startpos_20) in
            let _v = _menhir_action_077 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState196 _tok
        | Elpi_lexer_config.Tokens.LPAREN ->
            let _menhir_stack = MenhirCell1_FAMILY_TILDE (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState196
        | Elpi_lexer_config.Tokens.LCURLY ->
            let _menhir_stack = MenhirCell1_FAMILY_TILDE (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState196
        | Elpi_lexer_config.Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_FAMILY_TILDE (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState196
        | Elpi_lexer_config.Tokens.IO _v_23 ->
            let _menhir_stack = MenhirCell1_FAMILY_TILDE (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos_24 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_25 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_25, _startpos_24, _v_23) in
            let _v = _menhir_action_082 c in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState196 _tok
        | Elpi_lexer_config.Tokens.INTEGER _v_27 ->
            let _menhir_stack = MenhirCell1_FAMILY_TILDE (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos_28 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_29 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_29, _startpos_28, _v_27) in
            let _v = _menhir_action_066 x in
            _menhir_run_053_spec_196 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.INDEX ->
            let _menhir_stack = MenhirCell1_FAMILY_TILDE (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos_31 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_32 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_32, _startpos_31) in
            let _v = _menhir_action_081 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState196 _tok
        | Elpi_lexer_config.Tokens.IF ->
            let _menhir_stack = MenhirCell1_FAMILY_TILDE (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos_34 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_35 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_35, _startpos_34) in
            let _v = _menhir_action_076 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState196 _tok
        | Elpi_lexer_config.Tokens.FRESHUV ->
            let _menhir_stack = MenhirCell1_FAMILY_TILDE (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos_37 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_38 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_38, _startpos_37) in
            let _v = _menhir_action_086 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState196 _tok
        | Elpi_lexer_config.Tokens.FLOAT _v_40 ->
            let _menhir_stack = MenhirCell1_FAMILY_TILDE (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos_41 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_42 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos_42, _startpos_41, _v_40) in
            let _v = _menhir_action_067 x in
            _menhir_run_053_spec_196 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_TILDE _v_44 ->
            let _menhir_stack = MenhirCell1_FAMILY_TILDE (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer _v_44 MenhirState196
        | Elpi_lexer_config.Tokens.CUT ->
            let _menhir_stack = MenhirCell1_FAMILY_TILDE (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos_45 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_46 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_46, _startpos_45) in
            let _v = _menhir_action_083 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState196 _tok
        | Elpi_lexer_config.Tokens.CONSTANT _v_48 ->
            let _menhir_stack = MenhirCell1_FAMILY_TILDE (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos_49 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_50 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_50, _startpos_49, _v_48) in
            let _v = _menhir_action_075 c in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState196 _tok
        | Elpi_lexer_config.Tokens.BEFORE ->
            let _menhir_stack = MenhirCell1_FAMILY_TILDE (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos_52 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_53 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_53, _startpos_52) in
            let _v = _menhir_action_078 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState196 _tok
        | Elpi_lexer_config.Tokens.AFTER ->
            let _menhir_stack = MenhirCell1_FAMILY_TILDE (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos_55 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_56 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_56, _startpos_55) in
            let _v = _menhir_action_079 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState196 _tok
        | Elpi_lexer_config.Tokens.RPAREN ->
            let (_endpos_s_, _startpos_s_, s) = (_endpos, _startpos, _v) in
            let _v = _menhir_action_202 s in
            _menhir_goto_mixfix_SYMB _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_s_ _startpos_s_ _v _menhir_s _tok
        | _ ->
            _eRR 196
    
    and _menhir_run_053_spec_196 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_LPAREN, ttv_result) _menhir_cell1_FAMILY_TILDE -> _ -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_317 t in
        _menhir_run_040 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v MenhirState196 _tok
    
    and _menhir_goto_mixfix_SYMB : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match _menhir_s with
        | MenhirState354 ->
            _menhir_run_355 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState455 ->
            _menhir_run_224 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | MenhirState425 ->
            _menhir_run_224 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | MenhirState293 ->
            _menhir_run_224 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | MenhirState274 ->
            _menhir_run_224 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | MenhirState281 ->
            _menhir_run_224 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | MenhirState271 ->
            _menhir_run_224 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | MenhirState008 ->
            _menhir_run_224 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_355 : type  ttv_stack. (ttv_stack, _menhir_box_program) _menhir_cell1_FIXITY -> _ -> _ -> _ -> _ -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.INTEGER _v_0 ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let MenhirCell1_FIXITY (_menhir_stack, _menhir_s, f, _startpos_f_) = _menhir_stack in
            let (_endpos_c_, _startpos_c_, c, i) = (_endpos, _startpos, _v, _v_0) in
            let _v = _menhir_action_110 _endpos_c_ _startpos_c_ c f i in
            _menhir_goto_fixity _menhir_stack _menhir_lexbuf _menhir_lexer _startpos_f_ _v _menhir_s _tok
        | _ ->
            _eRR 355
    
    and _menhir_goto_fixity : type  ttv_stack. ttv_stack -> _ -> _ -> _ -> _ -> (ttv_stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.FULLSTOP ->
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__2_, _startpos_f_, f) = (_endpos, _startpos, _v) in
            let _v = _menhir_action_106 _endpos__2_ _startpos_f_ f in
            _menhir_goto_decl _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | _ ->
            _eRR 412
    
    and _menhir_run_431 : type  ttv_stack. (ttv_stack, _menhir_box_program) _menhir_cell1_sequent -> _ -> _ -> _ -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let MenhirCell1_sequent (_menhir_stack, _menhir_s, x, _) = _menhir_stack in
        let xs = _v in
        let _v = _menhir_action_162 x xs in
        _menhir_goto_list_sequent_ _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
    
    and _menhir_goto_list_sequent_ : type  ttv_stack. ttv_stack -> _ -> _ -> _ -> _ -> (ttv_stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        match _menhir_s with
        | MenhirState424 ->
            _menhir_run_433 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState430 ->
            _menhir_run_431 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_433 : type  ttv_stack. (((ttv_stack, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_RULE as 'stack) -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_list_sequent_ (_menhir_stack, _menhir_s, _v) in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.BIND ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell0_BIND (_menhir_stack, _startpos, _endpos) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Elpi_lexer_config.Tokens.STRING _v_0 ->
                let _endpos_2 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, x) = (_endpos_2, _v_0) in
                let _v = _menhir_action_068 x in
                _menhir_run_432_spec_434 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.SIGMA ->
                let _endpos_5 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let _endpos__1_ = _endpos_5 in
                let _v = _menhir_action_085 () in
                _menhir_run_048_spec_434 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _v _tok
            | Elpi_lexer_config.Tokens.REPLACE ->
                let _endpos_8 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let _endpos__1_ = _endpos_8 in
                let _v = _menhir_action_080 () in
                _menhir_run_048_spec_434 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _v _tok
            | Elpi_lexer_config.Tokens.QUOTED _v_10 ->
                let _startpos_11 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_12 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_12, _startpos_11, _v_10) in
                let _v = _menhir_action_069 _endpos_x_ _startpos_x_ x in
                _menhir_run_432_spec_434 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.PI ->
                let _endpos_15 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let _endpos__1_ = _endpos_15 in
                let _v = _menhir_action_084 () in
                _menhir_run_048_spec_434 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _v _tok
            | Elpi_lexer_config.Tokens.NIL ->
                let _endpos_18 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let _endpos__1_ = _endpos_18 in
                let _v = _menhir_action_089 () in
                _menhir_run_048_spec_434 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _v _tok
            | Elpi_lexer_config.Tokens.NAME ->
                let _endpos_21 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let _endpos__1_ = _endpos_21 in
                let _v = _menhir_action_077 () in
                _menhir_run_048_spec_434 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _v _tok
            | Elpi_lexer_config.Tokens.LPAREN ->
                _menhir_run_425 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState434
            | Elpi_lexer_config.Tokens.LCURLY ->
                _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState434
            | Elpi_lexer_config.Tokens.LBRACKET ->
                _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState434
            | Elpi_lexer_config.Tokens.IO _v_23 ->
                let _endpos_25 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_c_, c) = (_endpos_25, _v_23) in
                let _v = _menhir_action_082 c in
                _menhir_run_048_spec_434 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _v _tok
            | Elpi_lexer_config.Tokens.INTEGER _v_27 ->
                let _endpos_29 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, x) = (_endpos_29, _v_27) in
                let _v = _menhir_action_066 x in
                _menhir_run_432_spec_434 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.INDEX ->
                let _endpos_32 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let _endpos__1_ = _endpos_32 in
                let _v = _menhir_action_081 () in
                _menhir_run_048_spec_434 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _v _tok
            | Elpi_lexer_config.Tokens.IF ->
                let _endpos_35 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let _endpos__1_ = _endpos_35 in
                let _v = _menhir_action_076 () in
                _menhir_run_048_spec_434 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _v _tok
            | Elpi_lexer_config.Tokens.FRESHUV ->
                let _endpos_38 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let _endpos__1_ = _endpos_38 in
                let _v = _menhir_action_086 () in
                _menhir_run_048_spec_434 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _v _tok
            | Elpi_lexer_config.Tokens.FLOAT _v_40 ->
                let _endpos_42 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, x) = (_endpos_42, _v_40) in
                let _v = _menhir_action_067 x in
                _menhir_run_432_spec_434 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.CUT ->
                let _endpos_45 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let _endpos__1_ = _endpos_45 in
                let _v = _menhir_action_083 () in
                _menhir_run_048_spec_434 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _v _tok
            | Elpi_lexer_config.Tokens.CONSTANT _v_47 ->
                let _endpos_49 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_c_, c) = (_endpos_49, _v_47) in
                let _v = _menhir_action_075 c in
                _menhir_run_048_spec_434 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _v _tok
            | Elpi_lexer_config.Tokens.BEFORE ->
                let _endpos_52 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let _endpos__1_ = _endpos_52 in
                let _v = _menhir_action_078 () in
                _menhir_run_048_spec_434 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _v _tok
            | Elpi_lexer_config.Tokens.AFTER ->
                let _endpos_55 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let _endpos__1_ = _endpos_55 in
                let _v = _menhir_action_079 () in
                _menhir_run_048_spec_434 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _v _tok
            | _ ->
                _eRR 434)
        | Elpi_lexer_config.Tokens.FULLSTOP | Elpi_lexer_config.Tokens.IFF | Elpi_lexer_config.Tokens.PIPE ->
            let _v = _menhir_action_286 () in
            _menhir_goto_option_preceded_BIND_nonempty_list_sequent___ _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_048_spec_434 : type  ttv_stack. (((ttv_stack, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_RULE, _menhir_box_program) _menhir_cell1_list_sequent_ _menhir_cell0_BIND -> _ -> _ -> _ -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let (_endpos_t_, t) = (_endpos, _v) in
        let _v = _menhir_action_113 t in
        _menhir_run_047_spec_434 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _v _tok
    
    and _menhir_run_053_spec_458 : type  ttv_stack. ((ttv_stack, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_FAMILY_TILDE -> _ -> _ -> _ -> _ -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_317 t in
        _menhir_run_459 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v MenhirState458 _tok
    
    and _menhir_run_459 : type  ttv_stack. (((ttv_stack, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_FAMILY_TILDE as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_0 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_041 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.CONS | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.DIV | Elpi_lexer_config.Tokens.EQ | Elpi_lexer_config.Tokens.EQ2 | Elpi_lexer_config.Tokens.FAMILY_AND _ | Elpi_lexer_config.Tokens.FAMILY_BTICK _ | Elpi_lexer_config.Tokens.FAMILY_EQ _ | Elpi_lexer_config.Tokens.FAMILY_EXP _ | Elpi_lexer_config.Tokens.FAMILY_GT _ | Elpi_lexer_config.Tokens.FAMILY_LT _ | Elpi_lexer_config.Tokens.FAMILY_MINUS _ | Elpi_lexer_config.Tokens.FAMILY_OR _ | Elpi_lexer_config.Tokens.FAMILY_PLUS _ | Elpi_lexer_config.Tokens.FAMILY_SHARP _ | Elpi_lexer_config.Tokens.FAMILY_TICK _ | Elpi_lexer_config.Tokens.FAMILY_TIMES _ | Elpi_lexer_config.Tokens.FULLSTOP | Elpi_lexer_config.Tokens.IS | Elpi_lexer_config.Tokens.MINUS | Elpi_lexer_config.Tokens.MINUSi | Elpi_lexer_config.Tokens.MINUSr | Elpi_lexer_config.Tokens.MINUSs | Elpi_lexer_config.Tokens.MOD | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.SLASH | Elpi_lexer_config.Tokens.VDASH ->
            let MenhirCell1_FAMILY_TILDE (_menhir_stack, _menhir_s, s, _startpos_s_, _) = _menhir_stack in
            let (_endpos_r_, r) = (_endpos, _v) in
            let _v = _menhir_action_062 r s in
            _menhir_goto_clause_hd_open_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_s_ _v _menhir_s _tok
        | _ ->
            _eRR 459
    
    and _menhir_run_053_spec_455 : type  ttv_stack. ((ttv_stack, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_LPAREN -> _ -> _ -> _ -> _ -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_317 t in
        _menhir_run_456 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v MenhirState455 _tok
    
    and _menhir_run_456 : type  ttv_stack. (((ttv_stack, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_LPAREN as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.VDASH ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_056 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.SLASH ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.RPAREN ->
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.CONS | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.DIV | Elpi_lexer_config.Tokens.EQ | Elpi_lexer_config.Tokens.EQ2 | Elpi_lexer_config.Tokens.FAMILY_AND _ | Elpi_lexer_config.Tokens.FAMILY_BTICK _ | Elpi_lexer_config.Tokens.FAMILY_EQ _ | Elpi_lexer_config.Tokens.FAMILY_EXP _ | Elpi_lexer_config.Tokens.FAMILY_GT _ | Elpi_lexer_config.Tokens.FAMILY_LT _ | Elpi_lexer_config.Tokens.FAMILY_MINUS _ | Elpi_lexer_config.Tokens.FAMILY_OR _ | Elpi_lexer_config.Tokens.FAMILY_PLUS _ | Elpi_lexer_config.Tokens.FAMILY_QMARK _ | Elpi_lexer_config.Tokens.FAMILY_SHARP _ | Elpi_lexer_config.Tokens.FAMILY_TICK _ | Elpi_lexer_config.Tokens.FAMILY_TIMES _ | Elpi_lexer_config.Tokens.FULLSTOP | Elpi_lexer_config.Tokens.IS | Elpi_lexer_config.Tokens.MINUS | Elpi_lexer_config.Tokens.MINUSi | Elpi_lexer_config.Tokens.MINUSr | Elpi_lexer_config.Tokens.MINUSs | Elpi_lexer_config.Tokens.MOD | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.SLASH | Elpi_lexer_config.Tokens.VDASH ->
                let MenhirCell1_LPAREN (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
                let (_endpos__3_, t) = (_endpos_0, _v) in
                let _v = _menhir_action_031 t in
                _menhir_goto_clause_hd_closed_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__3_ _startpos__1_ _v _menhir_s _tok
            | Elpi_lexer_config.Tokens.AFTER | Elpi_lexer_config.Tokens.BEFORE | Elpi_lexer_config.Tokens.CONSTANT _ | Elpi_lexer_config.Tokens.CUT | Elpi_lexer_config.Tokens.FLOAT _ | Elpi_lexer_config.Tokens.FRESHUV | Elpi_lexer_config.Tokens.IF | Elpi_lexer_config.Tokens.INDEX | Elpi_lexer_config.Tokens.INTEGER _ | Elpi_lexer_config.Tokens.IO _ | Elpi_lexer_config.Tokens.LBRACKET | Elpi_lexer_config.Tokens.LCURLY | Elpi_lexer_config.Tokens.LPAREN | Elpi_lexer_config.Tokens.NAME | Elpi_lexer_config.Tokens.NIL | Elpi_lexer_config.Tokens.PI | Elpi_lexer_config.Tokens.QUOTED _ | Elpi_lexer_config.Tokens.REPLACE | Elpi_lexer_config.Tokens.SIGMA | Elpi_lexer_config.Tokens.STRING _ ->
                let MenhirCell1_LPAREN (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
                let (_endpos__3_, t) = (_endpos_0, _v) in
                let _v = _menhir_action_114 t in
                _menhir_goto_head_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__3_ _startpos__1_ _v _menhir_s _tok
            | _ ->
                _eRR 457)
        | Elpi_lexer_config.Tokens.QDASH ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_114 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.OR ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_072 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MOD ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_074 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSs ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_076 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSr ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_082 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUSi ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_084 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_086 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.IS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_088 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.FAMILY_TIMES _v_1 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_078 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1
        | Elpi_lexer_config.Tokens.FAMILY_TICK _v_2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_090 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_3 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_4 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_041 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4
        | Elpi_lexer_config.Tokens.FAMILY_PLUS _v_5 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_092 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_6 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_7 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer _v_7
        | Elpi_lexer_config.Tokens.FAMILY_LT _v_8 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_098 _menhir_stack _menhir_lexbuf _menhir_lexer _v_8
        | Elpi_lexer_config.Tokens.FAMILY_GT _v_9 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_100 _menhir_stack _menhir_lexbuf _menhir_lexer _v_9
        | Elpi_lexer_config.Tokens.FAMILY_EXP _v_10 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_094 _menhir_stack _menhir_lexbuf _menhir_lexer _v_10
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_11 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer _v_11
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_12 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer _v_12
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_13 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer _v_13
        | Elpi_lexer_config.Tokens.EQ2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_102 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.EQ ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_104 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.DIV ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_080 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.DARROW ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_106 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONS ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_096 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONJ2 ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_108 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.CONJ ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_110 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Elpi_lexer_config.Tokens.ARROW ->
            let _menhir_stack = MenhirCell1_term (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_112 _menhir_stack _menhir_lexbuf _menhir_lexer
        | _ ->
            _eRR 456
    
    and _menhir_goto_clause_hd_closed_term : type  ttv_stack. ((ttv_stack, _menhir_box_program) _menhir_cell1_attributes as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_065 t in
        _menhir_goto_clause_hd_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v _menhir_s _tok
    
    and _menhir_run_053_spec_008 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_LPAREN -> _ -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_317 t in
        _menhir_run_219 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v MenhirState008 _tok
    
    and _menhir_run_339 : type  ttv_stack. ttv_stack -> _ -> _ -> (ttv_stack, _menhir_box_program) _menhir_state -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_LOCALKIND (_menhir_stack, _menhir_s, _startpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.SIGMA ->
            let _startpos_0 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_0) in
            let _v = _menhir_action_085 () in
            _menhir_run_289 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState339 _tok
        | Elpi_lexer_config.Tokens.REPLACE ->
            let _startpos_1 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_1) in
            let _v = _menhir_action_080 () in
            _menhir_run_289 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState339 _tok
        | Elpi_lexer_config.Tokens.PI ->
            let _startpos_2 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_2) in
            let _v = _menhir_action_084 () in
            _menhir_run_289 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState339 _tok
        | Elpi_lexer_config.Tokens.NIL ->
            let _startpos_3 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_3) in
            let _v = _menhir_action_089 () in
            _menhir_run_289 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState339 _tok
        | Elpi_lexer_config.Tokens.NAME ->
            let _startpos_4 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_4) in
            let _v = _menhir_action_077 () in
            _menhir_run_289 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState339 _tok
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_271 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState339
        | Elpi_lexer_config.Tokens.IO _v ->
            let _startpos_5 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos, _startpos_5, _v) in
            let _v = _menhir_action_082 c in
            _menhir_run_289 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState339 _tok
        | Elpi_lexer_config.Tokens.INDEX ->
            let _startpos_6 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_6) in
            let _v = _menhir_action_081 () in
            _menhir_run_289 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState339 _tok
        | Elpi_lexer_config.Tokens.IF ->
            let _startpos_7 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_7) in
            let _v = _menhir_action_076 () in
            _menhir_run_289 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState339 _tok
        | Elpi_lexer_config.Tokens.FRESHUV ->
            let _startpos_8 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_8) in
            let _v = _menhir_action_086 () in
            _menhir_run_289 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState339 _tok
        | Elpi_lexer_config.Tokens.CUT ->
            let _startpos_9 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_9) in
            let _v = _menhir_action_083 () in
            _menhir_run_289 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState339 _tok
        | Elpi_lexer_config.Tokens.CONSTANT _v ->
            let _startpos_10 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos, _startpos_10, _v) in
            let _v = _menhir_action_075 c in
            _menhir_run_289 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState339 _tok
        | Elpi_lexer_config.Tokens.BEFORE ->
            let _startpos_11 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_11) in
            let _v = _menhir_action_078 () in
            _menhir_run_289 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState339 _tok
        | Elpi_lexer_config.Tokens.AFTER ->
            let _startpos_12 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_12) in
            let _v = _menhir_action_079 () in
            _menhir_run_289 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState339 _tok
        | _ ->
            _eRR 339
    
    and _menhir_run_341 : type  ttv_stack. ttv_stack -> _ -> _ -> (ttv_stack, _menhir_box_program) _menhir_state -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _menhir_stack = MenhirCell1_LOCAL (_menhir_stack, _menhir_s) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.SIGMA ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos) in
            let _v = _menhir_action_085 () in
            _menhir_run_289 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState341 _tok
        | Elpi_lexer_config.Tokens.REPLACE ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos) in
            let _v = _menhir_action_080 () in
            _menhir_run_289 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState341 _tok
        | Elpi_lexer_config.Tokens.PI ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos) in
            let _v = _menhir_action_084 () in
            _menhir_run_289 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState341 _tok
        | Elpi_lexer_config.Tokens.NIL ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos) in
            let _v = _menhir_action_089 () in
            _menhir_run_289 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState341 _tok
        | Elpi_lexer_config.Tokens.NAME ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos) in
            let _v = _menhir_action_077 () in
            _menhir_run_289 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState341 _tok
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_271 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState341
        | Elpi_lexer_config.Tokens.IO _v ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos, _startpos, _v) in
            let _v = _menhir_action_082 c in
            _menhir_run_289 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState341 _tok
        | Elpi_lexer_config.Tokens.INDEX ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos) in
            let _v = _menhir_action_081 () in
            _menhir_run_289 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState341 _tok
        | Elpi_lexer_config.Tokens.IF ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos) in
            let _v = _menhir_action_076 () in
            _menhir_run_289 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState341 _tok
        | Elpi_lexer_config.Tokens.FRESHUV ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos) in
            let _v = _menhir_action_086 () in
            _menhir_run_289 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState341 _tok
        | Elpi_lexer_config.Tokens.CUT ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos) in
            let _v = _menhir_action_083 () in
            _menhir_run_289 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState341 _tok
        | Elpi_lexer_config.Tokens.CONSTANT _v ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos, _startpos, _v) in
            let _v = _menhir_action_075 c in
            _menhir_run_289 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState341 _tok
        | Elpi_lexer_config.Tokens.BEFORE ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos) in
            let _v = _menhir_action_078 () in
            _menhir_run_289 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState341 _tok
        | Elpi_lexer_config.Tokens.AFTER ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos) in
            let _v = _menhir_action_079 () in
            _menhir_run_289 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState341 _tok
        | _ ->
            _eRR 341
    
    and _menhir_run_347 : type  ttv_stack. ttv_stack -> _ -> _ -> (ttv_stack, _menhir_box_program) _menhir_state -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_KIND (_menhir_stack, _menhir_s, _startpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.SIGMA ->
            let _startpos_0 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_0) in
            let _v = _menhir_action_085 () in
            _menhir_run_289 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState347 _tok
        | Elpi_lexer_config.Tokens.REPLACE ->
            let _startpos_1 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_1) in
            let _v = _menhir_action_080 () in
            _menhir_run_289 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState347 _tok
        | Elpi_lexer_config.Tokens.PI ->
            let _startpos_2 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_2) in
            let _v = _menhir_action_084 () in
            _menhir_run_289 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState347 _tok
        | Elpi_lexer_config.Tokens.NIL ->
            let _startpos_3 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_3) in
            let _v = _menhir_action_089 () in
            _menhir_run_289 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState347 _tok
        | Elpi_lexer_config.Tokens.NAME ->
            let _startpos_4 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_4) in
            let _v = _menhir_action_077 () in
            _menhir_run_289 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState347 _tok
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_271 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState347
        | Elpi_lexer_config.Tokens.IO _v ->
            let _startpos_5 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos, _startpos_5, _v) in
            let _v = _menhir_action_082 c in
            _menhir_run_289 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState347 _tok
        | Elpi_lexer_config.Tokens.INDEX ->
            let _startpos_6 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_6) in
            let _v = _menhir_action_081 () in
            _menhir_run_289 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState347 _tok
        | Elpi_lexer_config.Tokens.IF ->
            let _startpos_7 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_7) in
            let _v = _menhir_action_076 () in
            _menhir_run_289 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState347 _tok
        | Elpi_lexer_config.Tokens.FRESHUV ->
            let _startpos_8 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_8) in
            let _v = _menhir_action_086 () in
            _menhir_run_289 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState347 _tok
        | Elpi_lexer_config.Tokens.CUT ->
            let _startpos_9 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_9) in
            let _v = _menhir_action_083 () in
            _menhir_run_289 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState347 _tok
        | Elpi_lexer_config.Tokens.CONSTANT _v ->
            let _startpos_10 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos, _startpos_10, _v) in
            let _v = _menhir_action_075 c in
            _menhir_run_289 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState347 _tok
        | Elpi_lexer_config.Tokens.BEFORE ->
            let _startpos_11 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_11) in
            let _v = _menhir_action_078 () in
            _menhir_run_289 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState347 _tok
        | Elpi_lexer_config.Tokens.AFTER ->
            let _startpos_12 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_12) in
            let _v = _menhir_action_079 () in
            _menhir_run_289 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState347 _tok
        | _ ->
            _eRR 347
    
    and _menhir_run_354 : type  ttv_stack. ttv_stack -> _ -> _ -> _ -> (ttv_stack, _menhir_box_program) _menhir_state -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_FIXITY (_menhir_stack, _menhir_s, _v, _startpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.VDASH ->
            let _startpos_0 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_0) in
            let _v = _menhir_action_201 () in
            _menhir_run_355 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v _tok
        | Elpi_lexer_config.Tokens.SLASH ->
            let _startpos_2 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_2) in
            let _v = _menhir_action_198 () in
            _menhir_run_355 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v _tok
        | Elpi_lexer_config.Tokens.SIGMA ->
            let _startpos_4 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_4) in
            let _v = _menhir_action_085 () in
            _menhir_run_357 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v _tok
        | Elpi_lexer_config.Tokens.REPLACE ->
            let _startpos_6 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_6) in
            let _v = _menhir_action_080 () in
            _menhir_run_357 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v _tok
        | Elpi_lexer_config.Tokens.QDASH ->
            let _startpos_8 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_8) in
            let _v = _menhir_action_197 () in
            _menhir_run_355 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v _tok
        | Elpi_lexer_config.Tokens.PI ->
            let _startpos_10 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_10) in
            let _v = _menhir_action_084 () in
            _menhir_run_357 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v _tok
        | Elpi_lexer_config.Tokens.OR ->
            let _startpos_12 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_12) in
            let _v = _menhir_action_191 () in
            _menhir_run_355 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v _tok
        | Elpi_lexer_config.Tokens.NIL ->
            let _startpos_14 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_14) in
            let _v = _menhir_action_089 () in
            _menhir_run_357 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v _tok
        | Elpi_lexer_config.Tokens.NAME ->
            let _startpos_16 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_16) in
            let _v = _menhir_action_077 () in
            _menhir_run_357 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v _tok
        | Elpi_lexer_config.Tokens.MOD ->
            let _startpos_18 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_18) in
            let _v = _menhir_action_193 () in
            _menhir_run_355 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v _tok
        | Elpi_lexer_config.Tokens.MINUSs ->
            let _startpos_20 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_20) in
            let _v = _menhir_action_189 () in
            _menhir_run_355 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v _tok
        | Elpi_lexer_config.Tokens.MINUSr ->
            let _startpos_22 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_22) in
            let _v = _menhir_action_187 () in
            _menhir_run_355 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v _tok
        | Elpi_lexer_config.Tokens.MINUSi ->
            let _startpos_24 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_24) in
            let _v = _menhir_action_188 () in
            _menhir_run_355 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v _tok
        | Elpi_lexer_config.Tokens.MINUS ->
            let _startpos_26 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_26) in
            let _v = _menhir_action_186 () in
            _menhir_run_355 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v _tok
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_271 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState354
        | Elpi_lexer_config.Tokens.IS ->
            let _startpos_28 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_28) in
            let _v = _menhir_action_192 () in
            _menhir_run_355 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v _tok
        | Elpi_lexer_config.Tokens.IO _v_30 ->
            let _startpos_31 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos, _startpos_31, _v_30) in
            let _v = _menhir_action_082 c in
            _menhir_run_357 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v _tok
        | Elpi_lexer_config.Tokens.INDEX ->
            let _startpos_33 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_33) in
            let _v = _menhir_action_081 () in
            _menhir_run_357 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v _tok
        | Elpi_lexer_config.Tokens.IF ->
            let _startpos_35 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_35) in
            let _v = _menhir_action_076 () in
            _menhir_run_357 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v _tok
        | Elpi_lexer_config.Tokens.FRESHUV ->
            let _startpos_37 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_37) in
            let _v = _menhir_action_086 () in
            _menhir_run_357 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_TIMES _v_39 ->
            let _startpos_40 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_s_, _startpos_s_, s) = (_endpos, _startpos_40, _v_39) in
            let _v = _menhir_action_173 s in
            _menhir_run_355 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_s_ _startpos_s_ _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_TILDE _v_42 ->
            let _startpos_43 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_s_, _startpos_s_, s) = (_endpos, _startpos_43, _v_42) in
            let _v = _menhir_action_202 s in
            _menhir_run_355 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_s_ _startpos_s_ _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_TICK _v_45 ->
            let _startpos_46 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_s_, _startpos_s_, s) = (_endpos, _startpos_46, _v_45) in
            let _v = _menhir_action_183 s in
            _menhir_run_355 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_s_ _startpos_s_ _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_48 ->
            let _startpos_49 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_s_, _startpos_s_, s) = (_endpos, _startpos_49, _v_48) in
            let _v = _menhir_action_181 s in
            _menhir_run_355 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_s_ _startpos_s_ _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_51 ->
            let _startpos_52 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_s_, _startpos_s_, s) = (_endpos, _startpos_52, _v_51) in
            let _v = _menhir_action_203 s in
            _menhir_run_355 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_s_ _startpos_s_ _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_PLUS _v_54 ->
            let _startpos_55 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_s_, _startpos_s_, s) = (_endpos, _startpos_55, _v_54) in
            let _v = _menhir_action_172 s in
            _menhir_run_355 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_s_ _startpos_s_ _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_OR _v_57 ->
            let _startpos_58 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_s_, _startpos_s_, s) = (_endpos, _startpos_58, _v_57) in
            let _v = _menhir_action_180 s in
            _menhir_run_355 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_s_ _startpos_s_ _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_60 ->
            let _startpos_61 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_s_, _startpos_s_, s) = (_endpos, _startpos_61, _v_60) in
            let _v = _menhir_action_174 s in
            _menhir_run_355 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_s_ _startpos_s_ _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_LT _v_63 ->
            let _startpos_64 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_s_, _startpos_s_, s) = (_endpos, _startpos_64, _v_63) in
            let _v = _menhir_action_176 s in
            _menhir_run_355 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_s_ _startpos_s_ _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_GT _v_66 ->
            let _startpos_67 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_s_, _startpos_s_, s) = (_endpos, _startpos_67, _v_66) in
            let _v = _menhir_action_177 s in
            _menhir_run_355 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_s_ _startpos_s_ _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_EXP _v_69 ->
            let _startpos_70 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_s_, _startpos_s_, s) = (_endpos, _startpos_70, _v_69) in
            let _v = _menhir_action_175 s in
            _menhir_run_355 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_s_ _startpos_s_ _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v_72 ->
            let _startpos_73 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_s_, _startpos_s_, s) = (_endpos, _startpos_73, _v_72) in
            let _v = _menhir_action_178 s in
            _menhir_run_355 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_s_ _startpos_s_ _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_75 ->
            let _startpos_76 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_s_, _startpos_s_, s) = (_endpos, _startpos_76, _v_75) in
            let _v = _menhir_action_182 s in
            _menhir_run_355 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_s_ _startpos_s_ _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_AND _v_78 ->
            let _startpos_79 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_s_, _startpos_s_, s) = (_endpos, _startpos_79, _v_78) in
            let _v = _menhir_action_179 s in
            _menhir_run_355 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_s_ _startpos_s_ _v _tok
        | Elpi_lexer_config.Tokens.EQ2 ->
            let _startpos_81 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_81) in
            let _v = _menhir_action_190 () in
            _menhir_run_355 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v _tok
        | Elpi_lexer_config.Tokens.EQ ->
            let _startpos_83 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_83) in
            let _v = _menhir_action_185 () in
            _menhir_run_355 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v _tok
        | Elpi_lexer_config.Tokens.DIV ->
            let _startpos_85 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_85) in
            let _v = _menhir_action_194 () in
            _menhir_run_355 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v _tok
        | Elpi_lexer_config.Tokens.DARROW ->
            let _startpos_87 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_87) in
            let _v = _menhir_action_196 () in
            _menhir_run_355 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v _tok
        | Elpi_lexer_config.Tokens.CUT ->
            let _startpos_89 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_89) in
            let _v = _menhir_action_083 () in
            _menhir_run_357 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v _tok
        | Elpi_lexer_config.Tokens.CONSTANT _v_91 ->
            let _startpos_92 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos, _startpos_92, _v_91) in
            let _v = _menhir_action_075 c in
            _menhir_run_357 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v _tok
        | Elpi_lexer_config.Tokens.CONS ->
            let _startpos_94 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_94) in
            let _v = _menhir_action_184 () in
            _menhir_run_355 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v _tok
        | Elpi_lexer_config.Tokens.CONJ2 ->
            let _startpos_96 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_96) in
            let _v = _menhir_action_199 () in
            _menhir_run_355 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v _tok
        | Elpi_lexer_config.Tokens.CONJ ->
            let _startpos_98 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_98) in
            let _v = _menhir_action_200 () in
            _menhir_run_355 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v _tok
        | Elpi_lexer_config.Tokens.BEFORE ->
            let _startpos_100 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_100) in
            let _v = _menhir_action_078 () in
            _menhir_run_357 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v _tok
        | Elpi_lexer_config.Tokens.ARROW ->
            let _startpos_102 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_102) in
            let _v = _menhir_action_195 () in
            _menhir_run_355 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v _tok
        | Elpi_lexer_config.Tokens.AFTER ->
            let _startpos_104 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_104) in
            let _v = _menhir_action_079 () in
            _menhir_run_357 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v _tok
        | _ ->
            _eRR 354
    
    and _menhir_run_357 : type  ttv_stack. (ttv_stack, _menhir_box_program) _menhir_cell1_FIXITY -> _ -> _ -> _ -> _ -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.INTEGER _v_0 ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let MenhirCell1_FIXITY (_menhir_stack, _menhir_s, f, _startpos_f_) = _menhir_stack in
            let (_endpos_c_, _startpos_c_, c, i) = (_endpos, _startpos, _v, _v_0) in
            let _v = _menhir_action_109 _endpos_c_ _startpos_c_ c f i in
            _menhir_goto_fixity _menhir_stack _menhir_lexbuf _menhir_lexer _startpos_f_ _v _menhir_s _tok
        | _ ->
            _eRR 357
    
    and _menhir_run_420 : type  ttv_stack. ttv_stack -> _ -> _ -> _ -> _ -> _ -> (ttv_stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_attributes (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.TYPE ->
            let _startpos_0 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_1 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell1_TYPE (_menhir_stack, MenhirState420, _startpos_0, _endpos_1) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Elpi_lexer_config.Tokens.SIGMA ->
                let _startpos_2 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_3 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_3, _startpos_2) in
                let _v = _menhir_action_085 () in
                _menhir_run_289 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState421 _tok
            | Elpi_lexer_config.Tokens.REPLACE ->
                let _startpos_5 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_6 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_6, _startpos_5) in
                let _v = _menhir_action_080 () in
                _menhir_run_289 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState421 _tok
            | Elpi_lexer_config.Tokens.PI ->
                let _startpos_8 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_9 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_9, _startpos_8) in
                let _v = _menhir_action_084 () in
                _menhir_run_289 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState421 _tok
            | Elpi_lexer_config.Tokens.NIL ->
                let _startpos_11 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_12 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_12, _startpos_11) in
                let _v = _menhir_action_089 () in
                _menhir_run_289 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState421 _tok
            | Elpi_lexer_config.Tokens.NAME ->
                let _startpos_14 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_15 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_15, _startpos_14) in
                let _v = _menhir_action_077 () in
                _menhir_run_289 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState421 _tok
            | Elpi_lexer_config.Tokens.LPAREN ->
                _menhir_run_271 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState421
            | Elpi_lexer_config.Tokens.IO _v_17 ->
                let _startpos_18 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_19 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_c_, _startpos_c_, c) = (_endpos_19, _startpos_18, _v_17) in
                let _v = _menhir_action_082 c in
                _menhir_run_289 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState421 _tok
            | Elpi_lexer_config.Tokens.INDEX ->
                let _startpos_21 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_22 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_22, _startpos_21) in
                let _v = _menhir_action_081 () in
                _menhir_run_289 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState421 _tok
            | Elpi_lexer_config.Tokens.IF ->
                let _startpos_24 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_25 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_25, _startpos_24) in
                let _v = _menhir_action_076 () in
                _menhir_run_289 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState421 _tok
            | Elpi_lexer_config.Tokens.FRESHUV ->
                let _startpos_27 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_28 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_28, _startpos_27) in
                let _v = _menhir_action_086 () in
                _menhir_run_289 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState421 _tok
            | Elpi_lexer_config.Tokens.CUT ->
                let _startpos_30 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_31 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_31, _startpos_30) in
                let _v = _menhir_action_083 () in
                _menhir_run_289 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState421 _tok
            | Elpi_lexer_config.Tokens.CONSTANT _v_33 ->
                let _startpos_34 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_35 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_c_, _startpos_c_, c) = (_endpos_35, _startpos_34, _v_33) in
                let _v = _menhir_action_075 c in
                _menhir_run_289 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState421 _tok
            | Elpi_lexer_config.Tokens.BEFORE ->
                let _startpos_37 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_38 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_38, _startpos_37) in
                let _v = _menhir_action_078 () in
                _menhir_run_289 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState421 _tok
            | Elpi_lexer_config.Tokens.AFTER ->
                let _startpos_40 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_41 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_41, _startpos_40) in
                let _v = _menhir_action_079 () in
                _menhir_run_289 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState421 _tok
            | _ ->
                _eRR 421)
        | Elpi_lexer_config.Tokens.SIGMA ->
            let _startpos_43 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_44 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_44, _startpos_43) in
            let _v = _menhir_action_085 () in
            _menhir_run_463 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState420 _tok
        | Elpi_lexer_config.Tokens.RULE ->
            let _startpos_46 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_47 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell1_RULE (_menhir_stack, MenhirState420, _startpos_46) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Elpi_lexer_config.Tokens.STRING _v_48 ->
                let _endpos_50 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, x) = (_endpos_50, _v_48) in
                let _v = _menhir_action_068 x in
                _menhir_run_432_spec_424 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.SIGMA ->
                let _endpos_53 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let _endpos__1_ = _endpos_53 in
                let _v = _menhir_action_085 () in
                _menhir_run_048_spec_424 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _v _tok
            | Elpi_lexer_config.Tokens.REPLACE ->
                let _endpos_56 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let _endpos__1_ = _endpos_56 in
                let _v = _menhir_action_080 () in
                _menhir_run_048_spec_424 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _v _tok
            | Elpi_lexer_config.Tokens.QUOTED _v_58 ->
                let _startpos_59 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_60 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_60, _startpos_59, _v_58) in
                let _v = _menhir_action_069 _endpos_x_ _startpos_x_ x in
                _menhir_run_432_spec_424 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.PI ->
                let _endpos_63 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let _endpos__1_ = _endpos_63 in
                let _v = _menhir_action_084 () in
                _menhir_run_048_spec_424 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _v _tok
            | Elpi_lexer_config.Tokens.NIL ->
                let _endpos_66 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let _endpos__1_ = _endpos_66 in
                let _v = _menhir_action_089 () in
                _menhir_run_048_spec_424 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _v _tok
            | Elpi_lexer_config.Tokens.NAME ->
                let _endpos_69 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let _endpos__1_ = _endpos_69 in
                let _v = _menhir_action_077 () in
                _menhir_run_048_spec_424 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _v _tok
            | Elpi_lexer_config.Tokens.LPAREN ->
                _menhir_run_425 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState424
            | Elpi_lexer_config.Tokens.LCURLY ->
                _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState424
            | Elpi_lexer_config.Tokens.LBRACKET ->
                _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState424
            | Elpi_lexer_config.Tokens.IO _v_71 ->
                let _endpos_73 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_c_, c) = (_endpos_73, _v_71) in
                let _v = _menhir_action_082 c in
                _menhir_run_048_spec_424 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _v _tok
            | Elpi_lexer_config.Tokens.INTEGER _v_75 ->
                let _endpos_77 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, x) = (_endpos_77, _v_75) in
                let _v = _menhir_action_066 x in
                _menhir_run_432_spec_424 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.INDEX ->
                let _endpos_80 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let _endpos__1_ = _endpos_80 in
                let _v = _menhir_action_081 () in
                _menhir_run_048_spec_424 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _v _tok
            | Elpi_lexer_config.Tokens.IF ->
                let _endpos_83 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let _endpos__1_ = _endpos_83 in
                let _v = _menhir_action_076 () in
                _menhir_run_048_spec_424 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _v _tok
            | Elpi_lexer_config.Tokens.FRESHUV ->
                let _endpos_86 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let _endpos__1_ = _endpos_86 in
                let _v = _menhir_action_086 () in
                _menhir_run_048_spec_424 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _v _tok
            | Elpi_lexer_config.Tokens.FLOAT _v_88 ->
                let _endpos_90 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, x) = (_endpos_90, _v_88) in
                let _v = _menhir_action_067 x in
                _menhir_run_432_spec_424 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.CUT ->
                let _endpos_93 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let _endpos__1_ = _endpos_93 in
                let _v = _menhir_action_083 () in
                _menhir_run_048_spec_424 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _v _tok
            | Elpi_lexer_config.Tokens.CONSTANT _v_95 ->
                let _endpos_97 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_c_, c) = (_endpos_97, _v_95) in
                let _v = _menhir_action_075 c in
                _menhir_run_048_spec_424 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _v _tok
            | Elpi_lexer_config.Tokens.BEFORE ->
                let _endpos_100 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let _endpos__1_ = _endpos_100 in
                let _v = _menhir_action_078 () in
                _menhir_run_048_spec_424 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _v _tok
            | Elpi_lexer_config.Tokens.AFTER ->
                let _endpos_103 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let _endpos__1_ = _endpos_103 in
                let _v = _menhir_action_079 () in
                _menhir_run_048_spec_424 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _v _tok
            | Elpi_lexer_config.Tokens.BIND | Elpi_lexer_config.Tokens.FULLSTOP | Elpi_lexer_config.Tokens.IFF | Elpi_lexer_config.Tokens.PIPE ->
                let _endpos = _endpos_47 in
                let _v = _menhir_action_161 () in
                _menhir_run_433 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v MenhirState424 _tok
            | _ ->
                _eRR 424)
        | Elpi_lexer_config.Tokens.REPLACE ->
            let _startpos_106 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_107 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_107, _startpos_106) in
            let _v = _menhir_action_080 () in
            _menhir_run_463 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState420 _tok
        | Elpi_lexer_config.Tokens.PRED ->
            let _startpos_109 = _menhir_lexbuf.Lexing.lex_start_p in
            let _menhir_stack = MenhirCell1_PRED (_menhir_stack, MenhirState420, _startpos_109) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Elpi_lexer_config.Tokens.SIGMA ->
                let _startpos_110 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_111 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_111, _startpos_110) in
                let _v = _menhir_action_085 () in
                _menhir_run_446 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState445 _tok
            | Elpi_lexer_config.Tokens.REPLACE ->
                let _startpos_113 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_114 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_114, _startpos_113) in
                let _v = _menhir_action_080 () in
                _menhir_run_446 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState445 _tok
            | Elpi_lexer_config.Tokens.PI ->
                let _startpos_116 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_117 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_117, _startpos_116) in
                let _v = _menhir_action_084 () in
                _menhir_run_446 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState445 _tok
            | Elpi_lexer_config.Tokens.NIL ->
                let _startpos_119 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_120 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_120, _startpos_119) in
                let _v = _menhir_action_089 () in
                _menhir_run_446 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState445 _tok
            | Elpi_lexer_config.Tokens.NAME ->
                let _startpos_122 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_123 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_123, _startpos_122) in
                let _v = _menhir_action_077 () in
                _menhir_run_446 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState445 _tok
            | Elpi_lexer_config.Tokens.LPAREN ->
                _menhir_run_271 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState445
            | Elpi_lexer_config.Tokens.IO _v_125 ->
                let _startpos_126 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_127 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_c_, _startpos_c_, c) = (_endpos_127, _startpos_126, _v_125) in
                let _v = _menhir_action_082 c in
                _menhir_run_446 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState445 _tok
            | Elpi_lexer_config.Tokens.INDEX ->
                let _startpos_129 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_130 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_130, _startpos_129) in
                let _v = _menhir_action_081 () in
                _menhir_run_446 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState445 _tok
            | Elpi_lexer_config.Tokens.IF ->
                let _startpos_132 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_133 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_133, _startpos_132) in
                let _v = _menhir_action_076 () in
                _menhir_run_446 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState445 _tok
            | Elpi_lexer_config.Tokens.FRESHUV ->
                let _startpos_135 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_136 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_136, _startpos_135) in
                let _v = _menhir_action_086 () in
                _menhir_run_446 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState445 _tok
            | Elpi_lexer_config.Tokens.CUT ->
                let _startpos_138 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_139 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_139, _startpos_138) in
                let _v = _menhir_action_083 () in
                _menhir_run_446 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState445 _tok
            | Elpi_lexer_config.Tokens.CONSTANT _v_141 ->
                let _startpos_142 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_143 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_c_, _startpos_c_, c) = (_endpos_143, _startpos_142, _v_141) in
                let _v = _menhir_action_075 c in
                _menhir_run_446 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState445 _tok
            | Elpi_lexer_config.Tokens.BEFORE ->
                let _startpos_145 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_146 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_146, _startpos_145) in
                let _v = _menhir_action_078 () in
                _menhir_run_446 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState445 _tok
            | Elpi_lexer_config.Tokens.AFTER ->
                let _startpos_148 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_149 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_149, _startpos_148) in
                let _v = _menhir_action_079 () in
                _menhir_run_446 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState445 _tok
            | _ ->
                _eRR 445)
        | Elpi_lexer_config.Tokens.PI ->
            let _startpos_151 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_152 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_152, _startpos_151) in
            let _v = _menhir_action_084 () in
            _menhir_run_463 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState420 _tok
        | Elpi_lexer_config.Tokens.NIL ->
            let _startpos_154 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_155 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_155, _startpos_154) in
            let _v = _menhir_action_089 () in
            _menhir_run_463 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState420 _tok
        | Elpi_lexer_config.Tokens.NAME ->
            let _startpos_157 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_158 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_158, _startpos_157) in
            let _v = _menhir_action_077 () in
            _menhir_run_463 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState420 _tok
        | Elpi_lexer_config.Tokens.LPAREN ->
            let _startpos_160 = _menhir_lexbuf.Lexing.lex_start_p in
            let _menhir_stack = MenhirCell1_LPAREN (_menhir_stack, MenhirState420, _startpos_160) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Elpi_lexer_config.Tokens.VDASH ->
                let _tok = _menhir_lexer _menhir_lexbuf in
                let _v = _menhir_action_201 () in
                _menhir_run_224 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
            | Elpi_lexer_config.Tokens.STRING _v_164 ->
                let _startpos_165 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_166 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_166, _startpos_165, _v_164) in
                let _v = _menhir_action_068 x in
                _menhir_run_053_spec_455 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.SLASH ->
                let _tok = _menhir_lexer _menhir_lexbuf in
                let _v = _menhir_action_198 () in
                _menhir_run_224 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
            | Elpi_lexer_config.Tokens.SIGMA ->
                let _startpos_171 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_172 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_172, _startpos_171) in
                let _v = _menhir_action_085 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState455 _tok
            | Elpi_lexer_config.Tokens.REPLACE ->
                let _startpos_174 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_175 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_175, _startpos_174) in
                let _v = _menhir_action_080 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState455 _tok
            | Elpi_lexer_config.Tokens.QUOTED _v_177 ->
                let _startpos_178 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_179 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_179, _startpos_178, _v_177) in
                let _v = _menhir_action_069 _endpos_x_ _startpos_x_ x in
                _menhir_run_053_spec_455 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.QDASH ->
                let _tok = _menhir_lexer _menhir_lexbuf in
                let _v = _menhir_action_197 () in
                _menhir_run_224 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
            | Elpi_lexer_config.Tokens.PI ->
                let _startpos_184 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_185 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_185, _startpos_184) in
                let _v = _menhir_action_084 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState455 _tok
            | Elpi_lexer_config.Tokens.OR ->
                let _tok = _menhir_lexer _menhir_lexbuf in
                let _v = _menhir_action_191 () in
                _menhir_run_224 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
            | Elpi_lexer_config.Tokens.NIL ->
                let _startpos_190 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_191 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_191, _startpos_190) in
                let _v = _menhir_action_089 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState455 _tok
            | Elpi_lexer_config.Tokens.NAME ->
                let _startpos_193 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_194 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_194, _startpos_193) in
                let _v = _menhir_action_077 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState455 _tok
            | Elpi_lexer_config.Tokens.MOD ->
                let _tok = _menhir_lexer _menhir_lexbuf in
                let _v = _menhir_action_193 () in
                _menhir_run_224 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
            | Elpi_lexer_config.Tokens.MINUSs ->
                let _tok = _menhir_lexer _menhir_lexbuf in
                let _v = _menhir_action_189 () in
                _menhir_run_224 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
            | Elpi_lexer_config.Tokens.MINUSr ->
                let _tok = _menhir_lexer _menhir_lexbuf in
                let _v = _menhir_action_187 () in
                _menhir_run_224 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
            | Elpi_lexer_config.Tokens.MINUSi ->
                let _tok = _menhir_lexer _menhir_lexbuf in
                let _v = _menhir_action_188 () in
                _menhir_run_224 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
            | Elpi_lexer_config.Tokens.MINUS ->
                let _tok = _menhir_lexer _menhir_lexbuf in
                let _v = _menhir_action_186 () in
                _menhir_run_224 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
            | Elpi_lexer_config.Tokens.LPAREN ->
                _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState455
            | Elpi_lexer_config.Tokens.LCURLY ->
                _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState455
            | Elpi_lexer_config.Tokens.LBRACKET ->
                _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState455
            | Elpi_lexer_config.Tokens.IS ->
                let _tok = _menhir_lexer _menhir_lexbuf in
                let _v = _menhir_action_192 () in
                _menhir_run_224 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
            | Elpi_lexer_config.Tokens.IO _v_214 ->
                let _startpos_215 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_216 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_c_, _startpos_c_, c) = (_endpos_216, _startpos_215, _v_214) in
                let _v = _menhir_action_082 c in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState455 _tok
            | Elpi_lexer_config.Tokens.INTEGER _v_218 ->
                let _startpos_219 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_220 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_220, _startpos_219, _v_218) in
                let _v = _menhir_action_066 x in
                _menhir_run_053_spec_455 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.INDEX ->
                let _startpos_222 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_223 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_223, _startpos_222) in
                let _v = _menhir_action_081 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState455 _tok
            | Elpi_lexer_config.Tokens.IF ->
                let _startpos_225 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_226 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_226, _startpos_225) in
                let _v = _menhir_action_076 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState455 _tok
            | Elpi_lexer_config.Tokens.FRESHUV ->
                let _startpos_228 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_229 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_229, _startpos_228) in
                let _v = _menhir_action_086 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState455 _tok
            | Elpi_lexer_config.Tokens.FLOAT _v_231 ->
                let _startpos_232 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_233 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_233, _startpos_232, _v_231) in
                let _v = _menhir_action_067 x in
                _menhir_run_053_spec_455 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.FAMILY_TIMES _v_235 ->
                let _tok = _menhir_lexer _menhir_lexbuf in
                let s = _v_235 in
                let _v = _menhir_action_173 s in
                _menhir_run_224 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
            | Elpi_lexer_config.Tokens.FAMILY_TILDE _v_239 ->
                _menhir_run_196 _menhir_stack _menhir_lexbuf _menhir_lexer _v_239 MenhirState455
            | Elpi_lexer_config.Tokens.FAMILY_TICK _v_240 ->
                let _tok = _menhir_lexer _menhir_lexbuf in
                let s = _v_240 in
                let _v = _menhir_action_183 s in
                _menhir_run_224 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
            | Elpi_lexer_config.Tokens.FAMILY_SHARP _v_244 ->
                let _tok = _menhir_lexer _menhir_lexbuf in
                let s = _v_244 in
                let _v = _menhir_action_181 s in
                _menhir_run_224 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
            | Elpi_lexer_config.Tokens.FAMILY_QMARK _v_248 ->
                let _tok = _menhir_lexer _menhir_lexbuf in
                let s = _v_248 in
                let _v = _menhir_action_203 s in
                _menhir_run_224 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
            | Elpi_lexer_config.Tokens.FAMILY_PLUS _v_252 ->
                let _tok = _menhir_lexer _menhir_lexbuf in
                let s = _v_252 in
                let _v = _menhir_action_172 s in
                _menhir_run_224 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
            | Elpi_lexer_config.Tokens.FAMILY_OR _v_256 ->
                let _tok = _menhir_lexer _menhir_lexbuf in
                let s = _v_256 in
                let _v = _menhir_action_180 s in
                _menhir_run_224 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
            | Elpi_lexer_config.Tokens.FAMILY_MINUS _v_260 ->
                let _tok = _menhir_lexer _menhir_lexbuf in
                let s = _v_260 in
                let _v = _menhir_action_174 s in
                _menhir_run_224 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
            | Elpi_lexer_config.Tokens.FAMILY_LT _v_264 ->
                let _tok = _menhir_lexer _menhir_lexbuf in
                let s = _v_264 in
                let _v = _menhir_action_176 s in
                _menhir_run_224 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
            | Elpi_lexer_config.Tokens.FAMILY_GT _v_268 ->
                let _tok = _menhir_lexer _menhir_lexbuf in
                let s = _v_268 in
                let _v = _menhir_action_177 s in
                _menhir_run_224 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
            | Elpi_lexer_config.Tokens.FAMILY_EXP _v_272 ->
                let _tok = _menhir_lexer _menhir_lexbuf in
                let s = _v_272 in
                let _v = _menhir_action_175 s in
                _menhir_run_224 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
            | Elpi_lexer_config.Tokens.FAMILY_EQ _v_276 ->
                let _tok = _menhir_lexer _menhir_lexbuf in
                let s = _v_276 in
                let _v = _menhir_action_178 s in
                _menhir_run_224 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
            | Elpi_lexer_config.Tokens.FAMILY_BTICK _v_280 ->
                let _tok = _menhir_lexer _menhir_lexbuf in
                let s = _v_280 in
                let _v = _menhir_action_182 s in
                _menhir_run_224 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
            | Elpi_lexer_config.Tokens.FAMILY_AND _v_284 ->
                let _tok = _menhir_lexer _menhir_lexbuf in
                let s = _v_284 in
                let _v = _menhir_action_179 s in
                _menhir_run_224 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
            | Elpi_lexer_config.Tokens.EQ2 ->
                let _tok = _menhir_lexer _menhir_lexbuf in
                let _v = _menhir_action_190 () in
                _menhir_run_224 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
            | Elpi_lexer_config.Tokens.EQ ->
                let _tok = _menhir_lexer _menhir_lexbuf in
                let _v = _menhir_action_185 () in
                _menhir_run_224 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
            | Elpi_lexer_config.Tokens.DIV ->
                let _tok = _menhir_lexer _menhir_lexbuf in
                let _v = _menhir_action_194 () in
                _menhir_run_224 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
            | Elpi_lexer_config.Tokens.DARROW ->
                let _tok = _menhir_lexer _menhir_lexbuf in
                let _v = _menhir_action_196 () in
                _menhir_run_224 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
            | Elpi_lexer_config.Tokens.CUT ->
                let _startpos_300 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_301 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_301, _startpos_300) in
                let _v = _menhir_action_083 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState455 _tok
            | Elpi_lexer_config.Tokens.CONSTANT _v_303 ->
                let _startpos_304 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_305 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_c_, _startpos_c_, c) = (_endpos_305, _startpos_304, _v_303) in
                let _v = _menhir_action_075 c in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState455 _tok
            | Elpi_lexer_config.Tokens.CONS ->
                let _tok = _menhir_lexer _menhir_lexbuf in
                let _v = _menhir_action_184 () in
                _menhir_run_224 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
            | Elpi_lexer_config.Tokens.CONJ2 ->
                let _tok = _menhir_lexer _menhir_lexbuf in
                let _v = _menhir_action_199 () in
                _menhir_run_224 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
            | Elpi_lexer_config.Tokens.CONJ ->
                let _tok = _menhir_lexer _menhir_lexbuf in
                let _v = _menhir_action_200 () in
                _menhir_run_224 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
            | Elpi_lexer_config.Tokens.BEFORE ->
                let _startpos_316 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_317 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_317, _startpos_316) in
                let _v = _menhir_action_078 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState455 _tok
            | Elpi_lexer_config.Tokens.AS ->
                _menhir_run_216 _menhir_stack _menhir_lexbuf _menhir_lexer
            | Elpi_lexer_config.Tokens.ARROW ->
                let _tok = _menhir_lexer _menhir_lexbuf in
                let _v = _menhir_action_195 () in
                _menhir_run_224 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
            | Elpi_lexer_config.Tokens.AFTER ->
                let _startpos_322 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_323 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_323, _startpos_322) in
                let _v = _menhir_action_079 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState455 _tok
            | _ ->
                _eRR 455)
        | Elpi_lexer_config.Tokens.IO _v_325 ->
            let _startpos_326 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_327 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_327, _startpos_326, _v_325) in
            let _v = _menhir_action_082 c in
            _menhir_run_463 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState420 _tok
        | Elpi_lexer_config.Tokens.INDEX ->
            let _startpos_329 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_330 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_330, _startpos_329) in
            let _v = _menhir_action_081 () in
            _menhir_run_463 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState420 _tok
        | Elpi_lexer_config.Tokens.IF ->
            let _startpos_332 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_333 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_333, _startpos_332) in
            let _v = _menhir_action_076 () in
            _menhir_run_463 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState420 _tok
        | Elpi_lexer_config.Tokens.FRESHUV ->
            let _startpos_335 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_336 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_336, _startpos_335) in
            let _v = _menhir_action_086 () in
            _menhir_run_463 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState420 _tok
        | Elpi_lexer_config.Tokens.FAMILY_TILDE _v_338 ->
            let _startpos_339 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_340 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell1_FAMILY_TILDE (_menhir_stack, MenhirState420, _v_338, _startpos_339, _endpos_340) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Elpi_lexer_config.Tokens.STRING _v_341 ->
                let _startpos_342 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_343 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_343, _startpos_342, _v_341) in
                let _v = _menhir_action_068 x in
                _menhir_run_053_spec_458 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.SIGMA ->
                let _startpos_345 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_346 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_346, _startpos_345) in
                let _v = _menhir_action_085 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState458 _tok
            | Elpi_lexer_config.Tokens.REPLACE ->
                let _startpos_348 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_349 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_349, _startpos_348) in
                let _v = _menhir_action_080 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState458 _tok
            | Elpi_lexer_config.Tokens.QUOTED _v_351 ->
                let _startpos_352 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_353 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_353, _startpos_352, _v_351) in
                let _v = _menhir_action_069 _endpos_x_ _startpos_x_ x in
                _menhir_run_053_spec_458 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.PI ->
                let _startpos_355 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_356 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_356, _startpos_355) in
                let _v = _menhir_action_084 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState458 _tok
            | Elpi_lexer_config.Tokens.NIL ->
                let _startpos_358 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_359 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_359, _startpos_358) in
                let _v = _menhir_action_089 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState458 _tok
            | Elpi_lexer_config.Tokens.NAME ->
                let _startpos_361 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_362 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_362, _startpos_361) in
                let _v = _menhir_action_077 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState458 _tok
            | Elpi_lexer_config.Tokens.LPAREN ->
                _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState458
            | Elpi_lexer_config.Tokens.LCURLY ->
                _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState458
            | Elpi_lexer_config.Tokens.LBRACKET ->
                _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState458
            | Elpi_lexer_config.Tokens.IO _v_364 ->
                let _startpos_365 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_366 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_c_, _startpos_c_, c) = (_endpos_366, _startpos_365, _v_364) in
                let _v = _menhir_action_082 c in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState458 _tok
            | Elpi_lexer_config.Tokens.INTEGER _v_368 ->
                let _startpos_369 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_370 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_370, _startpos_369, _v_368) in
                let _v = _menhir_action_066 x in
                _menhir_run_053_spec_458 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.INDEX ->
                let _startpos_372 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_373 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_373, _startpos_372) in
                let _v = _menhir_action_081 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState458 _tok
            | Elpi_lexer_config.Tokens.IF ->
                let _startpos_375 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_376 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_376, _startpos_375) in
                let _v = _menhir_action_076 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState458 _tok
            | Elpi_lexer_config.Tokens.FRESHUV ->
                let _startpos_378 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_379 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_379, _startpos_378) in
                let _v = _menhir_action_086 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState458 _tok
            | Elpi_lexer_config.Tokens.FLOAT _v_381 ->
                let _startpos_382 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_383 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_x_, _startpos_x_, x) = (_endpos_383, _startpos_382, _v_381) in
                let _v = _menhir_action_067 x in
                _menhir_run_053_spec_458 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
            | Elpi_lexer_config.Tokens.FAMILY_TILDE _v_385 ->
                _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer _v_385 MenhirState458
            | Elpi_lexer_config.Tokens.CUT ->
                let _startpos_386 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_387 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_387, _startpos_386) in
                let _v = _menhir_action_083 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState458 _tok
            | Elpi_lexer_config.Tokens.CONSTANT _v_389 ->
                let _startpos_390 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_391 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos_c_, _startpos_c_, c) = (_endpos_391, _startpos_390, _v_389) in
                let _v = _menhir_action_075 c in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState458 _tok
            | Elpi_lexer_config.Tokens.BEFORE ->
                let _startpos_393 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_394 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_394, _startpos_393) in
                let _v = _menhir_action_078 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState458 _tok
            | Elpi_lexer_config.Tokens.AFTER ->
                let _startpos_396 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_397 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__1_, _startpos__1_) = (_endpos_397, _startpos_396) in
                let _v = _menhir_action_079 () in
                _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState458 _tok
            | _ ->
                _eRR 458)
        | Elpi_lexer_config.Tokens.CUT ->
            let _startpos_399 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_400 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_400, _startpos_399) in
            let _v = _menhir_action_083 () in
            _menhir_run_463 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState420 _tok
        | Elpi_lexer_config.Tokens.CONSTANT _v_402 ->
            let _startpos_403 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_404 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_404, _startpos_403, _v_402) in
            let _v = _menhir_action_075 c in
            _menhir_run_463 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState420 _tok
        | Elpi_lexer_config.Tokens.BEFORE ->
            let _startpos_406 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_407 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_407, _startpos_406) in
            let _v = _menhir_action_078 () in
            _menhir_run_463 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState420 _tok
        | Elpi_lexer_config.Tokens.AFTER ->
            let _startpos_409 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_410 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_410, _startpos_409) in
            let _v = _menhir_action_079 () in
            _menhir_run_463 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState420 _tok
        | _ ->
            _eRR 420
    
    and _menhir_run_463 : type  ttv_stack. ((ttv_stack, _menhir_box_program) _menhir_cell1_attributes as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.ARROW | Elpi_lexer_config.Tokens.CONJ | Elpi_lexer_config.Tokens.CONJ2 | Elpi_lexer_config.Tokens.CONS | Elpi_lexer_config.Tokens.DARROW | Elpi_lexer_config.Tokens.DIV | Elpi_lexer_config.Tokens.EQ | Elpi_lexer_config.Tokens.EQ2 | Elpi_lexer_config.Tokens.FAMILY_AND _ | Elpi_lexer_config.Tokens.FAMILY_BTICK _ | Elpi_lexer_config.Tokens.FAMILY_EQ _ | Elpi_lexer_config.Tokens.FAMILY_EXP _ | Elpi_lexer_config.Tokens.FAMILY_GT _ | Elpi_lexer_config.Tokens.FAMILY_LT _ | Elpi_lexer_config.Tokens.FAMILY_MINUS _ | Elpi_lexer_config.Tokens.FAMILY_OR _ | Elpi_lexer_config.Tokens.FAMILY_PLUS _ | Elpi_lexer_config.Tokens.FAMILY_QMARK _ | Elpi_lexer_config.Tokens.FAMILY_SHARP _ | Elpi_lexer_config.Tokens.FAMILY_TICK _ | Elpi_lexer_config.Tokens.FAMILY_TIMES _ | Elpi_lexer_config.Tokens.FULLSTOP | Elpi_lexer_config.Tokens.IS | Elpi_lexer_config.Tokens.MINUS | Elpi_lexer_config.Tokens.MINUSi | Elpi_lexer_config.Tokens.MINUSr | Elpi_lexer_config.Tokens.MINUSs | Elpi_lexer_config.Tokens.MOD | Elpi_lexer_config.Tokens.OR | Elpi_lexer_config.Tokens.QDASH | Elpi_lexer_config.Tokens.SLASH | Elpi_lexer_config.Tokens.VDASH ->
            let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
            let _v = _menhir_action_030 t in
            _menhir_goto_clause_hd_closed_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v _menhir_s _tok
        | Elpi_lexer_config.Tokens.AFTER | Elpi_lexer_config.Tokens.BEFORE | Elpi_lexer_config.Tokens.CONSTANT _ | Elpi_lexer_config.Tokens.CUT | Elpi_lexer_config.Tokens.FLOAT _ | Elpi_lexer_config.Tokens.FRESHUV | Elpi_lexer_config.Tokens.IF | Elpi_lexer_config.Tokens.INDEX | Elpi_lexer_config.Tokens.INTEGER _ | Elpi_lexer_config.Tokens.IO _ | Elpi_lexer_config.Tokens.LBRACKET | Elpi_lexer_config.Tokens.LCURLY | Elpi_lexer_config.Tokens.LPAREN | Elpi_lexer_config.Tokens.NAME | Elpi_lexer_config.Tokens.NIL | Elpi_lexer_config.Tokens.PI | Elpi_lexer_config.Tokens.QUOTED _ | Elpi_lexer_config.Tokens.REPLACE | Elpi_lexer_config.Tokens.SIGMA | Elpi_lexer_config.Tokens.STRING _ ->
            let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
            let _v = _menhir_action_113 t in
            _menhir_goto_head_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v _menhir_s _tok
        | _ ->
            _eRR 463
    
    and _menhir_run_048_spec_424 : type  ttv_stack. ((ttv_stack, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_RULE -> _ -> _ -> _ -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let (_endpos_t_, t) = (_endpos, _v) in
        let _v = _menhir_action_113 t in
        _menhir_run_047_spec_424 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _v _tok
    
    and _menhir_run_446 : type  ttv_stack. (((ttv_stack, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_PRED as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_constant (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.IO_COLON _v_0 ->
            _menhir_run_447 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0 MenhirState446
        | Elpi_lexer_config.Tokens.FULLSTOP ->
            let _v = _menhir_action_169 () in
            _menhir_run_454 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v
        | _ ->
            _eRR 446
    
    and _menhir_run_360 : type  ttv_stack. ttv_stack -> _ -> _ -> (ttv_stack, _menhir_box_program) _menhir_state -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_EXPORTDEF (_menhir_stack, _menhir_s, _startpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.SIGMA ->
            let _startpos_0 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_0) in
            let _v = _menhir_action_085 () in
            _menhir_run_289 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState360 _tok
        | Elpi_lexer_config.Tokens.REPLACE ->
            let _startpos_1 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_1) in
            let _v = _menhir_action_080 () in
            _menhir_run_289 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState360 _tok
        | Elpi_lexer_config.Tokens.PI ->
            let _startpos_2 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_2) in
            let _v = _menhir_action_084 () in
            _menhir_run_289 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState360 _tok
        | Elpi_lexer_config.Tokens.NIL ->
            let _startpos_3 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_3) in
            let _v = _menhir_action_089 () in
            _menhir_run_289 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState360 _tok
        | Elpi_lexer_config.Tokens.NAME ->
            let _startpos_4 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_4) in
            let _v = _menhir_action_077 () in
            _menhir_run_289 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState360 _tok
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_271 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState360
        | Elpi_lexer_config.Tokens.IO _v ->
            let _startpos_5 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos, _startpos_5, _v) in
            let _v = _menhir_action_082 c in
            _menhir_run_289 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState360 _tok
        | Elpi_lexer_config.Tokens.INDEX ->
            let _startpos_6 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_6) in
            let _v = _menhir_action_081 () in
            _menhir_run_289 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState360 _tok
        | Elpi_lexer_config.Tokens.IF ->
            let _startpos_7 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_7) in
            let _v = _menhir_action_076 () in
            _menhir_run_289 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState360 _tok
        | Elpi_lexer_config.Tokens.FRESHUV ->
            let _startpos_8 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_8) in
            let _v = _menhir_action_086 () in
            _menhir_run_289 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState360 _tok
        | Elpi_lexer_config.Tokens.CUT ->
            let _startpos_9 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_9) in
            let _v = _menhir_action_083 () in
            _menhir_run_289 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState360 _tok
        | Elpi_lexer_config.Tokens.CONSTANT _v ->
            let _startpos_10 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos, _startpos_10, _v) in
            let _v = _menhir_action_075 c in
            _menhir_run_289 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState360 _tok
        | Elpi_lexer_config.Tokens.BEFORE ->
            let _startpos_11 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_11) in
            let _v = _menhir_action_078 () in
            _menhir_run_289 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState360 _tok
        | Elpi_lexer_config.Tokens.AFTER ->
            let _startpos_12 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_12) in
            let _v = _menhir_action_079 () in
            _menhir_run_289 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState360 _tok
        | _ ->
            _eRR 360
    
    and _menhir_run_364 : type  ttv_stack. ttv_stack -> _ -> _ -> (ttv_stack, _menhir_box_program) _menhir_state -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_CONSTRAINT (_menhir_stack, _menhir_s, _startpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.SIGMA ->
            let _startpos_0 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_0) in
            let _v = _menhir_action_085 () in
            _menhir_run_367 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState364 _tok
        | Elpi_lexer_config.Tokens.REPLACE ->
            let _startpos_1 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_1) in
            let _v = _menhir_action_080 () in
            _menhir_run_367 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState364 _tok
        | Elpi_lexer_config.Tokens.PI ->
            let _startpos_2 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_2) in
            let _v = _menhir_action_084 () in
            _menhir_run_367 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState364 _tok
        | Elpi_lexer_config.Tokens.NIL ->
            let _startpos_3 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_3) in
            let _v = _menhir_action_089 () in
            _menhir_run_367 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState364 _tok
        | Elpi_lexer_config.Tokens.NAME ->
            let _startpos_4 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_4) in
            let _v = _menhir_action_077 () in
            _menhir_run_367 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState364 _tok
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_271 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState364
        | Elpi_lexer_config.Tokens.IO _v ->
            let _startpos_5 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos, _startpos_5, _v) in
            let _v = _menhir_action_082 c in
            _menhir_run_367 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState364 _tok
        | Elpi_lexer_config.Tokens.INDEX ->
            let _startpos_6 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_6) in
            let _v = _menhir_action_081 () in
            _menhir_run_367 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState364 _tok
        | Elpi_lexer_config.Tokens.IF ->
            let _startpos_7 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_7) in
            let _v = _menhir_action_076 () in
            _menhir_run_367 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState364 _tok
        | Elpi_lexer_config.Tokens.FRESHUV ->
            let _startpos_8 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_8) in
            let _v = _menhir_action_086 () in
            _menhir_run_367 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState364 _tok
        | Elpi_lexer_config.Tokens.CUT ->
            let _startpos_9 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_9) in
            let _v = _menhir_action_083 () in
            _menhir_run_367 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState364 _tok
        | Elpi_lexer_config.Tokens.CONSTANT _v ->
            let _startpos_10 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos, _startpos_10, _v) in
            let _v = _menhir_action_075 c in
            _menhir_run_367 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState364 _tok
        | Elpi_lexer_config.Tokens.BEFORE ->
            let _startpos_11 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_11) in
            let _v = _menhir_action_078 () in
            _menhir_run_367 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState364 _tok
        | Elpi_lexer_config.Tokens.AFTER ->
            let _startpos_12 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_12) in
            let _v = _menhir_action_079 () in
            _menhir_run_367 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState364 _tok
        | Elpi_lexer_config.Tokens.LCURLY ->
            let _v = _menhir_action_159 () in
            _menhir_run_365 _menhir_stack _menhir_lexbuf _menhir_lexer _v
        | _ ->
            _eRR 364
    
    and _menhir_run_367 : type  ttv_stack. ttv_stack -> _ -> _ -> _ -> _ -> _ -> (ttv_stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_constant (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.SIGMA ->
            let _startpos_0 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_1 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_1, _startpos_0) in
            let _v = _menhir_action_085 () in
            _menhir_run_367 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState367 _tok
        | Elpi_lexer_config.Tokens.REPLACE ->
            let _startpos_3 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_4 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_4, _startpos_3) in
            let _v = _menhir_action_080 () in
            _menhir_run_367 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState367 _tok
        | Elpi_lexer_config.Tokens.PI ->
            let _startpos_6 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_7 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_7, _startpos_6) in
            let _v = _menhir_action_084 () in
            _menhir_run_367 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState367 _tok
        | Elpi_lexer_config.Tokens.NIL ->
            let _startpos_9 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_10 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_10, _startpos_9) in
            let _v = _menhir_action_089 () in
            _menhir_run_367 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState367 _tok
        | Elpi_lexer_config.Tokens.NAME ->
            let _startpos_12 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_13 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_13, _startpos_12) in
            let _v = _menhir_action_077 () in
            _menhir_run_367 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState367 _tok
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_271 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState367
        | Elpi_lexer_config.Tokens.IO _v_15 ->
            let _startpos_16 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_17 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_17, _startpos_16, _v_15) in
            let _v = _menhir_action_082 c in
            _menhir_run_367 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState367 _tok
        | Elpi_lexer_config.Tokens.INDEX ->
            let _startpos_19 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_20 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_20, _startpos_19) in
            let _v = _menhir_action_081 () in
            _menhir_run_367 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState367 _tok
        | Elpi_lexer_config.Tokens.IF ->
            let _startpos_22 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_23 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_23, _startpos_22) in
            let _v = _menhir_action_076 () in
            _menhir_run_367 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState367 _tok
        | Elpi_lexer_config.Tokens.FRESHUV ->
            let _startpos_25 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_26 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_26, _startpos_25) in
            let _v = _menhir_action_086 () in
            _menhir_run_367 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState367 _tok
        | Elpi_lexer_config.Tokens.CUT ->
            let _startpos_28 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_29 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_29, _startpos_28) in
            let _v = _menhir_action_083 () in
            _menhir_run_367 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState367 _tok
        | Elpi_lexer_config.Tokens.CONSTANT _v_31 ->
            let _startpos_32 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_33 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos_33, _startpos_32, _v_31) in
            let _v = _menhir_action_075 c in
            _menhir_run_367 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState367 _tok
        | Elpi_lexer_config.Tokens.BEFORE ->
            let _startpos_35 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_36 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_36, _startpos_35) in
            let _v = _menhir_action_078 () in
            _menhir_run_367 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState367 _tok
        | Elpi_lexer_config.Tokens.AFTER ->
            let _startpos_38 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_39 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos_39, _startpos_38) in
            let _v = _menhir_action_079 () in
            _menhir_run_367 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState367 _tok
        | Elpi_lexer_config.Tokens.LCURLY ->
            let _v = _menhir_action_159 () in
            _menhir_run_368 _menhir_stack _menhir_lexbuf _menhir_lexer _v
        | _ ->
            _eRR 367
    
    and _menhir_run_368 : type  ttv_stack. (ttv_stack, _menhir_box_program) _menhir_cell1_constant -> _ -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let MenhirCell1_constant (_menhir_stack, _menhir_s, x, _, _) = _menhir_stack in
        let xs = _v in
        let _v = _menhir_action_160 x xs in
        _menhir_goto_list_constant_ _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
    
    and _menhir_goto_list_constant_ : type  ttv_stack. ttv_stack -> _ -> _ -> _ -> (ttv_stack, _menhir_box_program) _menhir_state -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s ->
        match _menhir_s with
        | MenhirState367 ->
            _menhir_run_368 _menhir_stack _menhir_lexbuf _menhir_lexer _v
        | MenhirState364 ->
            _menhir_run_365 _menhir_stack _menhir_lexbuf _menhir_lexer _v
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_365 : type  ttv_stack. (ttv_stack, _menhir_box_program) _menhir_cell1_CONSTRAINT -> _ -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        let MenhirCell1_CONSTRAINT (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
        let (_endpos__3_, cl) = (_endpos, _v) in
        let _v = _menhir_action_097 _endpos__3_ _startpos__1_ cl in
        _menhir_goto_decl _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
    
    and _menhir_run_369 : type  ttv_stack. ttv_stack -> _ -> _ -> (ttv_stack, _menhir_box_program) _menhir_state -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_COLON (_menhir_stack, _menhir_s, _startpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.REPLACE ->
            _menhir_run_370 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState369
        | Elpi_lexer_config.Tokens.NAME ->
            _menhir_run_372 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState369
        | Elpi_lexer_config.Tokens.INDEX ->
            _menhir_run_374 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState369
        | Elpi_lexer_config.Tokens.IF ->
            _menhir_run_382 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState369
        | Elpi_lexer_config.Tokens.EXTERNAL ->
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _endpos__1_ = _endpos in
            let _v = _menhir_action_016 () in
            _menhir_run_390 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _v MenhirState369 _tok
        | Elpi_lexer_config.Tokens.BEFORE ->
            _menhir_run_385 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState369
        | Elpi_lexer_config.Tokens.AFTER ->
            _menhir_run_387 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState369
        | _ ->
            _eRR 369
    
    and _menhir_run_370 : type  ttv_stack. ttv_stack -> _ -> _ -> (ttv_stack, _menhir_box_program) _menhir_state -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v ->
            let _endpos_1 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_s_, s) = (_endpos_1, _v) in
            let _v = _menhir_action_015 s in
            _menhir_goto_attribute _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_s_ _v _menhir_s _tok
        | _ ->
            _eRR 370
    
    and _menhir_goto_attribute : type  ttv_stack. ttv_stack -> _ -> _ -> _ -> _ -> (ttv_stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        _menhir_run_390 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
    
    and _menhir_run_390 : type  ttv_stack. ttv_stack -> _ -> _ -> _ -> _ -> (ttv_stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.COLON ->
            let _menhir_stack = MenhirCell1_attribute (_menhir_stack, _menhir_s, _v, _endpos) in
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _menhir_stack = MenhirCell0_COLON (_menhir_stack, _startpos) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Elpi_lexer_config.Tokens.REPLACE ->
                _menhir_run_370 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState391
            | Elpi_lexer_config.Tokens.NAME ->
                _menhir_run_372 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState391
            | Elpi_lexer_config.Tokens.INDEX ->
                _menhir_run_374 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState391
            | Elpi_lexer_config.Tokens.IF ->
                _menhir_run_382 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState391
            | Elpi_lexer_config.Tokens.EXTERNAL ->
                let _endpos_1 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let _endpos__1_ = _endpos_1 in
                let _v = _menhir_action_016 () in
                _menhir_run_390 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _v MenhirState391 _tok
            | Elpi_lexer_config.Tokens.BEFORE ->
                _menhir_run_385 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState391
            | Elpi_lexer_config.Tokens.AFTER ->
                _menhir_run_387 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState391
            | _ ->
                _eRR 391)
        | Elpi_lexer_config.Tokens.AFTER | Elpi_lexer_config.Tokens.BEFORE | Elpi_lexer_config.Tokens.CONSTANT _ | Elpi_lexer_config.Tokens.CUT | Elpi_lexer_config.Tokens.FAMILY_TILDE _ | Elpi_lexer_config.Tokens.FRESHUV | Elpi_lexer_config.Tokens.IF | Elpi_lexer_config.Tokens.INDEX | Elpi_lexer_config.Tokens.IO _ | Elpi_lexer_config.Tokens.LPAREN | Elpi_lexer_config.Tokens.NAME | Elpi_lexer_config.Tokens.NIL | Elpi_lexer_config.Tokens.PI | Elpi_lexer_config.Tokens.PRED | Elpi_lexer_config.Tokens.REPLACE | Elpi_lexer_config.Tokens.RULE | Elpi_lexer_config.Tokens.SIGMA | Elpi_lexer_config.Tokens.TYPE ->
            let (_endpos_x_, x) = (_endpos, _v) in
            let _v = _menhir_action_300 x in
            _menhir_goto_separated_nonempty_list_COLON_attribute_ _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _v _menhir_s _tok
        | _ ->
            _eRR 390
    
    and _menhir_run_372 : type  ttv_stack. ttv_stack -> _ -> _ -> (ttv_stack, _menhir_box_program) _menhir_state -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v ->
            let _endpos_1 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_s_, s) = (_endpos_1, _v) in
            let _v = _menhir_action_012 s in
            _menhir_goto_attribute _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_s_ _v _menhir_s _tok
        | _ ->
            _eRR 372
    
    and _menhir_run_374 : type  ttv_stack. ttv_stack -> _ -> _ -> (ttv_stack, _menhir_box_program) _menhir_state -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell1_INDEX (_menhir_stack, _menhir_s, _startpos, _endpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.LPAREN ->
            let _startpos_0 = _menhir_lexbuf.Lexing.lex_start_p in
            let _menhir_stack = MenhirCell0_LPAREN (_menhir_stack, _startpos_0) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Elpi_lexer_config.Tokens.INTEGER _v ->
                let _tok = _menhir_lexer _menhir_lexbuf in
                let i = _v in
                let _v = _menhir_action_125 i in
                _menhir_run_380 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState375 _tok
            | Elpi_lexer_config.Tokens.FRESHUV ->
                let _tok = _menhir_lexer _menhir_lexbuf in
                let _v = _menhir_action_124 () in
                _menhir_run_380 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState375 _tok
            | _ ->
                _eRR 375)
        | _ ->
            _eRR 374
    
    and _menhir_run_380 : type  ttv_stack. ttv_stack -> _ -> _ -> _ -> (ttv_stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.INTEGER _v_0 ->
            let _menhir_stack = MenhirCell1_indexing (_menhir_stack, _menhir_s, _v) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let i = _v_0 in
            let _v = _menhir_action_125 i in
            _menhir_run_380 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState380 _tok
        | Elpi_lexer_config.Tokens.FRESHUV ->
            let _menhir_stack = MenhirCell1_indexing (_menhir_stack, _menhir_s, _v) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _v = _menhir_action_124 () in
            _menhir_run_380 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState380 _tok
        | Elpi_lexer_config.Tokens.RPAREN ->
            let x = _v in
            let _v = _menhir_action_213 x in
            _menhir_goto_nonempty_list_indexing_ _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | _ ->
            _eRR 380
    
    and _menhir_goto_nonempty_list_indexing_ : type  ttv_stack. ttv_stack -> _ -> _ -> _ -> (ttv_stack, _menhir_box_program) _menhir_state -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s ->
        match _menhir_s with
        | MenhirState380 ->
            _menhir_run_381 _menhir_stack _menhir_lexbuf _menhir_lexer _v
        | MenhirState375 ->
            _menhir_run_378 _menhir_stack _menhir_lexbuf _menhir_lexer _v
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_381 : type  ttv_stack. (ttv_stack, _menhir_box_program) _menhir_cell1_indexing -> _ -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let MenhirCell1_indexing (_menhir_stack, _menhir_s, x) = _menhir_stack in
        let xs = _v in
        let _v = _menhir_action_214 x xs in
        _menhir_goto_nonempty_list_indexing_ _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
    
    and _menhir_run_378 : type  ttv_stack. (ttv_stack, _menhir_box_program) _menhir_cell1_INDEX _menhir_cell0_LPAREN -> _ -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        let MenhirCell0_LPAREN (_menhir_stack, _) = _menhir_stack in
        let MenhirCell1_INDEX (_menhir_stack, _menhir_s, _, _) = _menhir_stack in
        let (l, _endpos__4_) = (_v, _endpos) in
        let _v = _menhir_action_017 l in
        _menhir_goto_attribute _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__4_ _v _menhir_s _tok
    
    and _menhir_run_382 : type  ttv_stack. ttv_stack -> _ -> _ -> (ttv_stack, _menhir_box_program) _menhir_state -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v ->
            let _endpos_1 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_s_, s) = (_endpos_1, _v) in
            let _v = _menhir_action_011 s in
            _menhir_goto_attribute _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_s_ _v _menhir_s _tok
        | _ ->
            _eRR 382
    
    and _menhir_run_385 : type  ttv_stack. ttv_stack -> _ -> _ -> (ttv_stack, _menhir_box_program) _menhir_state -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v ->
            let _endpos_1 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_s_, s) = (_endpos_1, _v) in
            let _v = _menhir_action_014 s in
            _menhir_goto_attribute _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_s_ _v _menhir_s _tok
        | _ ->
            _eRR 385
    
    and _menhir_run_387 : type  ttv_stack. ttv_stack -> _ -> _ -> (ttv_stack, _menhir_box_program) _menhir_state -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v ->
            let _endpos_1 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_s_, s) = (_endpos_1, _v) in
            let _v = _menhir_action_013 s in
            _menhir_goto_attribute _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_s_ _v _menhir_s _tok
        | _ ->
            _eRR 387
    
    and _menhir_goto_separated_nonempty_list_COLON_attribute_ : type  ttv_stack. ttv_stack -> _ -> _ -> _ -> _ -> (ttv_stack, _menhir_box_program) _menhir_state -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        match _menhir_s with
        | MenhirState391 ->
            _menhir_run_392 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState369 ->
            _menhir_run_389 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_392 : type  ttv_stack. (ttv_stack, _menhir_box_program) _menhir_cell1_attribute _menhir_cell0_COLON -> _ -> _ -> _ -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let MenhirCell0_COLON (_menhir_stack, _) = _menhir_stack in
        let MenhirCell1_attribute (_menhir_stack, _menhir_s, x, _) = _menhir_stack in
        let (_endpos_xs_, xs) = (_endpos, _v) in
        let _v = _menhir_action_301 x xs in
        _menhir_goto_separated_nonempty_list_COLON_attribute_ _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_xs_ _v _menhir_s _tok
    
    and _menhir_run_389 : type  ttv_stack. (ttv_stack, _menhir_box_program) _menhir_cell1_COLON -> _ -> _ -> _ -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let MenhirCell1_COLON (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
        let (_endpos_l_, l) = (_endpos, _v) in
        let _v = _menhir_action_020 l in
        _menhir_run_420 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_l_ _startpos__1_ _v _menhir_s _tok
    
    and _menhir_run_393 : type  ttv_stack. ttv_stack -> _ -> _ -> (ttv_stack, _menhir_box_program) _menhir_state -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_CLOSED (_menhir_stack, _menhir_s, _startpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.SIGMA ->
            let _startpos_0 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_0) in
            let _v = _menhir_action_085 () in
            _menhir_run_289 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState393 _tok
        | Elpi_lexer_config.Tokens.REPLACE ->
            let _startpos_1 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_1) in
            let _v = _menhir_action_080 () in
            _menhir_run_289 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState393 _tok
        | Elpi_lexer_config.Tokens.PI ->
            let _startpos_2 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_2) in
            let _v = _menhir_action_084 () in
            _menhir_run_289 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState393 _tok
        | Elpi_lexer_config.Tokens.NIL ->
            let _startpos_3 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_3) in
            let _v = _menhir_action_089 () in
            _menhir_run_289 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState393 _tok
        | Elpi_lexer_config.Tokens.NAME ->
            let _startpos_4 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_4) in
            let _v = _menhir_action_077 () in
            _menhir_run_289 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState393 _tok
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_271 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState393
        | Elpi_lexer_config.Tokens.IO _v ->
            let _startpos_5 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos, _startpos_5, _v) in
            let _v = _menhir_action_082 c in
            _menhir_run_289 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState393 _tok
        | Elpi_lexer_config.Tokens.INDEX ->
            let _startpos_6 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_6) in
            let _v = _menhir_action_081 () in
            _menhir_run_289 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState393 _tok
        | Elpi_lexer_config.Tokens.IF ->
            let _startpos_7 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_7) in
            let _v = _menhir_action_076 () in
            _menhir_run_289 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState393 _tok
        | Elpi_lexer_config.Tokens.FRESHUV ->
            let _startpos_8 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_8) in
            let _v = _menhir_action_086 () in
            _menhir_run_289 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState393 _tok
        | Elpi_lexer_config.Tokens.CUT ->
            let _startpos_9 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_9) in
            let _v = _menhir_action_083 () in
            _menhir_run_289 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState393 _tok
        | Elpi_lexer_config.Tokens.CONSTANT _v ->
            let _startpos_10 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos, _startpos_10, _v) in
            let _v = _menhir_action_075 c in
            _menhir_run_289 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState393 _tok
        | Elpi_lexer_config.Tokens.BEFORE ->
            let _startpos_11 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_11) in
            let _v = _menhir_action_078 () in
            _menhir_run_289 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState393 _tok
        | Elpi_lexer_config.Tokens.AFTER ->
            let _startpos_12 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos_12) in
            let _v = _menhir_action_079 () in
            _menhir_run_289 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState393 _tok
        | _ ->
            _eRR 393
    
    and _menhir_goto_binder_body : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        match _menhir_s with
        | MenhirState426 ->
            _menhir_run_052 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState051 ->
            _menhir_run_052 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState461 ->
            _menhir_run_046_spec_461 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState037 ->
            _menhir_run_046_spec_037 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState044 ->
            _menhir_run_046_spec_044 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_052 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_constant -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let MenhirCell1_constant (_menhir_stack, _menhir_s, t, _startpos_t_, _) = _menhir_stack in
        let (_endpos_b_, b) = (_endpos, _v) in
        let _v = _menhir_action_025 b t in
        let (_endpos, _startpos) = (_endpos_b_, _startpos_t_) in
        let (_endpos_t_, _startpos_t_, t) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_316 t in
        _menhir_goto_term _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_t_ _v _menhir_s _tok
    
    and _menhir_run_046_spec_461 : type  ttv_stack. (((ttv_stack, _menhir_box_program) _menhir_cell1_attributes, _menhir_box_program) _menhir_cell1_head_term, _menhir_box_program) _menhir_cell1_nonempty_list_closed_term_ -> _ -> _ -> _ -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let (_endpos_x_, x) = (_endpos, _v) in
        let _v = _menhir_action_285 x in
        _menhir_run_462 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _v _tok
    
    and _menhir_run_046_spec_037 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_head_term, ttv_result) _menhir_cell1_nonempty_list_closed_term_ -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let (_endpos_x_, x) = (_endpos, _v) in
        let _v = _menhir_action_285 x in
        _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _v _tok
    
    and _menhir_run_046_spec_044 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_head_term, ttv_result) _menhir_cell1_nonempty_list_closed_term_ -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let (_endpos_x_, x) = (_endpos, _v) in
        let _v = _menhir_action_285 x in
        _menhir_run_045 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _v _tok
    
    let rec _menhir_run_000 : type  ttv_stack. ttv_stack -> _ -> _ -> _menhir_box_goal =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer ->
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.STRING _v ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos, _startpos, _v) in
            let _v = _menhir_action_068 x in
            _menhir_run_053_spec_000 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.SIGMA ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos) in
            let _v = _menhir_action_085 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState000 _tok
        | Elpi_lexer_config.Tokens.REPLACE ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos) in
            let _v = _menhir_action_080 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState000 _tok
        | Elpi_lexer_config.Tokens.QUOTED _v ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos, _startpos, _v) in
            let _v = _menhir_action_069 _endpos_x_ _startpos_x_ x in
            _menhir_run_053_spec_000 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.PI ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos) in
            let _v = _menhir_action_084 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState000 _tok
        | Elpi_lexer_config.Tokens.NIL ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos) in
            let _v = _menhir_action_089 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState000 _tok
        | Elpi_lexer_config.Tokens.NAME ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos) in
            let _v = _menhir_action_077 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState000 _tok
        | Elpi_lexer_config.Tokens.LPAREN ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState000
        | Elpi_lexer_config.Tokens.LCURLY ->
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState000
        | Elpi_lexer_config.Tokens.LBRACKET ->
            _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState000
        | Elpi_lexer_config.Tokens.IO _v ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos, _startpos, _v) in
            let _v = _menhir_action_082 c in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState000 _tok
        | Elpi_lexer_config.Tokens.INTEGER _v ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos, _startpos, _v) in
            let _v = _menhir_action_066 x in
            _menhir_run_053_spec_000 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.INDEX ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos) in
            let _v = _menhir_action_081 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState000 _tok
        | Elpi_lexer_config.Tokens.IF ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos) in
            let _v = _menhir_action_076 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState000 _tok
        | Elpi_lexer_config.Tokens.FRESHUV ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos) in
            let _v = _menhir_action_086 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState000 _tok
        | Elpi_lexer_config.Tokens.FLOAT _v ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, _startpos_x_, x) = (_endpos, _startpos, _v) in
            let _v = _menhir_action_067 x in
            _menhir_run_053_spec_000 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _tok
        | Elpi_lexer_config.Tokens.FAMILY_TILDE _v ->
            _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState000
        | Elpi_lexer_config.Tokens.CUT ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos) in
            let _v = _menhir_action_083 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState000 _tok
        | Elpi_lexer_config.Tokens.CONSTANT _v ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_c_, _startpos_c_, c) = (_endpos, _startpos, _v) in
            let _v = _menhir_action_075 c in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _startpos_c_ _v MenhirState000 _tok
        | Elpi_lexer_config.Tokens.BEFORE ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos) in
            let _v = _menhir_action_078 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState000 _tok
        | Elpi_lexer_config.Tokens.AFTER ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos) in
            let _v = _menhir_action_079 () in
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState000 _tok
        | _ ->
            _eRR 0
    
    let rec _menhir_goto_infix_SYMB : type  ttv_stack. ttv_stack -> _ -> _menhir_box_infix_SYMB =
      fun _menhir_stack _v ->
        MenhirBox_infix_SYMB _v
    
    let rec _menhir_run_230 : type  ttv_stack. ttv_stack -> _ -> _ -> _menhir_box_infix_SYMB =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer ->
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.VDASH ->
            let _v = _menhir_action_155 () in
            _menhir_goto_infix_SYMB _menhir_stack _v
        | Elpi_lexer_config.Tokens.SLASH ->
            let _v = _menhir_action_152 () in
            _menhir_goto_infix_SYMB _menhir_stack _v
        | Elpi_lexer_config.Tokens.QDASH ->
            let _v = _menhir_action_151 () in
            _menhir_goto_infix_SYMB _menhir_stack _v
        | Elpi_lexer_config.Tokens.OR ->
            let _v = _menhir_action_145 () in
            _menhir_goto_infix_SYMB _menhir_stack _v
        | Elpi_lexer_config.Tokens.MOD ->
            let _v = _menhir_action_147 () in
            _menhir_goto_infix_SYMB _menhir_stack _v
        | Elpi_lexer_config.Tokens.MINUSs ->
            let _v = _menhir_action_143 () in
            _menhir_goto_infix_SYMB _menhir_stack _v
        | Elpi_lexer_config.Tokens.MINUSr ->
            let _v = _menhir_action_141 () in
            _menhir_goto_infix_SYMB _menhir_stack _v
        | Elpi_lexer_config.Tokens.MINUSi ->
            let _v = _menhir_action_142 () in
            _menhir_goto_infix_SYMB _menhir_stack _v
        | Elpi_lexer_config.Tokens.MINUS ->
            let _v = _menhir_action_140 () in
            _menhir_goto_infix_SYMB _menhir_stack _v
        | Elpi_lexer_config.Tokens.IS ->
            let _v = _menhir_action_146 () in
            _menhir_goto_infix_SYMB _menhir_stack _v
        | Elpi_lexer_config.Tokens.FAMILY_TIMES _v ->
            let s = _v in
            let _v = _menhir_action_127 s in
            _menhir_goto_infix_SYMB _menhir_stack _v
        | Elpi_lexer_config.Tokens.FAMILY_TICK _v ->
            let s = _v in
            let _v = _menhir_action_137 s in
            _menhir_goto_infix_SYMB _menhir_stack _v
        | Elpi_lexer_config.Tokens.FAMILY_SHARP _v ->
            let s = _v in
            let _v = _menhir_action_135 s in
            _menhir_goto_infix_SYMB _menhir_stack _v
        | Elpi_lexer_config.Tokens.FAMILY_PLUS _v ->
            let s = _v in
            let _v = _menhir_action_126 s in
            _menhir_goto_infix_SYMB _menhir_stack _v
        | Elpi_lexer_config.Tokens.FAMILY_OR _v ->
            let s = _v in
            let _v = _menhir_action_134 s in
            _menhir_goto_infix_SYMB _menhir_stack _v
        | Elpi_lexer_config.Tokens.FAMILY_MINUS _v ->
            let s = _v in
            let _v = _menhir_action_128 s in
            _menhir_goto_infix_SYMB _menhir_stack _v
        | Elpi_lexer_config.Tokens.FAMILY_LT _v ->
            let s = _v in
            let _v = _menhir_action_130 s in
            _menhir_goto_infix_SYMB _menhir_stack _v
        | Elpi_lexer_config.Tokens.FAMILY_GT _v ->
            let s = _v in
            let _v = _menhir_action_131 s in
            _menhir_goto_infix_SYMB _menhir_stack _v
        | Elpi_lexer_config.Tokens.FAMILY_EXP _v ->
            let s = _v in
            let _v = _menhir_action_129 s in
            _menhir_goto_infix_SYMB _menhir_stack _v
        | Elpi_lexer_config.Tokens.FAMILY_EQ _v ->
            let s = _v in
            let _v = _menhir_action_132 s in
            _menhir_goto_infix_SYMB _menhir_stack _v
        | Elpi_lexer_config.Tokens.FAMILY_BTICK _v ->
            let s = _v in
            let _v = _menhir_action_136 s in
            _menhir_goto_infix_SYMB _menhir_stack _v
        | Elpi_lexer_config.Tokens.FAMILY_AND _v ->
            let s = _v in
            let _v = _menhir_action_133 s in
            _menhir_goto_infix_SYMB _menhir_stack _v
        | Elpi_lexer_config.Tokens.EQ2 ->
            let _v = _menhir_action_144 () in
            _menhir_goto_infix_SYMB _menhir_stack _v
        | Elpi_lexer_config.Tokens.EQ ->
            let _v = _menhir_action_139 () in
            _menhir_goto_infix_SYMB _menhir_stack _v
        | Elpi_lexer_config.Tokens.DIV ->
            let _v = _menhir_action_148 () in
            _menhir_goto_infix_SYMB _menhir_stack _v
        | Elpi_lexer_config.Tokens.DARROW ->
            let _v = _menhir_action_150 () in
            _menhir_goto_infix_SYMB _menhir_stack _v
        | Elpi_lexer_config.Tokens.CONS ->
            let _v = _menhir_action_138 () in
            _menhir_goto_infix_SYMB _menhir_stack _v
        | Elpi_lexer_config.Tokens.CONJ2 ->
            let _v = _menhir_action_153 () in
            _menhir_goto_infix_SYMB _menhir_stack _v
        | Elpi_lexer_config.Tokens.CONJ ->
            let _v = _menhir_action_154 () in
            _menhir_goto_infix_SYMB _menhir_stack _v
        | Elpi_lexer_config.Tokens.ARROW ->
            let _v = _menhir_action_149 () in
            _menhir_goto_infix_SYMB _menhir_stack _v
        | _ ->
            _eRR 230
    
    let rec _menhir_run_262 : type  ttv_stack. ttv_stack -> _ -> _ -> _menhir_box_postfix_SYMB =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer ->
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.FAMILY_QMARK _v ->
            let s = _v in
            let _v = _menhir_action_294 s in
            MenhirBox_postfix_SYMB _v
        | _ ->
            _eRR 262
    
    let rec _menhir_run_265 : type  ttv_stack. ttv_stack -> _ -> _ -> _menhir_box_prefix_SYMB =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer ->
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.FAMILY_TILDE _v ->
            let s = _v in
            let _v = _menhir_action_297 s in
            MenhirBox_prefix_SYMB _v
        | _ ->
            _eRR 265
    
    let rec _menhir_run_268 : type  ttv_stack. ttv_stack -> _ -> _ -> _menhir_box_program =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer ->
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Elpi_lexer_config.Tokens.USE_SIG ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _startpos__1_ = _startpos in
            let _v = _menhir_action_010 () in
            _menhir_run_528 _menhir_stack _menhir_lexbuf _menhir_lexer _startpos__1_ _v MenhirState268 _tok
        | Elpi_lexer_config.Tokens.USEONLY ->
            _menhir_run_270 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState268
        | Elpi_lexer_config.Tokens.TYPEABBREV ->
            _menhir_run_292 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState268
        | Elpi_lexer_config.Tokens.SIG ->
            _menhir_run_302 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState268
        | Elpi_lexer_config.Tokens.SHORTEN ->
            _menhir_run_304 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState268
        | Elpi_lexer_config.Tokens.RCURLY ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos) in
            let _v = _menhir_action_102 _endpos__1_ _startpos__1_ in
            _menhir_run_414 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v MenhirState268 _tok
        | Elpi_lexer_config.Tokens.NAMESPACE ->
            _menhir_run_322 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState268
        | Elpi_lexer_config.Tokens.MODULE ->
            _menhir_run_325 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState268
        | Elpi_lexer_config.Tokens.MODE ->
            _menhir_run_327 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState268
        | Elpi_lexer_config.Tokens.MACRO ->
            _menhir_run_335 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState268
        | Elpi_lexer_config.Tokens.LOCALKIND ->
            _menhir_run_339 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState268
        | Elpi_lexer_config.Tokens.LOCAL ->
            _menhir_run_341 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState268
        | Elpi_lexer_config.Tokens.LCURLY ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos) in
            let _v = _menhir_action_101 _endpos__1_ _startpos__1_ in
            _menhir_run_414 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v MenhirState268 _tok
        | Elpi_lexer_config.Tokens.KIND ->
            _menhir_run_347 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState268
        | Elpi_lexer_config.Tokens.IMPORT ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _startpos__1_ = _startpos in
            let _v = _menhir_action_008 () in
            _menhir_run_528 _menhir_stack _menhir_lexbuf _menhir_lexer _startpos__1_ _v MenhirState268 _tok
        | Elpi_lexer_config.Tokens.FIXITY _v ->
            _menhir_run_354 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState268
        | Elpi_lexer_config.Tokens.EXTERNAL ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__1_, _startpos__1_) = (_endpos, _startpos) in
            let _v = _menhir_action_019 () in
            _menhir_run_420 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v MenhirState268 _tok
        | Elpi_lexer_config.Tokens.EXPORTDEF ->
            _menhir_run_360 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState268
        | Elpi_lexer_config.Tokens.EOF ->
            let _v = _menhir_action_298 () in
            _menhir_run_401_spec_268 _menhir_stack _v
        | Elpi_lexer_config.Tokens.CONSTRAINT ->
            _menhir_run_364 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState268
        | Elpi_lexer_config.Tokens.COLON ->
            _menhir_run_369 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState268
        | Elpi_lexer_config.Tokens.CLOSED ->
            _menhir_run_393 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState268
        | Elpi_lexer_config.Tokens.ACCUM_SIG ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _startpos__1_ = _startpos in
            let _v = _menhir_action_009 () in
            _menhir_run_528 _menhir_stack _menhir_lexbuf _menhir_lexer _startpos__1_ _v MenhirState268 _tok
        | Elpi_lexer_config.Tokens.ACCUMULATE ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _startpos__1_ = _startpos in
            let _v = _menhir_action_007 () in
            _menhir_run_528 _menhir_stack _menhir_lexbuf _menhir_lexer _startpos__1_ _v MenhirState268 _tok
        | Elpi_lexer_config.Tokens.AFTER | Elpi_lexer_config.Tokens.BEFORE | Elpi_lexer_config.Tokens.CONSTANT _ | Elpi_lexer_config.Tokens.CUT | Elpi_lexer_config.Tokens.FAMILY_TILDE _ | Elpi_lexer_config.Tokens.FRESHUV | Elpi_lexer_config.Tokens.IF | Elpi_lexer_config.Tokens.INDEX | Elpi_lexer_config.Tokens.IO _ | Elpi_lexer_config.Tokens.LPAREN | Elpi_lexer_config.Tokens.NAME | Elpi_lexer_config.Tokens.NIL | Elpi_lexer_config.Tokens.PI | Elpi_lexer_config.Tokens.PRED | Elpi_lexer_config.Tokens.REPLACE | Elpi_lexer_config.Tokens.RULE | Elpi_lexer_config.Tokens.SIGMA | Elpi_lexer_config.Tokens.TYPE ->
            let _v = _menhir_action_018 () in
            _menhir_run_420 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _endpos _v MenhirState268 _tok
        | _ ->
            _eRR 268
    
  end
  
  let program =
    fun _menhir_lexer _menhir_lexbuf ->
      let _menhir_stack = () in
      let MenhirBox_program v = _menhir_run_268 _menhir_stack _menhir_lexbuf _menhir_lexer in
      v
  
  let prefix_SYMB =
    fun _menhir_lexer _menhir_lexbuf ->
      let _menhir_stack = () in
      let MenhirBox_prefix_SYMB v = _menhir_run_265 _menhir_stack _menhir_lexbuf _menhir_lexer in
      v
  
  let postfix_SYMB =
    fun _menhir_lexer _menhir_lexbuf ->
      let _menhir_stack = () in
      let MenhirBox_postfix_SYMB v = _menhir_run_262 _menhir_stack _menhir_lexbuf _menhir_lexer in
      v
  
  let infix_SYMB =
    fun _menhir_lexer _menhir_lexbuf ->
      let _menhir_stack = () in
      let MenhirBox_infix_SYMB v = _menhir_run_230 _menhir_stack _menhir_lexbuf _menhir_lexer in
      v
  
  let goal =
    fun _menhir_lexer _menhir_lexbuf ->
      let _menhir_stack = () in
      let MenhirBox_goal v = _menhir_run_000 _menhir_stack _menhir_lexbuf _menhir_lexer in
      v
  
end
